BEGIN TRANSACTION;
INSERT INTO users (userid,alias,name,surname,passwd,url,autologin,autologout,lang,refresh,type,theme,rows_per_page) values ('1','Admin','Zabbix','Administrator','$2y$10$92nDno4n0Zm7Ej7Jfsz8WukBfgSS/U0QkIuu8WkJPihXBb2A1UrEK','','1','0','en_GB','30s','3','default','50');
INSERT INTO users (userid,alias,name,surname,passwd,url,autologin,autologout,lang,refresh,type,theme,rows_per_page) values ('2','guest','','','$2y$10$89otZrRNmde97rIyzclecuk6LwKAsHN0BcvoOKGjbT.BwMBfm7G06','','0','15m','en_GB','30s','1','default','50');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('1','Templates','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('2','Linux servers','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('4','Zabbix servers','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('5','Discovered hosts','1','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('6','Virtual machines','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('7','Hypervisors','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('8','Templates/Modules','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('9','Templates/Network devices','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('10','Templates/Operating systems','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('11','Templates/Server hardware','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('12','Templates/Applications','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('13','Templates/Databases','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('14','Templates/Virtualization','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('15','Templates/Telephony','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('16','Templates/SAN','0','0');
INSERT INTO hstgrp (groupid,name,internal,flags) values ('17','Templates/Power','0','0');
INSERT INTO drules (druleid,proxy_hostid,name,iprange,delay,status) values ('2',NULL,'Local network','192.168.0.1-254','1h','1');
INSERT INTO dchecks (dcheckid,druleid,type,key_,snmp_community,ports,snmpv3_securityname,snmpv3_securitylevel,snmpv3_authpassphrase,snmpv3_privpassphrase,uniq,snmpv3_authprotocol,snmpv3_privprotocol,snmpv3_contextname,host_source,name_source) values ('2','2','9','system.uname','','10050','','0','','','0','0','0','','1','0');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('1','0','Email','mail.example.com','example.com','zabbix@example.com','','','','','0','25','0','0','0','0','','1','3','10s','0','','30s','0','0','','','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('3','2','SMS','','','','','/dev/ttyS0','','','0','25','0','0','0','0','','1','3','10s','1','','30s','0','0','','','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('4','0','Email (HTML)','mail.example.com','example.com','zabbix@example.com','','','','','0','25','0','0','0','0','','1','3','10s','1','','30s','0','0','','','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('5','4','Mattermost','','','','','','','','0','25','0','0','0','0','','1','1','10s','1','var SEVERITY_COLORS = [
    ''#97AAB3'', ''#7499FF'', ''#FFC859'',
    ''#FFA059'', ''#E97659'', ''#E45959''
];

var RESOLVE_COLOR = ''#009900'';

var SEND_MODE_HANDLERS = {
    alarm: handlerAlarm,
    event: handlerEvent
};

if (!String.prototype.format) {
    String.prototype.format = function() {
        var args = arguments;

        return this.replace(/{(\d+)}/g, function(match, number) {
            return number in args
                ? args[number]
                : match
            ;
        });
    };
}

function isEventProblem(params) {
    return params.event_value == 1
        && params.event_update_status == 0
    ;
}

function isEventUpdate(params) {
    return params.event_value == 1
        && params.event_update_status == 1
    ;
}

function isEventResolve(params) {
    return params.event_value == 0;
}

function getPermalink(mattermost_url, team_name, postid) {
    return ''{0}/{1}/pl/{2}''.format(
        mattermost_url.replace(/\/+$/, ''''),
        team_name,
        postid
    );
}

function getChannel(send_to) {
    switch (true) {
        case /.+\/#.+/.test(send_to):
            return getChannelByName(send_to);

        case /@.+/.test(send_to):
            return getDirectChannel(send_to);

        default:
            return getChannelByID(send_to);
    }
}

function getChannelByName(send_to) {
    var team_chan = send_to
        .trim()
        .split(''/#'');

    var resp = JSON.parse(req.Get(
        Mattermost.channel_byname.format(team_chan[0], team_chan[1]),
        JSON.stringify(fields)
    )
    );

    if (req.Status() != 200) {
        throw ''[{0}] {1}''.format(resp.status_code, resp.message);
    }

    return resp;
}

function getDirectChannel(send_to) {
    Zabbix.Log(5, ''[ Mattermost Webhook ] Call {0}({1})''.format(
        arguments.callee.name,
        JSON.stringify(arguments)
    ));

    var teamUser = send_to
            .trim()
            .split(''/@''),
        bot = getBotUser(),
        user = getUserByName(teamUser[1]);

    var resp = JSON.parse(req.Post(
        Mattermost.direct_channel,
        JSON.stringify([bot.id, user.id])
    )
    );

    Zabbix.Log(5, ''[ Mattermost Webhook ] Result {0}: {1}''.format(
        arguments.callee.name,
        JSON.stringify(resp)
    ));

    if (req.Status() != 201) {
        throw ''[{0}] {1}''.format(resp.status_code, resp.message);
    }

    resp.team_name = teamUser[0];

    return resp;
}

function getChannelByID(channelID) {
    Zabbix.Log(5, ''[ Mattermost Webhook ] Call {0}({1})''.format(
        arguments.callee.name,
        JSON.stringify(arguments)
    ));

    var resp = JSON.parse(req.Get(
        Mattermost.get_channel.format(channelID),
        JSON.stringify(fields)
    )
    );

    Zabbix.Log(5, ''[ Mattermost Webhook ] Result {0}: {1}''.format(
        arguments.callee.name,
        JSON.stringify(resp)
    ));

    if (req.Status() != 200) {
        throw ''[{0}] {1}''.format(resp.status_code, resp.message);
    }

    return resp;
}

function getBotUser() {
    Zabbix.Log(5, ''[ Mattermost Webhook ] Call {0}({1})''.format(
        arguments.callee.name,
        JSON.stringify(arguments)
    ));

    var resp = JSON.parse(req.Get(
        Mattermost.bot_user,
        JSON.stringify(fields)
    )
    );

    Zabbix.Log(5, ''[ Mattermost Webhook ] Result {0}: {1}''.format(
        arguments.callee.name,
        JSON.stringify(resp)
    ));

    if (req.Status() != 200) {
        throw ''[{0}] {1}''.format(resp.status_code, resp.message);
    }

    return resp;
}

function getUserByName(userName) {
    Zabbix.Log(5, ''[ Mattermost Webhook ] Call {0}({1})''.format(
        arguments.callee.name,
        JSON.stringify(arguments)
    ));

    var resp = JSON.parse(req.Get(
        Mattermost.user_byname.format(userName),
        JSON.stringify(fields)
    )
    );

    Zabbix.Log(5, ''[ Mattermost Webhook ] Result {0}: {1}''.format(
        arguments.callee.name,
        JSON.stringify(resp)
    ));

    if (req.Status() != 200) {
        throw ''[{0}] {1}''.format(resp.status_code, resp.message);
    }

    return resp;
}

function getTeamByID(teamID) {
    Zabbix.Log(5, ''[ Mattermost Webhook ] Call {0}({1})''.format(
        arguments.callee.name,
        JSON.stringify(arguments)
    ));

    var resp = JSON.parse(req.Get(
        Mattermost.get_team.format(teamID),
        JSON.stringify(fields)
    )
    );

    Zabbix.Log(5, ''[ Mattermost Webhook ] Result {0}: {1}''.format(
        arguments.callee.name,
        JSON.stringify(resp)
    ));

    if (req.Status() != 200) {
        throw ''[{0}] {1}''.format(resp.status_code, resp.message);
    }

    return resp;
}

function createProblemURL(zabbix_url, triggerid, eventid, event_source) {
    var problem_url = '''';
    if (event_source === ''0'') {
        problem_url = ''{0}/tr_events.php?triggerid={1}&eventid={2}''
            .format(
                zabbix_url,
                triggerid,
                eventid
            );
    }
    else {
        problem_url = zabbix_url;
    }

    return problem_url;
}

function getTagValue(event_tags, key) {
    var pattern = new RegExp(''('' + key + '':.+)'');
    var tagValue = event_tags
        .split('','')
        .filter(function (v) {
            return v.match(pattern);
        })
        .map(function (v) {
            return v.split('':'')[1];
        })[0]
        || 0;

    return tagValue;
}

function handlerAlarm(req, params) {
    var channel = getChannel(params.send_to);
    var fields = {
        channel_id: channel.id,
        props: {}
    };

    if (isEventProblem(params)) {
        var team_name = channel.team_name
            ? channel.team_name
            : getTeamByID(channel.team_id).name;

        fields.props.attachments = [
            createMessage(
                SEVERITY_COLORS[params.event_nseverity] || 0,
                params.event_date,
                params.event_time,
                createProblemURL(params.zabbix_url, params.trigger_id, params.event_id, params.event_source)
            )
        ];

        var resp = JSON.parse(req.Post(
            Mattermost.post_message,
            JSON.stringify(fields)
        )
        );

        if (req.Status() != 201) {
            throw ''[{0}] {1}''.format(resp.status_code, resp.message);
        }

        result.tags.__mattermost_post_id = resp.id;
        result.tags.__mattermost_channel_id = channel.id;
        result.tags.__mattermost_channel_name = channel.name;
        result.tags.__mattermost_message_link = getPermalink(
            params.mattermost_url,
            team_name,
            resp.id
        );

    }
    else if (isEventUpdate(params)) {
        fields.root_id = getTagValue(params.event_tags, ''mattermost_post_id'');

        if (params.event_source === ''0'') {}
        fields.props.attachments = [
            createMessage(
                SEVERITY_COLORS[params.event_nseverity] || 0,
                params.event_update_date,
                params.event_update_time,
                createProblemURL(params.zabbix_url, params.trigger_id, params.event_id, params.event_source),
                true
            )
        ];

        resp = JSON.parse(req.Post(
            Mattermost.post_message, JSON.stringify(fields)
        )
        );

        if (req.Status() != 201) {
            throw ''[{0}] {1}''.format(resp.status_code, resp.message);
        }

    }
    else if (isEventResolve(params)) {
        fields.channel_id = getTagValue(params.event_tags, ''mattermost_channel_id'');
        fields.id = getTagValue(params.event_tags, ''mattermost_post_id'');
        fields.props.attachments = [
            createMessage(
                RESOLVE_COLOR,
                params.event_date,
                params.event_time,
                createProblemURL(params.zabbix_url, params.trigger_id, params.event_id, params.event_source)
            )
        ];

        var post_id = getTagValue(params.event_tags, ''mattermost_post_id'');

        resp = JSON.parse(req.Put(
            Mattermost.chat_update.format(post_id),
            JSON.stringify(fields)
        )
        );

        if (req.Status() != 200) {
            throw ''[{0}] {1}''.format(resp.status_code, resp.message);
        }
    }
}

function handlerEvent(req, params) {
    var channel = getChannel(params.send_to);
    var fields = {
        channel_id: channel.id,
        props: {}
    };

    if (isEventProblem(params)) {
        var team_name = channel.team_name
            ? channel.team_name
            : getTeamByID(channel.team_id).name;

        fields.props.attachments = [
            createMessage(
                SEVERITY_COLORS[params.event_nseverity] || 0,
                params.event_date,
                params.event_time,
                createProblemURL(params.zabbix_url, params.trigger_id, params.event_id, params.event_source)
            )
        ];

        var resp = JSON.parse(req.Post(Mattermost.post_message, JSON.stringify(fields)));

        if (req.Status() != 201) {
            throw ''[{0}] {1}''.format(resp.status_code, resp.message);
        }

        result.tags.__mattermost_channel_name = channel.name;
        result.tags.__mattermost_message_link = getPermalink(
            params.mattermost_url,
            team_name,
            resp.id
        );

    }
    else if (isEventUpdate(params)) {
        fields.props.attachments = [
            createMessage(
                SEVERITY_COLORS[params.event_nseverity] || 0,
                params.event_update_date,
                params.event_update_time,
                createProblemURL(params.zabbix_url, params.trigger_id, params.event_id, params.event_source),
                false
            )
        ];

        resp = JSON.parse(req.Post(Mattermost.post_message, JSON.stringify(fields)));

        if (req.Status() != 201) {
            throw ''[{0}] {1}''.format(resp.status_code, resp.message);
        }

    }
    else if (isEventResolve(params)) {
        fields.props.attachments = [
            createMessage(
                RESOLVE_COLOR,
                params.event_recovery_date,
                params.event_recovery_time,
                createProblemURL(params.zabbix_url, params.trigger_id, params.event_id, params.event_source)
            )
        ];

        resp = JSON.parse(req.Post(Mattermost.post_message, JSON.stringify(fields)));

        if (req.Status() != 201) {
            throw ''[{0}] {1}''.format(resp.status_code, resp.message);
        }
    }
}

function createMessage(
    event_severity_color,
    event_date,
    event_time,
    problem_url,
    isShort
) {
    var message = {
        fallbac: params.alert_subject,
        title: params.alert_subject,
        color: event_severity_color,
        title_link: problem_url,
        footer: problem_url,

        fields: [
            {
                title: ''Host'',
                value: ''{0} [{1}]''.format(params.host_name, params.host_ip),
                short: true
            },
            {
                title: ''Event time'',
                value: ''{0} {1}''.format(event_date, event_time),
                short: true
            }
        ],
    };

    
    if (params.event_source === ''0'') {
        message.fields.push(
            {
                title: ''Severity'',
                value: params.event_severity,
                short: true
            },
            {
                title: ''Opdata'',
                value: params.event_opdata,
                short: true
            }
        );
    }

    if (!isShort && params.event_source === ''0'') {
        message.fields.push(
            {
                title: ''Event tags'',
                value: ''`{0}`''.format(params.event_tags.replace(/__.+?:(.+?,|.+)/g, '''') || ''None''),
                short: true
            },
            {
                title: ''Trigger description'',
                value: params.trigger_description,
                short: true
            }
        );
    }

    if (params.event_source !== ''0'' || params.event_update_status === ''1'') {
        message.fields.push(
            {
                title: ''Details'',
                value: params.alert_message,
                short: false
            }
        );
    }

    return message;
}

function validateParams(params) {
    if (typeof params.bot_token !== ''string'' || params.bot_token.trim() === '''') {
        throw ''Field "bot_token" cannot be empty'';
    }

    if (isNaN(params.event_id)) {
        throw ''Field "event_id" is not a number'';
    }

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: "'' + params.event_source + ''".\nMust be 0-3.'';
    }

    if (params.event_source !== ''0'') {
        params.event_nseverity = ''0'';
        params.event_severity = ''Not classified'';
        params.event_update_status = ''0'';
        params.send_mode = ''event'';
    }

    if (params.event_source === ''1'' || params.event_source === ''2'') {
        params.event_value = ''1'';
    }

    if (params.event_source === ''1'') {
        params.host_name = params.discovery_host_dns;
        params.host_ip = params.discovery_host_ip;
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        throw ''Incorrect "event_nseverity" parameter given: '' + params.event_nseverity + ''\nMust be 0-5.'';
    }

    if (typeof params.event_severity !== ''string'' || params.event_severity.trim() === '''') {
        throw ''Field "event_severity" cannot be empty'';
    }

    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_value !== ''0'' && params.event_value !== ''1'') {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    if (typeof params.host_ip !== ''string'' || params.host_ip.trim() === '''') {
        throw ''Field "host_ip" cannot be empty'';
    }

    if (typeof params.host_name !== ''string'' || params.host_name.trim() === '''') {
        throw ''Field "host_name" cannot be empty'';
    }

    if (typeof params.mattermost_url !== ''string'' || params.mattermost_url.trim() === '''') {
        throw ''Field "mattermost_url" cannot be empty'';
    }

    if (!/^(http|https):\/\/.+/.test(params.mattermost_url)) {
        throw ''Field "mattermost_url" must contain a schema'';
    }

    if ([''alarm'', ''event''].indexOf(params.send_mode) === -1) {
        throw ''Incorrect "send_mode" parameter given: '' + params.send_mode + ''\nMust be "alarm" or "event".'';
    }

    if (typeof params.send_to !== ''string'' || params.send_to.trim() === '''') {
        throw ''Field "send_to" cannot be empty'';
    }

    if (isNaN(params.trigger_id) && params.event_source === ''0'') {
        throw ''field "trigger_id" is not a number'';
    }

    if (typeof params.zabbix_url !== ''string'' || params.zabbix_url.trim() === '''') {
        throw ''Field "zabbix_url" cannot be empty'';
    }

    if (!/^(http|https):\/\/.+/.test(params.zabbix_url)) {
        throw ''Field "zabbix_url" must contain a schema'';
    }

}

try {
    var params = JSON.parse(value);

    validateParams(params);

    var req = new CurlHttpRequest(),
        fields = {},
        result = {tags: {}};

    if (typeof params.HTTPProxy === ''string'' && params.HTTPProxy.trim() !== '''') {
        req.SetProxy(params.HTTPProxy);
    }

    req.AddHeader(''Content-Type: application/json; charset=utf-8'');
    req.AddHeader(''Authorization: Bearer '' + params.bot_token);

    params.mattermost_url = params.mattermost_url.replace(/\/+$/, '''');
    params.zabbix_url = params.zabbix_url.replace(/\/+$/, '''');

    var APIEndpoint = params.mattermost_url + ''/api/v4/'';

    var Mattermost = {
        post_message: APIEndpoint + ''posts'',
        get_channel: APIEndpoint + ''channels/{0}'',
        get_team: APIEndpoint + ''teams/{0}'',
        chat_update: APIEndpoint + ''posts/{0}'',
        direct_channel: APIEndpoint + ''channels/direct'',
        channel_byname: APIEndpoint + ''teams/name/{0}/channels/name/{1}'',
        user_byname: APIEndpoint + ''users/username/{0}'',
        bot_user: APIEndpoint + ''users/me''

    };

    params.send_mode = params.send_mode.toLowerCase();
    params.send_mode = params.send_mode in SEND_MODE_HANDLERS
        ? params.send_mode
        : ''alarm'';

    SEND_MODE_HANDLERS[params.send_mode](req, params);

    if (params.event_source === ''0'') {
        return JSON.stringify(result);
    }
    else {
        return ''OK'';
    }
}
catch (error) {
    Zabbix.Log(4, ''[ Mattermost Webhook ] Mattermost notification failed: '' + error);
    throw ''Mattermost notification failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__mattermost_message_link}','Open in Mattermost: {EVENT.TAGS.__mattermost_channel_name}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('6','4','Opsgenie','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var Media = {
    params: {},
    name: '''',
    labels: [],
    HTTPProxy: '''',

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        Media.params = params;
        Media.params.api += Media.params.api.endsWith(''/'') ? '''' : ''/'';
        Media.params.web += Media.params.web.endsWith(''/'') ? '''' : ''/'';
    },

    setProxy: function (HTTPProxy) {
        if (typeof HTTPProxy !== ''undefined'' && HTTPProxy.trim() !== '''') {
            Media.HTTPProxy = HTTPProxy;
        }
    },

    setTags: function(event_tags_json) {
        if (typeof event_tags_json !== ''undefined'' && event_tags_json !== ''''
                && event_tags_json !== ''{EVENT.TAGSJSON}'') {

            try {
                var tags = JSON.parse(event_tags_json),
                    label;

                tags.forEach(function (tag) {
                    if (typeof tag.tag === ''string'') {
                        label = (tag.tag + (typeof tag.value !== ''undefined''
                                && tag.value !== '''' ? ('':'' + tag.value) : '''')).replace(/\s/g, ''_'');
                        Media.labels.push(label);
                    }
                });
            }
            catch (error) {
                Zabbix.Log(4, ''[ '' + Media.name + '' Webhook ] Failed to parse "event_tags_json" param'');
            }
        }
    },

    request: function (method, query, data, allow_404) {
        if (typeof(allow_404) === ''undefined'') {
            allow_404 = false;
        }

        [''api'', ''token''].forEach(function (field) {
            if (typeof Media.params !== ''object'' || typeof Media.params[field] === ''undefined''
                    || Media.params[field] === '''') {
                throw ''Required '' + Media.name + '' param is not set: "'' + field + ''".'';
            }
        });

        var response,
            url = Media.params.api + query,
            request = new CurlHttpRequest();

        request.AddHeader(''Content-Type: application/json'');
        request.AddHeader(''Authorization: '' + Media.params.token);
        request.SetProxy(Media.HTTPProxy);

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ '' + Media.name + '' Webhook ] Sending request: '' +
            url + ((typeof data === ''string'') ? (''\n'' + data) : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            case ''put'':
                response = request.Put(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ '' + Media.name + '' Webhook ] Received response with status code '' +
            request.Status() + ''\n'' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ '' + Media.name + '' Webhook ] Failed to parse response.'');
                response = null;
            }
        }

        if ((request.Status() < 200 || request.Status() >= 300)
                && (!allow_404 || request.Status() !== 404)) {
            var message = ''Request failed with status code '' + request.Status();

            if (response !== null) {
                if (typeof response.errors === ''object'' && Object.keys(response.errors).length > 0) {
                    message += '': '' + JSON.stringify(response.errors);
                }
                else if (typeof response.errorMessages === ''object'' && Object.keys(response.errorMessages).length > 0) {
                    message += '': '' + JSON.stringify(response.errorMessages);
                }
                else if (typeof response.message === ''string'') {
                    message += '': '' + response.message;
                }
            }

            throw message + '' Check debug log for more information.'';
        }

        return {
            status: request.Status(),
            response: response
        };
    },

    getAlertId: function (requestId) {
        do {
            resp = Media.request(''get'', ''requests/'' + requestId, undefined, true);
        }
        while (typeof resp.response !== ''object'' || typeof resp.response.data === ''undefined''
                || resp.response.data.success === false);

        if (typeof resp.response !== ''object'' || typeof resp.response.data === ''undefined'') {
            throw ''Cannot get '' + Media.name + '' issue ID. Check debug log for more information.'';
        }

        return resp;
    }
};

try {
    var result = {tags: {}},
        params = JSON.parse(value),
        media = {},
        fields = {},
        resp = {},
        responders = [],
        tags = [],
        required_params = [
            ''alert_subject'',
            ''alert_message'',
            ''event_id'',
            ''event_source'',
            ''event_value'',
            ''event_update_status'',
            ''opsgenie_api'',
            ''opsgenie_web'',
            ''opsgenie_token''
        ],
        severities = [
            ''not_classified'',
            ''information'',
            ''warning'',
            ''average'',
            ''high'',
            ''disaster'',
            ''resolved'',
            ''default''
        ],
        priority;

    Object.keys(params)
        .forEach(function (key) {
            if (required_params.indexOf(key) !== -1 && params[key].trim() === '''') {
                throw ''Parameter "'' + key + ''" cannot be empty.'';
            }
            if (key.startsWith(''opsgenie_'')) {
                media[key.substring(9)] = params[key];
            }
        });

    // Possible values of event_source:
    // 0 - Trigger, 1 - Discovery, 2 - Autoregistration, 3 - Internal.
    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: "'' + params.event_source + ''".\nMust be 0-3.'';
    }

    // Check event_value for trigger-based and internal events.
    // Possible values: 1 for problem, 0 for recovering
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check event_update_status only for trigger-based events.
    // Possible values: 0 - Webhook was called because of problem/recovery event, 1 - Update operation.
    if (params.event_source === ''0'' && params.event_update_status !== ''0'' && params.event_update_status !== ''1'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    // Check event_id for a numeric value.
    if (isNaN(parseInt(params.event_id)) || params.event_id < 1) {
        throw ''Incorrect "event_id" parameter given: '' + params.event_id + ''\nMust be a positive number.'';
    }

    if ((params.event_source === ''1'' || params.event_source === ''2'')  && params.event_value === ''0'') {
        throw ''Recovery operations are supported only for Trigger and Internal actions.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''7'';
    }

    if (params.event_value === ''0'') {
        params.event_nseverity = ''6'';
    }

    priority = params[''severity_'' + severities[params.event_nseverity]];
    params.zbxurl = params.zbxurl + (params.zbxurl.endsWith(''/'') ? '''' : ''/'');

    Media.name = ''Opsgenie'';
    Media.setParams(media);
    Media.params.token = ''GenieKey '' + Media.params.token;
    Media.setProxy(params.HTTPProxy);
    Media.setTags(params.event_tags_json); // Set Media.labels

    // Create an issue.
    // Numeric value of the event that triggered an action (1 for problem, 0 for recovering).
    // Numeric value of of the problem update status. Possible values:
    // 0 - Webhook was called because of problem/recovery event, 1 - Update operation.
    if ((params.event_source == 0 && params.event_value == 1 && params.event_update_status == 0)
            || (params.event_source == 3 && params.event_value == 1)
            || params.event_source == 1 || params.event_source == 2) {
        fields.message = params.alert_subject;
        fields.alias = params.event_id;
        fields.description = params.alert_message;
        fields.priority = priority;
        fields.source = ''Zabbix'';

        if (params.event_source === ''0'') {
            fields.details = {
                ''Zabbix server'': params.zbxurl,
                Problem: params.zbxurl + ''tr_events.php?triggerid='' + params.trigger_id + ''&eventid='' + params.event_id
            };
        }
        else {
            fields.details = {''Zabbix server'': params.zbxurl};
        }

        if (typeof params.opsgenie_teams === ''string'') {
            responders = params.opsgenie_teams.split('','');
            fields.responders = responders.map(function(team) {
                return {type: ''team'', name: team.trim()};
            });
        }

        fields.tags = Media.labels;
        if (typeof params.opsgenie_tags === ''string'') {
            tags = params.opsgenie_tags.split('','');
            tags.forEach(function(item) {
                fields.tags.push(item.trim());
            });
        }

        resp = Media.request(''post'', '''', fields);
        if (typeof resp.response !== ''object'' || typeof resp.response.result === ''undefined'') {
            throw ''Cannot create '' + Media.name + '' issue. Check debug log for more information.'';
        }

        if (resp.status === 202) {
            resp = Media.getAlertId(resp.response.requestId);
            if (params.event_source == 0 && params.event_value == 1 && params.event_update_status == 0) {
                result.tags.__zbx_ops_issuekey = resp.response.data.alertId;
                result.tags.__zbx_ops_issuelink = Media.params.web + ''alert/detail/'' + resp.response.data.alertId;
            }
        }
        else {
            throw Media.name + '' response code is unexpected. Check debug log for more information.'';
        }
    }
    // Update a created issue.
    else {
        fields.user = (params.event_value != 0) ? params.zbxuser : '''';
        fields.note = params.alert_message;

        resp = Media.request(''post'', params.event_id + ''/notes?identifierType=alias'', fields);
        if (typeof resp.response !== ''object'' || typeof resp.response.result === ''undefined'') {
            throw ''Cannot update '' + Media.name + '' issue. Check debug log for more information.'';
        }

        if (resp.status === 202) {
            resp = Media.getAlertId(resp.response.requestId);
        }
        else {
            throw Media.name + '' response code is unexpected. Check debug log for more information.'';
        }
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ '' + Media.name + '' Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_ops_issuelink}','Opsgenie: {EVENT.TAGS.__zbx_ops_issuekey}','Please refer to https://docs.opsgenie.com/docs/alert-api and https://www.zabbix.com/documentation/5.0/manual/config/notifications/media/webhook#example_scripts.
  
Set global macro {$ZABBIX.URL} with your Zabbix server URL.
Add dedicated user with media type "Opsgenie".
Change the values of the variables opsgenie_api (https://api.opsgenie.com/v2/alerts or https://api.eu.opsgenie.com/v2/alerts),
opsgenie_web (for example, https://myzabbix.app.opsgenie.com), opsgenie_token.');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('7','4','PagerDuty','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','try {

    var params = JSON.parse(value),
        req = new CurlHttpRequest(),
        fields = {},
        resp = '''';

    // Correspondence between the PagerDuty and Zabbix severity level
    var severityMapping = [
        ''info'',    // Not classified
        ''info'',    // Information
        ''warning'', // Warning
        ''warning'', // Average
        ''error'',   // High
        ''critical'' // Disaster
    ];

    if (!severityMapping[params.severity]) {
        params.severity = ''0'';
    }

    if (typeof params.HTTPProxy === ''string'' && params.HTTPProxy.trim() !== '''') {
        req.SetProxy(params.HTTPProxy);
    }

    if (isNaN(parseInt(params.eventid)) || params.eventid < 1) {
        throw ''incorrect value for variable "eventid". The value must be a positive number.'';
    }
    if (params.eventname.length < 1) {
        throw ''incorrect value for variable "eventname". The value must be a non-empty string.'';
    }
    if (isNaN(parseInt(params.severity)) || (params.severity < 0 && params.severity > 5)) {
        throw ''incorrect value for variable "severity". The value must be a number 0..5.'';
    }

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: "'' + params.event_source + ''".\nMust be 0-3.'';
    }
    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.eventvalue !== ''0'' && params.eventvalue !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "eventvalue" parameter given: "'' + params.eventvalue + ''".\nMust be 0 or 1.'';
    }

    if (params.event_source === ''0'') {
        if (params.hostname.length < 1) {
            throw ''incorrect value for variable "hostname". The value must be a non-empty string.'';
        }
        if (isNaN(parseInt(params.triggerid)) || params.triggerid < 1) {
            throw ''incorrect value for variable "triggerid". The value must be a positive number.'';
        }
        if (params.eventack != ''Yes'' && params.eventack != ''No'') {
            throw ''incorrect value for variable "eventack". The value must be Yes or No.'';
        }
        if (isNaN(parseInt(params.eventupdate)) || (params.eventupdate < 0 || params.eventupdate > 1)) {
            throw ''incorrect value for variable "eventupdate". The value must be 0 or 1.'';
        }
    }



    req.AddHeader(''Content-Type: application/json'');

    fields.routing_key = params.token;
    fields.dedup_key = params.eventid;

    if (((params.eventvalue == 1) && (params.eventupdate == 0)) || params.event_source !== ''0'') {
        fields.event_action = ''trigger'';
        fields.payload = {
            summary: params.eventname,
            source: (params.event_source === ''1'') ? ''Discovery'' : params.hostname + '' : '' + params.hostip,
            severity: severityMapping[params.severity],
        };
        
        if (params.event_source === ''0'') {
            fields.payload.custom_details = {
                ''Event date'': params.eventdate,
                ''Event time'': params.eventtime,
                ''Trigger description'': params.triggerdesc,
                ''Trigger opdata'': params.triggeropdata,
                ''Event tags'': params.eventtags,
                ''Event host'': params.hostname,
                ''Event host ip'': params.hostip
            };
            fields.links = [{
                href: params.url + ''/tr_events.php?triggerid='' + params.triggerid + ''&eventid='' + params.eventid,
                text: ''Event link''
            }];
        }
        else {
            fields.payload.custom_details = {
                ''Alert message'': params.alert_message
            };
        }

        fields.client = ''Zabbix'';
        fields.client_url = params.url;
    }
    else if ((params.eventvalue == 1) && (params.eventupdate == 1) && (params.eventack == ''Yes''))
        fields.event_action = ''acknowledge'';
    else if (params.eventvalue == 0)
        fields.event_action = ''resolve'';
    else
        throw ''incorrect values. Update message without ack will not be sent.'';

    Zabbix.Log(4, ''[PagerDuty Webhook] Sending request:'' + JSON.stringify(fields));
    resp = req.Post(''https://events.pagerduty.com/v2/enqueue'',
        JSON.stringify(fields)
    );
    Zabbix.Log(4, ''[PagerDuty Webhook] Receiving response:'' + resp);

    try {
        resp = JSON.parse(resp);
    }
    catch (error) {
        throw ''incorrect response. PagerDuty returned a non-JSON object.'';
    }

    if (req.Status() != 202) {
        if (typeof resp === ''object'' && typeof resp.errors === ''object'' && typeof resp.errors[0] === ''string'') {
            throw resp.errors[0];
        }
        else {
            throw ''Unknown error.'';
        }
    }

    if (resp.status != ''success'') {
        throw ''Unknown error.'';
    }

    return ''OK'';
}
catch (error) {
    Zabbix.Log(3, ''[PagerDuty Webhook] Notification failed : '' + error);
    throw ''PagerDuty notification failed : '' + error;
}','30s','0','0','','','Please refer to https://v2.developer.pagerduty.com/docs/send-an-event-events-api-v2 and https://www.zabbix.com/documentation/5.0/manual/config/notifications/media/webhook#example_scripts.
  
Set global macro {$ZABBIX.URL} with your Zabbix server URL.
Add a dedicated user with the media type "PagerDuty" and place the integration key in the "token" parameter to integrate into the service.');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('8','4','Pushover','','','','','','','','0','25','0','0','0','0','','0','3','10s','1','try {
    var params = JSON.parse(value),
        request = new CurlHttpRequest(),
        data,
        response,
        severities = [
            {name: ''not_classified'', color: ''#97AAB3''},
            {name: ''information'', color: ''#7499FF''},
            {name: ''warning'', color: ''#FFC859''},
            {name: ''average'', color: ''#FFA059''},
            {name: ''high'', color: ''#E97659''},
            {name: ''disaster'', color: ''#E45959''},
            {name: ''resolved'', color: ''#009900''},
            {name: ''default'', color: ''#000000''}
        ],
        priority;

    if (typeof params.HTTPProxy === ''string'' && params.HTTPProxy.trim() !== '''') {
        request.SetProxy(params.HTTPProxy);
    }

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: "'' + params.event_source + ''".\nMust be 0-3.'';
    }

    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''7'';
    }

    if (params.event_value === ''0'') {
        params.event_nseverity = ''6'';
    }

    priority = params[''priority_'' + severities[params.event_nseverity].name] || params.priority_default;

    if (isNaN(priority) || priority < -2 || priority > 2) {
        throw ''"priority" should be -2..2'';
    }

    if (params.event_source === ''0'' && isNaN(params.triggerid)) {
        throw ''field "triggerid" is not a number'';
    }

    if (isNaN(params.eventid)) {
        throw ''field "eventid" is not a number'';
    }

    if (typeof params.message !== ''string'' || params.message.trim() === '''') {
        throw ''field "message" cannot be empty'';
    }

    data = {
        token: params.token,
        user: params.user,
        title: params.title,
        message: params.message,
        url: (params.event_source === ''0'') 
            ? params.url + ''/tr_events.php?triggerid='' + params.triggerid + ''&eventid='' + params.eventid
            : params.url,
        url_title: params.url_title,
        priority: priority
    };

    if (priority == 2) {
        if (isNaN(params.retry) || params.retry < 30) {
            throw ''field "retry" should be a number with value of at least 30 if "priority" is set to 2'';
        }

        if (isNaN(params.expire) || params.expire > 10800) {
            throw ''field "expire" should be a number with value of at most 10800 if "priority" is set to 2'';
        }

        data.retry = params.retry;
        data.expire = params.expire;
    }

    data = JSON.stringify(data);
    Zabbix.Log(4, ''[ Pushover Webhook ] Sending request: '' + params.endpoint + ''\n'' + data);

    request.AddHeader(''Content-Type: application/json'');
    response = request.Post(params.endpoint, data);

    Zabbix.Log(4, ''[ Pushover Webhook ] Received response with status code '' + request.Status() + ''\n'' + response);

    if (response !== null) {
        try {
            response = JSON.parse(response);
        }
        catch (error) {
            Zabbix.Log(4, ''[ Pushover Webhook ] Failed to parse response received from Pushover'');
            response = null;
        }
    }

    if (request.Status() != 200 || response === null || typeof response !== ''object'' || response.status !== 1) {
        if (response !== null && typeof response === ''object'' && typeof response.errors === ''object''
                && typeof response.errors[0] === ''string'') {
            throw response.errors[0];
        }
        else {
            throw ''Unknown error. Check debug log for more information.'';
        }
    }

    return ''OK'';
}
catch (error) {
    Zabbix.Log(4, ''[ Pushover Webhook ] Pushover notification failed: '' + error);
    throw ''Pushover notification failed: '' + error;
}','30s','0','0','','','Please refer to setup guide here: https://git.zabbix.com/projects/ZBX/repos/zabbix/browse/templates/media/pushover

Set token parameter with to your Pushover application key.
When assigning Pushover media to the Zabbix user - add user key into send to field.');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('9','4','Slack','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var SEVERITY_COLORS = [
    ''#97AAB3'', ''#7499FF'', ''#FFC859'',
    ''#FFA059'', ''#E97659'', ''#E45959''
];

var RESOLVE_COLOR = ''#009900'';

var SLACK_MODE_HANDLERS = {
    alarm: handlerAlarm,
    event: handlerEvent
};


if (!String.prototype.format) {
    String.prototype.format = function() {
        var args = arguments;

        return this.replace(/{(\d+)}/g, function(match, number) {
            return number in args
                ? args[number]
                : match
            ;
        });
    };
}

function isEventProblem(params) {
    return params.event_value == 1
        && params.event_update_status == 0
    ;
}

function isEventUpdate(params) {
    return params.event_value == 1
        && params.event_update_status == 1
    ;
}

function isEventResolve(params) {
    return params.event_value == 0;
}

function getPermalink(channelId, messageTimestamp) {
    var req = new CurlHttpRequest();

    if (typeof params.HTTPProxy === ''string'' && params.HTTPProxy.trim() !== '''') {
        req.SetProxy(params.HTTPProxy);
    }

    req.AddHeader(''Content-Type: application/x-www-form-urlencoded; charset=utf-8'');
    req.AddHeader(''Authorization: Bearer '' + params.bot_token);

    var query = ''{0}?channel={1}&message_ts={2}''.format(
            Slack.getPermalink,
            encodeURIComponent(channelId),
            encodeURIComponent(messageTimestamp)),
        resp = JSON.parse(req.Get(query));

    if (req.Status() != 200 || !resp.ok || resp.ok === ''false'') {
        throw ''message was created, but getting message link was failed with reason "'' + resp.error + ''"'';
    }

    return resp.permalink;
}

function createProblemURL(zabbix_url, triggerid, eventid, event_source) {
    var problem_url = '''';
    if (event_source === ''0'') {
        problem_url = ''{0}/tr_events.php?triggerid={1}&eventid={2}''
            .format(
                zabbix_url,
                triggerid,
                eventid
            );
    }
    else {
        problem_url = zabbix_url;
    }

    return problem_url;
}

function handlerAlarm(params) {
    var fields = {
        channel: params.channel,
        as_user: params.slack_as_user,
    };

    if (isEventProblem(params)) {
        fields.attachments = [
            createMessage(
                SEVERITY_COLORS[params.event_nseverity] || 0,
                params.event_date,
                params.event_time,
                createProblemURL(params.zabbix_url, params.trigger_id, params.event_id, params.event_source)
            )
        ];

        var resp = JSON.parse(req.Post(Slack.postMessage, JSON.stringify(fields)));

        if (req.Status() != 200 || !resp.ok || resp.ok === ''false'') {
            throw resp.error;
        }

        result.tags.__message_ts = resp.ts;
        result.tags.__channel_id = resp.channel;
        result.tags.__channel_name = params.channel;
        result.tags.__message_link = getPermalink(resp.channel, resp.ts);
    }
    else if (isEventUpdate(params)) {
        fields.thread_ts = params.message_ts;
        fields.attachments = [
            createMessage(
                SEVERITY_COLORS[params.event_nseverity] || 0,
                params.event_update_date,
                params.event_update_time,
                createProblemURL(params.zabbix_url, params.trigger_id, params.event_id, params.event_source),
                true
            )
        ];

        resp = JSON.parse(req.Post(Slack.postMessage, JSON.stringify(fields)));
        if (req.Status() != 200 || !resp.ok || resp.ok === ''false'') {
            throw resp.error;
        }

    }
    else if (isEventResolve(params)) {
        fields.channel = params.channel_id;
        fields.text = '''';
        fields.ts = params.message_ts;
        fields.attachments = [
            createMessage(
                RESOLVE_COLOR,
                params.event_date,
                params.event_time,
                createProblemURL(params.zabbix_url, params.trigger_id, params.event_id, params.event_source)
            )
        ];

        resp = JSON.parse(req.Post(Slack.chatUpdate, JSON.stringify(fields)));
        if (req.Status() != 200 || !resp.ok || resp.ok === ''false'') {
            throw resp.error;
        }
    }
}

function handlerEvent(params) {
    var fields = {
        channel: params.channel,
        as_user: params.slack_as_user
    };

    if (isEventProblem(params)) {
        fields.attachments = [
            createMessage(
                SEVERITY_COLORS[params.event_nseverity] || 0,
                params.event_date,
                params.event_time,
                createProblemURL(params.zabbix_url, params.trigger_id, params.event_id, params.event_source)
            )
        ];

        var resp = JSON.parse(req.Post(Slack.postMessage, JSON.stringify(fields)));

        if (req.Status() != 200 || !resp.ok || resp.ok === ''false'') {
            throw resp.error;
        }

        result.tags.__channel_name = params.channel;
        result.tags.__message_link = getPermalink(resp.channel, resp.ts);

    }
    else if (isEventUpdate(params)) {
        fields.attachments = [
            createMessage(
                SEVERITY_COLORS[params.event_nseverity] || 0,
                params.event_update_date,
                params.event_update_time,
                createProblemURL(params.zabbix_url, params.trigger_id, params.event_id, params.event_source),
                false
            )
        ];

        resp = JSON.parse(req.Post(Slack.postMessage, JSON.stringify(fields)));

        if (req.Status() != 200 || !resp.ok || resp.ok === ''false'') {
            throw resp.error;
        }

    }
    else if (isEventResolve(params)) {
        fields.attachments = [
            createMessage(
                RESOLVE_COLOR,
                params.event_recovery_date,
                params.event_recovery_time,
                createProblemURL(params.zabbix_url, params.trigger_id, params.event_id, params.event_source)
            )
        ];

        resp = JSON.parse(req.Post(Slack.postMessage, JSON.stringify(fields)));

        if (req.Status() != 200 || !resp.ok || resp.ok === ''false'') {
            throw resp.error;
        }
    }
}

function createMessage(
    event_severity_color,
    event_date,
    event_time,
    problem_url,
    isShort,
    messageText
) {
    var message = {
        fallback: params.alert_subject,
        title: params.alert_subject,
        color: event_severity_color,
        title_link: problem_url,
        pretext: messageText || '''',

        fields: [
            {
                title: ''Host'',
                value: ''{0} [{1}]''.format(params.host_name, params.host_conn),
                short: true
            },
            {
                title: ''Event time'',
                value: ''{0} {1}''.format(event_date, event_time),
                short: true
            }
        ],
    };

    if (params.event_source === ''0'') {
        message.fields.push(
            {
                title: ''Severity'',
                value: params.event_severity,
                short: true
            },
            {
                title: ''Opdata'',
                value: params.event_opdata,
                short: true
            }
        );
    }

    if (!isShort  && params.event_source === ''0'') {
        message[''actions''] = [
            {
                type: ''button'',
                text: ''Open in Zabbix'',
                url: problem_url
            }
        ];

        message.fields.push(
            {
                title: ''Event tags'',
                value: params.event_tags.replace(/__.+?:(.+?,|.+)/g, '''') || ''None'',
                short: true
            },
            {
                title: ''Trigger description'',
                value: params.trigger_description,
                short: true
            }
        );
    }

    if (params.event_source !== ''0'' || params.event_update_status === ''1'') {
        message.fields.push(
            {
                title: ''Details'',
                value: params.alert_message,
                short: false
            }
        );
    }

    return message;
}

function validateParams(params) {
    if (typeof params.bot_token !== ''string'' || params.bot_token.trim() === '''') {
        throw ''Field "bot_token" cannot be empty'';
    }

    if (typeof params.channel !== ''string'' || params.channel.trim() === '''') {
        throw ''Field "channel" cannot be empty'';
    }

    if (isNaN(params.event_id)) {
        throw ''Field "event_id" is not a number'';
    }

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: "'' + params.event_source + ''".\nMust be 0-3.'';
    }

    if (params.event_source !== ''0'') {
        params.event_nseverity = ''0'';
        params.event_severity = ''Not classified'';
        params.event_update_status = ''0'';
        params.slack_mode = ''event'';
    }

    if (params.event_source === ''1'' || params.event_source === ''2'') {
        params.event_value = ''1'';
    }

    if (params.event_source === ''1'') {
        params.host_name = params.discovery_host_dns;
        params.host_ip = params.discovery_host_ip;
    }

    if (!~[0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity))) {
        throw ''Incorrect "event_nseverity" parameter given: '' + params.event_nseverity + ''\nMust be 0-5.'';
    }

    if (typeof params.event_severity !== ''string'' || params.event_severity.trim() === '''') {
        throw ''Field "event_severity" cannot be empty'';
    }

    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_value !== ''0'' && params.event_value !== ''1'') {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    if (typeof params.host_conn !== ''string'' || params.host_conn.trim() === '''') {
        throw ''Field "host_conn" cannot be empty'';
    }

    if (typeof params.host_name !== ''string'' || params.host_name.trim() === '''') {
        throw ''Field "host_name" cannot be empty'';
    }

    if (!~[''true'', ''false''].indexOf(params.slack_as_user.toLowerCase())) {
        throw ''Incorrect "slack_as_user" parameter given: '' + params.slack_as_user + ''\nMust be "true" or "false".'';
    }

    if (!~[''alarm'', ''event''].indexOf(params.slack_mode)) {
        throw ''Incorrect "slack_mode" parameter given: '' + params.slack_mode + ''\nMust be "alarm" or "event".'';
    }

    if (isNaN(params.trigger_id) && params.event_source === ''0'') {
        throw ''field "trigger_id" is not a number'';
    }

    if (typeof params.zabbix_url !== ''string'' || params.zabbix_url.trim() === '''') {
        throw ''Field "zabbix_url" cannot be empty'';
    }

    if (!/^(http|https):\/\/.+/.test(params.zabbix_url)) {
        throw ''Field "zabbix_url" must contain a schema'';
    }
}

try {
    var params = JSON.parse(value);

    validateParams(params);

    var req = new CurlHttpRequest(),
        result = {tags: {}};

    if (typeof params.HTTPProxy === ''string'' && params.HTTPProxy.trim() !== '''') {
        req.SetProxy(params.HTTPProxy);
    }

    req.AddHeader(''Content-Type: application/json; charset=utf-8'');
    req.AddHeader(''Authorization: Bearer '' + params.bot_token);

    var slack_endpoint = ''https://slack.com/api/'';

    var Slack = {
        postMessage: slack_endpoint + ''chat.postMessage'',
        getPermalink: slack_endpoint + ''chat.getPermalink'',
        chatUpdate: slack_endpoint + ''chat.update''
    };

    params.slack_mode = params.slack_mode.toLowerCase();
    params.slack_mode = params.slack_mode in SLACK_MODE_HANDLERS
        ? params.slack_mode
        : ''alarm'';

    SLACK_MODE_HANDLERS[params.slack_mode](params);

    if (params.event_source === ''0'') {
        return JSON.stringify(result);
    }
    else {
        return ''OK'';
    }
}
catch (error) {
    Zabbix.Log(4, ''[ Slack Webhook ] Slack notification failed : '' + error);
    throw ''Slack notification failed : '' + error;
}','30s','1','1','{EVENT.TAGS.__message_link}','Open in Slack: {EVENT.TAGS.__channel_name}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('10','4','Discord','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var SEVERITY_COLORS = [
    ''#97AAB3'', // Not classified.
    ''#7499FF'', // Information.
    ''#FFC859'', // Warning.
    ''#FFA059'', // Average.
    ''#E97659'', // High.
    ''#E45959'', // Disaster.
    ''#009900''  // Resolved.
];

function stringTruncate(str, len) {
    return str.length > len ? str.substring(0, len - 3) + ''...'' : str;
}

try {
    Zabbix.Log(4, ''[ Discord Webhook ] Executed with params: '' + value);

    var params = JSON.parse(value);

    if (!params.discord_endpoint) {
        throw ''Cannot get discord_endpoint'';
    }
    else {
        params.discord_endpoint = params.discord_endpoint.replace(''/api/'', ''/api/v7/'') + ''?wait=True'';
    }

    params.zabbix_url = (params.zabbix_url.endsWith(''/''))
        ? params.zabbix_url.slice(0, -1) : params.zabbix_url;

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: "'' + params.event_source + ''".\nMust be 0-3.'';
    }

    // Set params to true for non trigger-based events.
    if (params.event_source !== ''0'') {
        params.use_default_message = ''true'';
        params.event_nseverity = ''0'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: "'' + params.event_value + ''".\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'' && params.event_source === ''0'') {
        throw ''Incorrect "event_update_status" parameter given: "'' + params.event_update_status + ''".\nMust be 0 or 1.'';
    }

    if (params.event_value == 0) {
        params.event_nseverity = ''6'';
    }

    if (!SEVERITY_COLORS[params.event_nseverity]) {
        throw ''Incorrect "event_nseverity" parameter given: '' + params.event_nseverity + ''\nMust be 0-5.'';
    }

    var color = parseInt(SEVERITY_COLORS[params.event_nseverity].replace(''#'', ''''), 16),
        fields = [],
        body = {
            embeds: [
                {
                    color: color || 0,
                    url: (params.event_source === ''0'')
                        ? params.zabbix_url + ''/tr_events.php?triggerid='' + params.trigger_id +
                            ''&eventid='' + params.event_id
                        : params.zabbix_url
                }
            ]
        };

    // Default message from {ALERT.MESSAGE}.
    if (params.use_default_message.toLowerCase() == ''true'') {
        body.embeds[0].title = stringTruncate(params.alert_subject, 256);
        body.embeds[0].description = stringTruncate(params.alert_message, 2048);
    }
    else {
        fields.push(
            {
                name: ''Host'',
                value: params.host_name + '' ['' + params.host_ip + '']''
            }
        );

        // Resolved message.
        if (params.event_value == 0 && params.event_update_status == 0) {
            body.embeds[0].title = stringTruncate(''OK: '' + params.event_name, 256);
            fields.push(
                {
                    name: ''Recovery time'',
                    value: params.event_recovery_time + '' '' + params.event_recovery_date,
                    inline: ''True''
                }
            );
        }

        // Problem message.
        else if (params.event_value == 1 && params.event_update_status == 0) {
            body.embeds[0].title = stringTruncate(''PROBLEM: '' + params.event_name, 256);
            fields.push(
                {
                    name: ''Event time'',
                    value: params.event_time + '' '' + params.event_date,
                    inline: ''True''
                }
            );
        }

        // Update message.
        else if (params.event_update_status == 1) {
            body.embeds[0].title = stringTruncate(''UPDATE: '' + params.event_name, 256);
            body.embeds[0].description = params.event_update_user + '' '' + params.event_update_action + ''.'';

            if (params.event_update_message) {
                body.embeds[0].description += '' Comment:\n>>> '' + params.event_update_message;
            }

            body.embeds[0].description = stringTruncate(body.embeds[0].description, 2048);

            fields.push(
                {
                    name: ''Event update time'',
                    value: params.event_update_time + '' '' + params.event_update_date,
                    inline: ''True''
                }
            );
        }

        fields.push(
            {
                name: ''Severity'',
                value: params.event_severity,
                inline: ''True''
            }
        );

        if (params.event_opdata) {
            fields.push(
                {
                    name: ''Operational data'',
                    value: stringTruncate(params.event_opdata, 1024),
                    inline: ''True''
                }
            );
        }

        if (params.event_value == 1 && params.event_update_status == 0 && params.trigger_description) {
            fields.push(
                {
                    name: ''Trigger description'',
                    value: stringTruncate(params.trigger_description, 1024)
                }
            );
        }

        body.embeds[0].footer = {
            text: ''Event ID: '' + params.event_id
        };

        if (params.event_tags) {
            body.embeds[0].footer.text += ''\nEvent tags: '' + params.event_tags;
        }
        body.embeds[0].footer.text = stringTruncate(body.embeds[0].footer.text, 2048);
    }

    if (fields.length > 0) {
        body.embeds[0].fields = fields;
    }

    var req = new CurlHttpRequest();

    if (typeof params.HTTPProxy === ''string'' && params.HTTPProxy.trim() !== '''') {
        req.SetProxy(params.HTTPProxy);
    }

    req.AddHeader(''Content-Type: application/json'');

    var resp = req.Post(params.discord_endpoint, JSON.stringify(body)),
        data = JSON.parse(resp);

    Zabbix.Log(4, ''[ Discord Webhook ] JSON: '' + JSON.stringify(body));
    Zabbix.Log(4, ''[ Discord Webhook ] Response: '' + resp);

    if (data.id) {
        return resp;
    }
    else {
        var message = ((typeof data.message === ''string'') ? data.message : ''Unknown error'');

        Zabbix.Log(3, ''[ Discord Webhook ] FAILED with response: '' + resp);
        throw message + ''. For more details check zabbix server log.'';
    }
}
catch (error) {
    Zabbix.Log(3, ''[ Discord Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','0','0','','','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('11','4','SIGNL4','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','// SIGNL4 Webhook
try {
    var response,
        payload,
        params = JSON.parse(value),
        endpoint = ''https://connect.signl4.com/webhook/'',
        request = new CurlHttpRequest();

    if (typeof params.HTTPProxy === ''string'' && params.HTTPProxy.trim() !== '''') {
        request.SetProxy(params.HTTPProxy);
    }

    if (typeof params.teamsecret === ''string'' && params.teamsecret.trim() !== '''') {
        endpoint += params.teamsecret;
        delete params.teamsecret;
    }
    else {
        throw ''The team secret of your SIGNL4 team cannot be empty.'';
    }

    if (typeof params.Severity === ''string'' && params.Severity === ''{EVENT.SEVERITY}'') {
        params.Severity = ''Not classified'';
    }

if (typeof params.User === ''string'' && params.User === ''{USER.FULLNAME}'') {
        params.User = '''';
    }

if (typeof params.Event_Update_Action === ''string'' && params.Event_Update_Action === ''{EVENT.UPDATE.ACTION}'') {
        params.Event_Update_Action = '''';
    }

// Assemble X-S4-ExternalID for two-way integration
// Format: "ZabbixEventID: 222 ZabbixURL: https://your-zabbix-server/zabbix/"
params[''X-S4-ExternalID''] = ''ZabbixEventID: '' + params.Event_ID;
if (typeof params.Zabbix_URL === ''string'' && params.Zabbix_URL.indexOf(''http'') == 0) {
// Make sure the URL ends with ''/''
if (params.Zabbix_URL.charAt(params.Zabbix_URL.length - 1) != ''/'') {
params.Zabbix_URL = params.Zabbix_URL + ''/'';
}

params[''X-S4-ExternalID''] = params[''X-S4-ExternalID''] + '' ZabbixURL: '' +  params.Zabbix_URL;

// Add Link parameter
params[''Link''] = params.Zabbix_URL + "tr_events.php?triggerid="+params.Trigger_ID + "&eventid=" + params.Event_ID;
}

// Check if this is a new problem or a recovery
if (params.Trigger_Status == ''OK'') {
params[''X-S4-Status''] = ''resolved'';
}
else {
params[''X-S4-Status''] = ''new'';
}

    payload = JSON.stringify(params);
    Zabbix.Log(4, ''[ SIGNL4 Webhook ] Sending request: '' + payload);

    request.AddHeader(''Content-Type: application/json'');
    response = request.Post(endpoint, ''payload='' + payload);

    Zabbix.Log(4, ''[ SIGNL4 Webhook ] Received response with status code '' +
            request.Status() + ''\n'' + response
    );

    if (request.Status() !== 201) {
        throw ''Request failed with status code '' + request.Status() +
                ''. Check debug log for more information.'';
    }

    return ''OK'';
}
catch (error) {
    Zabbix.Log(4, ''[ SIGNL4 Webhook ] ERROR: '' + error);

    throw ''Sending failed: '' + error;
}','30s','0','0','','','SIGNL4 is a mobile alert notification app for powerful alerting, alert management and mobile assignment of work items. It offers alerting via app push, SMS and voice calls including escalations, tracking, and duty scheduling.

Get the app at https://www.signl4.com.

Find out more including an integration video here: https://www.signl4.com/blog/portfolio_item/zabbix-mobile-alert-notification-duty-schedule-escalation/
');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('12','4','Jira','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var Jira = {
    params: {},

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        Jira.params = params;
        if (typeof Jira.params.url === ''string'') {
            if (!Jira.params.url.endsWith(''/'')) {
                Jira.params.url += ''/'';
            }

            Jira.params.url += ''rest/api/latest/'';
        }
    },

    setProxy: function (HTTPProxy) {
        Jira.HTTPProxy = HTTPProxy;
    },

    setTags: function(event_tags_json) {
        if (typeof event_tags_json !== ''undefined'' && event_tags_json !== ''''
            && event_tags_json !== ''{EVENT.TAGSJSON}'') {
            try {
                var tags = JSON.parse(event_tags_json),
                    label;

                Jira.labels = [];

                tags.forEach(function (tag) {
                    if (typeof tag.tag !== ''undefined'' && typeof tag.value !== ''undefined''
                        && !tag.tag.startsWith(''__zbx'')) {
                        label = (tag.tag + (tag.value ? ('':'' + tag.value) : '''')).replace(/\s/g, ''_'');
                        if (label.length < 256) {
                            Jira.labels.push(label);
                        }
                    }
                });
            }
            catch (error) {
                // Code is not missing here.
            }
        }
    },

    escapeMarkup: function (str) {
        var length = str.length,
            result = '''',
            markup = [''{'', ''|'', ''}'', ''~'', ''_'', ''\\'', ''['', '']'', ''^'', ''<'', ''>'', ''?'', ''!'', ''#'', ''+'', ''*'', ''&''];

        for (var i = 0; i < length; i++) {
            var char = str[i];

            result += (markup.indexOf(char) !== -1) ? (''&#'' + str[i].charCodeAt() + '';'') : char;
        }

        return result;
    },

    addCustomFields: function (data, fields) {
        if (typeof fields === ''object'' && Object.keys(fields).length) {
            var schema = Jira.getSchema(),
                path = [''projects'', 0, ''issuetypes'', 0, ''fields''],
                field;

            while ((field = path.shift()) !== undefined) {
                schema = schema[field];
                if (typeof schema === ''undefined'') {
                    schema = null;
                    break;
                }
            }

            if (schema) {
                Object.keys(fields)
                    .forEach(function(field) {
                        if (typeof schema[field] === ''object'' && typeof schema[field].schema === ''object'') {
                            switch (schema[field].schema.type) {
                                case ''number'':
                                    data.fields[field] = parseInt(fields[field]);
                                    break;

                                case ''datetime'':
                                    if (fields[field].match(/\d+[.-]\d+[.-]\d+T\d+:\d+:\d+/) !== null) {
                                        data.fields[field] = fields[field].replace(/\./g, ''-'');
                                    }
                                    break;

                                case ''option'':
                                    data.fields[field] = {value: fields[field]};
                                    break;

                                case ''array'':
                                    if (schema[field].schema.items === ''option'') {
                                        data.fields[field] = [{value: fields[field]}];
                                    }
                                    else {
                                        data.fields[field] = [fields[field]];
                                    }
                                    break;

                                default:
                                    data.fields[field] = fields[field];
                            }
                        }
                    });
            }
            else {
                Zabbix.Log(4, ''[ Jira Webhook ] Failed to retrieve field schema.'');
            }
        }

        return data;
    },

    request: function (method, query, data) {
        [''url'', ''user'', ''password'', ''project_key'', ''issue_type''].forEach(function (field) {
            if (typeof Jira.params !== ''object'' || typeof Jira.params[field] === ''undefined''
                || Jira.params[field] === '''' ) {
                throw ''Required Jira param is not set: "'' + field + ''".'';
            }
        });

        var response,
            url = Jira.params.url + query,
            request = new CurlHttpRequest();

        request.AddHeader(''Content-Type: application/json'');
        request.AddHeader(''Authorization: Basic '' + btoa(Jira.params.user + '':'' + Jira.params.password));

        if (typeof Jira.HTTPProxy !== ''undefined'' && Jira.HTTPProxy !== '''') {
            request.SetProxy(Jira.HTTPProxy);
        }

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ Jira Webhook ] Sending request: '' + url + ((typeof data === ''string'') ? (''\n'' + data) : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            case ''put'':
                response = request.Put(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ Jira Webhook ] Received response with status code '' + request.Status() + ''\n'' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ Jira Webhook ] Failed to parse response received from Jira'');
                response = null;
            }
        }

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            if (response !== null && typeof response.errors !== ''undefined''
                && Object.keys(response.errors).length > 0) {
                message += '': '' + JSON.stringify(response.errors);
            }
            else if (response !== null && typeof response.errorMessages !== ''undefined''
                && Object.keys(response.errorMessages).length > 0) {
                message += '': '' + JSON.stringify(response.errorMessages);
            }

            throw message + '' Check debug log for more information.'';
        }

        return {
            status: request.Status(),
            response: response
        };
    },

    getSchema: function() {
        var result = Jira.request(''get'', ''issue/createmeta?expand=projects.issuetypes.fields&projectKeys='' +
            encodeURIComponent(Jira.params.project_key) + ''&issuetypeNames='' +
            encodeURIComponent(Jira.params.issue_type));

        return result.response;
    },

    createIssue: function(summary, description, fields) {
        var data = {
            fields: {
                project: {
                    key: Jira.params.project_key
                },
                issuetype: {
                    name: Jira.params.issue_type
                },
                summary: summary,
                description: description
            }
        };

        if (Jira.labels && Jira.labels.length > 0) {
            data.fields.labels = Jira.labels;
        }
        var result = Jira.request(''post'', ''issue'', Jira.addCustomFields(data, fields));

        if (typeof result.response !== ''object'' || typeof result.response.key === ''undefined'') {
            throw ''Cannot create Jira issue. Check debug log for more information.'';
        }

        return result.response.key;
    },

    updateIssue: function(summary, fields, update) {
        var data = {fields: {}};

        if (summary) {
            data.fields.summary = summary;
        }

        Jira.request(''put'', ''issue/'' + encodeURIComponent(Jira.params.issue_key), Jira.addCustomFields(data, fields));
        Jira.commentIssue(update);
    },

    commentIssue: function(update) {
        var data = {};

        if (typeof update === ''string'') {
            data.body = update;
            Jira.request(''post'', ''issue/'' + encodeURIComponent(Jira.params.issue_key) + ''/comment'', data);
        }
        else if (update.status === ''1'') {
            data.body = update.user + '' '' + update.action + ''.'';

            if (update.message) {
                data.body += ''\nMessage: {quote}'' + Jira.escapeMarkup(update.message) + ''{quote}'';
            }

            Jira.request(''post'', ''issue/'' + encodeURIComponent(Jira.params.issue_key) + ''/comment'', data);
        }
    }
};

try {
    var params = JSON.parse(value),
        fields = {},
        jira = {},
        update = {},
        result = {tags: {}},
        required_params = [''alert_subject'', ''summary'', ''event_recovery_value'', ''event_source'', ''event_value''];

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''jira_'')) {
                jira[key.substring(5)] = params[key];
            }
            else if (key.startsWith(''customfield_'')) {
                fields[key] = params[key];
            }
            else if (key.startsWith(''event_update_'')) {
                update[key.substring(13)] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key] === '''') {
                throw ''Parameter "'' + key + ''" can\''t be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'' && params.event_source === ''0'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_source !== ''0'' && params.event_recovery_value === ''0'') {
        throw ''Recovery operations are supported only for trigger-based actions.'';
    }

    Jira.setParams(jira);
    Jira.setProxy(params.HTTPProxy);
    Jira.setTags(params.event_tags_json);

    // Create issue for non trigger-based events.
    if (params.event_source !== ''0'' && params.event_recovery_value !== ''0'') {
        Jira.createIssue(params.alert_subject, params.alert_message);
    }
    // Create issue for trigger-based events.
    else if (params.event_value === ''1'' && update.status === ''0'' && !jira.issue_key.startsWith(jira.project_key)) {
        var key = Jira.createIssue(params.alert_subject,
            (Object.keys(fields).length ? params.trigger_description : params.alert_message), fields);


        result.tags.__zbx_jira_issuekey = key;
        result.tags.__zbx_jira_issuelink = params.jira_url +
            (params.jira_url.endsWith(''/'') ? '''' : ''/'') + ''browse/'' + key;
    }
    // Update created issue for trigger-based event.
    else {
        if (!jira.issue_key.startsWith(jira.project_key)) {
            throw ''Incorrect Issue key given: '' + jira.issue_key;
        }
        Jira.updateIssue(params.alert_subject, fields,
            ((params.event_value === ''0'' && !Object.keys(fields).length)
                ? params.alert_message : update));
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ Jira Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_jira_issuelink}','Jira: {EVENT.TAGS.__zbx_jira_issuekey}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('13','4','Jira with CustomFields','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var Jira = {
    params: {},

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        Jira.params = params;
        if (typeof Jira.params.url === ''string'') {
            if (!Jira.params.url.endsWith(''/'')) {
                Jira.params.url += ''/'';
            }

            Jira.params.url += ''rest/api/latest/'';
        }
    },

    setProxy: function (HTTPProxy) {
        Jira.HTTPProxy = HTTPProxy;
    },

    setTags: function(event_tags_json) {
        if (typeof event_tags_json !== ''undefined'' && event_tags_json !== ''''
            && event_tags_json !== ''{EVENT.TAGSJSON}'') {
            try {
                var tags = JSON.parse(event_tags_json),
                    label;

                Jira.labels = [];

                tags.forEach(function (tag) {
                    if (typeof tag.tag !== ''undefined'' && typeof tag.value !== ''undefined'' ) {
                        label = (tag.tag + (tag.value ? ('':'' + tag.value) : '''')).replace(/\s/g, ''_'');
                        if (label.length < 256) {
                            Jira.labels.push(label);
                        }
                    }
                });
            }
            catch (error) {
                // Code is not missing here.
            }
        }
    },

    escapeMarkup: function (str) {
        var length = str.length,
            result = '''',
            markup = [''{'', ''|'', ''}'', ''~'', ''_'', ''\\'', ''['', '']'', ''^'', ''<'', ''>'', ''?'', ''!'', ''#'', ''+'', ''*'', ''&''];

        for (var i = 0; i < length; i++) {
            var char = str[i];

            result += (markup.indexOf(char) !== -1) ? (''&#'' + str[i].charCodeAt() + '';'') : char;
        }

        return result;
    },

    addCustomFields: function (data, fields) {
        if (typeof fields === ''object'' && Object.keys(fields).length) {
            var schema = Jira.getSchema(),
                path = [''projects'', 0, ''issuetypes'', 0, ''fields''],
                field;

            while ((field = path.shift()) !== undefined) {
                schema = schema[field];
                if (typeof schema === ''undefined'') {
                    schema = null;
                    break;
                }
            }

            if (schema) {
                Object.keys(fields)
                    .forEach(function(field) {
                        data.fields[field] = fields[field];

                        if (typeof schema[field] === ''object'' && typeof schema[field].schema === ''object''
                            && (schema[field].schema.type === ''number'' || schema[field].schema.type === ''datetime'')) {
                            switch (schema[field].schema.type) {
                                case ''number'':
                                    data.fields[field] = parseInt(fields[field]);
                                    break;

                                case ''datetime'':
                                    if (fields[field].match(/\d+[.-]\d+[.-]\d+T\d+:\d+:\d+/) !== null) {
                                        data.fields[field] = fields[field].replace(/\./g, ''-'');
                                    }
                                    else {
                                        delete data.fields[field];
                                    }
                                    break;
                            }
                        }
                    });
            }
            else {
                Zabbix.Log(4, ''[ Jira Webhook ] Failed to retrieve field schema.'');
            }
        }

        return data;
    },

    request: function (method, query, data) {
        [''url'', ''user'', ''password'', ''project_key'', ''issue_type''].forEach(function (field) {
            if (typeof Jira.params !== ''object'' || typeof Jira.params[field] === ''undefined''
                || Jira.params[field] === '''' ) {
                throw ''Required Jira param is not set: "'' + field + ''".'';
            }
        });

        var response,
            url = Jira.params.url + query,
            request = new CurlHttpRequest();

        request.AddHeader(''Content-Type: application/json'');
        request.AddHeader(''Authorization: Basic '' + btoa(Jira.params.user + '':'' + Jira.params.password));

        if (typeof Jira.HTTPProxy !== ''undefined'' && Jira.HTTPProxy !== '''') {
            request.SetProxy(Jira.HTTPProxy);
        }

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ Jira Webhook ] Sending request: '' + url + ((typeof data === ''string'') ? (''\n'' + data) : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            case ''put'':
                response = request.Put(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ Jira Webhook ] Received response with status code '' + request.Status() + ''\n'' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ Jira Webhook ] Failed to parse response received from Jira'');
                response = null;
            }
        }

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            if (response !== null && typeof response.errors !== ''undefined''
                && Object.keys(response.errors).length > 0) {
                message += '': '' + JSON.stringify(response.errors);
            }
            else if (response !== null && typeof response.errorMessages !== ''undefined''
                && Object.keys(response.errorMessages).length > 0) {
                message += '': '' + JSON.stringify(response.errorMessages);
            }

            throw message + '' Check debug log for more information.'';
        }

        return {
            status: request.Status(),
            response: response
        };
    },

    getSchema: function() {
        var result = Jira.request(''get'', ''issue/createmeta?expand=projects.issuetypes.fields&projectKeys='' +
                Jira.params.project_key + ''&issuetypeNames='' + Jira.params.issue_type);

        return result.response;
    },

    createIssue: function(summary, description, fields) {
        var data = {
            fields: {
                project: {
                    key: Jira.params.project_key
                },
                issuetype: {
                    name: Jira.params.issue_type
                },
                summary: summary,
                description: description
            }
        };

        if (Jira.labels && Jira.labels.length > 0) {
            data.fields.labels = Jira.labels;
        }
        var result = Jira.request(''post'', ''issue'', Jira.addCustomFields(data, fields));

        if (typeof result.response !== ''object'' || typeof result.response.key === ''undefined'') {
            throw ''Cannot create Jira issue. Check debug log for more information.'';
        }

        return result.response.key;
    },

    updateIssue: function(summary, fields, update) {
        var data = {fields: {}};

        if (summary) {
            data.fields.summary = summary;
        }

        Jira.request(''put'', ''issue/'' + Jira.params.issue_key, Jira.addCustomFields(data, fields));
        Jira.commentIssue(update);
    },

    commentIssue: function(update) {
        var data = {};

        if (typeof update === ''string'') {
            data.body = update;
            Jira.request(''post'', ''issue/'' + Jira.params.issue_key + ''/comment'', data);
        }
        else if (update.status === ''1'') {
            data.body = update.user + '' '' + update.action + ''.'';

            if (update.message) {
                data.body += ''\nMessage: {quote}'' + Jira.escapeMarkup(update.message) + ''{quote}'';
            }

            Jira.request(''post'', ''issue/'' + Jira.params.issue_key + ''/comment'', data);
        }
    }
};

try {
    var params = JSON.parse(value),
        fields = {},
        jira = {},
        update = {},
        result = {tags: {}},
        required_params = [''alert_subject'', ''summary'', ''event_recovery_value'', ''event_source'', ''event_value''];

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''jira_'')) {
                jira[key.substring(5)] = params[key];
            }
            else if (key.startsWith(''customfield_'')) {
                fields[key] = params[key];
            }
            else if (key.startsWith(''event_update_'')) {
                update[key.substring(13)] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key] === '''') {
                throw ''Parameter "'' + key + ''" can\''t be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'' && params.event_source === ''0'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_source !== ''0'' && params.event_recovery_value === ''0'') {
        throw ''Recovery operations are supported only for trigger-based actions.'';
    }

    Jira.setParams(jira);
    Jira.setProxy(params.HTTPProxy);
    Jira.setTags(params.event_tags_json);

    // Create issue for non trigger-based events.
    if (params.event_source !== ''0'' && params.event_recovery_value !== ''0'') {
        Jira.createIssue(params.alert_subject, params.alert_message);
    }
    // Create issue for trigger-based events.
    else if (params.event_value === ''1'' && update.status === ''0'' && !jira.issue_key.startsWith(jira.project_key)) {
        var key = Jira.createIssue(params.alert_subject,
            (Object.keys(fields).length ? params.trigger_description : params.alert_message), fields);


        result.tags.__zbx_jira_issuekey = key;
        result.tags.__zbx_jira_issuelink = params.jira_url +
            (params.jira_url.endsWith(''/'') ? '''' : ''/'') + ''browse/'' + key;
    }
    // Update created issue for trigger-based event.
    else {
        if (!jira.issue_key.startsWith(jira.project_key)) {
            throw ''Incorrect Issue key given: '' + jira.issue_key;
        }
        Jira.updateIssue(params.alert_subject, fields,
            ((params.event_value === ''0'' && !Object.keys(fields).length)
                ? params.alert_message : update));
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ Jira Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_jira_issuelink}','Jira: {EVENT.TAGS.__zbx_jira_issuekey}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('14','4','MS Teams','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var SEVERITY_COLORS = [
    ''#97AAB3'', // Not classified.
    ''#7499FF'', // Information.
    ''#FFC859'', // Warning.
    ''#FFA059'', // Average.
    ''#E97659'', // High.
    ''#E45959'', // Disaster.
    ''#009900'', // Resolved.
    ''#000000''  // Default.
];

try {
    var params = JSON.parse(value);

    if (typeof params.teams_endpoint !== ''string'' || params.teams_endpoint.trim() === '''') {
        throw ''Cannot get teams_endpoint'';
    }
    else if (!params.teams_endpoint.startsWith(''http'')) {
        throw ''Invalid MS Teams webhook URL: '' + params.teams_endpoint;
    }

    params.zabbix_url = (params.zabbix_url.endsWith(''/''))
        ? params.zabbix_url.slice(0, -1) : params.zabbix_url;

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: "'' + params.event_source + ''".\nMust be 0-3.'';
    }

    // Set "use_default_message" to true for non trigger-based events.
    if (params.event_source !== ''0'') {
        params.use_default_message = ''true'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
            && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: "'' + params.event_value + ''".\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'' && params.event_source === ''0'') {
        throw ''Incorrect "event_update_status" parameter given: "'' + params.event_update_status + ''".\nMust be 0 or 1.'';
    }

    if (params.event_value == 0) {
        params.event_nseverity = ''6'';
    }

    if (!SEVERITY_COLORS[params.event_nseverity]) {
        params.event_nseverity = ''7'';
    }

    var request = new CurlHttpRequest(),
        facts = [],
        body = {
            themeColor: SEVERITY_COLORS[params.event_nseverity].replace(''#'', ''''),
            summary: ''Zabbix'',
            sections: [
                {
                    markdown: ''false'',
                    activityTitle: params.alert_subject,
                    activitySubtitle: ''On '' + params.host_name + '' ['' + params.host_ip + '']'',
                    text: (params.use_default_message.toLowerCase() == ''true'')
                        ? params.alert_message
                        : params.trigger_description
                }
            ],
            potentialAction: [
                {
                    ''@type'': ''OpenUri'',
                    name: (params.event_source === ''0'')
                        ? ''Event Info''
                        : ''Zabbix Home'',
                    targets: [
                        {
                            os: ''default'',
                            uri: (params.event_source === ''0'')
                                ? params.zabbix_url + ''/tr_events.php?triggerid='' +
                                    params.trigger_id + ''&eventid='' + params.event_id
                                : params.zabbix_url
                        }
                    ]
                }
            ]
        };

    if (params.use_default_message.toLowerCase() !== ''true'') {
        // Problem message.
        if (params.event_value === ''1'' && params.event_update_status === ''0'') {
            facts.push({
                name: ''Event time'',
                value: params.event_time + '' '' + params.event_date
            });
        }
        // Update message.
        else if (params.event_update_status === ''1'') {
            body.sections[0].text = params.event_update_user + '' '' + params.event_update_action + ''.'';

            if (params.event_update_message) {
                body.sections[0].text += ''<br>Message:<br>'' + params.event_update_message;
            }

            facts.push({
                name: ''Event update time'',
                value: params.event_update_time + '' '' + params.event_update_date
            });
        }
        // Resolved message.
        else {
            facts.push({
                name: ''Recovery time'',
                value: params.event_recovery_time + '' '' + params.event_recovery_date
            });
        }

        if (params.event_severity && params.event_severity !== ''{EVENT.SEVERITY}'') {
            facts.push({
                name: ''Severity'',
                value: params.event_severity
            });
        }


        if (params.event_opdata && params.event_opdata !== ''{EVENT.OPDATA}'') {
            facts.push({
                name: ''Operational data'',
                value: params.event_opdata
            });
        }

        if (params.event_tags && params.event_tags !== ''{EVENT.TAGS}'') {
            facts.push({
                name: ''Event tags'',
                value: params.event_tags
            });
        }

        Object.keys(params)
            .forEach(function (key) {
                if (key.startsWith(''fact_'') && params[key] !== '''') {
                    facts.push({
                        name: key.substring(5),
                        value: params[key]
                    });
                }
                else if (key.startsWith(''openUri_'') && params[key] !== '''' && !params[key].startsWith(''{'')) {
                    body.potentialAction.push({
                        ''@type'': ''OpenUri'',
                        name: key.substring(8),
                        targets: [
                            {
                                os: ''default'',
                                uri: params[key]
                            }
                        ]
                    });
                }
            });
        body.sections[0].facts = facts;
    }

    body.sections[0].text = body.sections[0].text.replace(/(?:\r\n|\r|\n)/g, ''<br>'');

    request.AddHeader(''Content-Type: application/json'');

    if (typeof params.HTTPProxy === ''string'' && params.HTTPProxy !== '''') {
        request.SetProxy(params.HTTPProxy);
    }

    Zabbix.Log(4, ''[ MS Teams Webhook ] JSON: '' + JSON.stringify(body));

    var response = request.Post(params.teams_endpoint, JSON.stringify(body));

    Zabbix.Log(4, ''[ MS Teams Webhook ] Response: '' + response);

    if (response === ''1'') {
        return ''OK'';
    }
    else {
        Zabbix.Log(4, ''[ MS Teams Webhook ] FAILED with response: '' + response);
        throw response;
    }
}
catch (error) {
    Zabbix.Log(3, ''[ MS Teams Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','0','0','','','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('15','4','Redmine','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var Redmine = {
    params: {},

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        Redmine.params = params;
        if (typeof Redmine.params.url === ''string'') {
            if (!Redmine.params.url.endsWith(''/'')) {
                Redmine.params.url += ''/'';
            }
        }
    },

    addCustomFields: function (data, fields) {
        if (typeof fields === ''object'' && Object.keys(fields).length) {
            var schema = Redmine.getSchema();

            if (schema) {
                data.issue.custom_fields = [];

                Object.keys(fields)
                    .forEach(function(field) {
                        for (var idx in schema.custom_fields) {
                            if (schema.custom_fields[idx].id != field) {
                                continue;
                            }

                            var field_value;

                            switch (schema.custom_fields[idx].field_format) {
                                case ''string'':
                                    field_value = fields[field];
                                    break;

                                case ''int'':
                                    field_value = parseInt(fields[field]);
                                    break;

                                case ''float'':
                                    field_value = parseFloat(fields[field]);
                                    break;

                                case ''date'':
                                    if (fields[field].match(/^\d{4}[.-]\d{2}[.-]\d{2}$/)) {
                                        field_value = fields[field].replace(/\./g, ''-'');
                                    }
                                    break;
                            }

                            if (field_value !== undefined) {
                                data.issue.custom_fields.push({id: field, value: field_value});
                            }
                        }
                    });
            }
            else {
                Zabbix.Log(4, ''[ Redmine Webhook ] Failed to retrieve field schema.'');
            }
        }

        return data;
    },

    request: function (method, query, data) {
        [''url'', ''access_key''].forEach(function (field) {
            if (typeof Redmine.params !== ''object'' || typeof Redmine.params[field] === ''undefined''
                || Redmine.params[field] === '''' ) {
                throw ''Required param is not set: "'' + field + ''".'';
            }
        });

        var response,
            url = Redmine.params.url + query,
            request = new CurlHttpRequest();

        if (typeof Redmine.HTTPProxy === ''string'' && Redmine.HTTPProxy.trim() !== '''') {
            request.SetProxy(Redmine.HTTPProxy);
        }

        request.AddHeader(''Content-Type: application/json'');
        request.AddHeader(''X-Redmine-API-Key: '' + Redmine.params.access_key);

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ Redmine Webhook ] Sending request: '' +
            url + ((typeof data === ''string'') ? ('' '' + data) : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            case ''put'':
                response = request.Put(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ Redmine Webhook ] Received response with status code '' + request.Status() + '': '' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ Redmine Webhook ] Failed to parse response received from Redmine'');
                response = null;
            }
        }

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            if (response !== null && typeof response.errors !== ''undefined''
                && Object.keys(response.errors).length > 0) {
                message += '': '' + JSON.stringify(response.errors);
            }
            else if (response !== null && typeof response.errorMessages !== ''undefined''
                && Object.keys(response.errorMessages).length > 0) {
                message += '': '' + JSON.stringify(response.errorMessages);
            }

            throw message + '' Check debug log for more information.'';
        }

        return {
            status: request.Status(),
            response: response
        };
    },

    getProjectID: function(name) {
        var result = Redmine.request(''get'', ''projects.json''),
            project_id;

        if (result.response) {
            var projects = result.response.projects || [];

            for (var i in projects) {
                if (projects[i].name === name) {
                    project_id = projects[i].id;
                    break;
                }
            }
        }
        else {
            Zabbix.Log(4, ''[ Redmine Webhook ] Failed to retrieve project data.'');
        }

        if (typeof project_id === ''undefined'') {
            throw ''Cannot find project with name: '' + name;
        }

        return project_id;
    },

    getSchema: function() {
        var result = Redmine.request(''get'', ''custom_fields.json'');

        return result.response;
    },

    createIssue: function(subject, description, priority, fields) {
        var project_id = /^\d+$/.test(Redmine.params.project)
                ? Redmine.params.project
                : Redmine.getProjectID(Redmine.params.project),
            data = {
                issue: {
                    project_id: project_id,
                    tracker_id: Redmine.params.tracker_id,
                    subject: subject,
                    description: description
                }
            },
            result;

        if (priority) {
            data.issue.priority_id = priority;
        }

        result = Redmine.request(''post'', ''issues.json'', Redmine.addCustomFields(data, fields));

        if (typeof result.response !== ''object''
            || typeof result.response.issue.id === ''undefined''
            || result.status != 201) {
            throw ''Cannot create Redmine issue. Check debug log for more information.'';
        }

        return result.response.issue.id;
    },

    updateIssue: function(note, fields) {
        var data = {
            issue: {
                notes: note || ''''
            }
        };

        Redmine.request(''put'', ''issues/'' + Redmine.params.issue_key + ''.json'', Redmine.addCustomFields(data, fields));
    }
};

try {
    var params = JSON.parse(value),
        params_redmine = {},
        params_fields = {},
        params_update = {},
        result = {tags: {}},
        required_params = [
            ''alert_subject'', ''tracker_id'', ''project'',
            ''event_source'', ''event_value'',  ''event_update_status''
        ],
        severities = [
            {name: ''not_classified'', color: ''#97AAB3''},
            {name: ''information'', color: ''#7499FF''},
            {name: ''warning'', color: ''#FFC859''},
            {name: ''average'', color: ''#FFA059''},
            {name: ''high'', color: ''#E97659''},
            {name: ''disaster'', color: ''#E45959''},
            {name: ''resolved'', color: ''#009900''},
            {name: null, color: ''#000000''}
        ],
        priority;

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''redmine_'')) {
                params_redmine[key.substring(8)] = params[key];
            }
            else if (key.startsWith(''customfield_'')) {
                params_fields[key.substring(12)] = params[key];
            }
            else if (key.startsWith(''event_update_'')) {
                params_update[key.substring(13)] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key].trim() === '''') {
                throw ''Parameter "'' + key + ''" cannot be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_source === ''0'' && params.event_update_status !== ''0'' && params.event_update_status !== ''1'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_source !== ''0'' && params.event_value === ''0'') {
        throw ''Recovery operations are supported only for trigger-based actions.'';
    }

    if (params.event_source === ''0''
        && ((params.event_value === ''1'' && params.event_update_status === ''1'')
            || (params.event_value === ''0''
                && (params.event_update_status === ''0'' || params.event_update_status === ''1'')))
        && (isNaN(parseInt(params.redmine_issue_key)) || parseInt(params.redmine_issue_key) < 1 )) {
        throw ''Incorrect "redmine_issue_key" parameter given: '' + params.redmine_issue_key +
            ''\nMust be positive integer.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''7'';
    }

    if (params.event_value === ''0'') {
        params.event_nseverity = ''6'';
    }

    priority = params[''severity_'' + severities[params.event_nseverity].name];
    priority = priority && priority.trim() || severities[7].name;

    Redmine.setParams(params_redmine);
    Redmine.HTTPProxy = params.HTTPProxy;

    // Create issue for non trigger-based events.
    if (params.event_source !== ''0''
        && params.event_value !== ''0'') {
        Redmine.createIssue(params.alert_subject, params.alert_message, priority);
    }
    // Create issue for trigger-based events.
    else if (params.event_value === ''1'' && params_update.status === ''0'') {
        var issue_id = Redmine.createIssue(params.alert_subject,
            params.alert_subject + ''\n'' + params.alert_message + ''\n'' +
            params.zabbix_url + (params.zabbix_url.endsWith(''/'') ? '''' : ''/'') +
            ''tr_events.php?triggerid='' + params.trigger_id + ''&eventid='' + params.event_id + ''\n'',
            priority,
            params_fields);

        result.tags.__zbx_redmine_issue_id = issue_id;
        result.tags.__zbx_redmine_issuelink = params.redmine_url +
            (params.redmine_url.endsWith(''/'') ? '''' : ''/'') + ''issues/'' + issue_id;
    }
    // Update created issue for trigger-based event.
    else {
        Redmine.updateIssue(params.alert_subject + ''\n'' + params.alert_message, params_fields);
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ Redmine Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_redmine_issuelink}','Redmine: issue #{EVENT.TAGS.__zbx_redmine_issue_id}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('16','4','Telegram','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var Telegram = {
    token: null,
    to: null,
    message: null,
    proxy: null,
    parse_mode: null,

    sendMessage: function() {
        var params = {
            chat_id: Telegram.to,
            text: Telegram.message,
            disable_web_page_preview: true,
            disable_notification: false
        },
        data,
        response,
        request = new CurlHttpRequest(),
        url = ''https://api.telegram.org/bot'' + Telegram.token + ''/sendMessage'';

        if (Telegram.parse_mode !== null) {
            params[''parse_mode''] = Telegram.parse_mode;
        }

        if (Telegram.proxy) {
            request.SetProxy(Telegram.proxy);
        }

        request.AddHeader(''Content-Type: application/json'');
        data = JSON.stringify(params);

        // Remove replace() function if you want to see the exposed token in the log file.
        Zabbix.Log(4, ''[Telegram Webhook] URL: '' + url.replace(Telegram.token, ''<TOKEN>''));
        Zabbix.Log(4, ''[Telegram Webhook] params: '' + data);
        response = request.Post(url, data);
        Zabbix.Log(4, ''[Telegram Webhook] HTTP code: '' + request.Status());

        try {
            response = JSON.parse(response);
        }
        catch (error) {
            response = null;
        }

        if (request.Status() !== 200 || typeof response.ok !== ''boolean'' || response.ok !== true) {
            if (typeof response.description === ''string'') {
                throw response.description;
            }
            else {
                throw ''Unknown error. Check debug log for more information.''
            }
        }
    }
}

try {
    var params = JSON.parse(value);

    if (typeof params.Token === ''undefined'') {
        throw ''Incorrect value is given for parameter "Token": parameter is missing'';
    }

    Telegram.token = params.Token;

    if (params.HTTPProxy) {
        Telegram.proxy = params.HTTPProxy;
    } 

    if ([''Markdown'', ''HTML'', ''MarkdownV2''].indexOf(params.ParseMode) !== -1) {
        Telegram.parse_mode = params.ParseMode;
    }

    Telegram.to = params.To;
    Telegram.message = params.Subject + ''\n'' + params.Message;
    Telegram.sendMessage();

    return ''OK'';
}
catch (error) {
    Zabbix.Log(4, ''[Telegram Webhook] notification failed: '' + error);
    throw ''Sending failed: '' + error + ''.'';
}','10s','0','0','','','https://git.zabbix.com/projects/ZBX/repos/zabbix/browse/templates/media/telegram

1. Register bot: send "/newbot" to @BotFather and follow instructions
2. Copy and paste the obtained token into the "Token" field above
3. If you want to send personal notifications, you need to get chat id of the user you want to send messages to:
    3.1. Send "/getid" to "@myidbot" in Telegram messenger
    3.2. Copy returned chat id and save it in the "Telegram Webhook" media for the user
    3.3. Ask the user to send "/start" to your bot (Telegram bot won''t send anything to the user without it)
4. If you want to send group notifications, you need to get group id of the group you want to send messages to:
    4.1. Add "@myidbot" to your group
    4.2. Send "/getgroupid@myidbot" in your group
    4.3. Copy returned group id save it in the "Telegram Webhook" media for the user you created for  group notifications
    4.4. Send "/start@your_bot_name_here" in your group (Telegram bot won''t send anything to the group without it)');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('17','4','Zendesk','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var Zendesk = {
    params: {},

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        Zendesk.params = params;
        if (typeof Zendesk.params.url === ''string'') {
            if (!Zendesk.params.url.endsWith(''/'')) {
                Zendesk.params.url += ''/'';
            }
            Zendesk.params.url += ''api/v2/'';
        }
    },

    addCustomFields: function (data, fields) {
        if (typeof fields === ''object'' && Object.keys(fields).length) {
            var schema = Zendesk.getSchema(),
                arr = [],
                i,
                n;

            if (schema) {
                Object.keys(fields)
                    .forEach(function(field) {
                        for (i = 0, n = schema.ticket_fields.length; i < n; i++) {
                            if (schema.ticket_fields[i].id == field
                                && [''text'', ''integer'', ''date''].indexOf(schema.ticket_fields[i].type) !== -1){

                                switch (schema.ticket_fields[i].type) {
                                    case ''integer'':
                                        fields[field] = parseInt(fields[field]);
                                        break;
                                    case ''date'':
                                        if (fields[field].match(/^\d{4}[.-]\d{2}[.-]\d{2}$/) !== null) {
                                            fields[field] = fields[field].replace(/\./g, ''-'');
                                        }
                                        else {
                                            fields[field] = '''';
                                        }
                                        break;
                                }

                                arr.push({id: field, value: fields[field]});
                                break;
                            }
                        }
                    });

                if (arr.length) {
                    data.ticket[''custom_fields''] = arr;
                }
            }
            else {
                Zabbix.Log(4, ''[Zendesk Webhook] Failed to retrieve field schema.'');
            }
        }

        return data;
    },

    request: function (method, query, data) {
        [''url'', ''token'', ''type''].forEach(function (field) {
            if (typeof Zendesk.params !== ''object'' || typeof Zendesk.params[field] === ''undefined'') {
                throw ''Required Zendesk param is not set: '' + field + ''\n'' + Zendesk.params[field];
            }
        });

        var response,
            url = Zendesk.params.url + query,
            request = new CurlHttpRequest();

        if (typeof Zendesk.HTTPProxy === ''string'' && Zendesk.HTTPProxy.trim() !== '''') {
            request.SetProxy(Zendesk.HTTPProxy);
        }

        request.AddHeader(''Content-Type: application/json'');
        request.AddHeader(''Authorization: Basic '' + btoa(Zendesk.params.token));

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[Zendesk Webhook] Sending request: '' + url + ((typeof data === ''string'') ? ('' '' + data) : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            case ''put'':
                response = request.Put(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[Zendesk Webhook] Received response with status code '' + request.Status() + ''. '' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[Zendesk Webhook] Failed to parse response received from Zendesk.'');
            }
        }

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            if (response !== null && typeof response.error !== ''undefined''
                && Object.keys(response.error).length > 0) {
                message += '': '' + JSON.stringify(response.error);
            }
            else if (response !== null && typeof response.description !== ''undefined''
                && Object.keys(response.description).length > 0) {
                message += '': '' + JSON.stringify(response.description);
            }
            else {
                message += ''. '' + response;
            }
            throw message + ''. Check debug log for more information.'';
        }

        return {
            status: request.Status(),
            response: response
        };
    },

    getSchema: function() {
        var result = Zendesk.request(''get'', ''ticket_fields.json'');

        return result.response;
    },

    createIssue: function(data, fields) {
        var result = Zendesk.request(''post'', ''tickets.json'', Zendesk.addCustomFields(data, fields));

        if (typeof result.response !== ''object'' || typeof result.response.ticket.id === ''undefined''
            || result.status != 201) {
            throw ''Cannot create Zendesk issue. Check debug log for more information.'';
        }

        return result.response.ticket.id;
    },

    updateIssue: function(data, fields) {
        Zendesk.request(''put'', ''tickets/'' + Zendesk.params.issue_key + ''.json'', Zendesk.addCustomFields(data, fields));
    }
};

try {
    var params = JSON.parse(value),
        fields = {},
        zendesk = {},
        update = {},
        data = {},
        result = {tags: {}},
        required_params = [
            ''alert_subject'',
            ''alert_message'',
            ''event_id'',
            ''event_source'',
            ''event_value'',
            ''event_update_status''
        ],
        severities = [
            {name: ''not_classified'', color: ''#97AAB3''},
            {name: ''information'', color: ''#7499FF''},
            {name: ''warning'', color: ''#FFC859''},
            {name: ''average'', color: ''#FFA059''},
            {name: ''high'', color: ''#E97659''},
            {name: ''disaster'', color: ''#E45959''},
            {name: ''resolved'', color: ''#009900''},
            {name: ''default'', color: ''#000000''}
        ],
        priority;

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''zendesk_'')) {
                zendesk[key.substring(8)] = params[key];
            }
            else if (key.startsWith(''customfield_'')) {
                fields[key.substring(12)] = params[key];
            }
            else if (key.startsWith(''event_update_'')) {
                update[key.substring(13)] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key].trim() === '''') {
                throw ''Parameter '' + key + '' cannot be empty.'';
            }
        });

    // Possible values: question, incident, problems, task
    if ([''question'', ''incident'', ''problem'', ''task''].indexOf(params.zendesk_type) === -1) {
        throw ''Incorrect "zendesk_type" parameter given: '' + params.zendesk_type +
            ''\nMust be one of question, incident, problem, task.'';
    }

    // Possible values: 0 - Trigger, 1 - Discovery, 2 - Autoregistration, 3 - Internal.
    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    // Possible values: 1 for problem, 0 for recovering
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    // Possible values: 0 - Webhook was called because of problem/recovery event, 1 - Update operation.
    if (params.event_source === ''0'' && params.event_update_status !== ''0'' && params.event_update_status !== ''1'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_source !== ''0'' && params.event_value === ''0'') {
        throw ''Recovery operations are supported only for trigger-based actions.'';
    }

    // Zendesk_issue_key must be a positive integer if an update action is being performed.
    if (params.event_source === ''0'' && ((params.event_value === ''1'' && params.event_update_status === ''1'')
        || (params.event_value === ''0'' && (params.event_update_status === ''0'' || params.event_update_status === ''1'')))
        && (isNaN(parseInt(params.zendesk_issue_key)) || parseInt(params.zendesk_issue_key) < 1 )) {
        throw ''Incorrect "zendesk_issue_key" parameter given: '' + params.zendesk_issue_key +
            ''\nMust be positive integer.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''7'';
    }

    if (params.event_value === ''0'') {
        params.event_nseverity = ''6'';
    }

    priority = params[''severity_'' + severities[params.event_nseverity].name] || severities[7].name;

    Zendesk.setParams(zendesk);
    Zendesk.HTTPProxy = params.HTTPProxy;

    // Create issue for non trigger-based events.
    if (params.event_source !== ''0'' && params.event_value !== ''0'') {
        data = {
            ticket: {
                external_id: params.event_id,
                type: Zendesk.params.type,
                status: ''new'',
                subject: params.alert_subject,
                comment: {
                    body: params.alert_message,
                    public: ''false''
                },
                priority: priority,
                tags: params.event_tags
            }
        };

        Zendesk.createIssue(data, fields);
    }
    // Create issue for trigger-based events.
    else if (params.event_value === ''1'' && update.status === ''0'') {
        data = {
            ticket: {
                external_id: params.event_id,
                type: Zendesk.params.type,
                status: ''new'',
                subject: params.alert_subject,
                comment: {
                    body: params.zbxurl + (params.zbxurl.endsWith(''/'') ? '''' : ''/'') + ''tr_events.php?triggerid='' +
                        params.trigger_id + ''&eventid='' + params.event_id + ''\n'' + params.alert_message,
                    public: ''false''
                },
                priority: priority,
                tags: params.event_tags
            }
        };
        var key = Zendesk.createIssue(data, fields);

        result.tags.__zbx_zdk_issuekey = key;
        result.tags.__zbx_zdk_issuelink = params.zendesk_url +
            (params.zendesk_url.endsWith(''/'') ? '''' : ''/'') + ''agent/tickets/'' + key;
    }
    // Update created issue for trigger-based event.
    else {
        data = {
            ticket: {
                type: Zendesk.params.type,
                subject: params.alert_subject,
                comment: {
                    body: params.alert_message,
                    public: ''false''
                }
            }
        };

        Zendesk.updateIssue(data, fields);
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[Zendesk Webhook] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_zdk_issuelink}','Zendesk: {EVENT.TAGS.__zbx_zdk_issuekey}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('18','4','ServiceNow','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var ServiceNow = {
    params: {},

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        ServiceNow.params = params;
        if (typeof ServiceNow.params.url === ''string'') {
            if (!ServiceNow.params.url.endsWith(''/'')) {
                ServiceNow.params.url += ''/'';
            }

            ServiceNow.params.url += ''api/now/table/incident'';
        }
    },

    setProxy: function (HTTPProxy) {
        ServiceNow.HTTPProxy = HTTPProxy;
    },

    setFields: function (data, fields) {
        if (typeof fields === ''object'' && Object.keys(fields).length) {
            Object.keys(fields)
                .forEach(function(field) {
                    data[field] = (fields[field].match(/^\d{4}\.\d{2}\.\d{2}$/) !== null)
                        ? fields[field].replace(/\./g, ''-'')
                        : fields[field];
                });
        }
    },

    request: function (method, data) {
        [''url'', ''user'', ''password''].forEach(function (field) {
            if (typeof ServiceNow.params !== ''object'' || typeof ServiceNow.params[field] === ''undefined''
                || ServiceNow.params[field] === '''' ) {
                throw ''Required ServiceNow param is not set: "'' + field + ''".'';
            }
        });

        var response,
            url = ServiceNow.params.url,
            request = new CurlHttpRequest();

        request.AddHeader(''Content-Type: application/json'');
        request.AddHeader(''Authorization: Basic '' + btoa(ServiceNow.params.user + '':'' + ServiceNow.params.password));

        if (typeof ServiceNow.HTTPProxy !== ''undefined'' && ServiceNow.HTTPProxy !== '''') {
            request.SetProxy(ServiceNow.HTTPProxy);
        }

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ ServiceNow Webhook ] Sending request: '' + url + ((typeof data === ''string'')
            ? (''\n'' + data)
            : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            case ''put'':
                response = request.Put(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ ServiceNow Webhook ] Received response with status code '' +
            request.Status() + ''\n'' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ ServiceNow Webhook ] Failed to parse response received from ServiceNow'');
                response = null;
            }
        }

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            if (response !== null && typeof response.error.message !== ''undefined''
                && Object.keys(response.error).length > 0) {
                message += '': '' + JSON.stringify(response.error.message);
            }

            throw message + '' Check debug log for more information.'';
        }
        else if (typeof response.result !== ''object'' || typeof response.result.sys_id === ''undefined'') {
            throw ''Cannot create ServiceNow incident. Check debug log for more information.'';
        }

        return response.result;
    }
};

try {
    var params = JSON.parse(value),
        fields = {},
        servicenow = {},
        data = {},
        result = {tags: {}},
        required_params = [
            ''alert_subject'', ''alert_message'', ''event_source'', ''event_value'',
            ''event_update_status'', ''event_recovery_value'', ''event_nseverity''
        ],
        severities = [
            {name: ''not_classified'', color: ''#97AAB3''},
            {name: ''information'', color: ''#7499FF''},
            {name: ''warning'', color: ''#FFC859''},
            {name: ''average'', color: ''#FFA059''},
            {name: ''high'', color: ''#E97659''},
            {name: ''disaster'', color: ''#E45959''},
            {name: ''resolved'', color: ''#009900''},
            {name: ''default'', color: ''#000000''}
        ],
        method = ''post'',
        process_tags = true;

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''servicenow_'')) {
                servicenow[key.substring(11)] = params[key];
            }
            else if (key.startsWith(''u_'')) {
                fields[key] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key] === '''') {
                throw ''Parameter "'' + key + ''" can\''t be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''7'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'' && params.event_source === ''0'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_source !== ''0'' && params.event_recovery_value === ''0'') {
        throw ''Recovery operations are supported only for trigger-based actions.'';
    }

    data.short_description = params.alert_subject;
    data.description = params.alert_message;
    data.comments = params.alert_message;

    if (typeof params[''urgency_for_'' + severities[params.event_nseverity].name] !== ''undefined'') {
        data.urgency = params[''urgency_for_'' + severities[params.event_nseverity].name];
    }

    ServiceNow.setParams(servicenow);
    ServiceNow.setProxy(params.HTTPProxy);
    ServiceNow.setFields(data, fields);

    if (params.event_source === ''0'' && (params.event_value === ''0'' || params.event_update_status === ''1'')) {
        process_tags = false;
        method = ''put'';
        delete data.description;
        delete data.urgency;
        ServiceNow.params.url += ''/'' + params.servicenow_sys_id;
    }

    var response = ServiceNow.request(method, data);

    if (process_tags) {
        result.tags.__zbx_servicenow_sys_id = response.sys_id;
        result.tags.__zbx_servicenow_link = params.servicenow_url +
            (params.servicenow_url.endsWith(''/'') ? '''' : ''/'') + ''incident.do?sys_id='' + response.sys_id;
        result.tags.__zbx_servicenow_number = response.number;
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ ServiceNow Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_servicenow_link}','ServiceNow: {EVENT.TAGS.__zbx_servicenow_number}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('19','4','Zammad','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var Zammad = {
    params: {},

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        Zammad.params = params;
        if (typeof Zammad.params.url === ''string'') {
            if (!Zammad.params.url.endsWith(''/'')) {
                Zammad.params.url += ''/'';
            }
        }
    },

    request: function (method, query, data) {
        [''url'', ''access_token''].forEach(function (field) {
            if (typeof Zammad.params !== ''object'' || typeof Zammad.params[field] === ''undefined''
                || Zammad.params[field] === '''' ) {
                throw ''Required param is not set: "'' + field + ''".'';
            }
        });

        var response,
            url = Zammad.params.url + query,
            request = new CurlHttpRequest();

        if (typeof Zammad.HTTPProxy === ''string'' && Zammad.HTTPProxy.trim() !== '''') {
            request.SetProxy(Zammad.HTTPProxy);
        }

        request.AddHeader(''Content-Type: application/json'');
        request.AddHeader(''Authorization: Token token='' + Zammad.params.access_token);

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ Zammad Webhook ] Sending request: '' +
            url + ((typeof data === ''string'') ? ('' '' + data) : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            case ''put'':
                response = request.Put(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ Zammad Webhook ] Received response with status code '' + request.Status() + '': '' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ Zammad Webhook ] Failed to parse response received from Zammad'');
                response = null;
            }
        }

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            if (response !== null && typeof response.errors !== ''undefined''
                && Object.keys(response.errors).length > 0) {
                message += '': '' + JSON.stringify(response.errors);
            }
            else if (response !== null && typeof response.errorMessages !== ''undefined''
                && Object.keys(response.errorMessages).length > 0) {
                message += '': '' + JSON.stringify(response.errorMessages);
            }

            throw message + '' Check debug log for more information.'';
        }

        return {
            status: request.Status(),
            response: response
        };
    },

    setTicketTags: function(tags, ticket_id) {
        try {
            var tags_json = JSON.parse(tags),
                result;

            for (var i in tags_json) {
                result = Zammad.request(''get'',
                    ''/api/v1/tags/add?object=Ticket&o_id='' + ticket_id +
                    ''&item='' + tags_json[i].tag);

                if (typeof result.response !== ''object''
                    || result.status != 200) {
                    Zabbix.Log(4, ''[ Zammad Webhook ] Cannot add ticket tag:'' + tags_json[i].tag);
                }
            }
        }
        catch (error) {
            Zabbix.Log(4, ''[ Zammad Webhook ] Failed to add ticket tags:'' + error);
        }

        return;
    },

    createTicket: function(subject, message, priority) {
        var data = {
                title: subject,
                group: ''Users'',
                article: {
                    subject: subject,
                    body: message,
                    type: ''note'',
                    internal: false
                },
                customer: Zammad.params.customer
            },
            result;

        if (priority) {
            data.priority_id = priority;
        }

        result = Zammad.request(''post'', ''api/v1/tickets'', data);

        if (typeof result.response !== ''object''
            || typeof result.response.id === ''undefined''
            || result.status != 201) {
            throw ''Cannot create Zammad ticket. Check debug log for more information.'';
        }

        return result.response.id;
    },

    updateTicket: function(subject, message) {
        var data = {
            ticket_id: Zammad.params.ticket_id,
            subject: subject,
            body: message || '''',
            type: ''note'',
            internal: false
        };

        result = Zammad.request(''post'', ''api/v1/ticket_articles'', data);

        if (typeof result.response !== ''object''
            || typeof result.response.id === ''undefined''
            || result.status != 201) {
            throw ''Cannot update Zammad ticket. Check debug log for more information.'';
        }
    }
};

try {
    var params = JSON.parse(value),
        params_zammad = {},
        params_update = {},
        result = {tags: {}},
        required_params = [
            ''alert_subject'', ''customer'',
            ''event_source'', ''event_value'',
            ''event_update_status''
        ],
        severities = [
            {name: ''not_classified'', color: ''#97AAB3''},
            {name: ''information'', color: ''#7499FF''},
            {name: ''warning'', color: ''#FFC859''},
            {name: ''average'', color: ''#FFA059''},
            {name: ''high'', color: ''#E97659''},
            {name: ''disaster'', color: ''#E45959''},
            {name: ''resolved'', color: ''#009900''},
            {name: null, color: ''#000000''}
        ],
        priority;

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''zammad_'')) {
                params_zammad[key.substring(7)] = params[key].trim();
            }
            else if (key.startsWith(''event_update_'')) {
                params_update[key.substring(13)] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key].trim() === '''') {
                throw ''Parameter "'' + key + ''" cannot be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_source === ''0'' && params.event_update_status !== ''0'' && params.event_update_status !== ''1'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_source !== ''0'' && params.event_value === ''0'') {
        throw ''Recovery operations are supported only for trigger-based actions.'';
    }

    if (params.event_source === ''0''
        && ((params.event_value === ''1'' && params.event_update_status === ''1'')
            || (params.event_value === ''0''
                && (params.event_update_status === ''0'' || params.event_update_status === ''1'')))
        && (isNaN(parseInt(params.zammad_ticket_id)) || parseInt(params.zammad_ticket_id) < 1 )) {
        throw ''Incorrect "zammad_ticket_id" parameter given: '' + params.zammad_ticket_id +
            ''\nMust be positive integer.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''7'';
    }

    if (params.event_value === ''0'') {
        params.event_nseverity = ''6'';
    }

    priority = params[''severity_'' + severities[params.event_nseverity].name];
    priority = priority && priority.trim() || severities[7].name;

    Zammad.setParams(params_zammad);
    Zammad.HTTPProxy = params.HTTPProxy;

    // Create ticket for non trigger-based events.
    if (params.event_source !== ''0''
        && params.event_value !== ''0'') {
        Zammad.createTicket(params.alert_subject, params.alert_message, priority, params.event_tags);
    }
    // Create ticket for trigger-based events.
    else if (params.event_value === ''1'' && params_update.status === ''0'') {
        var ticket_id = Zammad.createTicket(params.alert_subject,
            params.alert_subject + ''\n'' + params.alert_message + ''\n'' +
            params.zabbix_url + (params.zabbix_url.endsWith(''/'') ? '''' : ''/'') +
            ''tr_events.php?triggerid='' + params.trigger_id + ''&eventid='' + params.event_id + ''\n'',
            priority);

        result.tags.__zbx_zammad_ticket_id = ticket_id;
        result.tags.__zbx_zammad_ticketlink = params.zammad_url +
            (params.zammad_url.endsWith(''/'') ? '''' : ''/'') + ''#ticket/zoom/'' + ticket_id;

        if (Zammad.params.enable_tags.toLowerCase() === ''true'') {
            Zammad.setTicketTags(params.event_tags, ticket_id);
        }
    }
    // Update created ticket for trigger-based event.
    else {
        Zammad.updateTicket(params.alert_subject, params.alert_message);
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ Zammad Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_zammad_ticketlink}','Zammad: ticket #{EVENT.TAGS.__zbx_zammad_ticket_id}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('20','4','Jira ServiceDesk','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var Jira = {
    params: {},
    schema: {},

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        Jira.params = params;
        if (typeof Jira.params.url === ''string'') {
            if (!Jira.params.url.endsWith(''/'')) {
                Jira.params.url += ''/'';
            }

            Jira.params.url += ''rest/servicedeskapi/latest/'';
        }
    },

    setProxy: function (HTTPProxy) {
        Jira.HTTPProxy = HTTPProxy;
    },

    setTags: function(event_tags_json) {
        if (!Jira.schema) {
            Zabbix.Log(4, ''[ Jira Service Desk Webhook ] Cannot add labels because failed to retrieve field schema.'');

            return;
        }

        var block = Jira.schema.requestTypeFields.filter(function(object) {
            return object.fieldId == ''labels'';
        });

        if (block[0] && typeof event_tags_json !== ''undefined'' && event_tags_json !== ''''
            && event_tags_json !== ''{EVENT.TAGSJSON}'') {
            try {
                var tags = JSON.parse(event_tags_json),
                    label;

                Jira.labels = [];

                tags.forEach(function (tag) {
                    if (typeof tag.tag !== ''undefined'' && typeof tag.value !== ''undefined'' ) {
                        label = (tag.tag + (tag.value ? ('':'' + tag.value) : '''')).replace(/\s/g, ''_'');
                        if (label.length < 255) {
                            Jira.labels.push(label);
                        }
                    }
                });
            }
            catch (error) {
                // Code is not missing here.
            }
        }
    },

    addCustomFields: function (data, fields) {
        if (typeof fields === ''object'' && Object.keys(fields).length) {
            if (Jira.schema) {
                Object.keys(fields)
                    .forEach(function(field) {
                        data.requestFieldValues[field] = fields[field];

                        var block = Jira.schema.requestTypeFields.filter(function(object) {
                            return object.fieldId == field;
                        });

                        if (typeof block[0] === ''object'' && typeof block[0].jiraSchema === ''object''
                            && (block[0].jiraSchema.type === ''number'' || block[0].jiraSchema.type === ''datetime'')) {
                            switch (block[0].jiraSchema.type) {
                                case ''number'':
                                    data.requestFieldValues[field] = parseInt(fields[field]);
                                    break;

                                case ''datetime'':
                                    if (fields[field].match(/\d+[.-]\d+[.-]\d+T\d+:\d+:\d+/) !== null) {
                                        data.requestFieldValues[field] = fields[field].replace(/\./g, ''-'');
                                    }
                                    else {
                                        delete data.requestFieldValues[field];
                                    }
                                    break;
                            }
                        }
                    });
            }
            else {
                Zabbix.Log(4, ''[ Jira Service Desk Webhook ] Cannot add custom fields'' +
                    ''because failed to retrieve field schema.'');
            }
        }

        return data;
    },

    request: function (method, query, data) {
        [''url'', ''user'', ''password'', ''servicedesk_id'', ''request_type_id''].forEach(function (field) {
            if (typeof Jira.params !== ''object'' || typeof Jira.params[field] === ''undefined''
                || Jira.params[field] === '''' ) {
                throw ''Required Jira param is not set: "'' + field + ''".'';
            }
        });

        var response,
            url = Jira.params.url + query,
            request = new CurlHttpRequest();

        request.AddHeader(''Content-Type: application/json'');
        request.AddHeader(''Authorization: Basic '' + btoa(Jira.params.user + '':'' + Jira.params.password));
        request.AddHeader(''X-ExperimentalApi: opt-in'');

        if (typeof Jira.HTTPProxy !== ''undefined'' && Jira.HTTPProxy !== '''') {
            request.SetProxy(Jira.HTTPProxy);
        }

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ Jira Service Desk Webhook ] Sending request: '' + url +
            ((typeof data === ''string'') ? (''\n'' + data) : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            case ''put'':
                response = request.Put(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ Jira Service Desk Webhook ] Received response with status code '' +
            request.Status() + ''\n'' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ Jira Service Desk Webhook ] Failed to parse response received from Jira'');
                response = null;
            }
        }

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            if (response !== null && typeof response.errors !== ''undefined''
                && Object.keys(response.errors).length > 0) {
                message += '': '' + JSON.stringify(response.errors);
            }
            else if (response !== null && typeof response.errorMessage !== ''undefined''
                && Object.keys(response.errorMessage).length > 0) {
                message += '': '' + JSON.stringify(response.errorMessage);
            }

            throw message + '' Check debug log for more information.'';
        }

        return {
            status: request.Status(),
            response: response
        };
    },

    getSchema: function() {
        var result = Jira.request(''get'', ''servicedesk/'' + Jira.params.servicedesk_id + ''/requesttype/'' +
            Jira.params.request_type_id + ''/field'');

        if (typeof Jira.schema !== ''object'' && typeof Jira.schema.requestTypeFields !== ''object'') {
            Jira.schema = null;
        }
        else {
            Jira.schema = result.response;
        }
    },

    createRequest: function(summary, description, fields) {
        var data = {
            serviceDeskId: Jira.params.servicedesk_id,
            requestTypeId: Jira.params.request_type_id,
            requestFieldValues: {
                summary: summary,
                description: description
            }
        };

        if (Jira.labels && Jira.labels.length > 0) {
            data.requestFieldValues.labels = Jira.labels;
        }
        var result = Jira.request(''post'', ''request'', Jira.addCustomFields(data, fields));

        if (typeof result.response !== ''object'' || typeof result.response.issueKey === ''undefined'') {
            throw ''Cannot create Jira request. Check debug log for more information.'';
        }

        return result.response.issueKey;
    }
};

try {
    var params = JSON.parse(value),
        fields = {},
        jira = {},
        comment = {public: true},
        result = {tags: {}},
        required_params = [
            ''alert_subject'', ''alert_message'', ''event_source'', ''event_value'',
            ''event_update_status'', ''event_recovery_value''
        ];

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''jira_'')) {
                jira[key.substring(5)] = params[key];
            }
            else if (key.startsWith(''customfield_'')) {
                fields[key] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key] === '''') {
                throw ''Parameter "'' + key + ''" cannot be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'' && params.event_source === ''0'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_source !== ''0'' && params.event_recovery_value === ''0'') {
        throw ''Recovery operations are supported only for trigger-based actions.'';
    }

    Jira.setParams(jira);
    Jira.setProxy(params.HTTPProxy);
    Jira.getSchema();
    Jira.setTags(params.event_tags_json);

    // Create request for non trigger-based events.
    if (params.event_source !== ''0'' && params.event_recovery_value !== ''0'') {
        Jira.createRequest(params.alert_subject, params.alert_message);
    }
    // Create request for trigger-based events.
    else if (params.event_value === ''1'' && params.event_update_status === ''0''
        && jira.request_key === ''{EVENT.TAGS.__zbx_jira_requestkey}'') {
        var key = Jira.createRequest(params.alert_subject, params.alert_message, fields);

        result.tags.__zbx_jira_requestkey = key;
        result.tags.__zbx_jira_requestlink = params.jira_url +
            (params.jira_url.endsWith(''/'') ? '''' : ''/'') + ''browse/'' + key;
    }
    // Comment created request for trigger-based event.
    else {
        if (jira.request_key === ''{EVENT.TAGS.__zbx_jira_requestkey}'' || jira.request_key.trim() === '''') {
            throw ''Incorrect Request key given: '' + jira.request_key;
        }
        comment.body = params.alert_message;
        Jira.request(''post'', ''request/'' + Jira.params.request_key + ''/comment'', comment);
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ Jira Service Desk Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_jira_requestlink}','Jira ServiceDesk: {EVENT.TAGS.__zbx_jira_requestkey}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('21','4','OTRS','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var OTRS = {
    params: {},
    entrypoint: ''nph-genericinterface.pl/Webservice/ZabbixTicketConnector/Ticket'',

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        OTRS.params = params;
        if (typeof OTRS.params.url === ''string'') {
            if (!OTRS.params.url.endsWith(''/'')) {
                OTRS.params.url += ''/'';
            }
        }
    },

    addDynamicFields: function (data, fields) {
        if (typeof fields === ''object'' && Object.keys(fields).length) {
            data.DynamicField = [];

            Object.keys(fields)
                .forEach(function(field) {
                    if (field !== undefined) {
                        if (fields[field].match(/^\d{4}[.-]\d{2}[.-]\d{2}$/)) {
                            fields[field] = fields[field].replace(/\./g, ''-'');
                        }

                        data.DynamicField.push({Name: field, Value: fields[field]});
                    }
                });
        }

        return data;
    },

    request: function (method, query, data) {
        [''url'', ''auth_user'', ''auth_password'', ''queue'',
            ''customer'', ''ticket_state'', ''default_priority_id'', ''time_unit''].forEach(function (field) {
            if (typeof OTRS.params !== ''object'' || typeof OTRS.params[field] === ''undefined''
                || OTRS.params[field] === '''' ) {
                throw ''Required param is not set: "'' + field + ''".'';
            }
        });

        var response,
            request = new CurlHttpRequest(),
            url = OTRS.params.url + query +
                ''?UserLogin='' + encodeURIComponent(OTRS.params.auth_user) +
                ''&Password='' + encodeURIComponent(OTRS.params.auth_password);

        if (typeof OTRS.HTTPProxy !== ''undefined'' && OTRS.HTTPProxy.trim() !== '''') {
            request.SetProxy(OTRS.HTTPProxy);
        }

        request.AddHeader(''Content-Type: application/json'');

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ OTRS Webhook ] Sending request: '' +
            url + ((typeof data === ''string'') ? ('' '' + data) : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            case ''put'':
                response = request.Put(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ OTRS Webhook ] Received response with status code '' + request.Status() + '': '' + response);

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            message += '': '' + response;
            throw message + '' Check debug log for more information.'';
        }

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ OTRS Webhook ] Failed to parse response received from OTRS'');
                response = null;
            }
        }

        if (typeof response.Error !== ''undefined''
            && Object.keys(response.Error).length > 0) {
            message = ''Request failed: '' + JSON.stringify(response.Error);
        }


        return {
            status: request.Status(),
            response: response
        };
    },

    createTicket: function(subject, message, priority, fields) {
        var result,
            data = {
                Ticket: {
                    Title: subject,
                    Queue: OTRS.params.queue,
                    State: OTRS.params.ticket_state,
                    PriorityID: priority || OTRS.params.default_priority_id,
                    CustomerUser: OTRS.params.customer
                },
                Article: {
                    Subject: subject,
                    Body: message,
                    TimeUnit: OTRS.params.time_unit,
                    ContentType: ''text/plain; charset=utf8''
                }
            };

        result = OTRS.request(''post'', OTRS.entrypoint, OTRS.addDynamicFields(data, fields));

        if (typeof result.response !== ''object''
            || typeof result.response.TicketID === ''undefined''
            || result.status != 200) {
            throw ''Cannot create OTRS ticket. Check debug log for more information.'';
        }

        return result.response.TicketID;
    },

    updateTicket: function(subject, message) {
        var result,
            data = {
                Article: {
                    Subject: subject,
                    Body: message || '''',
                    TimeUnit: OTRS.params.time_unit,
                    ContentType: ''text/plain; charset=utf8''
                }
            };

        result = OTRS.request(''put'', OTRS.entrypoint + ''/'' + encodeURIComponent(OTRS.params.ticket_id), data);

        if (typeof result.response !== ''object''
            || typeof result.response.TicketID === ''undefined''
            || result.status != 200) {
            throw ''Cannot update OTRS ticket. Check debug log for more information.'';
        }
    }
};

try {
    var params = JSON.parse(value),
        params_otrs = {},
        params_fields = {},
        params_update = {},
        result = {tags: {}},
        required_params = [
            ''alert_subject'', ''event_source'',
            ''event_value'',  ''event_update_status''
        ],
        severities = [
            {name: ''not_classified'', color: ''#97AAB3''},
            {name: ''information'', color: ''#7499FF''},
            {name: ''warning'', color: ''#FFC859''},
            {name: ''average'', color: ''#FFA059''},
            {name: ''high'', color: ''#E97659''},
            {name: ''disaster'', color: ''#E45959''},
            {name: ''resolved'', color: ''#009900''},
            {name: null, color: ''#000000''}
        ],
        priority;

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''otrs_'')) {
                params_otrs[key.substring(5)] = params[key];
            }
            else if (key.startsWith(''dynamicfield_'')) {
                params_fields[key.substring(13)] = params[key];
            }
            else if (key.startsWith(''event_update_'')) {
                params_update[key.substring(13)] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key].trim() === '''') {
                throw ''Parameter "'' + key + ''" cannot be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_source === ''0'' && params.event_update_status !== ''0'' && params.event_update_status !== ''1'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_source !== ''0'' && params.event_value === ''0'') {
        throw ''Recovery operations are supported only for trigger-based actions.'';
    }

    if (params.event_source === ''0''
        && ((params.event_value === ''1'' && params.event_update_status === ''1'')
            || (params.event_value === ''0''
                && (params.event_update_status === ''0'' || params.event_update_status === ''1'')))
        && (isNaN(parseInt(params.otrs_ticket_id)) || parseInt(params.otrs_ticket_id) < 1 )) {
        throw ''Incorrect "otrs_ticket_id" parameter given: '' + params.otrs_ticket_id +
            ''\nMust be positive integer.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''7'';
    }

    if (params.event_value === ''0'') {
        params.event_nseverity = ''6'';
    }

    priority = params[''severity_'' + severities[params.event_nseverity].name];
    priority = priority && priority.trim() || severities[7].name;

    OTRS.setParams(params_otrs);
    OTRS.HTTPProxy = params.HTTPProxy;

    // Create ticket for non trigger-based events.
    if (params.event_source !== ''0''
        && params.event_value !== ''0'') {
        OTRS.createTicket(params.alert_subject, params.alert_message, priority);
    }
    // Create ticket for trigger-based events.
    else if (params.event_value === ''1'' && params_update.status === ''0'') {
        var ticket_id = OTRS.createTicket(params.alert_subject,
            params.alert_subject + ''\n'' + params.alert_message + ''\n'' +
            params.zabbix_url + (params.zabbix_url.endsWith(''/'') ? '''' : ''/'') +
            ''tr_events.php?triggerid='' + params.trigger_id + ''&eventid='' + params.event_id + ''\n'',
            priority,
            params_fields);

        result.tags.__zbx_otrs_ticket_id = ticket_id;
        result.tags.__zbx_otrs_ticketlink = params.otrs_url +
            (params.otrs_url.endsWith(''/'') ? '''' : ''/'') + ''index.pl?Action=AgentTicketZoom;TicketID='' + ticket_id;
    }
    // Update created ticket for trigger-based event.
    else {
        OTRS.updateTicket(params.alert_subject, params.alert_message);
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ OTRS Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_otrs_ticketlink}','OTRS: ticket #{EVENT.TAGS.__zbx_otrs_ticket_id}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('22','4','iLert','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','try {
    var result = { tags: {} },
        params = JSON.parse(value),
        req = new CurlHttpRequest(),
        resp = '''';

    if (typeof params.HTTPProxy === ''string'' && params.HTTPProxy.trim() !== '''') {
        req.SetProxy(params.HTTPProxy);
    }
    var alertSourceKey = params[''.ILERT.ALERT.SOURCE.KEY''];
    if (!alertSourceKey || (typeof alertSourceKey === ''string'' && alertSourceKey.trim() === '''')) {
        throw ''incorrect value for variable "ILERT.ALERT.SOURCE.KEY". The value must be a non-empty string.'';
    }
    delete params[''.ILERT.ALERT.SOURCE.KEY''];
    
    var ilertApiBaseURL = "https://api.ilert.com";
    var reqURL = encodeURI(ilertApiBaseURL + "/api/v1/events/zabbix-mt/" + alertSourceKey)

    var incidentKey = "zabbix-" + params[''EVENT.ID''];
    var incidentViewURL = ilertApiBaseURL + "/api/v1/incidents/resolve-ik/" + alertSourceKey + "/" + incidentKey;

    req.AddHeader(''Accept: application/json'');
    req.AddHeader(''Content-Type: application/json'');

    Zabbix.Log(4, ''[iLert Webhook] Sending request:'' + JSON.stringify(params));
    resp = req.Post(reqURL, JSON.stringify(params));
    Zabbix.Log(4, ''[iLert Webhook] Receiving response:'' + resp);

    try {
        resp = JSON.parse(resp);
    }
    catch (error) {
        throw ''incorrect response. iLert returned a non-JSON object.'';
    }

    if (req.Status() == 200) {
        result.tags.__ilert_incident_url = incidentViewURL;
        return JSON.stringify(result);
    }

    if (req.Status() == 400 && typeof resp === ''object'' && typeof resp.code === ''string'') {
        if (resp.code === ''NO_OPEN_INCIDENT_WITH_KEY'') {
          return JSON.stringify(result);
        }
        if (resp.code === ''INCIDENT_ALREADY_ACCEPTED'') {
          result.tags.__ilert_incident_url = incidentViewURL;
          return JSON.stringify(result);
        }
    }

    if (typeof resp === ''object'' && typeof resp.message === ''string'') {
        throw resp.message;
    }
    else {
        throw ''Unknown error.'';
    }
}
catch (error) {
    Zabbix.Log(3, ''[iLert Webhook] Notification failed : '' + error);
    throw ''iLert notification failed : '' + error;
}','30s','1','1','{EVENT.TAGS.__ilert_incident_url}','iLert incident','Please refer to https://docs.ilert.com/integrations/zabbix/native 
  
Set global macro {$ZABBIX.URL} with your Zabbix server URL.
Add a dedicated user with the media type "iLert". You can also rewrite the incident summary via ".ILERT.INCIDENT.SUMMARY" parameter or leave it empty to use the standard pattern.');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('23','4','SolarWinds Service Desk','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var SolarWinds = {
    params: {},

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        SolarWinds.params = params;
        SolarWinds.params.endpoint = ''https://api.samanage.com/'';
    },

    setProxy: function (HTTPProxy) {
        SolarWinds.HTTPProxy = HTTPProxy;
    },

    addCustomFields: function (data, fields) {
        if (typeof data.incident === ''object'' && typeof fields === ''object'' && Object.keys(fields).length) {
            if (typeof fields.sw_fields === ''object'' && Object.keys(fields.sw_fields).length) {
                Object.keys(fields.sw_fields)
                    .forEach(function(field) {
                        try {
                            data.incident[field] = JSON.parse(fields.sw_fields[field]);
                        }
                        catch (error) {
                            data.incident[field] = fields.sw_fields[field];
                        }
                    });
            }

            if (typeof fields.sw_customfields === ''object'' && Object.keys(fields.sw_customfields).length) {
                data.incident.custom_fields_values = {custom_fields_value: []};
                Object.keys(fields.sw_customfields)
                    .forEach(function(field) {
                        data.incident.custom_fields_values.custom_fields_value.push({
                            name: field,
                            value: fields.sw_customfields[field]
                        });
                    });
            }
        }

        return data;
    },

    request: function (method, query, data) {
        [''token''].forEach(function (field) {
            if (typeof SolarWinds.params !== ''object'' || typeof SolarWinds.params[field] === ''undefined''
                || SolarWinds.params[field] === '''' ) {
                throw ''Required SolarWinds param is not set: "'' + field + ''".'';
            }
        });

        var response,
            url = SolarWinds.params.endpoint + query,
            request = new CurlHttpRequest();

        request.AddHeader(''Content-Type: application/json'');
        request.AddHeader(''X-Samanage-Authorization: Bearer '' + SolarWinds.params.token);
        request.AddHeader(''Accept: application/vnd.samanage.v2.1+json'');

        if (typeof SolarWinds.HTTPProxy !== ''undefined'' && SolarWinds.HTTPProxy !== '''') {
            request.SetProxy(SolarWinds.HTTPProxy);
        }

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ SolarWinds SD Webhook ] Sending request: '' + url + ((typeof data === ''string'')
            ? (''\n'' + data)
            : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            case ''put'':
                response = request.Put(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ SolarWinds SD Webhook ] Received response with status code '' + request.Status() +
            ''\n'' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ SolarWinds SD Webhook ] Failed to parse response received from SolarWinds'');
                response = null;
            }
        }

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            if (response !== null && typeof response.error !== ''undefined''
                && Object.keys(response.error).length > 0) {
                message += '': '' + JSON.stringify(response.error);
            }
            else if (response !== null && typeof response === ''object''
                && Object.keys(response).length > 0) {
                Object.keys(response)
                    .forEach(function(field) {
                        message += ''\n'' + field + '': '' + response[field][0];
                    });
            }

            throw message + '' Check debug log for more information.'';
        }

        return {
            status: request.Status(),
            response: response
        };
    },

    createIncident: function(name, description, fields) {
        var data = {
            incident: {
                name: name,
                description: description,
                priority: SolarWinds.params.priority
            }
        };

        var result = SolarWinds.request(''post'', ''incidents.json'', SolarWinds.addCustomFields(data, fields));

        if (typeof result.response !== ''object'' || typeof result.response.id === ''undefined'') {
            throw ''Cannot create SolarWinds incident. Check debug log for more information.'';
        }

        return result.response.id;
    },

    updateIncident: function(name, fields, message) {
        var data = {
            incident: {
                name: name,
                priority: SolarWinds.params.priority
            }
        };

        SolarWinds.request(
            ''put'',
            ''incidents/'' + SolarWinds.params.incident_id + ''.json'',
            SolarWinds.addCustomFields(data, fields));

        SolarWinds.commenIncident(message);
    },

    commenIncident: function(message) {
        var data = {
            comment: {
                body: message
            }
        };

        SolarWinds.request(''post'', ''incidents/'' + SolarWinds.params.incident_id + ''/comments.json'', data);
    }
};

try {
    var params = JSON.parse(value),
        fields = {},
        samanage = {},
        result = {tags: {}},
        required_params = [''alert_subject'', ''event_recovery_value'', ''event_source'', ''event_value'', ''priority_default''],
        severities = [
            {name: ''not_classified''},
            {name: ''information''},
            {name: ''warning''},
            {name: ''average''},
            {name: ''high''},
            {name: ''disaster''},
            {name: ''resolved''},
            {name: ''default''}
        ];

    fields.sw_fields = {};
    fields.sw_customfields = {};

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''samanage_'')) {
                samanage[key.substring(9)] = params[key];
            }
            else if (key.startsWith(''sw_field_'')) {
                fields.sw_fields[key.substring(9)] = params[key];
            }
            else if (key.startsWith(''sw_customfield_'')) {
                fields.sw_customfields[key.substring(15)] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key] === '''') {
                throw ''Parameter "'' + key + ''" can\''t be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'' && params.event_source === ''0'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_source !== ''0'' && params.event_recovery_value === ''0'') {
        throw ''Recovery operations are supported only for trigger-based actions.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''7'';
    }

    if (params.event_value === ''0'') {
        params.event_nseverity = ''6'';
    }

    samanage.priority = params[''priority_'' + severities[params.event_nseverity].name] || params.priority_default;

    SolarWinds.setParams(samanage);
    SolarWinds.setProxy(params.HTTPProxy);

    // Create incident for non trigger-based events.
    if (params.event_source !== ''0'' && params.event_recovery_value !== ''0'') {
        SolarWinds.createIncident(params.alert_subject, params.alert_message);
    }
    // Create incident for trigger-based events.
    else if (params.event_value === ''1'' && params.event_update_status === ''0''
            && samanage.incident_id === ''{EVENT.TAGS.__zbx_solarwinds_inc_id}'') {
        var key = SolarWinds.createIncident(params.alert_subject, params.alert_message, fields);


        result.tags.__zbx_solarwinds_inc_id = key;
        result.tags.__zbx_solarwinds_inc_link = params.samanage_url +
            (params.samanage_url.endsWith(''/'') ? '''' : ''/'') + ''incidents/'' + key;
    }
    // Update created incident for trigger-based event.
    else {
        if (samanage.incident_id === ''{EVENT.TAGS.__zbx_solarwinds_inc_id}'' || samanage.incident_id === '''') {
            throw ''Incorrect incident key given: '' + samanage.incident_id;
        }
        if (!params.alert_message) {
            throw ''Parameter "alert_message" can\''t be empty.'';
        }
        SolarWinds.updateIncident(params.alert_subject, fields, params.alert_message);
    }

    if (params.event_source === ''0'') {
        return JSON.stringify(result);
    }
    else {
        return ''OK'';
    }
}
catch (error) {
    Zabbix.Log(3, ''[ SolarWinds SD Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_solarwinds_inc_link}','SolarWinds incident ID: {EVENT.TAGS.__zbx_solarwinds_inc_id}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('24','4','SysAid','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var SysAid = {
    params: {},

    setParams: function (params) {
        var required = [''url'', ''auth_user'', ''auth_password'', ''category_level_1'', ''category_level_2'',
            ''category_level_3'', ''incident_id'', ''template_id'', ''urgency_id'', ''incident_state'',
            ''default_priority_id''
        ];

        required.forEach(function (field) {
            if (typeof params !== ''object'' || typeof params[field] === ''undefined'' || params[field] === '''') {
                throw ''Required param is not set: "'' + field + ''".'';
            }
        });

        SysAid.params = params;
        if (typeof SysAid.params.url === ''string'' && !SysAid.params.url.endsWith(''/'')) {
            SysAid.params.url += ''/'';
        }
    },

    login: function () {
        var result = SysAid.request(''post'', ''api/v1/login'', {
            user_name: SysAid.params.auth_user,
            password: SysAid.params.auth_password
        });

        return result.response.user.id;
    },

    request: function (method, query, data) {
        var response,
            request = SysAid.req || (SysAid.req = new CurlHttpRequest()),
            url = SysAid.params.url + query;

        if (typeof SysAid.HTTPProxy !== ''undefined'' && SysAid.HTTPProxy.trim() !== '''') {
            request.SetProxy(SysAid.HTTPProxy);
        }

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ SysAid Webhook ] Sending request: '' +
            url + ((typeof data === ''string'') ? ('' '' + data) : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            case ''put'':
                response = request.Put(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ SysAid Webhook ] Received response with status code '' + request.Status() + '': '' + response);

        if (request.Status() !== 200) {
            var message = ''Request failed with status code '' + request.Status();

            message += '': '' + response;
            throw message + '' Check debug log for more information.'';
        }

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ SysAid Webhook ] Failed to parse response received from SysAid'');
                response = null;
            }
        }

        if (response === null || (typeof response.Error !== ''undefined'' && Object.keys(response.Error).length > 0)) {
            throw ''Request failed: '' + JSON.stringify(response.Error);
        }

        return {
            status: request.Status(),
            response: response
        };
    },

    createIncident: function(subject, message, priority) {
        var result = SysAid.request(''post'', ''api/v1/sr/?template='' + encodeURIComponent(SysAid.params.template_id), {
            info: [
                {
                    key: ''problem_type'',
                    value: [
                        SysAid.params.category_level_1,
                        SysAid.params.category_level_2,
                        SysAid.params.category_level_3
                    ].join(''_'')
                },
                {
                    key: ''title'',
                    value: subject
                },
                {
                    key: ''description'',
                    value: message
                },
                {
                    key: ''status'',
                    value: ''1''
                },
                {
                    key: ''urgency'',
                    value: SysAid.params.urgency_id
                },
                {
                    key: ''priority'',
                    value: priority || SysAid.params.default_priority_id,
                }
            ]
        });

        if (result.response.id === ''undefined'') {
            throw ''Cannot create SysAid incident. Check debug log for more information.'';
        }

        return result.response.id;
    },

    updateTicket: function(note) {
        var date = new Date().getTime();

        SysAid.request(''put'', ''api/v1/sr/'' + encodeURIComponent(SysAid.params.incident_id), {
            id: SysAid.params.incident_id,
            info: [
                {
                    key: ''update_time'',
                    value: date
                },
                {
                    key: ''notes'',
                    value: [
                        {
                            userName: ''Zabbix'',
                            createDate: date,
                            text: note
                        }
                    ]
                }
            ]
        });
    }
};

try {
    var params = JSON.parse(value),
        params_sysaid = {},
        params_update = {},
        result = {tags: {}},
        required_params = [''alert_subject'', ''event_source'', ''event_value'',  ''event_update_status''],
        severities = [
            {name: ''not_classified'', color: ''#97AAB3''},
            {name: ''information'', color: ''#7499FF''},
            {name: ''warning'', color: ''#FFC859''},
            {name: ''average'', color: ''#FFA059''},
            {name: ''high'', color: ''#E97659''},
            {name: ''disaster'', color: ''#E45959''},
            {name: ''resolved'', color: ''#009900''},
            {name: null, color: ''#000000''}
        ],
        priority;

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''sysaid_'')) {
                params_sysaid[key.substring(7)] = params[key];
            }
            else if (key.startsWith(''event_update_'')) {
                params_update[key.substring(13)] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key].trim() === '''') {
                throw ''Parameter "'' + key + ''" cannot be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_source === ''0'' && params.event_update_status !== ''0'' && params.event_update_status !== ''1'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_source !== ''0'' && params.event_value === ''0'') {
        throw ''Recovery operations are supported only for trigger-based actions.'';
    }

    if (params.event_source === ''0'' && ((params.event_value === ''1'' && params.event_update_status === ''1'')
            || (params.event_value === ''0'' && (params.event_update_status === ''0'' || params.event_update_status === ''1'')))
            && (isNaN(parseInt(params.sysaid_incident_id)) || parseInt(params.sysaid_incident_id) < 1 )) {
        throw ''Incorrect "sysaid_incident_id" parameter given: '' + params.sysaid_incident_id + ''\nMust be positive integer.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''7'';
    }

    if (params.event_value === ''0'') {
        params.event_nseverity = ''6'';
    }

    priority = params[''severity_'' + severities[params.event_nseverity].name];
    priority = priority && priority.trim() || severities[7].name;

    SysAid.setParams(params_sysaid);
    SysAid.HTTPProxy = params.HTTPProxy;
    SysAid.login();

    if (params.event_source !== ''0'' && params.event_value !== ''0'') {
        // Create ticket for non trigger-based events.
        SysAid.createIncident(params.alert_subject, params.alert_message, priority);
    }
    else if (params.event_value === ''1'' && params_update.status === ''0'') {
        // Create ticket for trigger-based events.
        var incident_id = SysAid.createIncident(params.alert_subject, params.alert_subject + ''\n'' + params.alert_message +
                ''\n'' + params.zabbix_url + (params.zabbix_url.endsWith(''/'') ? '''' : ''/'') + ''tr_events.php?triggerid='' +
                params.trigger_id + ''&eventid='' + params.event_id + ''\n'', priority
        );

        result.tags.__zbx_sysaid_incident_id = incident_id;
        result.tags.__zbx_sysaid_incidentlink = params.sysaid_url +
            (params.sysaid_url.endsWith(''/'') ? '''' : ''/'') + ''SREdit.jsp?id='' + incident_id + ''&fromId=IncidentsList'';
    }
    else {
        // Update created ticket for trigger-based event.
        SysAid.updateTicket(params.alert_subject + ''\n'' + params.alert_message);
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ SysAid Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_sysaid_incidentlink}','SysAid: incident #{EVENT.TAGS.__zbx_sysaid_incident_id}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('25','4','TOPdesk','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var Media = {
    params: {},
    name: '''',
    labels: [],
    HTTPProxy: '''',

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        Media.params = params;
        Media.params.api += Media.params.api.endsWith(''/'') ? '''' : ''/'';
    },

    setProxy: function (HTTPProxy) {
        if (typeof HTTPProxy !== ''undefined'' && HTTPProxy.trim() !== '''') {
            Media.HTTPProxy = HTTPProxy;
        }
    },

    request: function (method, query, data) {
        [''api'', ''token''].forEach(function (field) {
            if (typeof Media.params !== ''object'' || typeof Media.params[field] === ''undefined''
                    || Media.params[field] === '''') {
                throw ''Required '' + Media.name + '' param is not set: "'' + field + ''".'';
            }
        });

        var response,
            url = Media.params.api + query,
            request = new CurlHttpRequest();

        request.AddHeader(''Content-Type: application/json'');
        request.AddHeader(''Accept: application/json'');
        request.AddHeader(''Authorization: '' + Media.params.token);
        request.SetProxy(Media.HTTPProxy);

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ '' + Media.name + '' Webhook ] Sending request: '' +
            url + ((typeof data === ''string'') ? (''\n'' + data) : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            case ''put'':
                response = request.Put(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ '' + Media.name + '' Webhook ] Received response with status code '' +
            request.Status() + ''\n'' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ '' + Media.name + '' Webhook ] Failed to parse response.'');
                response = null;
            }
        }

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            if (response !== null) {
                if (typeof response.errors === ''object'' && Object.keys(response.errors).length > 0) {
                    message += '': '' + JSON.stringify(response.errors);
                }
                else if (typeof response.errorMessages === ''object'' && Object.keys(response.errorMessages).length > 0) {
                    message += '': '' + JSON.stringify(response.errorMessages);
                }
                else if (typeof response.message === ''string'') {
                    message += '': '' + response.message;
                }
            }

            throw message + '' Check debug log for more information.'';
        }

        return {
            status: request.Status(),
            response: response
        };
    }
};

try {
    var result = {tags: {}},
        params = JSON.parse(value),
        media = {},
        fields = {},
        resp = {},
        required_params = [
            ''alert_subject'',
            ''alert_message'',
            ''event_id'',
            ''event_source'',
            ''event_value'',
            ''event_update_status'',
            ''topdesk_api'',
            ''topdesk_user'',
            ''topdesk_password''
        ],
        severities = [
            ''not_classified'',
            ''information'',
            ''warning'',
            ''average'',
            ''high'',
            ''disaster'',
            ''resolved'',
            ''default''
        ],
        priority;

    Object.keys(params)
        .forEach(function (key) {
            if (required_params.indexOf(key) !== -1 && params[key].trim() === '''') {
                throw ''Parameter "'' + key + ''" cannot be empty.'';
            }
            if (key.startsWith(''topdesk_'')) {
                media[key.substring(8)] = params[key];
            }
        });

    // Possible values of event_source:
    // 0 - Trigger, 1 - Discovery, 2 - Autoregistration, 3 - Internal.
    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: "'' + params.event_source + ''".\nMust be 0-3.'';
    }

    // Check event_value for trigger-based and internal events.
    // Possible values: 1 for problem, 0 for recovering
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check event_update_status only for trigger-based events.
    // Possible values: 0 - Webhook was called because of problem/recovery event, 1 - Update operation.
    if (params.event_source === ''0'' && params.event_update_status !== ''0'' && params.event_update_status !== ''1'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    // Check event_id for a numeric value.
    if (isNaN(parseInt(params.event_id)) || params.event_id < 1) {
        throw ''Incorrect "event_id" parameter given: '' + params.event_id + ''\nMust be a positive number.'';
    }

    if ((params.event_source === ''1'' || params.event_source === ''2'')  && params.event_value === ''0'') {
        throw ''Recovery operations are supported only for Trigger and Internal actions.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''7'';
    }

    if (params.event_value === ''0'') {
        params.event_nseverity = ''6'';
    }

    priority = params[''severity_'' + severities[params.event_nseverity]];
    params.zbxurl = params.zbxurl + (params.zbxurl.endsWith(''/'') ? '''' : ''/'');

    Media.name = ''TOPdesk'';
    Media.setParams(media);
    Media.params.token = ''Basic '' + btoa(Media.params.user + '':'' + Media.params.password);
    Media.setProxy(params.HTTPProxy);

    // Create an issue.
    // Numeric value of the event that triggered an action (1 for problem, 0 for recovering).
    // Numeric value of of the problem update status. Possible values:
    // 0 - Webhook was called because of problem/recovery event, 1 - Update operation.
    if ((params.event_source == 0 && params.event_value == 1 && params.event_update_status == 0)
            || (params.event_source == 3 && params.event_value == 1)
            || params.event_source == 1 || params.event_source == 2) {
        Zabbix.Log(4, ''[ '' + Media.name + '' Webhook ] Request of the ticket creating.'');
        fields.caller = {dynamicName: ''Zabbix''};
        fields.briefDescription = params.alert_subject;
        fields.request = params.alert_message.replace(/\n/g, ''<br>'');
        fields.priority = {name: priority};
        fields.processingStatus = {name: Media.params.status};
        fields.externalNumber = params.event_id;
        fields.request += ''<br>'' + params.zbxurl;

        if (params.event_source === ''0'') {
            fields.request += ''tr_events.php?triggerid='' + params.trigger_id + ''&eventid='' + params.event_id;
        }

        resp = Media.request(''post'', ''tas/api/incidents'', fields);
        if (typeof resp.response !== ''object'' || typeof resp.response.id === ''undefined'') {
            throw ''Cannot create '' + Media.name + '' issue. Check debug log for more information.'';
        }

        if (params.event_source == 0 && params.event_value == 1 && params.event_update_status == 0) {
            result.tags.__zbx_tpd_issuekey = resp.response.number;
            result.tags.__zbx_tpd_issuelink = Media.params.api +
                ''tas/secure/incident?action=show&unid='' + resp.response.id;
        }
    }
    // Update a created issue.
    else {
        if (params.event_source == 3 && params.event_value == 0) {
            throw ''Internal event recovery actions are not supported.'';
        }

        Zabbix.Log(4, ''[ '' + Media.name + '' Webhook ] Request of the ticket updating.'');
        fields.action = params.alert_message.replace(/\n/g, ''<br>'');

        resp = Media.request(''put'', ''tas/api/incidents/number/'' + Media.params.issue_key, fields);
        if (typeof resp.response !== ''object'' || typeof resp.response.id === ''undefined''
                || resp.response.number !== Media.params.issue_key) {
            throw ''Cannot update '' + Media.name + '' issue. Check debug log for more information.'';
        }
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ '' + Media.name + '' Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_tpd_issuelink}','TOPdesk: {EVENT.TAGS.__zbx_tpd_issuekey}','Please refer to https://developers.topdesk.com/documentation/index.html and https://www.zabbix.com/documentation/5.0/manual/config/notifications/media/webhook#example_scripts.
  
Set global macro {$ZABBIX.URL} with your Zabbix server URL.
Add a dedicated user with the media type "TOPdesk".
Change the values of the variables topdesk_api (URL), topdesk_password, topdesk_user. The topdesk_status is the default status for creating a new TOPdesk ticket.');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('26','4','iTop','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var Itop = {
    params: {},

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        if (params.log !== ''private_log'' && params.log !== ''public_log'') {
            throw ''Incorrect "itop_log" parameter given: '' + params.log + ''\nMust be "private_log" or "public_log".'';
        }

        Itop.params = params;
        if (typeof Itop.params.url === ''string'') {
            if (!Itop.params.url.endsWith(''/'')) {
                Itop.params.url += ''/'';
            }

            Itop.params.url += ''webservices/rest.php?version='' + encodeURIComponent(Itop.params.api_version);
        }
    },

    setProxy: function (HTTPProxy) {
        Itop.HTTPProxy = HTTPProxy;
    },

    setCreatePayload: function () {
        json_data.operation = ''core/create'';
        json_data.fields.org_id = Itop.params.organization_id;
        json_data.fields.title = params.alert_subject;
        json_data.fields.description = params.alert_message.replace(''<'', ''&lt;'')
            .replace(''>'', ''&gt;'')
            .replace(/(?:\r\n|\r|\n)/g, ''<br>'');
    },

    setUpdatePayload: function () {
        json_data.operation = ''core/update'';
        json_data.key = Itop.params.id;
        json_data.fields.title = params.alert_subject;
        json_data.fields[Itop.params.log] = {
            add_item: {
                message: params.alert_subject + ''\n'' + params.alert_message,
                format: ''text''
            }
        };
    },

    request: function (data) {
        [''url'', ''user'', ''password'', ''organization_id'', ''class'', ''api_version'', ''id''].forEach(function (field) {
            if (typeof Itop.params !== ''object'' || typeof Itop.params[field] === ''undefined''
                    || Itop.params[field] === '''' ) {
                throw ''Required Itop param is not set: "itop_'' + field + ''".'';
            }
        });

        var response,
            url = Itop.params.url,
            request = new CurlHttpRequest(),
            object;

        request.AddHeader(''Content-Type: multipart/form-data'');
        request.AddHeader(''Authorization: Basic '' + btoa(Itop.params.user + '':'' + Itop.params.password));

        if (Itop.HTTPProxy) {
            request.SetProxy(Itop.HTTPProxy);
        }

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ iTop Webhook ] Sending request: '' + url + ''&json_data='' + data);

        response = request.Post(url + ''&json_data='' + encodeURIComponent(data));

        Zabbix.Log(4, ''[ iTop Webhook ] Received response with status code '' + request.Status() + ''\n'' + response);

        try {
            response = JSON.parse(response);
        }
        catch (error) {
            Zabbix.Log(4, ''[ iTop Webhook ] Failed to parse response received from iTop'');
            throw ''Failed to parse response received from iTop.\nRequest status code '' +
                    request.Status() + ''. Check debug log for more information.'';
        }

        if (request.Status() < 200 || request.Status() >= 300) {
            throw ''Request failed with status code '' + request.Status() + ''. Check debug log for more information.'';
        }
        else if (typeof response.code !== ''undefined'' && response.code !== 0) {
            throw ''Request failed with iTop code '' + response.code + '': '' +
                    JSON.stringify(response.message) + ''. Check debug log for more information.'';
        }
        else {
            Object.keys(response.objects)
                .forEach(function (key) {
                    object = response.objects[key];
                });

            return {
                status: request.Status(),
                response: object.fields
            };
        }
    }
};

try {
    var params = JSON.parse(value),
        json_data = {},
        itop_params = {},
        result = {tags: {}},
        required_params = [
            ''alert_subject'', ''summary'', ''event_recovery_value'',
            ''event_source'', ''event_value'', ''action_name''
        ];

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''itop_'')) {
                itop_params[key.substring(5)] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key] === '''') {
                throw ''Parameter "'' + key + ''" can\''t be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
            && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'' && params.event_source === ''0'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_source !== ''0'' && params.event_recovery_value === ''0'') {
        throw ''Recovery operations are supported only for trigger-based actions.'';
    }

    Itop.setParams(itop_params);
    Itop.setProxy(params.HTTPProxy);

    json_data.operation = '''';
    json_data.class = Itop.params.class;
    json_data.comment = Itop.params.comment;
    json_data.output_fields = ''id, friendlyname'';
    json_data.fields = {};

    // Create issue for non trigger-based events.
    if (params.event_source !== ''0'' && params.event_recovery_value !== ''0'') {
        Itop.setCreatePayload();
        Itop.request(json_data);
    }
    // Create issue for trigger-based events.
    else if (params.event_value === ''1'' && params.event_update_status === ''0''
            && Itop.params.id === ''{EVENT.TAGS.__zbx_itop_id}'') {
        Itop.setCreatePayload();

        var response = Itop.request(json_data);

        result.tags.__zbx_itop_id = response.response.id;
        result.tags.__zbx_itop_key = response.response.friendlyname;
        result.tags.__zbx_itop_link = params.itop_url + (params.itop_url.endsWith(''/'') ? '''' : ''/'') +
                ''pages/UI.php?operation=details&class='' + encodeURIComponent(Itop.params.class) + ''&id='' +
                encodeURIComponent(response.response.id);
    }
    // Update created issue for trigger-based event.
    else {
        if (Itop.params.id === ''{EVENT.TAGS.__zbx_itop_id}'') {
            throw ''Incorrect iTop ticket ID given: '' + Itop.params.id;
        }
        Itop.setUpdatePayload();
        Itop.request(json_data);
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ iTop Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_itop_link}','iTop: {EVENT.TAGS.__zbx_itop_key}','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('27','4','Rocket.Chat','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var RocketChat = {
    params: {},

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        RocketChat.params = params;
        if (RocketChat.params.url && RocketChat.params.api_url) {
            if (!RocketChat.params.url.endsWith(''/'')) {
                RocketChat.params.url += ''/'';
            }
            if (!RocketChat.params.api_url.endsWith(''/'')) {
                RocketChat.params.api_url += ''/'';
            }
            if (RocketChat.params.api_url.startsWith(''/'')) {
                RocketChat.params.api_url = RocketChat.params.api_url.substring(1);
            }

            RocketChat.params.url += RocketChat.params.api_url;
        }
    },

    setProxy: function (HTTPProxy) {
        RocketChat.HTTPProxy = HTTPProxy;
    },

    addFields: function (fields) {
        var data = [];

        if (typeof fields === ''object'' && Object.keys(fields).length) {
            Object.keys(fields)
                .forEach(function(field) {
                    if (fields[field] === '''') {
                        Zabbix.Log(4, ''[ RocketChat Webhook ] Field "'' + field +
                            ''" can\''t be empty. The field ignored.'');
                    }
                    else {
                        try {
                            var parts = field.split('':''),
                                prefix = parts[0].split(''_'');

                            if (typeof prefix[2] === ''undefined''
                                    || (prefix[2] === ''p'' && params.event_value === ''1'')
                                    || (prefix[2] === ''r'' && params.event_value === ''0'')) {
                                data.push({
                                    title: field.substring(field.indexOf('':'') + 1),
                                    value: fields[field],
                                    short: prefix[1] === ''short''
                                });
                            }
                        }
                        catch (error) {
                            Zabbix.Log(4, ''[ RocketChat Webhook ] Can\''t parse field "'' + field +
                                ''". The field ignored.'');
                        }
                    }
                });
        }

        return data;
    },

    request: function (method, query, data) {
        [''url'', ''api_url'', ''user_id'', ''user_token'', ''send_to''].forEach(function (field) {
            if (typeof RocketChat.params !== ''object'' || typeof RocketChat.params[field] === ''undefined''
                    || RocketChat.params[field] === '''' ) {
                throw ''Required parameter is not set: "'' + field + ''".'';
            }
        });

        var response,
            url = RocketChat.params.url + query,
            request = new CurlHttpRequest();

        request.AddHeader(''Content-Type: application/json'');
        request.AddHeader(''X-Auth-Token:'' + RocketChat.params.user_token);
        request.AddHeader(''X-User-Id:'' + RocketChat.params.user_id);

        if (typeof RocketChat.HTTPProxy !== ''undefined'' && RocketChat.HTTPProxy !== '''') {
            request.SetProxy(RocketChat.HTTPProxy);
        }

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ RocketChat Webhook ] Sending request: '' + url +
            ((typeof data === ''string'') ? (''\n'' + data) : ''''));

        switch (method) {
            case ''get'':
                response = request.Get(url, data);
                break;

            case ''post'':
                response = request.Post(url, data);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ RocketChat Webhook ] Received response with status code '' +
            request.Status() + ''\n'' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ RocketChat Webhook ] Failed to parse response received from RocketChat'');
                response = null;
            }
        }

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            if (response !== null && typeof response.message !== ''undefined'') {
                message += '': '' + JSON.stringify(response.message);
            }
            else if (response !== null && typeof response.error !== ''undefined'') {
                message += '': '' + JSON.stringify(response.error);
            }

            throw message + ''. Check debug log for more information.'';
        }

        return {
            status: request.Status(),
            response: response
        };
    },

    postMessage: function(use_default_message, message, fields) {
        var data = {
            channel: RocketChat.params.send_to,
            attachments: [{
                collapsed: false,
                color: RocketChat.params.color,
                title: params.alert_subject
            }]
        };

        if (RocketChat.params.title_link) {
            data.attachments[0].title_link = RocketChat.params.title_link;
        }

        if (use_default_message) {
            data.attachments[0].text = message;
        }
        else {
            data.attachments[0].fields = RocketChat.addFields(fields);
        }

        var result = RocketChat.request(''post'', ''chat.postMessage'', data);

        if (typeof result.response !== ''object'' || typeof result.response.message._id === ''undefined'') {
            throw ''Cannot send RocketChat message. Check debug log for more information.'';
        }

        return {
            id: result.response.message._id,
            rid: result.response.message.rid,
            channel: result.response.channel
        };
    },

    sendMessage: function(update, fields) {

        var data = {
            message: {
                rid: RocketChat.params.room_id,
                tmid: RocketChat.params.msg_id,
                tshow: true
            }
        };

        if (update.status === ''0'') {
            data.message.attachments = [{
                collapsed: false,
                color: RocketChat.params.color,
                title: params.alert_subject,
                title_link: RocketChat.params.title_link,
                fields: RocketChat.addFields(fields)
            }];
        }
        else {
            data.message.alias = update.user;
            data.message.msg = update.action;
            if (update.message) {
                data.message.attachments = [{
                    color: RocketChat.params.color,
                    text: update.message
                }];
            }
        }

        RocketChat.request(''post'', ''chat.sendMessage'', data);
    },

    getMessageLink: function(rid, id) {
        var room = RocketChat.request(''get'', ''rooms.info?roomId='' + encodeURIComponent(rid)),
            link = params.rc_url +
                (params.rc_url.endsWith(''/'') ? '''' : ''/'');

        switch (room.response.room.t) {
            case ''c'':
                link += ''channel/'' + room.response.room.name + ''?msg='' + id;
                break;

            case ''p'':
                link += ''group/'' + room.response.room.name + ''?msg='' + id;
                break;

            case ''d'':
                link += ''direct/'' + rid + ''?msg='' + id;
                break;

            default:
                Zabbix.Log(4, ''[ RocketChat Webhook ] Can\''t get room type. Link to message will not be added.'');
        }

        return link;
    }
};

try {
    var params = JSON.parse(value),
        response,
        fields = {},
        rc = {},
        update = {},
        result = {tags: {}},
        required_params = [''alert_subject'', ''alert_message'', ''event_source'', ''event_value''],
        severities = [
            {name: ''not_classified'', color: ''#97AAB3''},
            {name: ''information'', color: ''#7499FF''},
            {name: ''warning'', color: ''#FFC859''},
            {name: ''average'', color: ''#FFA059''},
            {name: ''high'', color: ''#E97659''},
            {name: ''disaster'', color: ''#E45959''},
            {name: ''resolved'', color: ''#009900''},
            {name: ''default'', color: ''#000000''}
        ];

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''rc_'')) {
                rc[key.substring(3)] = params[key];
            }
            else if (key.startsWith(''field_'')) {
                fields[key.substring(6)] = params[key];
            }
            else if (key.startsWith(''event_update_'')) {
                update[key.substring(13)] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key] === '''') {
                throw ''Parameter "'' + key + ''" can\''t be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Forcing parameters for non trigger-based events.
    if (params.event_source !== ''0'') {
        params.use_default_message = ''true'';
        params.event_nseverity = ''0'';
        params.rc_title_link = false;
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
            && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'' && params.event_source === ''0'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''7'';
    }

    if (params.event_value === ''0'') {
        params.event_nseverity = ''6'';
    }

    RocketChat.setParams(rc);
    RocketChat.setProxy(params.HTTPProxy);
    RocketChat.params.color = severities[params.event_nseverity].color;

    // Send default message if use_default_message === true.
    if (params.use_default_message.toLowerCase() === ''true'') {
        response = RocketChat.postMessage(true, params.alert_message);
        result.tags.__zbx_rc_id = response.id;
        result.tags.__zbx_rc_rid = response.rid;
        result.tags.__zbx_rc_msg_url = RocketChat.getMessageLink(response.rid, response.id);
    }
    // Send message for trigger-based events.
    else if (params.event_value === ''1'' && update.status === ''0'') {
        response = RocketChat.postMessage(false, params.alert_message, fields);
        result.tags.__zbx_rc_id = response.id;
        result.tags.__zbx_rc_rid = response.rid;
        result.tags.__zbx_rc_msg_url = RocketChat.getMessageLink(response.rid, response.id);
    }
    // Send thread message for trigger-based event.
    else {
        RocketChat.sendMessage(update, fields);
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ RocketChat Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_rc_msg_url}','Rocket.Chat','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('28','4','VictorOps','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var VictorOps = {
    params: {},

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        VictorOps.params = params;
        if (VictorOps.params.endpoint) {
            if (!VictorOps.params.endpoint.endsWith(''/'')) {
                VictorOps.params.endpoint += ''/'';
            }

            if (typeof VictorOps.params.routing_key !== ''undefined''
                    && VictorOps.params.routing_key !== ''{ALERT.SENDTO}''
                    && VictorOps.params.routing_key !== ''Default'') {
                VictorOps.params.endpoint += VictorOps.params.routing_key;
            }
        }
    },

    setProxy: function (HTTPProxy) {
        VictorOps.HTTPProxy = HTTPProxy;
    },

    addFields: function (fields) {
        var data = {};

        if (typeof fields === ''object'') {
            Object.keys(fields)
                .forEach(function(field) {
                    if (fields[field] === '''') {
                        Zabbix.Log(4, ''[ VictorOps Webhook ] Field "'' + field +
                            ''" can\''t be empty. The field ignored.'');
                    }
                    else {
                        try {
                            var parts = field.split('':''),
                                prefix = parts[0].split(''_'');

                            if (typeof prefix[1] === ''undefined''
                                    || (prefix[1] === ''p'' && params.event_value === ''1''
                                        && (params.event_update_status === ''0''
                                            || params.event_update_status === ''{EVENT.UPDATE.STATUS}''))
                                    || (prefix[1] === ''r'' && params.event_value === ''0''
                                        && (params.event_update_status === ''0''
                                            || params.event_update_status === ''{EVENT.UPDATE.STATUS}''))
                                    || (prefix[1] === ''u'' && params.event_update_status === ''1'')) {
                                data[field.substring(field.indexOf('':'') + 1)] = fields[field];
                            }
                        }
                        catch (error) {
                            Zabbix.Log(4, ''[ VictorOps Webhook ] Can\''t parse field "'' + field +
                                ''". The field ignored.'');
                        }
                    }
                });
        }

        return data;
    },

    request: function (data) {
        if (typeof VictorOps.params !== ''object'' || typeof VictorOps.params.endpoint === ''undefined''
                || VictorOps.params.endpoint === '''' ) {
            throw ''Required parameter is not set: "vops_endpoint".'';
        }

        var response,
            url = VictorOps.params.endpoint,
            request = new CurlHttpRequest();

        request.AddHeader(''Content-Type: application/json'');

        if (typeof VictorOps.HTTPProxy !== ''undefined'' && VictorOps.HTTPProxy !== '''') {
            request.SetProxy(VictorOps.HTTPProxy);
        }

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ VictorOps Webhook ] Sending request: '' + url +
            ((typeof data === ''string'') ? (''\n'' + data) : ''''));

        response = request.Post(url, data);

        Zabbix.Log(4, ''[ VictorOps Webhook ] Received response with status code '' +
            request.Status() + ''\n'' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ VictorOps Webhook ] Failed to parse response received from VictorOps'');
                response = null;
            }
        }

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            if (response !== null && typeof response.messages !== ''undefined'') {
                message += '': '' + JSON.stringify(response.messages);
            }

            throw message + ''. Check debug log for more information.'';
        }

        return response;
    }
};

try {
    var params = JSON.parse(value),
        fields = {},
        vops = {},
        required_params = [''event_source'', ''event_value'', ''priority_update''],
        severities = [
            {name: ''not_classified'', color: ''#97AAB3''},
            {name: ''information'', color: ''#7499FF''},
            {name: ''warning'', color: ''#FFC859''},
            {name: ''average'', color: ''#FFA059''},
            {name: ''high'', color: ''#E97659''},
            {name: ''disaster'', color: ''#E45959''},
            {name: ''resolved'', color: ''#009900''},
            {name: ''default'', color: ''#000000''}
        ];

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''vops_'')) {
                vops[key.substring(5)] = params[key];
            }
            else if (key.startsWith(''field'')) {
                fields[key.substring(5)] = params[key];
            }
            else if (required_params.indexOf(key) !== -1 && params[key] === '''') {
                throw ''Parameter "'' + key + ''" can\''t be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
            && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'' && params.event_source === ''0'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''7'';
    }

    if (params.event_value === ''0'') {
        params.event_nseverity = ''6'';
    }

    if (params.event_update_status === ''1'') {
        fields['':message_type''] = params.priority_update;
    }
    else {
        fields['':message_type''] = params[''priority_'' + severities[params.event_nseverity].name]
            || ''INFO'';
    }

    if (params.event_info && params.event_source === ''0'') {
        fields['':event_info''] = params.event_info;
    }

    VictorOps.setParams(vops);
    VictorOps.setProxy(params.HTTPProxy);
    VictorOps.request(VictorOps.addFields(fields));

    return ''OK'';
}
catch (error) {
    Zabbix.Log(3, ''[ VictorOps Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','0','0','','','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('29','4','Brevis.one','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var BrevisOne = {
    params: [],

    addParam: function (name, value) {
        BrevisOne.params.push(name + ''='' + encodeURIComponent(value));
    },

    setProxy: function (HTTPProxy) {
        BrevisOne.HTTPProxy = HTTPProxy;
    },

    setPayload: function (params) {
        var parts = params.send_to.split('':''),
            defaultValues = {
                ring: ''true'',
                flash: ''true'',
                telauto: ''false''
            };

        BrevisOne.addParam(''username'', params.username);
        BrevisOne.addParam(''password'', params.password);
        BrevisOne.addParam(''text'', params.text);

        if (parts.length > 1) {
            BrevisOne.addParam(''mode'', parts[0]);
            BrevisOne.addParam(''to'', parts[1]);
        }
        else {
            BrevisOne.addParam(''to'', parts[0]);
        }

        Object.keys(defaultValues)
            .forEach(function (key) {
                if (params[key] && params[key].trim() && params[key].toLowerCase() === defaultValues[key]) {
                    BrevisOne.addParam(key, defaultValues[key]);
                }
            });
    },

    request: function () {
        var response,
            request = new CurlHttpRequest(),
            data = ''?'' + BrevisOne.params.join(''&'');

        request.AddHeader(''Content-Type: multipart/form-data'');

        if (typeof BrevisOne.HTTPProxy !== ''undefined'' && BrevisOne.HTTPProxy !== '''') {
            request.SetProxy(BrevisOne.HTTPProxy);
        }

        Zabbix.Log(4, ''[ BrevisOne Webhook ] Sending request.'');

        response = request.Post(params.endpoint + data);

        Zabbix.Log(4, ''[ BrevisOne Webhook ] Received response with status code '' +
            request.Status() + ''\n'' + response);

        if (request.Status() < 200 || request.Status() >= 300) {
            var message = ''Request failed with status code '' + request.Status();

            if (response) {
                message += '': '' + response;
            }

            throw message + ''. Check debug log for more information.'';
        }
    }
};

try {
    var params = JSON.parse(value);

    [''endpoint'', ''password'', ''username'', ''text'', ''send_to''].forEach(function (field) {
        if (typeof params !== ''object'' || typeof params[field] === ''undefined''
                || !params[field].trim()) {
            throw ''Required parameter is not set: "'' + field + ''".'';
        }
    });

    if (params.send_to === ''{ALERT.SENDTO}'') {
        throw ''Required parameter is not set: "send_to".'';
    }

    BrevisOne.setProxy(params.HTTPProxy);
    BrevisOne.setPayload(params);
    BrevisOne.request();

    return ''OK'';
}
catch (error) {
    Zabbix.Log(3, ''[ BrevisOne Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','0','0','','','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('30','4','Express.ms','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var Express = {
    params: [],

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        Express.params = params;

        if (typeof Express.params.url === ''string'' && !Express.params.url.endsWith(''/'')) {
            Express.params.url += ''/'';
        }
    },

    setProxy: function (HTTPProxy) {
        Express.HTTPProxy = HTTPProxy;
    },

    request: function (query, data) {
        var response,
            url = Express.params.url + query,
            request = new CurlHttpRequest();

        request.AddHeader(''Content-Type: application/json'');
        request.AddHeader(''Authorization: Bearer '' + Express.params.token);

        if (typeof Express.HTTPProxy !== ''undefined'' && Express.HTTPProxy !== '''') {
            request.SetProxy(Express.HTTPProxy);
        }

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        Zabbix.Log(4, ''[ Express Webhook ] Sending request: '' + url +
            ((typeof data === ''string'') ? (''\n'' + data) : ''''));

        response = request.Post(url, data);

        Zabbix.Log(4, ''[ Express Webhook ] Received response with status code '' +
            request.Status() + ''\n'' + response);

        if (response !== null) {
            try {
                response = JSON.parse(response);
            }
            catch (error) {
                Zabbix.Log(4, ''[ Express Webhook ] Failed to parse response received from Express'');
                response = {};
            }
        }

        if (response.status !== ''ok'') {
            var message = ''Request failed with status code '' + request.Status();

            if (typeof response.reason !== ''undefined'') {
                message += '': '' + JSON.stringify(response.reason);
            }

            throw message + ''. Check debug log for more information.'';
        }

        return response.result;
    },

    postMessage: function (is_problem) {
        var data,
            url,
            result = {tags: {}},
            response;

        if (is_problem) {
            data = {
                group_chat_id: Express.params.send_to,
                notification: {
                    status: ''ok'',
                    body: Express.params.message
                }
            };
            url = ''api/v3/botx/notification/callback/direct'';
        }
        else {
            data = {
                reply: {
                    status: ''ok'',
                    body: Express.params.message
                }
            };
            url = ''api/v3/botx/events/reply_event'';

            try {
                var tags = JSON.parse(Express.params.tags);
            }
            catch (error) {
                throw ''Value of "express_tags" is not JSON. Value: '' + Express.params.tags + ''.'';
            }

            tags.forEach(function(tag) {
                if (tag.tag === ''__zbx_ex_sync_id_'' + Express.params.send_to) {
                    data.source_sync_id = tag.value;
                }
            });

            if (!data.source_sync_id) {
                throw ''Cannot update data. sync_id for the provided sender is unknown.'';
            }
        }

        response = Express.request(url, data);

        if (is_problem && response.sync_id) {
            result.tags[''__zbx_ex_sync_id_'' + Express.params.send_to] = response.sync_id;

            return JSON.stringify(result);
        }
        else {
            return ''OK'';
        }
    }
};

try {
    var params = JSON.parse(value),
        express = {},
        required_params = [
            ''express_url'', ''express_send_to'', ''express_message'', ''express_tags'', ''express_token'',
            ''event_source'', ''event_value'', ''event_update_status''
        ];

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''express_'')) {
                express[key.substring(8)] = params[key];
            }

            if (required_params.indexOf(key) !== -1
                    && (params[key].trim() === '''' || params[key] === ''{ALERT.SENDTO}'')) {
                throw ''Parameter "'' + key + ''" can\''t be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Forcing event_value and event_update_status for non trigger-based events.
    if (params.event_source !== ''0'' ) {
        params.event_value = ''1'';
        params.event_update_status = ''0'';
    }

    if (params.event_value !== ''0'' && params.event_value !== ''1'') {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'' && params.event_source === ''0'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    Express.setParams(express);
    Express.setProxy(params.HTTPProxy);

    return Express.postMessage(params.event_value === ''1'' && params.event_update_status === ''0'');
}
catch (error) {
    Zabbix.Log(3, ''[ Express Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','0','','','');
INSERT INTO media_type (mediatypeid,type,name,smtp_server,smtp_helo,smtp_email,exec_path,gsm_modem,username,passwd,status,smtp_port,smtp_security,smtp_verify_peer,smtp_verify_host,smtp_authentication,exec_params,maxsessions,maxattempts,attempt_interval,content_type,script,timeout,process_tags,show_event_menu,event_menu_url,event_menu_name,description) values ('31','4','ManageEngine ServiceDesk','','','','','','','','0','25','0','0','0','0','','1','3','10s','1','var MEngine = {
    params: {},

    setParams: function (params) {
        if (typeof params !== ''object'') {
            return;
        }

        MEngine.params = params;
        if (typeof MEngine.params.url === ''string'') {
            if (!MEngine.params.url.endsWith(''/'')) {
                MEngine.params.url += ''/'';
            }

            MEngine.params.url += ''api/v3/'';
        }

        if (MEngine.params.on_premise.toLowerCase() !== ''true''
                && typeof MEngine.params.on_demand_url_auth === ''string'') {
            if (!MEngine.params.on_demand_url_auth.endsWith(''/'')) {
                MEngine.params.on_demand_url_auth += ''/'';
            }

            MEngine.params.on_demand_url_auth += ''oauth/v2/token?'';
        }
    },

    setProxy: function (HTTPProxy) {
        MEngine.HTTPProxy = HTTPProxy;
    },

    createLink: function (id, url) {
        return url + (url.endsWith(''/'') ? '''' : ''/'') +
            ((MEngine.params.on_premise.toLowerCase() === ''true'')
                ? (''WorkOrder.do?woMode=viewWO&woID='' + id)
                : (''app/itdesk/ui/requests/'' + id + ''/details'')
            );
    },

    refreshAccessToken: function () {
        [
            ''on_demand_url_auth'',
            ''on_demand_refresh_token'',
            ''on_demand_client_id'',
            ''on_demand_client_secret''
        ].forEach(function (field) {
            if (typeof MEngine.params !== ''object'' || typeof MEngine.params[field] === ''undefined''
                    || MEngine.params[field].trim() === '''' ) {
                throw ''Required MEngine param is not set: "sd_'' + field + ''".'';
            }
        });

        var response,
            request = new CurlHttpRequest(),
            url = MEngine.params.on_demand_url_auth +
                ''refresh_token='' + encodeURIComponent(MEngine.params.on_demand_refresh_token) +
                ''&grant_type=refresh_token&client_id='' + encodeURIComponent(MEngine.params.on_demand_client_id) +
                ''&client_secret='' + encodeURIComponent(MEngine.params.on_demand_client_secret) +
                ''&redirect_uri=https://www.zoho.com&scope=SDPOnDemand.requests.ALL'';

        if (MEngine.HTTPProxy) {
            request.SetProxy(MEngine.HTTPProxy);
        }

        Zabbix.Log(4, ''[ ManageEngine Webhook ] Refreshing access token. Request: '' + url);

        response = request.Post(url);

        Zabbix.Log(4, ''[ ManageEngine Webhook ] Received response with status code '' +
        request.Status() + ''\n'' + response);

        try {
            response = JSON.parse(response);
        }
        catch (error) {
            Zabbix.Log(4, ''[ ManageEngine Webhook ] Failed to parse response received from Zoho Accounts'');
        }

        if ((request.Status() < 200 || request.Status() >= 300) && !response.access_token) {
            throw ''Access token refresh failed with HTTP status code '' + request.Status() +
                ''. Check debug log for more information.'';
        }
        else {
            MEngine.params.on_demand_auth_token = response.access_token;
        }
    },

    request: function (method, query, data) {
        var response,
            url = MEngine.params.url + query,
            input,
            request = new CurlHttpRequest(),
            message;

        if (MEngine.params.on_premise.toLowerCase() === ''true'') {
            request.AddHeader(''TECHNICIAN_KEY: '' + MEngine.params.on_premise_auth_token);
        }
        else {
            request.AddHeader(''Authorization: Zoho-oauthtoken '' + MEngine.params.on_demand_auth_token);
            request.AddHeader(''Accept: application/v3+json'');
        }

        if (MEngine.HTTPProxy) {
            request.SetProxy(MEngine.HTTPProxy);
        }

        if (typeof data !== ''undefined'') {
            data = JSON.stringify(data);
        }

        input = ''input_data='' + encodeURIComponent(data);
        Zabbix.Log(4, ''[ ManageEngine Webhook ] Sending request: '' + url + ''?'' + input);

        switch (method) {
            case ''post'':
                response = request.Post(url, input);
                break;

            case ''put'':
                response = request.Put(url, input);
                break;

            default:
                throw ''Unsupported HTTP request method: '' + method;
        }

        Zabbix.Log(4, ''[ ManageEngine Webhook ] Received response with status code '' +
            request.Status() + ''\n'' + response);

        try {
            response = JSON.parse(response);
        }
        catch (error) {
            Zabbix.Log(4, ''[ ManageEngine Webhook ] Failed to parse response received from ManageEngine'');
        }

        if ((request.Status() < 200 || request.Status() >= 300)
                && typeof response.response_status !== ''object'') {
            throw ''Request failed with HTTP status code '' + request.Status() +
                ''. Check debug log for more information.'';
        }
        else if (typeof response.response_status === ''object'' && response.response_status.status === ''failed'') {
            message = ''Request failed with status_code '';

            if (typeof response.response_status.messages === ''object''
                    && response.response_status.messages[0]
                    && response.response_status.messages[0].message) {
                message += response.response_status.messages[0].status_code +
                    ''. Message: '' + response.response_status.messages[0].message;
            }
            else {
                message += response.response_status.status_code;
            }

            message += ''. Check debug log for more information.'';
            throw message;
        }
        else if (response.request) {
            return response.request.id;
        }
    },

    createPaylaod: function (fields, isNote) {
        var data = {},
            result;

        if (isNote) {
            data.description = fields[''field_string:description''].replace(/(?:\r\n|\r|\n)/g, ''<br>'');
            result = {request_note: data};
        }
        else {
            Object.keys(fields)
                .forEach(function(field) {
                    if (fields[field].trim() === '''') {
                        Zabbix.Log(4, ''[ ManageEngine Webhook ] Field "'' + field +
                            ''" can\''t be empty. The field ignored.'');
                    }
                    else {
                        try {
                            var prefix = field.split('':'')[0],
                                root;

                            if  (prefix.startsWith(''udf_'') && !data.udf_fields) {
                                data.udf_fields = {};
                                root = data.udf_fields;
                            }
                            else if (prefix.startsWith(''udf_'')) {
                                root = data.udf_fields;
                            }
                            else {
                                root = data;
                            }

                            if (prefix.endsWith(''string'')) {
                                root[field.substring(field.indexOf('':'') + 1)
                                    .toLowerCase()] = fields[field];
                            }
                            else {
                                root[field.substring(field.indexOf('':'') + 1)
                                    .toLowerCase()] = {
                                    name: fields[field]
                                };
                            }
                        }
                        catch (error) {
                            Zabbix.Log(4, ''[ ManageEngine Webhook ] Can\''t parse field "'' + field +
                                ''". The field ignored.'');
                        }
                    }
                });
            if (data.description) {
                data.description = data.description.replace(/(?:\r\n|\r|\n)/g, ''<br>'');
            }

            result = {request: data};
        }

        return result;
    }
};

try {
    var params = JSON.parse(value),
        fields = {},
        sd = {},
        result = {tags: {}},
        required_params = [
            ''sd_on_premise'', ''field_string:subject'', ''field_string:description'',
            ''event_recovery_value'', ''event_source'', ''event_value'', ''event_update_status''
        ],
        severities = [
            {name: ''not_classified'', color: ''#97AAB3''},
            {name: ''information'', color: ''#7499FF''},
            {name: ''warning'', color: ''#FFC859''},
            {name: ''average'', color: ''#FFA059''},
            {name: ''high'', color: ''#E97659''},
            {name: ''disaster'', color: ''#E45959''},
            {name: ''default'', color: ''#000000''}
        ];

    Object.keys(params)
        .forEach(function (key) {
            if (key.startsWith(''sd_'')) {
                sd[key.substring(3)] = params[key];
            }
            else if (key.startsWith(''field_'') || key.startsWith(''udf_field_'')) {
                fields[key] = params[key];
            }

            if (required_params.indexOf(key) !== -1 && params[key].trim() === '''') {
                throw ''Parameter "'' + key + ''" can\''t be empty.'';
            }
        });

    if ([0, 1, 2, 3].indexOf(parseInt(params.event_source)) === -1) {
        throw ''Incorrect "event_source" parameter given: '' + params.event_source + ''\nMust be 0-3.'';
    }

    // Check {EVENT.VALUE} for trigger-based and internal events.
    if (params.event_value !== ''0'' && params.event_value !== ''1''
        && (params.event_source === ''0'' || params.event_source === ''3'')) {
        throw ''Incorrect "event_value" parameter given: '' + params.event_value + ''\nMust be 0 or 1.'';
    }

    // Check {EVENT.UPDATE.STATUS} only for trigger-based events.
    if (params.event_update_status !== ''0'' && params.event_update_status !== ''1'' && params.event_source === ''0'') {
        throw ''Incorrect "event_update_status" parameter given: '' + params.event_update_status + ''\nMust be 0 or 1.'';
    }

    if (params.event_source !== ''0'' && params.event_recovery_value === ''0'') {
        throw ''Recovery operations are supported only for trigger-based actions.'';
    }

    if ([0, 1, 2, 3, 4, 5].indexOf(parseInt(params.event_nseverity)) === -1) {
        params.event_nseverity = ''6'';
    }

    if (params.event_update_status === ''1'' && (typeof params.sd_request_id === ''undefined''
            || params.sd_request_id.trim() === ''''
            || params.sd_request_id === ''{EVENT.TAGS.__zbx_sd_request_id}'')) {
        throw ''Parameter "sd_request_id" can\''t be empty for update operation.'';
    }

    MEngine.setParams(sd);
    MEngine.setProxy(params.HTTPProxy);

    if (MEngine.params.on_premise.toLowerCase() !== ''true'') {
        MEngine.refreshAccessToken();
    }

    // Create issue for non trigger-based events.
    if (params.event_source !== ''0'' && params.event_recovery_value !== ''0'') {
        fields[''field_object:priority''] = params[''priority_'' + severities[params.event_nseverity].name]
        || ''Normal'';

        MEngine.request(''post'', ''requests'', MEngine.createPaylaod(fields));
    }
    // Create issue for trigger-based events.
    else if (params.event_value === ''1'' && params.event_update_status === ''0'') {
        fields[''field_object:priority''] = params[''priority_'' + severities[params.event_nseverity].name]
        || ''Normal'';

        var id = MEngine.request(''post'', ''requests'', MEngine.createPaylaod(fields));

        result.tags.__zbx_sd_request_id = id;
        result.tags.__zbx_sd_request_link = MEngine.createLink(id, params.sd_url);
    }
    // Update created issue for trigger-based event.
    else {
        if (params.event_update_status === ''1'') {
            MEngine.request(''post'', ''requests/'' + params.sd_request_id + ''/notes'',
                MEngine.createPaylaod(fields, true)
            );
        }
        delete fields[''field_string:description''];
        MEngine.request(''put'', ''requests/'' + params.sd_request_id, MEngine.createPaylaod(fields));
    }

    return JSON.stringify(result);
}
catch (error) {
    Zabbix.Log(3, ''[ ManageEngine Webhook ] ERROR: '' + error);
    throw ''Sending failed: '' + error;
}','30s','1','1','{EVENT.TAGS.__zbx_sd_request_link}','ManageEngine: {EVENT.TAGS.__zbx_sd_request_id}','');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('1','5','zabbix_url','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('2','5','bot_token','<YOUR BOT TOKEN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('3','5','mattermost_url','<YOUR MATTERMOST URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('4','5','send_mode','alarm');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('5','5','send_to','{ALERT.SENDTO}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('6','5','event_tags','{EVENT.TAGS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('8','5','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('10','5','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('11','5','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('12','5','event_date','{EVENT.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('13','5','event_time','{EVENT.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('14','5','event_severity','{EVENT.SEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('15','5','event_opdata','{EVENT.OPDATA}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('16','5','event_id','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('18','5','trigger_id','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('19','5','trigger_description','{TRIGGER.DESCRIPTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('20','5','host_name','{HOST.HOST}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('21','5','host_ip','{HOST.IP}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('22','5','event_update_date','{EVENT.UPDATE.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('23','5','event_update_time','{EVENT.UPDATE.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('24','5','event_recovery_date','{EVENT.RECOVERY.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('25','5','event_recovery_time','{EVENT.RECOVERY.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('37','6','zbxurl','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('39','7','token','<put your key>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('40','7','eventid','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('41','7','eventname','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('42','7','hostname','{HOST.NAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('43','7','hostip','{HOST.IP}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('44','7','severity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('45','7','triggerdesc','{TRIGGER.DESCRIPTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('46','7','triggeropdata','{EVENT.OPDATA}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('47','7','eventtags','{EVENT.TAGS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('48','7','triggerid','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('49','7','eventdate','{EVENT.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('50','7','eventtime','{EVENT.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('52','7','eventack','{EVENT.ACK.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('53','7','eventupdate','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('54','7','eventvalue','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('55','7','url','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('56','8','token','<PUSHOVER TOKEN HERE>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('57','8','user','{ALERT.SENDTO}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('58','8','message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('59','8','title','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('60','8','url','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('61','8','url_title','Zabbix');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('63','8','eventid','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('64','8','triggerid','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('65','9','zabbix_url','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('66','9','bot_token','<PLACE YOUR KEY HERE>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('67','9','channel','{ALERT.SENDTO}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('68','9','slack_mode','alarm');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('69','9','slack_as_user','true');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('71','9','event_tags','{EVENT.TAGS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('73','9','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('75','9','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('76','9','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('77','9','event_date','{EVENT.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('78','9','event_time','{EVENT.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('79','9','event_severity','{EVENT.SEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('80','9','event_opdata','{EVENT.OPDATA}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('81','9','event_id','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('83','9','trigger_id','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('84','9','trigger_description','{TRIGGER.DESCRIPTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('85','9','host_name','{HOST.NAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('87','9','event_update_date','{EVENT.UPDATE.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('88','9','event_update_time','{EVENT.UPDATE.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('89','9','event_recovery_date','{EVENT.RECOVERY.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('90','9','event_recovery_time','{EVENT.RECOVERY.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('91','10','zabbix_url','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('92','10','discord_endpoint','{ALERT.SENDTO}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('93','10','use_default_message','false');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('94','10','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('95','10','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('96','10','event_name','{EVENT.NAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('97','10','event_id','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('98','10','event_severity','{EVENT.SEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('99','10','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('100','10','event_opdata','{EVENT.OPDATA}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('101','10','event_tags','{EVENT.TAGS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('102','10','event_time','{EVENT.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('103','10','event_date','{EVENT.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('104','10','event_recovery_date','{EVENT.RECOVERY.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('105','10','event_recovery_time','{EVENT.RECOVERY.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('106','10','event_update_date','{EVENT.UPDATE.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('107','10','event_update_time','{EVENT.UPDATE.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('108','10','event_update_action','{EVENT.UPDATE.ACTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('109','10','event_update_message','{EVENT.UPDATE.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('110','10','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('111','10','event_update_user','{USER.FULLNAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('112','10','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('113','10','host_ip','{HOST.IP}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('114','10','host_name','{HOST.NAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('115','10','trigger_description','{TRIGGER.DESCRIPTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('116','10','trigger_id','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('117','8','endpoint','https://api.pushover.net/1/messages.json');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('118','8','retry','60');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('119','8','expire','1200');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('120','11','teamsecret','{ALERT.SENDTO}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('121','11','Subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('122','11','Message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('123','11','Severity','{EVENT.SEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('125','11','Hostname','{HOST.NAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('127','12','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('128','12','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('129','12','event_recovery_value','{EVENT.RECOVERY.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('130','12','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('131','12','event_tags_json','{EVENT.TAGSJSON}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('132','12','event_update_action','{EVENT.UPDATE.ACTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('133','12','event_update_message','{EVENT.UPDATE.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('134','12','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('135','12','event_update_user','{USER.FULLNAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('136','12','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('137','12','jira_issue_key','{EVENT.TAGS.__zbx_jira_issuekey}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('138','12','jira_issue_type','<PLACE ISSUETYPE NAME>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('139','12','jira_password','<PLACE PASSWORD OR TOKEN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('140','12','jira_project_key','<PLACE PROJECT KEY>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('141','12','jira_url','<PLACE YOUR JIRA URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('142','12','jira_user','<PLACE LOGIN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('143','12','trigger_description','{TRIGGER.DESCRIPTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('144','13','<''DATETIME'' CUSTOMFIELD FOR EVENT RECOVERY TIME>','{EVENT.RECOVERY.DATE}T{EVENT.RECOVERY.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('145','13','<''DATETIME'' CUSTOMFIELD FOR EVENT TIME>','{EVENT.DATE}T{EVENT.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('146','13','<''NUMBER'' CUSTOMFIELD FOR EVENT.ID>','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('147','13','<''NUMBER'' CUSTOMFIELD FOR TRIGGER.ID>','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('148','13','<''STRING'' CUSTOMFIELD FOR HOST\IP>','{HOST.HOST} [{HOST.IP}]');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('149','13','<''STRING'' CUSTOMFIELD FOR OPERATIONAL DATA>','{EVENT.OPDATA}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('150','13','<''STRING'' CUSTOMFIELD FOR SEVERITY>','{EVENT.SEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('151','13','<''URL'' CUSTOMFIELD FOR EVENT URL>','{$ZABBIX.URL}/tr_events.php?triggerid={TRIGGER.ID}&eventid={EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('152','13','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('153','13','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('154','13','event_recovery_value','{EVENT.RECOVERY.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('155','13','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('156','13','event_tags_json','{EVENT.TAGSJSON}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('157','13','event_update_action','{EVENT.UPDATE.ACTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('158','13','event_update_message','{EVENT.UPDATE.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('159','13','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('160','13','event_update_user','{USER.FULLNAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('161','13','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('162','13','jira_issue_key','{EVENT.TAGS.__zbx_jira_issuekey}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('163','13','jira_issue_type','<PLACE ISSUETYPE NAME>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('164','13','jira_password','<PLACE PASSWORD OR TOKEN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('165','13','jira_project_key','<PLACE PROJECT KEY>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('166','13','jira_url','<PLACE YOUR JIRA URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('167','13','jira_user','<PLACE LOGIN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('168','13','trigger_description','{TRIGGER.DESCRIPTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('169','14','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('170','14','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('171','14','event_date','{EVENT.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('172','14','event_id','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('173','14','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('174','14','event_opdata','{EVENT.OPDATA}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('175','14','event_recovery_date','{EVENT.RECOVERY.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('176','14','event_recovery_time','{EVENT.RECOVERY.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('177','14','event_severity','{EVENT.SEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('178','14','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('179','14','event_status','{EVENT.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('180','14','event_tags','{EVENT.TAGS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('181','14','event_time','{EVENT.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('182','14','event_update_action','{EVENT.UPDATE.ACTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('183','14','event_update_date','{EVENT.UPDATE.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('184','14','event_update_message','{EVENT.UPDATE.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('185','14','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('186','14','event_update_time','{EVENT.UPDATE.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('187','14','event_update_user','{USER.FULLNAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('188','14','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('189','14','host_ip','{HOST.IP}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('190','14','host_name','{HOST.NAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('191','14','teams_endpoint','<PLACE WEBHOOK URL HERE>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('192','14','trigger_description','{TRIGGER.DESCRIPTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('193','14','trigger_id','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('194','14','use_default_message','false');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('195','14','zabbix_url','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('196','15','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('197','15','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('198','15','event_id','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('199','15','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('200','15','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('201','15','event_update_message','{EVENT.UPDATE.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('202','15','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('203','15','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('204','15','redmine_access_key','<PUT YOUR ACCESS KEY>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('205','15','redmine_issue_key','{EVENT.TAGS.__zbx_redmine_issue_id}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('206','15','redmine_project','<PUT YOUR PROJECT ID OR NAME>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('207','15','redmine_tracker_id','<PUT YOUR TRACKER ID>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('208','15','redmine_url','<PUT YOUR REDMINE URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('209','15','trigger_id','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('210','15','zabbix_url','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('211','16','Message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('212','16','ParseMode','');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('213','16','Subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('214','16','To','{ALERT.SENDTO}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('215','16','Token','<PLACE YOUR TOKEN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('216','17','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('217','17','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('218','17','event_id','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('219','17','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('220','17','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('221','17','event_tags','{EVENT.TAGS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('222','17','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('223','17','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('224','17','severity_average','normal');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('225','17','severity_default','-');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('226','17','severity_disaster','urgent');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('227','17','severity_high','high');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('228','17','severity_information','low');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('229','17','severity_not_classified','low');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('230','17','severity_warning','normal');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('231','17','trigger_id','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('232','17','zbxurl','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('233','17','zendesk_issue_key','{EVENT.TAGS.__zbx_zdk_issuekey}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('234','17','zendesk_token','<put your {enduser_email_address}/token:{api_token}>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('235','17','zendesk_type','incident');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('236','17','zendesk_url','<put your Zendesk URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('237','18','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('238','18','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('239','18','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('240','18','event_recovery_value','{EVENT.RECOVERY.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('241','18','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('242','18','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('243','18','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('244','18','servicenow_password','<PLACE PASSWORD HERE>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('245','18','servicenow_sys_id','{EVENT.TAGS.__zbx_servicenow_sys_id}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('246','18','servicenow_url','{ALERT.SENDTO}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('247','18','servicenow_user','<PLACE USERNAME HERE>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('248','18','urgency_for_average','2');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('249','18','urgency_for_disaster','1');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('250','18','urgency_for_high','2');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('251','18','urgency_for_information','3');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('252','18','urgency_for_not_classified','3');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('253','18','urgency_for_warning','3');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('254','19','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('255','19','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('256','19','event_id','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('257','19','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('258','19','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('259','19','event_tags','{EVENT.TAGSJSON}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('260','19','event_update_message','{EVENT.UPDATE.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('261','19','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('262','19','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('263','19','trigger_id','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('264','19','zabbix_url','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('265','19','zammad_access_token','<PUT YOUR ACCESS TOKEN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('266','19','zammad_customer','<PUT YOUR CUSTOMER EMAIL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('267','19','zammad_enable_tags','true');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('268','19','zammad_ticket_id','{EVENT.TAGS.__zbx_zammad_ticket_id}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('269','19','zammad_url','<PUT YOUR ZAMMAD URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('270','20','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('271','20','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('272','20','event_recovery_value','{EVENT.RECOVERY.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('273','20','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('274','20','event_tags_json','{EVENT.TAGSJSON}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('275','20','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('276','20','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('277','20','jira_password','<PLACE PASSWORD OR TOKEN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('278','20','jira_request_key','{EVENT.TAGS.__zbx_jira_requestkey}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('279','20','jira_request_type_id','<PLACE REQUEST TYPE ID>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('280','20','jira_servicedesk_id','<PLACE SERVICEDESK ID>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('281','20','jira_url','<PLACE YOUR JIRA URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('282','20','jira_user','<PLACE LOGIN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('283','21','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('284','21','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('285','21','event_id','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('286','21','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('287','21','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('288','21','event_update_message','{EVENT.UPDATE.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('289','21','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('290','21','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('291','21','otrs_auth_password','<PUT YOUR USER PASSWORD>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('292','21','otrs_auth_user','<PUT YOUR USER NAME>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('293','21','otrs_customer','<PUT YOUR CUSTOMER EMAIL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('294','21','otrs_default_priority_id','3');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('295','21','otrs_queue','<PUT YOUR QUEUE NAME>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('296','21','otrs_ticket_id','{EVENT.TAGS.__zbx_otrs_ticket_id}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('297','21','otrs_ticket_state','new');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('298','21','otrs_time_unit','0');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('299','21','otrs_url','<PUT YOUR OTRS URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('300','21','trigger_id','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('301','21','zabbix_url','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('302','11','Event_Ack_Status','{EVENT.ACK.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('303','11','Event_Date_Time','{EVENT.DATE} {EVENT.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('304','11','Event_ID','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('305','11','Event_Update_Action','{EVENT.UPDATE.ACTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('306','11','Event_Update_Status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('307','11','Host_IP','{HOST.IP}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('308','11','Trigger_ID','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('309','11','Trigger_Status','{TRIGGER.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('310','11','User','{USER.FULLNAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('311','11','Zabbix_URL','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('312','10','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('313','22','.ILERT.ALERT.SOURCE.KEY','{ALERT.SENDTO}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('314','22','.ILERT.INCIDENT.SUMMARY','');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('315','22','ALERT.MESSAGE','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('316','22','ALERT.SUBJECT','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('317','22','EVENT.ACK.STATUS','{EVENT.ACK.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('318','22','EVENT.DATE','{EVENT.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('319','22','EVENT.ID','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('320','22','EVENT.NAME','{EVENT.NAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('321','22','EVENT.NSEVERITY','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('322','22','EVENT.OPDATA','{EVENT.OPDATA}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('323','22','EVENT.RECOVERY.DATE','{EVENT.RECOVERY.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('324','22','EVENT.RECOVERY.TIME','{EVENT.RECOVERY.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('325','22','EVENT.RECOVERY.VALUE','{EVENT.RECOVERY.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('326','22','EVENT.SEVERITY','{EVENT.SEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('327','22','EVENT.TAGS','{EVENT.TAGS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('328','22','EVENT.TIME','{EVENT.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('329','22','EVENT.UPDATE.ACTION','{EVENT.UPDATE.ACTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('330','22','EVENT.UPDATE.DATE','{EVENT.UPDATE.DATE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('331','22','EVENT.UPDATE.MESSAGE','{EVENT.UPDATE.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('332','22','EVENT.UPDATE.STATUS','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('333','22','EVENT.UPDATE.TIME','{EVENT.UPDATE.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('334','22','EVENT.VALUE','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('335','22','HOST.HOST','{HOST.HOST}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('336','22','HOST.IP','{HOST.IP}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('337','22','HOST.NAME','{HOST.NAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('338','22','ITEM.ID1','{ITEM.ID1}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('339','22','ITEM.ID2','{ITEM.ID2}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('340','22','ITEM.ID3','{ITEM.ID3}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('341','22','ITEM.ID4','{ITEM.ID4}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('342','22','ITEM.ID5','{ITEM.ID5}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('343','22','ITEM.NAME1','{ITEM.NAME1}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('344','22','ITEM.NAME2','{ITEM.NAME2}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('345','22','ITEM.NAME3','{ITEM.NAME3}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('346','22','ITEM.NAME4','{ITEM.NAME4}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('347','22','ITEM.NAME5','{ITEM.NAME5}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('348','22','TRIGGER.DESCRIPTION','{TRIGGER.DESCRIPTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('349','22','TRIGGER.ID','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('350','22','TRIGGER.NAME','{TRIGGER.NAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('351','22','TRIGGER.SEVERITY','{TRIGGER.SEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('352','22','TRIGGER.STATUS','{TRIGGER.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('353','22','TRIGGER.URL','{TRIGGER.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('354','22','TRIGGER.VALUE','{TRIGGER.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('355','22','USER.FULLNAME','{USER.FULLNAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('356','22','ZABBIX.URL','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('357','5','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('358','5','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('359','5','discovery_host_dns','{DISCOVERY.DEVICE.DNS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('360','5','discovery_host_ip','{DISCOVERY.DEVICE.IPADDRESS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('361','5','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('362','6','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('363','6','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('364','6','event_id','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('365','6','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('366','6','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('367','6','event_tags_json','{EVENT.TAGSJSON}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('368','6','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('369','6','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('370','6','opsgenie_api','<put your opsgenie api>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('371','6','opsgenie_tags','');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('372','6','opsgenie_teams','');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('373','6','opsgenie_token','<put your token>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('374','6','opsgenie_web','<put your opsgenie web>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('375','6','severity_average','P3');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('376','6','severity_default','P5');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('377','6','severity_disaster','P1');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('378','6','severity_high','P2');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('379','6','severity_information','P5');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('380','6','severity_not_classified','P5');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('381','6','severity_warning','P4');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('382','6','trigger_id','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('383','6','zbxuser','{USER.FULLNAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('384','7','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('385','7','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('386','8','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('387','8','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('388','8','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('389','8','priority_average','0');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('390','8','priority_default','0');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('391','8','priority_disaster','0');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('392','8','priority_high','0');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('393','8','priority_information','0');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('394','8','priority_not_classified','0');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('395','8','priority_warning','0');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('396','9','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('397','9','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('398','9','discovery_host_dns','{DISCOVERY.DEVICE.DNS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('399','9','discovery_host_ip','{DISCOVERY.DEVICE.IPADDRESS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('400','9','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('401','9','host_conn','{HOST.CONN}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('402','23','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('403','23','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('404','23','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('405','23','event_recovery_value','{EVENT.RECOVERY.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('406','23','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('407','23','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('408','23','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('409','23','priority_average','Medium');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('410','23','priority_default','Low');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('411','23','priority_disaster','Critical');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('412','23','priority_high','High');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('413','23','samanage_incident_id','{EVENT.TAGS.__zbx_solarwinds_inc_id}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('414','23','samanage_token','<PUT YOUR TOKEN HERE>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('415','23','samanage_url','<PUT YOUR INSTANCE URL HERE>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('416','24','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('417','24','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('418','24','event_id','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('419','24','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('420','24','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('421','24','event_update_message','{EVENT.UPDATE.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('422','24','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('423','24','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('424','24','sysaid_auth_password','<PUT YOUR USER PASSWORD>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('425','24','sysaid_auth_user','<PUT YOUR USER NAME>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('426','24','sysaid_category_level_1','<PUT YOUR CATEGORY>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('427','24','sysaid_category_level_2','<PUT YOUR SUB-CATEGORY>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('428','24','sysaid_category_level_3','<PUT YOUR THIRD LEVEL CATEGORY>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('429','24','sysaid_default_priority_id','1');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('430','24','sysaid_incident_id','{EVENT.TAGS.__zbx_sysaid_incident_id}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('431','24','sysaid_incident_state','1');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('432','24','sysaid_template_id','<PUT YOUR TEMPLATE ID>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('433','24','sysaid_urgency_id','<PUT YOUR URGENCY ID>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('434','24','sysaid_url','<PUT YOUR SYSAID URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('435','24','trigger_id','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('436','24','zabbix_url','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('437','25','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('438','25','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('439','25','event_id','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('440','25','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('441','25','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('442','25','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('443','25','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('444','25','severity_average','P3');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('445','25','severity_default','P5');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('446','25','severity_disaster','P1');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('447','25','severity_high','P2');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('448','25','severity_information','P5');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('449','25','severity_not_classified','P5');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('450','25','severity_warning','P4');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('451','25','topdesk_api','<put your TOPdesk API URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('452','25','topdesk_issue_key','{EVENT.TAGS.__zbx_tpd_issuekey}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('453','25','topdesk_password','<put your TOPdesk application password>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('454','25','topdesk_status','<put default status for new tickets>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('455','25','topdesk_user','<put your TOPdesk username>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('456','25','trigger_id','{TRIGGER.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('457','25','zbxurl','{$ZABBIX.URL}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('458','26','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('459','26','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('460','26','event_recovery_value','{EVENT.RECOVERY.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('461','26','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('462','26','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('463','26','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('464','26','itop_api_version','1.3');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('465','26','itop_class','UserRequest');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('466','26','itop_comment','Created by Zabbix action {ACTION.NAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('467','26','itop_id','{EVENT.TAGS.__zbx_itop_id}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('468','26','itop_log','private_log');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('469','26','itop_organization_id','<PLACE ORGANIZATION ID>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('470','26','itop_password','<PLACE PASSWORD OR TOKEN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('471','26','itop_url','<PLACE YOUR ITOP URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('472','26','itop_user','<PLACE LOGIN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('473','27','alert_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('474','27','alert_subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('475','27','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('476','27','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('477','27','event_update_action','{EVENT.UPDATE.ACTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('478','27','event_update_message','{EVENT.UPDATE.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('479','27','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('480','27','event_update_user','{USER.FULLNAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('481','27','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('482','27','field_1_full:Host','{HOST.NAME} [{HOST.IP}]');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('483','27','field_2_short:Severity','{EVENT.SEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('484','27','field_3_short:Event time','{EVENT.DATE} {EVENT.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('485','27','field_3_short_r:Recovery time','{EVENT.RECOVERY.DATE} {EVENT.RECOVERY.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('486','27','field_4_short_r:Event duration','{EVENT.DURATION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('487','27','field_5_short:Operational data','{EVENT.OPDATA}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('488','27','field_999_full_p:Trigger description','{TRIGGER.DESCRIPTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('489','27','rc_api_url','api/v1/');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('490','27','rc_msg_id','{EVENT.TAGS.__zbx_rc_id}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('491','27','rc_room_id','{EVENT.TAGS.__zbx_rc_rid}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('492','27','rc_send_to','{ALERT.SENDTO}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('493','27','rc_title_link','{$ZABBIX.URL}/tr_events.php?triggerid={TRIGGER.ID}&eventid={EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('494','27','rc_url','<PLACE YOUR INSTANCE URL HERE>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('495','27','rc_user_id','<PLACE USER ID HERE>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('496','27','rc_user_token','<PLACE TOKEN HERE>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('497','27','use_default_message','false');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('498','28','event_info','{$ZABBIX.URL}/tr_events.php?triggerid={TRIGGER.ID}&eventid={EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('499','28','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('500','28','event_recovery_value','{EVENT.RECOVERY.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('501','28','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('502','28','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('503','28','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('504','28','field:entity_display_name','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('505','28','field:entity_id','{EVENT.ID}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('506','28','field:hostname','{HOST.NAME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('507','28','field:monitoring_tool','Zabbix');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('508','28','field:operational_data','{EVENT.OPDATA}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('509','28','field:severity','{EVENT.SEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('510','28','field:state_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('511','28','field_p:trigger_description','{TRIGGER.DESCRIPTION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('512','28','field_r:event_duration','{EVENT.DURATION}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('513','28','field_r:recovery time','{EVENT.RECOVERY.DATE} {EVENT.RECOVERY.TIME}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('514','28','priority_average','WARNING');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('515','28','priority_default','INFO');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('516','28','priority_disaster','CRITICAL');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('517','28','priority_high','WARNING');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('518','28','priority_information','INFO');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('519','28','priority_not_classified','INFO');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('520','28','priority_resolved','OK');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('521','28','priority_update','INFO');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('522','28','priority_warning','INFO');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('523','28','vops_endpoint','<PLACE ENDPOINT URL HERE>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('524','28','vops_routing_key','{ALERT.SENDTO}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('525','29','endpoint','<PLACE HTTP API URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('526','29','flash','false');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('527','29','password','<PLACE PASSWORD>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('528','29','ring','false');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('529','29','send_to','{ALERT.SENDTO}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('530','29','telauto','true');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('531','29','text','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('532','29','username','<PLACE USERNAME>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('533','9','channel_id','{EVENT.TAGS.__channel_id}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('534','9','message_ts','{EVENT.TAGS.__message_ts}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('535','30','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('536','30','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('537','30','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('538','30','express_message','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('539','30','express_send_to','{ALERT.SENDTO}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('540','30','express_tags','{EVENT.TAGSJSON}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('541','30','express_token','<PLACE BOT TOKEN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('542','30','express_url','<PLACE INSTANCE URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('543','31','event_nseverity','{EVENT.NSEVERITY}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('544','31','event_recovery_value','{EVENT.RECOVERY.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('545','31','event_source','{EVENT.SOURCE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('546','31','event_update_status','{EVENT.UPDATE.STATUS}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('547','31','event_value','{EVENT.VALUE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('548','31','field_ref:requester','<PLACE API USER NAME>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('549','31','field_string:description','{ALERT.MESSAGE}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('550','31','field_string:subject','{ALERT.SUBJECT}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('551','31','priority_average','Normal');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('552','31','priority_default','Normal');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('553','31','priority_disaster','High');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('554','31','priority_high','High');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('555','31','priority_information','Low');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('556','31','priority_not_classified','Low');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('557','31','priority_warning','Medium');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('558','31','sd_on_demand_client_id','<PLACE ON DEMAND CLIENT ID>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('559','31','sd_on_demand_client_secret','<PLACE ON DEMAND CLIENT SECRET>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('560','31','sd_on_demand_refresh_token','<PLACE ON DEMAND REFRESH TOKEN>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('561','31','sd_on_demand_url_auth','<PLACE AUTHENTICATION URL FOR ON DEMAND>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('562','31','sd_on_premise','true');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('563','31','sd_on_premise_auth_token','<PLACE ON PREMISE TECHNICIAN_KEY>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('564','31','sd_request_id','{EVENT.TAGS.__zbx_sd_request_id}');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('565','31','sd_url','<PLACE INSTANCE URL>');
INSERT INTO media_type_param (mediatype_paramid,mediatypeid,name,value) values ('566','31','trigger_description','{TRIGGER.DESCRIPTION}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('1','1','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('2','1','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','Problem has been resolved at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Problem duration: {EVENT.DURATION}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('3','1','0','2','Updated problem in {EVENT.AGE}: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, age is {EVENT.AGE}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('4','1','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('5','1','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('6','3','0','0','','{EVENT.SEVERITY}: {EVENT.NAME}
Host: {HOST.NAME}
{EVENT.DATE} {EVENT.TIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('7','3','0','1','','Resolved in {EVENT.DURATION}: {EVENT.NAME}
Host: {HOST.NAME}
{EVENT.DATE} {EVENT.TIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('8','3','0','2','','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem in {EVENT.AGE} at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('9','3','1','0','','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('10','3','2','0','','Autoregistration: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('11','4','0','0','Problem: {EVENT.NAME}','<b>Problem started</b> at {EVENT.TIME} on {EVENT.DATE}<br><b>Problem name:</b> {EVENT.NAME}<br><b>Host:</b> {HOST.NAME}<br><b>Severity:</b> {EVENT.SEVERITY}<br><b>Operational data:</b> {EVENT.OPDATA}<br><b>Original problem ID:</b> {EVENT.ID}<br>{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('12','4','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','<b>Problem has been resolved</b> at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}<br><b>Problem name:</b> {EVENT.NAME}<br><b>Problem duration:</b> {EVENT.DURATION}<br><b>Host:</b> {HOST.NAME}<br><b>Severity:</b> {EVENT.SEVERITY}<br><b>Original problem ID:</b> {EVENT.ID}<br>{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('13','4','0','2','Updated problem in {EVENT.AGE}: {EVENT.NAME}','<b>{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem</b> at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.<br>{EVENT.UPDATE.MESSAGE}<br><br><b>Current problem status:</b> {EVENT.STATUS}<br><b>Age:</b> {EVENT.AGE}<br><b>Acknowledged:</b> {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('14','4','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','<b>Discovery rule:</b> {DISCOVERY.RULE.NAME}<br><br><b>Device IP:</b> {DISCOVERY.DEVICE.IPADDRESS}<br><b>Device DNS:</b> {DISCOVERY.DEVICE.DNS}<br><b>Device status:</b> {DISCOVERY.DEVICE.STATUS}<br><b>Device uptime:</b> {DISCOVERY.DEVICE.UPTIME}<br><br><b>Device service name:</b> {DISCOVERY.SERVICE.NAME}<br><b>Device service port:</b> {DISCOVERY.SERVICE.PORT}<br><b>Device service status:</b> {DISCOVERY.SERVICE.STATUS}<br><b>Device service uptime:</b> {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('15','4','2','0','Autoregistration: {HOST.HOST}','<b>Host name:</b> {HOST.HOST}<br><b>Host IP:</b> {HOST.IP}<br><b>Agent port:</b> {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('16','11','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('17','11','0','1','Resolved: {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('18','11','0','2','Updated problem: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('19','11','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('20','11','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('21','12','0','0','[{EVENT.STATUS}] {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('22','12','0','1','[{EVENT.STATUS}] {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('23','12','0','2','[{EVENT.STATUS}] {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('24','12','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('25','12','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('26','13','0','0','[{EVENT.STATUS}] {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('27','13','0','1','[{EVENT.STATUS}] {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('28','13','0','2','[{EVENT.STATUS}] {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('29','13','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('30','13','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('31','14','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('32','14','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('33','14','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('34','14','0','1','Resolved: {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('35','14','0','2','Updated problem: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('36','15','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('37','15','0','1','Resolved: {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('38','15','0','2','Updated problem: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('39','15','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('40','15','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('41','16','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('42','16','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('43','16','0','2','Updated problem: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('44','16','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('45','16','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('46','17','0','0','{EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('47','17','0','1','{EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('48','17','0','2','{EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('49','17','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('50','17','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('51','17','3','0','Internal problem: {EVENT.NAME}','Internal problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('52','18','0','0','[{EVENT.STATUS}] {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('53','18','0','1','[{EVENT.STATUS}] {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('54','18','0','2','[{EVENT.STATUS}] {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('55','18','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('56','18','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('57','19','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('58','19','0','1','Resolved: {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('59','19','0','2','Updated problem: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('60','19','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('61','19','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('62','20','0','0','{EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('63','20','0','1','{EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('64','20','0','2','{EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('65','20','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('66','20','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('67','21','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('68','21','0','1','Resolved: {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('69','21','0','2','Updated problem: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('70','21','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('71','21','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('72','10','0','0','[{EVENT.STATUS}] {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('73','10','0','1','[{EVENT.STATUS}] {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('74','10','0','2','[{EVENT.STATUS}] {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('75','10','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('76','10','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('77','22','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('78','22','0','2','Updated problem in {EVENT.AGE}: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, age is {EVENT.AGE}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('79','22','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','Problem has been resolved at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Problem duration: {EVENT.DURATION}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('80','5','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('81','5','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','Problem has been resolved at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Problem duration: {EVENT.DURATION}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('82','5','0','2','Updated problem in {EVENT.AGE}: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, age is {EVENT.AGE}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('83','5','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('84','5','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('85','6','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('86','6','0','2','Updated problem in {EVENT.AGE}: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, age is {EVENT.AGE}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('87','6','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('88','6','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('89','6','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','Problem has been resolved at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Problem duration: {EVENT.DURATION}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('90','7','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('91','7','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','Problem has been resolved at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Problem duration: {EVENT.DURATION}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('92','7','0','2','Updated problem in {EVENT.AGE}: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, age is {EVENT.AGE}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('93','7','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('94','7','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('95','8','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('96','8','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','Problem has been resolved at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Problem duration: {EVENT.DURATION}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('97','8','0','2','Updated problem in {EVENT.AGE}: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, age is {EVENT.AGE}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('98','8','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('99','8','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('100','9','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('101','9','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','Problem has been resolved at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Problem duration: {EVENT.DURATION}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('102','9','0','2','Updated problem in {EVENT.AGE}: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, age is {EVENT.AGE}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('103','9','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('104','9','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('105','23','0','0','[{EVENT.STATUS}] {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}

Trigger description: {TRIGGER.DESCRIPTION}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('106','23','0','1','[{EVENT.STATUS}] {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('107','23','0','2','[{EVENT.STATUS}] {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('108','23','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('109','23','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('110','24','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('111','24','0','1','Resolved: {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('112','24','0','2','Updated problem: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('113','24','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('114','24','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('115','25','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('116','25','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','Problem has been resolved at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Problem duration: {EVENT.DURATION}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('117','25','0','2','Updated problem in {EVENT.AGE}: {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, age is {EVENT.AGE}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('118','25','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('119','25','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('120','26','0','0','[{EVENT.STATUS}] {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('121','26','0','1','[{EVENT.STATUS}] {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('122','26','0','2','[{EVENT.STATUS}] {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('123','26','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('124','26','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('125','27','0','0','[{EVENT.STATUS}] {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('126','27','0','1','[{EVENT.STATUS}] {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('127','27','0','2','[{EVENT.STATUS}] {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('128','27','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('129','27','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('130','28','0','0','Problem: {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('131','28','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','Problem has been resolved at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Problem duration: {EVENT.DURATION}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('132','28','0','2','[{EVENT.STATUS}] {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('133','28','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('134','28','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('135','29','0','0','[{EVENT.STATUS}] {EVENT.NAME}','[{EVENT.STATUS}] {EVENT.NAME}
Started at {EVENT.TIME} on {EVENT.DATE}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Event info: {$ZABBIX.URL}/tr_events.php?triggerid={TRIGGER.ID}&eventid={EVENT.ID}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('136','29','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','[{EVENT.STATUS}] {EVENT.NAME}
Resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Event info: {$ZABBIX.URL}/tr_events.php?triggerid={TRIGGER.ID}&eventid={EVENT.ID}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('137','29','0','2','[{EVENT.STATUS}] {EVENT.NAME}','[{EVENT.STATUS}] {EVENT.NAME}

{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('138','29','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}
Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('139','29','2','0','Autoregistration: {HOST.HOST}','Autoregistration: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('140','30','0','0','[{EVENT.STATUS}] {EVENT.NAME}','[{EVENT.STATUS}] {EVENT.NAME}
Started at {EVENT.TIME} on {EVENT.DATE}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Event info: {$ZABBIX.URL}/tr_events.php?triggerid={TRIGGER.ID}&eventid={EVENT.ID}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('141','30','0','1','Resolved in {EVENT.DURATION}: {EVENT.NAME}','[{EVENT.STATUS}] {EVENT.NAME}
Resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Event info: {$ZABBIX.URL}/tr_events.php?triggerid={TRIGGER.ID}&eventid={EVENT.ID}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('142','30','0','2','[{EVENT.STATUS}] {EVENT.NAME}','[{EVENT.STATUS}] {EVENT.NAME}

{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('143','30','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}
Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('144','30','2','0','Autoregistration: {HOST.HOST}','Autoregistration: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('145','31','0','0','[{EVENT.STATUS}] {EVENT.NAME}','Problem started at {EVENT.TIME} on {EVENT.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Operational data: {EVENT.OPDATA}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('146','31','0','1','[{EVENT.STATUS}] {EVENT.NAME}','Problem has been resolved in {EVENT.DURATION} at {EVENT.RECOVERY.TIME} on {EVENT.RECOVERY.DATE}
Problem name: {EVENT.NAME}
Host: {HOST.NAME}
Severity: {EVENT.SEVERITY}
Original problem ID: {EVENT.ID}
{TRIGGER.URL}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('147','31','0','2','[{EVENT.STATUS}] {EVENT.NAME}','{USER.FULLNAME} {EVENT.UPDATE.ACTION} problem at {EVENT.UPDATE.DATE} {EVENT.UPDATE.TIME}.
{EVENT.UPDATE.MESSAGE}

Current problem status is {EVENT.STATUS}, acknowledged: {EVENT.ACK.STATUS}.');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('148','31','1','0','Discovery: {DISCOVERY.DEVICE.STATUS} {DISCOVERY.DEVICE.IPADDRESS}','Discovery rule: {DISCOVERY.RULE.NAME}

Device IP: {DISCOVERY.DEVICE.IPADDRESS}
Device DNS: {DISCOVERY.DEVICE.DNS}
Device status: {DISCOVERY.DEVICE.STATUS}
Device uptime: {DISCOVERY.DEVICE.UPTIME}

Device service name: {DISCOVERY.SERVICE.NAME}
Device service port: {DISCOVERY.SERVICE.PORT}
Device service status: {DISCOVERY.SERVICE.STATUS}
Device service uptime: {DISCOVERY.SERVICE.UPTIME}');
INSERT INTO media_type_message (mediatype_messageid,mediatypeid,eventsource,recovery,subject,message) values ('149','31','2','0','Autoregistration: {HOST.HOST}','Host name: {HOST.HOST}
Host IP: {HOST.IP}
Agent port: {HOST.PORT}');
INSERT INTO usrgrp (usrgrpid,name,gui_access,users_status,debug_mode) values ('7','Zabbix administrators','0','0','0');
INSERT INTO usrgrp (usrgrpid,name,gui_access,users_status,debug_mode) values ('8','Guests','1','0','0');
INSERT INTO usrgrp (usrgrpid,name,gui_access,users_status,debug_mode) values ('9','Disabled','0','1','0');
INSERT INTO usrgrp (usrgrpid,name,gui_access,users_status,debug_mode) values ('11','Enabled debug mode','0','0','1');
INSERT INTO usrgrp (usrgrpid,name,gui_access,users_status,debug_mode) values ('12','No access to the frontend','3','0','0');
INSERT INTO users_groups (id,usrgrpid,userid) values ('2','8','2');
INSERT INTO users_groups (id,usrgrpid,userid) values ('3','9','2');
INSERT INTO users_groups (id,usrgrpid,userid) values ('4','7','1');
INSERT INTO scripts (scriptid,name,command,host_access,usrgrpid,groupid,description,confirmation,type,execute_on) values ('1','Ping','ping -c 3 {HOST.CONN}; case $? in [01]) true;; *) false;; esac','2',NULL,NULL,'','','0','2');
INSERT INTO scripts (scriptid,name,command,host_access,usrgrpid,groupid,description,confirmation,type,execute_on) values ('2','Traceroute','/usr/sbin/traceroute {HOST.CONN}','2',NULL,NULL,'','','0','2');
INSERT INTO scripts (scriptid,name,command,host_access,usrgrpid,groupid,description,confirmation,type,execute_on) values ('3','Detect operating system','doas /usr/local/bin/nmap -O {HOST.CONN}','2','7',NULL,'','','0','2');
INSERT INTO actions (actionid,name,eventsource,evaltype,status,esc_period,formula,pause_suppressed) values ('2','Auto discovery. Linux servers.','1','0','1','0','','1');
INSERT INTO actions (actionid,name,eventsource,evaltype,status,esc_period,formula,pause_suppressed) values ('3','Report problems to Zabbix administrators','0','0','1','1h','','1');
INSERT INTO actions (actionid,name,eventsource,evaltype,status,esc_period,formula,pause_suppressed) values ('4','Report not supported items','3','0','1','1h','','1');
INSERT INTO actions (actionid,name,eventsource,evaltype,status,esc_period,formula,pause_suppressed) values ('5','Report not supported low level discovery rules','3','0','1','1h','','1');
INSERT INTO actions (actionid,name,eventsource,evaltype,status,esc_period,formula,pause_suppressed) values ('6','Report unknown triggers','3','0','1','1h','','1');
INSERT INTO operations (operationid,actionid,operationtype,esc_period,esc_step_from,esc_step_to,evaltype,recovery) values ('1','2','6','0','1','1','0','0');
INSERT INTO operations (operationid,actionid,operationtype,esc_period,esc_step_from,esc_step_to,evaltype,recovery) values ('2','2','4','0','1','1','0','0');
INSERT INTO operations (operationid,actionid,operationtype,esc_period,esc_step_from,esc_step_to,evaltype,recovery) values ('3','3','0','0','1','1','0','0');
INSERT INTO operations (operationid,actionid,operationtype,esc_period,esc_step_from,esc_step_to,evaltype,recovery) values ('4','4','0','0','1','1','0','0');
INSERT INTO operations (operationid,actionid,operationtype,esc_period,esc_step_from,esc_step_to,evaltype,recovery) values ('5','5','0','0','1','1','0','0');
INSERT INTO operations (operationid,actionid,operationtype,esc_period,esc_step_from,esc_step_to,evaltype,recovery) values ('6','6','0','0','1','1','0','0');
INSERT INTO operations (operationid,actionid,operationtype,esc_period,esc_step_from,esc_step_to,evaltype,recovery) values ('7','3','11','0','1','1','0','1');
INSERT INTO operations (operationid,actionid,operationtype,esc_period,esc_step_from,esc_step_to,evaltype,recovery) values ('8','4','11','0','1','1','0','1');
INSERT INTO operations (operationid,actionid,operationtype,esc_period,esc_step_from,esc_step_to,evaltype,recovery) values ('9','5','11','0','1','1','0','1');
INSERT INTO operations (operationid,actionid,operationtype,esc_period,esc_step_from,esc_step_to,evaltype,recovery) values ('10','6','11','0','1','1','0','1');
INSERT INTO opmessage (operationid,default_msg,subject,message,mediatypeid) values ('3','1','','',NULL);
INSERT INTO opmessage (operationid,default_msg,subject,message,mediatypeid) values ('4','1','','',NULL);
INSERT INTO opmessage (operationid,default_msg,subject,message,mediatypeid) values ('5','1','','',NULL);
INSERT INTO opmessage (operationid,default_msg,subject,message,mediatypeid) values ('6','1','','',NULL);
INSERT INTO opmessage (operationid,default_msg,subject,message,mediatypeid) values ('7','1','','',NULL);
INSERT INTO opmessage (operationid,default_msg,subject,message,mediatypeid) values ('8','1','','',NULL);
INSERT INTO opmessage (operationid,default_msg,subject,message,mediatypeid) values ('9','1','','',NULL);
INSERT INTO opmessage (operationid,default_msg,subject,message,mediatypeid) values ('10','1','','',NULL);
INSERT INTO opmessage_grp (opmessage_grpid,operationid,usrgrpid) values ('1','3','7');
INSERT INTO opmessage_grp (opmessage_grpid,operationid,usrgrpid) values ('2','4','7');
INSERT INTO opmessage_grp (opmessage_grpid,operationid,usrgrpid) values ('3','5','7');
INSERT INTO opmessage_grp (opmessage_grpid,operationid,usrgrpid) values ('4','6','7');
INSERT INTO opgroup (opgroupid,operationid,groupid) values ('1','2','2');
INSERT INTO conditions (conditionid,actionid,conditiontype,operator,value,value2) values ('2','2','10','0','0','');
INSERT INTO conditions (conditionid,actionid,conditiontype,operator,value,value2) values ('3','2','8','0','9','');
INSERT INTO conditions (conditionid,actionid,conditiontype,operator,value,value2) values ('4','2','12','2','Linux','');
INSERT INTO conditions (conditionid,actionid,conditiontype,operator,value,value2) values ('6','4','23','0','0','');
INSERT INTO conditions (conditionid,actionid,conditiontype,operator,value,value2) values ('7','5','23','0','2','');
INSERT INTO conditions (conditionid,actionid,conditiontype,operator,value,value2) values ('8','6','23','0','4','');
INSERT INTO config (configid,refresh_unsupported,work_period,alert_usrgrpid,discovery_groupid) values ('1','10m','1-5,09:00-18:00','7','5');
INSERT INTO graph_theme (graphthemeid,theme,backgroundcolor,graphcolor,gridcolor,maingridcolor,gridbordercolor,textcolor,highlightcolor,leftpercentilecolor,rightpercentilecolor,nonworktimecolor,colorpalette) values ('1','blue-theme','FFFFFF','FFFFFF','CCD5D9','ACBBC2','ACBBC2','1F2C33','E33734','429E47','E33734','EBEBEB','1A7C11,F63100,2774A4,A54F10,FC6EA3,6C59DC,AC8C14,611F27,F230E0,5CCD18,BB2A02,5A2B57,89ABF8,7EC25C,274482,2B5429,8048B4,FD5434,790E1F,87AC4D,E89DF4');
INSERT INTO graph_theme (graphthemeid,theme,backgroundcolor,graphcolor,gridcolor,maingridcolor,gridbordercolor,textcolor,highlightcolor,leftpercentilecolor,rightpercentilecolor,nonworktimecolor,colorpalette) values ('2','dark-theme','2B2B2B','2B2B2B','454545','4F4F4F','4F4F4F','F2F2F2','E45959','59DB8F','E45959','333333','199C0D,F63100,2774A4,F7941D,FC6EA3,6C59DC,C7A72D,BA2A5D,F230E0,5CCD18,BB2A02,AC41A5,89ABF8,7EC25C,3165D5,79A277,AA73DE,FD5434,F21C3E,87AC4D,E89DF4');
INSERT INTO graph_theme (graphthemeid,theme,backgroundcolor,graphcolor,gridcolor,maingridcolor,gridbordercolor,textcolor,highlightcolor,leftpercentilecolor,rightpercentilecolor,nonworktimecolor,colorpalette) values ('3','hc-light','FFFFFF','FFFFFF','555555','000000','333333','000000','333333','000000','000000','EBEBEB','1A7C11,F63100,2774A4,A54F10,FC6EA3,6C59DC,AC8C14,611F27,F230E0,5CCD18,BB2A02,5A2B57,89ABF8,7EC25C,274482,2B5429,8048B4,FD5434,790E1F,87AC4D,E89DF4');
INSERT INTO graph_theme (graphthemeid,theme,backgroundcolor,graphcolor,gridcolor,maingridcolor,gridbordercolor,textcolor,highlightcolor,leftpercentilecolor,rightpercentilecolor,nonworktimecolor,colorpalette) values ('4','hc-dark','000000','000000','666666','888888','4F4F4F','FFFFFF','FFFFFF','FFFFFF','FFFFFF','333333','199C0D,F63100,2774A4,F7941D,FC6EA3,6C59DC,C7A72D,BA2A5D,F230E0,5CCD18,BB2A02,AC41A5,89ABF8,7EC25C,3165D5,79A277,AA73DE,FD5434,F21C3E,87AC4D,E89DF4');
INSERT INTO globalmacro (globalmacroid,macro,value,description,type) values ('2','{$SNMP_COMMUNITY}','public','','0');
INSERT INTO regexps (regexpid,name,test_string) values ('1','File systems for discovery','ext3');
INSERT INTO regexps (regexpid,name,test_string) values ('2','Network interfaces for discovery','eth0');
INSERT INTO regexps (regexpid,name,test_string) values ('3','Storage devices for SNMP discovery','/boot');
INSERT INTO regexps (regexpid,name,test_string) values ('4','Windows service names for discovery','SysmonLog');
INSERT INTO regexps (regexpid,name,test_string) values ('5','Windows service startup states for discovery','automatic');
INSERT INTO expressions (expressionid,regexpid,expression,expression_type,exp_delimiter,case_sensitive) values ('1','1','^(btrfs|ext2|ext3|ext4|reiser|xfs|ffs|ufs|jfs|jfs2|vxfs|hfs|apfs|refs|ntfs|fat32|zfs)$','3',',','0');
INSERT INTO expressions (expressionid,regexpid,expression,expression_type,exp_delimiter,case_sensitive) values ('3','3','^(Physical memory|Virtual memory|Memory buffers|Cached memory|Swap space)$','4',',','1');
INSERT INTO expressions (expressionid,regexpid,expression,expression_type,exp_delimiter,case_sensitive) values ('5','4','^(MMCSS|gupdate|SysmonLog|clr_optimization_v2.0.50727_32|clr_optimization_v4.0.30319_32)$','4',',','1');
INSERT INTO expressions (expressionid,regexpid,expression,expression_type,exp_delimiter,case_sensitive) values ('6','5','^(automatic|automatic delayed)$','3',',','1');
INSERT INTO expressions (expressionid,regexpid,expression,expression_type,exp_delimiter,case_sensitive) values ('7','2','^Software Loopback Interface','4',',','1');
INSERT INTO expressions (expressionid,regexpid,expression,expression_type,exp_delimiter,case_sensitive) values ('8','2','^(In)?[Ll]oop[Bb]ack[0-9._]*$','4',',','1');
INSERT INTO expressions (expressionid,regexpid,expression,expression_type,exp_delimiter,case_sensitive) values ('9','2','^NULL[0-9.]*$','4',',','1');
INSERT INTO expressions (expressionid,regexpid,expression,expression_type,exp_delimiter,case_sensitive) values ('10','2','^[Ll]o[0-9.]*$','4',',','1');
INSERT INTO expressions (expressionid,regexpid,expression,expression_type,exp_delimiter,case_sensitive) values ('11','2','^[Ss]ystem$','4',',','1');
INSERT INTO expressions (expressionid,regexpid,expression,expression_type,exp_delimiter,case_sensitive) values ('12','2','^Nu[0-9.]*$','4',',','1');
INSERT INTO config_autoreg_tls (autoreg_tlsid,tls_psk_identity,tls_psk) values ('1','','');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10001',NULL,'Template OS Linux by Zabbix agent','3','-1','2','','','Template OS Linux by Zabbix agent','0',NULL,'Official Linux template. Requires agent of Zabbix 3.0.14, 3.4.5 and 4.0.0 or newer.

Known Issues:

  Description: Network discovery. Zabbix agent as of 4.2 doesn''t support items such as net.if.status, net.if.speed.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387225-discussion-thread-for-official-zabbix-template-for-linux

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10047',NULL,'Template App Zabbix Server','3','-1','2','','','Template App Zabbix Server','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10048',NULL,'Template App Zabbix Proxy','3','-1','2','','','Template App Zabbix Proxy','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10050',NULL,'Template Module Zabbix agent','3','-1','2','','','Template Module Zabbix agent','0',NULL,'Use this template for agents reachable from Zabbix server/proxy (passive mode).

Template tooling version used: 0.34','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10074',NULL,'Template OS OpenBSD','3','-1','2','','','Template OS OpenBSD','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10075',NULL,'Template OS FreeBSD','3','-1','2','','','Template OS FreeBSD','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10076',NULL,'Template OS AIX','3','-1','2','','','Template OS AIX','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10077',NULL,'Template OS HP-UX','3','-1','2','','','Template OS HP-UX','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10078',NULL,'Template OS Solaris','3','-1','2','','','Template OS Solaris','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10079',NULL,'Template OS Mac OS X','3','-1','2','','','Template OS Mac OS X','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10081',NULL,'Template OS Windows by Zabbix agent','3','-1','2','','','Template OS Windows by Zabbix agent','0',NULL,'Official Windows template. Requires agent of Zabbix 4.4 and newer.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387224-discussion-thread-for-official-zabbix-template-for-windows

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10084',NULL,'Zabbix server','0','-1','2','','','Zabbix server','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10093',NULL,'Template App FTP Service','3','-1','2','','','Template App FTP Service','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10094',NULL,'Template App HTTP Service','3','-1','2','','','Template App HTTP Service','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10095',NULL,'Template App HTTPS Service','3','-1','2','','','Template App HTTPS Service','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10096',NULL,'Template App IMAP Service','3','-1','2','','','Template App IMAP Service','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10097',NULL,'Template App LDAP Service','3','-1','2','','','Template App LDAP Service','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10098',NULL,'Template App NNTP Service','3','-1','2','','','Template App NNTP Service','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10099',NULL,'Template App NTP Service','3','-1','2','','','Template App NTP Service','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10100',NULL,'Template App POP Service','3','-1','2','','','Template App POP Service','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10101',NULL,'Template App SMTP Service','3','-1','2','','','Template App SMTP Service','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10102',NULL,'Template App SSH Service','3','-1','2','','','Template App SSH Service','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10103',NULL,'Template App Telnet Service','3','-1','2','','','Template App Telnet Service','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10169',NULL,'Template App Generic Java JMX','3','-1','2','','','Template App Generic Java JMX','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10170',NULL,'Template DB MySQL','3','-1','2','','','Template DB MySQL','0',NULL,'Requirements for template operation:
1.Install Zabbix agent and MySQL client.
2.Copy Template_DB_MySQL.conf into folder with Zabbix agent configuration (/etc/zabbix/zabbix_agentd.d/ by default). Don''t forget restart zabbix-agent. 
3.Create MySQL user for monitoring. For example:
CREATE USER ''zbx_monitor''@''%'' IDENTIFIED BY ''<password>'';
GRANT USAGE,REPLICATION CLIENT,PROCESS,SHOW DATABASES,SHOW VIEW ON *.* TO ''zbx_monitor''@''%'';
For more information read the MYSQL documentation https://dev.mysql.com/doc/refman/8.0/en/grant.html , please. 
4.Create .my.cnf in home directory of Zabbix agent for Linux (/var/lib/zabbix by default ) or my.cnf in c:\ for Windows. For example:
[client]
user=zbx_monitor
password=<password>','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10171',NULL,'Template Server Intel SR1530 IPMI','3','-1','2','','','Template Server Intel SR1530 IPMI','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10172',NULL,'Template Server Intel SR1630 IPMI','3','-1','2','','','Template Server Intel SR1630 IPMI','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10173',NULL,'Template VM VMware','3','-1','2','','','Template VM VMware','0',NULL,'You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10174',NULL,'Template VM VMware Guest','3','-1','2','','','Template VM VMware Guest','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10175',NULL,'Template VM VMware Hypervisor','3','-1','2','','','Template VM VMware Hypervisor','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10183',NULL,'Template Module EtherLike-MIB SNMP','3','-1','2','','','Template Module EtherLike-MIB SNMP','0',NULL,'Template EtherLike-MIB (duplex control only)

MIBs used:
EtherLike-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10185',NULL,'Template Module HOST-RESOURCES-MIB SNMP','3','-1','2','','','Template Module HOST-RESOURCES-MIB SNMP','0',NULL,'HOST-RESOURCES-MIB: CPU, memory and storage(vfs.fs.file) linked together.

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10186',NULL,'Template Module ICMP Ping','3','-1','2','','','Template Module ICMP Ping','0',NULL,'Template Module ICMP Ping

Template tooling version used: 0.34','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10188',NULL,'Template Module Interfaces Simple SNMP','3','-1','2','','','Template Module Interfaces Simple SNMP','0',NULL,'Template Module Interfaces Simple (no ifXTable). This is the exact copy of Template Module Interfaces template with the exception that metrics from ifXTable are replaced with ifTable counters where possible. Use this template with devices where IF-MIB::ifXtable is not available. If supported by the host - use Template Module Interfaces template instead.

MIBs used:
IF-MIB

Known Issues:

  Description: 32bit counters are used in this template (since there is no ifXtable available). If busy interfaces return incorrect bits sent/received - set update interval to 1m or less.

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10190',NULL,'Template Module Interfaces SNMP','3','-1','2','','','Template Module Interfaces SNMP','0',NULL,'Template Module Interfaces

MIBs used:
IF-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10192',NULL,'Template Module Interfaces Windows SNMP','3','-1','2','','','Template Module Interfaces Windows SNMP','0',NULL,'Template Interfaces Windows

MIBs used:
IF-MIB

Known Issues:

  Description: 32bit counters are used in this template (since 64bit are not supported by Windows OS). If busy interfaces return incorrect bits sent/received - set update interval to 1m or less.

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10204',NULL,'Template Module Generic SNMP','3','-1','2','','','Template Module Generic SNMP','0',NULL,'Template Module Generic

MIBs used:
SNMPv2-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10207',NULL,'Template Net Alcatel Timetra TiMOS SNMP','3','-1','2','','','Template Net Alcatel Timetra TiMOS SNMP','0',NULL,'Template Net Alcatel Timetra TiMOS

MIBs used:
TIMETRA-CHASSIS-MIB
TIMETRA-SYSTEM-MIB
SNMPv2-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10208',NULL,'Template Net Brocade FC SNMP','3','-1','2','','','Template Net Brocade FC SNMP','0',NULL,'Template Net Brocade FC

MIBs used:
SW-MIB

Known Issues:

  Description: no IF-MIB::ifAlias is available
  Version: v6.3.1c, v7.0.0c,  v7.4.1c
  Device: all

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10209',NULL,'Template Module Brocade_Foundry Performance SNMP','3','-1','2','','','Template Module Brocade_Foundry Performance SNMP','0',NULL,'Template Module Brocade_Foundry Performance

MIBs used:
FOUNDRY-SN-AGENT-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10210',NULL,'Template Net Brocade_Foundry Nonstackable SNMP','3','-1','2','','','Template Net Brocade_Foundry Nonstackable SNMP','0',NULL,'Template Net Brocade_Foundry Nonstackable

MIBs used:
FOUNDRY-SN-AGENT-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10211',NULL,'Template Net Brocade_Foundry Stackable SNMP','3','-1','2','','','Template Net Brocade_Foundry Stackable SNMP','0',NULL,'Template Brocade_Foundry Stackable

MIBs used:
FOUNDRY-SN-AGENT-MIB
FOUNDRY-SN-STACKING-MIB

Known Issues:

  Description: Correct fan(returns fan status as ''other(1)'' and temperature (returns 0) for the non-master Switches are not available in SNMP
  Version: Version 08.0.40b and above
  Device: ICX 7750 in stack

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10212',NULL,'Template Module Cisco CISCO-MEMORY-POOL-MIB SNMP','3','-1','2','','','Template Module Cisco CISCO-MEMORY-POOL-MIB SNMP','0',NULL,'Template Cisco CISCO-MEMORY-POOL-MIB

MIBs used:
CISCO-MEMORY-POOL-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10213',NULL,'Template Module Cisco CISCO-PROCESS-MIB SNMP','3','-1','2','','','Template Module Cisco CISCO-PROCESS-MIB SNMP','0',NULL,'Template Cisco CISCO-PROCESS-MIB

MIBs used:
CISCO-PROCESS-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10215',NULL,'Template Module Cisco OLD-CISCO-CPU-MIB SNMP','3','-1','2','','','Template Module Cisco OLD-CISCO-CPU-MIB SNMP','0',NULL,'Template Cisco OLD-CISCO-CPU-MIB

MIBs used:
OLD-CISCO-CPU-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10216',NULL,'Template Module Cisco Inventory SNMP','3','-1','2','','','Template Module Cisco Inventory SNMP','0',NULL,'Template Cisco Inventory

MIBs used:
ENTITY-MIB
SNMPv2-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10217',NULL,'Template Module Cisco CISCO-ENVMON-MIB SNMP','3','-1','2','','','Template Module Cisco CISCO-ENVMON-MIB SNMP','0',NULL,'Template Cisco CISCO-ENVMON-MIB

MIBs used:
CISCO-ENVMON-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10218',NULL,'Template Net Cisco IOS SNMP','3','-1','2','','','Template Net Cisco IOS SNMP','0',NULL,'Template Cisco IOS Software releases 12.2(3.5) or later

Known Issues:

  Description: no if(in|out)(Errors|Discards) are available for vlan ifType
  Version: IOS for example: 12.1(22)EA11, 15.4(3)M2
  Device: C2911, C7600

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10220',NULL,'Template Net Cisco IOS prior to 12.0_3_T SNMP','3','-1','2','','','Template Net Cisco IOS prior to 12.0_3_T SNMP','0',NULL,'Cisco IOS Software releases prior to 12.0(3)T

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10221',NULL,'Template Net Dell Force S-Series SNMP','3','-1','2','','','Template Net Dell Force S-Series SNMP','0',NULL,'Template Dell Force S-Series

MIBs used:
F10-S-SERIES-CHASSIS-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10222',NULL,'Template Net D-Link DES 7200 SNMP','3','-1','2','','','Template Net D-Link DES 7200 SNMP','0',NULL,'Template D-Link DES 7200

MIBs used:
MY-PROCESS-MIB
SNMPv2-MIB
MY-MEMORY-MIB
ENTITY-MIB
MY-SYSTEM-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10223',NULL,'Template Net D-Link DES_DGS Switch SNMP','3','-1','2','','','Template Net D-Link DES_DGS Switch SNMP','0',NULL,'Template D-Link DES_DGS Switch

MIBs used:
DLINK-AGENT-MIB
SNMPv2-MIB
ENTITY-MIB
EQUIPMENT-MIB

Known Issues:

  Description: D-Link reports missing PSU as fail(4)
  Version: Firmware: 1.73R008,hardware revision: B1
  Device: DGS-3420-26SC Gigabit Ethernet Switch

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10224',NULL,'Template Net Extreme EXOS SNMP','3','-1','2','','','Template Net Extreme EXOS SNMP','0',NULL,'Template Extreme EXOS

MIBs used:
EXTREME-SOFTWARE-MONITOR-MIB
EXTREME-SYSTEM-MIB
ENTITY-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10226',NULL,'Template Net Network Generic Device SNMP','3','-1','2','','','Template Net Network Generic Device SNMP','0',NULL,'Template Net Network Generic Device

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10227',NULL,'Template Net HP Comware HH3C SNMP','3','-1','2','','','Template Net HP Comware HH3C SNMP','0',NULL,'Template Net HP Comware (HH3C)

MIBs used:
ENTITY-MIB
HH3C-ENTITY-EXT-MIB

Known Issues:

  Description: No temperature sensors. All entities of them return 0 for HH3C-ENTITY-EXT-MIB::hh3cEntityExtTemperature
  Version: 1910-48 Switch Software Version 5.20.99, Release 1116 Copyright(c)2010-2016 Hewlett Packard Enterprise Development LP
  Device: HP 1910-48

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10229',NULL,'Template Net Huawei VRP SNMP','3','-1','2','','','Template Net Huawei VRP SNMP','0',NULL,'Template Net Huawei VRP

MIBs used:
HUAWEI-ENTITY-EXTENT-MIB
ENTITY-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10230',NULL,'Template Net Intel_Qlogic Infiniband SNMP','3','-1','2','','','Template Net Intel_Qlogic Infiniband SNMP','0',NULL,'Template Net Intel_Qlogic Infiniband

MIBs used:
ICS-CHASSIS-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10231',NULL,'Template Net Juniper SNMP','3','-1','2','','','Template Net Juniper SNMP','0',NULL,'Template Net Juniper

MIBs used:
JUNIPER-ALARM-MIB
JUNIPER-MIB
SNMPv2-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10233',NULL,'Template Net Mikrotik SNMP','3','-1','2','','','Template Net Mikrotik SNMP','0',NULL,'Template Net Mikrotik

MIBs used:
HOST-RESOURCES-MIB
MIKROTIK-MIB

Known Issues:

  Description: Doesn''t have ifHighSpeed filled. fixed in more recent versions
  Version: RouterOS 6.28 or lower

  Description: Doesn''t have any temperature sensors
  Version: RouterOS 6.38.5
  Device: Mikrotik 941-2nD, Mikrotik 951G-2HnD

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10234',NULL,'Template Net Netgear Fastpath SNMP','3','-1','2','','','Template Net Netgear Fastpath SNMP','0',NULL,'Template Net Netgear Fastpath

MIBs used:
FASTPATH-SWITCHING-MIB
FASTPATH-BOXSERVICES-PRIVATE-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10235',NULL,'Template Net QTech QSW SNMP','3','-1','2','','','Template Net QTech QSW SNMP','0',NULL,'Template Net QTech QSW

MIBs used:
QTECH-MIB
ENTITY-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10236',NULL,'Template Net TP-LINK SNMP','3','-1','2','','','Template Net TP-LINK SNMP','0',NULL,'Template Net TP-LINK

MIBs used:
TPLINK-SYSINFO-MIB
TPLINK-SYSMONITOR-MIB

Known Issues:

  Description: Default sysLocation, sysName and sysContact is not filled with proper data. Real hostname and location can be found only in private branch (TPLINK-SYSINFO-MIB). Please check whether this problem exists in the latest firmware: https://www.tp-link.com/en/support/download/t2600g-28ts/#Firmware
  Version: 2.0.0 Build 20170628 Rel.55184 (Beta)
  Device: T2600G-28TS 2.0

  Description: The Serial number of the product (tpSysInfoSerialNum) is missing in HW versions prior to V2_170323
  Version: Prior to version V2_170323
  Device: T2600G-28TS 2.0

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10237',NULL,'Template Net Ubiquiti AirOS SNMP','3','-1','2','','','Template Net Ubiquiti AirOS SNMP','0',NULL,'Template Net Ubiquiti AirOS

MIBs used:
IEEE802dot11-MIB
FROGFOOT-RESOURCES-MIB

Known Issues:

  Description: UBNT unifi reports speed: like IF-MIB::ifSpeed.1 = Gauge32: 4294967295 for all interfaces
  Version: Firmware: BZ.ar7240.v3.7.51.6230.170322.1513
  Device: UBNT UAP-LR

  Description: UBNT AirMax(NanoStation, NanoBridge etc) reports ifSpeed: as 0 for VLAN and wireless(ath0) interfaces
  Version: Firmware: XW.ar934x.v5.6-beta4.22359.140521.1836
  Device: NanoStation M5

  Description: UBNT AirMax(NanoStation, NanoBridge etc) reports always return ifType: as ethernet(6) even for wifi,vlans and other types
  Version: Firmware: XW.ar934x.v5.6-beta4.22359.140521.1836
  Device: NanoStation M5

  Description: ifXTable is not provided in IF-MIB. So Interfaces Simple Template is used instead
  Version: all above
  Device: NanoStation, UAP-LR

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10248',NULL,'Template OS Linux SNMP','3','-1','2','','','Template OS Linux SNMP','0',NULL,'Template OS Linux

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387225-discussion-thread-for-official-zabbix-template-for-linux

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10249',NULL,'Template OS Windows SNMP','3','-1','2','','','Template OS Windows SNMP','0',NULL,'Official Windows SNMP template. Requires Zabbix server 4.0.14, 4.2.8, 4.4.0 or newer (JSONPath function avg() used with types autoconversion).


Known Issues:

  Description: Doesn''t support In/Out 64 bit counters even though IfxTable is present:
Currently, Windows gets it’s interface status from MIB-2. Since these 64bit SNMP counters (ifHCInOctets, ifHCOutOctets, etc.) are defined as an extension to IF-MIB, Microsoft has not implemented it.
https://social.technet.microsoft.com/Forums/windowsserver/en-US/07b62ff0-94f6-40ca-a99d-d129c1b33d70/windows-2008-r2-snmp-64bit-counters-support?forum=winservergen

  Version: Win2008, Win2012R2.

  Description: Doesn''t support ifXTable at all
  Version: WindowsXP

  Description: EtherLike MIB is not supported
  Version: *
  Device: *

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10250',NULL,'Template Net HP Enterprise Switch SNMP','3','-1','2','','','Template Net HP Enterprise Switch SNMP','0',NULL,'Template Net HP Enterprise Switch

MIBs used:
SEMI-MIB
NETSWITCH-MIB
HP-ICF-CHASSIS
ENTITY-SENSORS-MIB
ENTITY-MIB
STATISTICS-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10251',NULL,'Template Net Mellanox SNMP','3','-1','2','','','Template Net Mellanox SNMP','0',NULL,'The updated template for monitoring the Mellanox network switches over SNMP agent. All items collected in one template without any linked templates.

MIBs used:
HOST-RESOURCES-MIB
SNMPv2-MIB
ENTITY-SENSORS-MIB
ENTITY-STATE-MIB
ENTITY-MIB
IF-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10252',NULL,'Template Module Cisco CISCO-PROCESS-MIB IOS versions 12.0_3_T-12.2_3.5 SNMP','3','-1','2','','','Template Module Cisco CISCO-PROCESS-MIB IOS versions 12.0_3_T-12.2_3.5 SNMP','0',NULL,'Template Module Cisco CISCO-PROCESS-MIB IOS versions 12.0_3_T-12.2_3.5

MIBs used:
CISCO-PROCESS-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10253',NULL,'Template Net Cisco IOS versions 12.0_3_T-12.2_3.5 SNMP','3','-1','2','','','Template Net Cisco IOS versions 12.0_3_T-12.2_3.5 SNMP','0',NULL,'Cisco IOS Software releases later to 12.0(3)T and prior to 12.2(3.5)

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10254',NULL,'Template Net Arista SNMP','3','-1','2','','','Template Net Arista SNMP','0',NULL,'Template Net Arista

MIBs used:
ENTITY-SENSORS-MIB
ENTITY-STATE-MIB
ENTITY-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10255',NULL,'Template Server Dell iDRAC SNMP','3','-1','2','','','Template Server Dell iDRAC SNMP','0',NULL,'Template Server iDRAC

MIBs used:
IDRAC-MIB-SMIv2

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10256',NULL,'Template Server HP iLO SNMP','3','-1','2','','','Template Server HP iLO SNMP','0',NULL,'Template Server HP iLO

MIBs used:
CPQSINFO-MIB
CPQHLTH-MIB
CPQIDA-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10258',NULL,'Template Server IBM IMM SNMP','3','-1','2','','','Template Server IBM IMM SNMP','0',NULL,'Template Server IBM IMM

MIBs used:
IMM-MIB

Known Issues:

  Description: Some IMMs (IMM1) do not return disks
  Version: IMM1
  Device: IBM x3250M3

  Description: Some IMMs (IMM1) do not return fan status: fanHealthStatus
  Version: IMM1
  Device: IBM x3250M3

  Description: IMM1 servers (M2, M3 generations) sysObjectID is NET-SNMP-MIB::netSnmpAgentOIDs.10
  Version: IMM1
  Device: IMM1 servers (M2,M3 generations)

  Description: IMM1 servers (M2, M3 generations) only Ambient temperature sensor available
  Version: IMM1
  Device: IMM1 servers (M2,M3 generations)

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10259',NULL,'Template Server Supermicro Aten SNMP','3','-1','2','','','Template Server Supermicro Aten SNMP','0',NULL,'Template Server Supermicro Aten

MIBs used:
ATEN-IPMI-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10260',NULL,'Template App Apache Tomcat JMX','3','-1','2','','','Template App Apache Tomcat JMX','0',NULL,'The template to monitor Apache Tomcat by Zabbix that work without any external scripts.
The metrics are collected by JMX.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/411862-discussion-thread-for-official-zabbix-template-tomcat

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10261',NULL,'Template App Remote Zabbix server','3','-1','2','','','Template App Remote Zabbix server','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10262',NULL,'Template App Remote Zabbix proxy','3','-1','2','','','Template App Remote Zabbix proxy','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10263',NULL,'Template DB PostgreSQL','3','-1','2','','','Template DB PostgreSQL','0',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10264',NULL,'Template App Apache by Zabbix agent','3','-1','2','','','Template App Apache by Zabbix agent','0',NULL,'Get metrics from mod_status module using HTTP agent.
https://httpd.apache.org/docs/current/mod/mod_status.html

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384764-discussion-thread-for-official-zabbix-template-apache

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10265',NULL,'Template App Apache by HTTP','3','-1','2','','','Template App Apache by HTTP','0',NULL,'Get metrics from mod_status module using HTTP agent.
https://httpd.apache.org/docs/current/mod/mod_status.html

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384764-discussion-thread-for-official-zabbix-template-apache

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10266',NULL,'Template App Nginx by Zabbix agent','3','-1','2','','','Template App Nginx by Zabbix agent','0',NULL,'Get metrics from stub status module using Zabbix agent running on Linux
https://nginx.ru/en/docs/http/ngx_http_stub_status_module.html


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384765-discussion-thread-for-official-zabbix-template-nginx

Template tooling version used: 0.37','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10267',NULL,'Template App Nginx by HTTP','3','-1','2','','','Template App Nginx by HTTP','0',NULL,'Get metrics from stub status module using HTTP agent
https://nginx.ru/en/docs/http/ngx_http_stub_status_module.html.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384765-discussion-thread-for-official-zabbix-template-nginx

Template tooling version used: 0.37','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10268',NULL,'Template Module Linux memory SNMP','3','-1','2','','','Template Module Linux memory SNMP','0',NULL,'MIBs used:
UCD-SNMP-MIB

Known Issues:

  Description: Please note that memory utilization is a rough estimate, since memory available is calculated as free+buffers+cached, which is not 100% accurate, but the best we can get using SNMP.

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10269',NULL,'Template Module Linux block devices SNMP','3','-1','2','','','Template Module Linux block devices SNMP','0',NULL,'MIBs used:
UCD-DISKIO-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10270',NULL,'Template Module Linux CPU SNMP','3','-1','2','','','Template Module Linux CPU SNMP','0',NULL,'MIBs used:
HOST-RESOURCES-MIB
UCD-SNMP-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10271',NULL,'Template Module Linux filesystems SNMP','3','-1','2','','','Template Module Linux filesystems SNMP','0',NULL,'MIBs used:
HOST-RESOURCES-MIB
UCD-SNMP-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10272',NULL,'Template Module Linux CPU by Zabbix agent','3','-1','2','','','Template Module Linux CPU by Zabbix agent','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10273',NULL,'Template Module Linux filesystems by Zabbix agent','3','-1','2','','','Template Module Linux filesystems by Zabbix agent','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10274',NULL,'Template Module Linux memory by Zabbix agent','3','-1','2','','','Template Module Linux memory by Zabbix agent','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10275',NULL,'Template Module Linux block devices by Zabbix agent','3','-1','2','','','Template Module Linux block devices by Zabbix agent','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10276',NULL,'Template Module Linux network interfaces by Zabbix agent','3','-1','2','','','Template Module Linux network interfaces by Zabbix agent','0',NULL,'Known Issues:

  Description: High interface utilization trigger is removed since currently it is not possible to retrieve interface speed to determine the max bandwidth.

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10277',NULL,'Template Module Linux generic by Zabbix agent','3','-1','2','','','Template Module Linux generic by Zabbix agent','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10278',NULL,'Template Module Linux CPU by Zabbix agent active','3','-1','2','','','Template Module Linux CPU by Zabbix agent active','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10279',NULL,'Template Module Linux filesystems by Zabbix agent active','3','-1','2','','','Template Module Linux filesystems by Zabbix agent active','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10280',NULL,'Template Module Linux memory by Zabbix agent active','3','-1','2','','','Template Module Linux memory by Zabbix agent active','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10281',NULL,'Template Module Linux block devices by Zabbix agent active','3','-1','2','','','Template Module Linux block devices by Zabbix agent active','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10282',NULL,'Template Module Linux network interfaces by Zabbix agent active','3','-1','2','','','Template Module Linux network interfaces by Zabbix agent active','0',NULL,'Known Issues:

  Description: High interface utilization trigger is removed since currently it is not possible to retrieve interface speed to determine the max bandwidth.

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10283',NULL,'Template Module Linux generic by Zabbix agent active','3','-1','2','','','Template Module Linux generic by Zabbix agent active','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10284',NULL,'Template OS Linux by Zabbix agent active','3','-1','2','','','Template OS Linux by Zabbix agent active','0',NULL,'Official Linux template. Requires agent of Zabbix 3.0.14, 3.4.5 and 4.0.0 or newer.

Known Issues:

  Description: Network discovery. Zabbix agent as of 4.2 doesn''t support items such as net.if.status, net.if.speed.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387225-discussion-thread-for-official-zabbix-template-for-linux

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10285',NULL,'Template OS Linux by Prom','3','-1','2','','','Template OS Linux by Prom','0',NULL,'Official Linux template using node exporter.

Known Issues:

  Description: node_exporter v0.16.0 renamed many metrics. CPU utilization for ''guest'' and ''guest_nice'' metrics are not supported in this template with node_exporter < 0.16. Disk IO metrics are not supported. Other metrics provided as ''best effort''.  
 See https://github.com/prometheus/node_exporter/releases/tag/v0.16.0 for details.
  Version: below 0.16.0

  Description: metric node_network_info with label ''device'' cannot be found, so network discovery is not possible.
  Version: below 0.18

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387225-discussion-thread-for-official-zabbix-template-for-linux

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10286',NULL,'Template Module Windows CPU by Zabbix agent','3','-1','2','','','Template Module Windows CPU by Zabbix agent','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10287',NULL,'Template Module Windows memory by Zabbix agent','3','-1','2','','','Template Module Windows memory by Zabbix agent','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10288',NULL,'Template Module Windows filesystems by Zabbix agent','3','-1','2','','','Template Module Windows filesystems by Zabbix agent','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10289',NULL,'Template Module Windows physical disks by Zabbix agent','3','-1','2','','','Template Module Windows physical disks by Zabbix agent','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10290',NULL,'Template Module Windows generic by Zabbix agent','3','-1','2','','','Template Module Windows generic by Zabbix agent','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10291',NULL,'Template Module Windows network by Zabbix agent','3','-1','2','','','Template Module Windows network by Zabbix agent','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10292',NULL,'Template Module Zabbix agent active','3','-1','2','','','Template Module Zabbix agent active','0',NULL,'Use this template instead of ''Template Module Zabbix agent'' for agents running in active mode only.

Template tooling version used: 0.34','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10293',NULL,'Template Module Windows CPU by Zabbix agent active','3','-1','2','','','Template Module Windows CPU by Zabbix agent active','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10294',NULL,'Template Module Windows memory by Zabbix agent active','3','-1','2','','','Template Module Windows memory by Zabbix agent active','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10295',NULL,'Template Module Windows filesystems by Zabbix agent active','3','-1','2','','','Template Module Windows filesystems by Zabbix agent active','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10296',NULL,'Template Module Windows physical disks by Zabbix agent active','3','-1','2','','','Template Module Windows physical disks by Zabbix agent active','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10297',NULL,'Template Module Windows generic by Zabbix agent active','3','-1','2','','','Template Module Windows generic by Zabbix agent active','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10298',NULL,'Template Module Windows network by Zabbix agent active','3','-1','2','','','Template Module Windows network by Zabbix agent active','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10299',NULL,'Template OS Windows by Zabbix agent active','3','-1','2','','','Template OS Windows by Zabbix agent active','0',NULL,'Official Windows template. Requires agent of Zabbix 4.4 and newer.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387224-discussion-thread-for-official-zabbix-template-for-windows

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10300',NULL,'Template App RabbitMQ cluster by Zabbix agent','3','-1','2','','','Template App RabbitMQ cluster by Zabbix agent','0',NULL,'Get cluster metrics from RabbitMQ management plugin provided an HTTP-based API using Zabbix agent.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387226-discussion-thread-for-official-zabbix-template-rabbitmq

Template tooling version used: 0.34','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10301',NULL,'Template App RabbitMQ node by Zabbix agent','3','-1','2','','','Template App RabbitMQ node by Zabbix agent','0',NULL,'Get node metrics from RabbitMQ management plugin provided an HTTP-based API using Zabbix agent.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387226-discussion-thread-for-official-zabbix-template-rabbitmq

Template tooling version used: 0.34','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10302',NULL,'Template App RabbitMQ cluster by HTTP','3','-1','2','','','Template App RabbitMQ cluster by HTTP','0',NULL,'Get cluster metrics from RabbitMQ management plugin provided an HTTP-based API using HTTP agent.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387226-discussion-thread-for-official-zabbix-template-rabbitmq

Template tooling version used: 0.34','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10303',NULL,'Template App RabbitMQ node by HTTP','3','-1','2','','','Template App RabbitMQ node by HTTP','0',NULL,'Get node metrics from RabbitMQ management plugin provided an HTTP-based API using HTTP agent.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387226-discussion-thread-for-official-zabbix-template-rabbitmq

Template tooling version used: 0.34','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10304',NULL,'Template Server Cisco UCS SNMP','3','-1','2','','','Template Server Cisco UCS SNMP','0',NULL,'Template Server Cisco UCS

MIBs used:
CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
CISCO-UNIFIED-COMPUTING-PROCESSOR-MIB
CISCO-UNIFIED-COMPUTING-EQUIPMENT-MIB
CISCO-UNIFIED-COMPUTING-STORAGE-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10305',NULL,'Template Module HOST-RESOURCES-MIB CPU SNMP','3','-1','2','','','Template Module HOST-RESOURCES-MIB CPU SNMP','0',NULL,'Requires Zabbix server 4.0.14, 4.2.8, 4.4.0 or newer (JSONPath function avg() used with types autoconversion).

MIBs used:
HOST-RESOURCES-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10306',NULL,'Template Module HOST-RESOURCES-MIB memory SNMP','3','-1','2','','','Template Module HOST-RESOURCES-MIB memory SNMP','0',NULL,'MIBs used:
HOST-RESOURCES-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10307',NULL,'Template Module HOST-RESOURCES-MIB storage SNMP','3','-1','2','','','Template Module HOST-RESOURCES-MIB storage SNMP','0',NULL,'MIBs used:
HOST-RESOURCES-MIB

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10308',NULL,'Template App HAProxy by Zabbix agent','3','-1','2','','','Template App HAProxy by Zabbix agent','0',NULL,'Get metrics from status page using Zabbix agent
https://www.haproxy.com/blog/exploring-the-haproxy-stats-page/.
Example configuration of HAProxy:
  frontend stats
      bind *:8404
      stats enable
      stats uri /stats
      stats refresh 10s

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/393527-discussion-thread-for-official-zabbix-template-haproxy

Template tooling version used: 0.39','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10309',NULL,'Template App HAProxy by HTTP','3','-1','2','','','Template App HAProxy by HTTP','0',NULL,'Get metrics from status page using HTTP agent
https://www.haproxy.com/blog/exploring-the-haproxy-stats-page/.
Example configuration of HAProxy:
  frontend stats
      bind *:8404
      stats enable
      stats uri /stats
      stats refresh 10s
      #stats auth Username:Password  # Authentication credentials

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/393527-discussion-thread-for-official-zabbix-template-haproxy

Template tooling version used: 0.39','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10310',NULL,'Template DB Redis','3','-1','2','','','Template DB Redis','0',NULL,'Get Redis metrics from plugin for the New Zabbix Agent (zabbix-agent2).

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/389050-discussion-thread-for-official-zabbix-template-redis

Template tooling version used: 0.33','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10314',NULL,'Template Module Windows services by Zabbix agent','3','-1','2','','','Template Module Windows services by Zabbix agent','0',NULL,'Template Services OS Windows

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10315',NULL,'Template Module Windows services by Zabbix agent active','3','-1','2','','','Template Module Windows services by Zabbix agent active','0',NULL,'Template Services OS Windows

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10316',NULL,'Template DB MySQL by Zabbix agent','3','-1','2','','','Template DB MySQL by Zabbix agent','0',NULL,'Requirements for template operation:
1.Install Zabbix agent and MySQL client.
2.Copy template_db_mysql.conf into folder with Zabbix agent configuration (/etc/zabbix/zabbix_agentd.d/ by default). Don''t forget to restart zabbix-agent. 
3.Create MySQL user for monitoring. For example:
CREATE USER ''zbx_monitor''@''%'' IDENTIFIED BY ''<password>'';
GRANT REPLICATION CLIENT,PROCESS,SHOW DATABASES,SHOW VIEW ON *.* TO ''zbx_monitor''@''%'';
For more information read the MySQL documentation https://dev.mysql.com/doc/refman/8.0/en/grant.html , please. 
4.Create .my.cnf in home directory of Zabbix agent for Linux (/var/lib/zabbix by default ) or my.cnf in c:\ for Windows. For example:
[client]
user=''zbx_monitor''
password=''<password>''


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384189-discussion-thread-for-official-zabbix-template-db-mysql

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10317',NULL,'Template DB MySQL by ODBC','3','-1','2','','','Template DB MySQL by ODBC','0',NULL,'Requirements for template operation:
1. Create MySQL user for monitoring. For example:
CREATE USER ''zbx_monitor''@''%'' IDENTIFIED BY ''<password>'';
GRANT REPLICATION CLIENT,PROCESS,SHOW DATABASES,SHOW VIEW ON *.* TO ''zbx_monitor''@''%'';
For more information read the MYSQL documentation https://dev.mysql.com/doc/refman/8.0/en/grant.html , please. 
2. Set the user name and password in host macros ({$MYSQL.USER} and {$MYSQL.PASSWORD}).


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384189-discussion-thread-for-official-zabbix-template-db-mysql

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10318',NULL,'Template App Docker','3','-1','2','','','Template App Docker','0',NULL,'Get Docker engine metrics from plugin for the New Zabbix Agent (zabbix-agent2).

You can discuss this template or leave feedback on our forum 

Template tooling version used: 0.35','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10319',NULL,'Template App Memcached','3','-1','2','','','Template App Memcached','0',NULL,'Get Memcached metrics from plugin for the New Zabbix Agent (zabbix-agent2).

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/398623-discussion-thread-for-official-zabbix-template-memcached

Template tooling version used: 0.35','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10320',NULL,'Template DB MySQL by Zabbix agent 2','3','-1','2','','','Template DB MySQL by Zabbix agent 2','0',NULL,'Requirements for template operation:
1. Create MySQL user for monitoring. For example:
CREATE USER ''zbx_monitor''@''%'' IDENTIFIED BY ''<password>'';
GRANT REPLICATION CLIENT,PROCESS,SHOW DATABASES,SHOW VIEW ON *.* TO ''zbx_monitor''@''%'';
For more information please read the MySQL documentation https://dev.mysql.com/doc/refman/8.0/en/grant.html.
2. Set in the {$MYSQL.DSN} macro the data source name of the MySQL instance either session name from Zabbix agent 2 configuration file or URI.
Examples: MySQL1, tcp://localhost:3306, tcp://172.16.0.10, unix:/var/run/mysql.sock
For more information about MySQL Unix socket file please read the MySQL documentation https://dev.mysql.com/doc/refman/8.0/en/problems-with-mysql-sock.html.
3. If you had set URI in the {$MYSQL.DSN}, please define the user name and password in host macros ({$MYSQL.USER} and {$MYSQL.PASSWORD}).
Leave macros {$MYSQL.USER} and {$MYSQL.PASSWORD} empty if you use a session name. Set the user name and password in the Plugins.Mysql.<...> section of your Zabbix agent 2 configuration file.
For more information about configuring the Zabbix MySQL plugin please read the documentation https://git.zabbix.com/projects/ZBX/repos/zabbix/browse/src/go/plugins/mysql/README.md.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/384189-discussion-thread-for-official-zabbix-template-db-mysql

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10321',NULL,'Template Server Chassis by IPMI','3','-1','2','','','Template Server Chassis by IPMI','0',NULL,'Template for monitoring servers with BMC over IPMI that work without any external scripts. 
All metrics are collected at once, thanks to Zabbix''s bulk data collection. The template is available starting from Zabbix version 5.0. 
It collects metrics by polling BMC remotely using an IPMI agent.


Known Issues:

  Description: If the BMC has a sensor with an empty threshold value, we get the LLD error "Cannot create trigger...".

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/398023-discussion-thread-for-official-zabbix-template-ipmi

Template tooling version used: 0.37','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10322',NULL,'Template App Elasticsearch Cluster by HTTP','3','-1','2','','','Template App Elasticsearch Cluster by HTTP','0',NULL,'The template to monitor Elasticsearch by Zabbix that work without any external scripts.
It works with both standalone and cluster instances.
The metrics are collected in one pass remotely using an HTTP agent. 
They are getting values from REST API _cluster/health, _cluster/stats, _nodes/stats requests.
You can set {$ELASTICSEARCH.USERNAME} and {$ELASTICSEARCH.PASSWORD} macros in the template for using on the host level.
If you use an atypical location ES API, don''t forget to change the macros {$ELASTICSEARCH.SCHEME},{$ELASTICSEARCH.PORT}.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/399473-discussion-thread-for-official-zabbix-template-for-elasticsearch

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10323',NULL,'Template DB ClickHouse by HTTP','3','-1','2','','','Template DB ClickHouse by HTTP','0',NULL,'Get node metrics from ClickHouse HTTP interface using HTTP agent.

Template tooling version used: 0.35','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10324',NULL,'Template App Etcd by HTTP','3','-1','2','','','Template App Etcd by HTTP','0',NULL,'Get Etcd metrics by HTTP agent.

Template tooling version used: 0.36','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10325',NULL,'Template App IIS by Zabbix agent','3','-1','2','','','Template App IIS by Zabbix agent','0',NULL,'Get metrics from IIS using Zabbix agent running on Windows


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/401862-discussion-thread-for-official-zabbix-template-internet-information-services

Template tooling version used: 0.35','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10326',NULL,'Template App IIS by Zabbix agent active','3','-1','2','','','Template App IIS by Zabbix agent active','0',NULL,'Get metrics from IIS using Zabbix agent running on Windows


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/401862-discussion-thread-for-official-zabbix-template-internet-information-services

Template tooling version used: 0.35','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10327',NULL,'Template DB MSSQL by ODBC','3','-1','2','','','Template DB MSSQL by ODBC','0',NULL,'1. Create an MSSQL user for monitoring.
  View Server State and View Any Definition permissions should be granted to the user.
  Grant this user read permissions to the sysjobschedules, sysjobhistory, sysjobs tables.  
  For more information, see MSSQL documentation.
2. Set the user name and password in host macros ({$MSSQL.USER} and {$MSSQL.PASSWORD}).
  Do not forget to install Microsoft ODBC driver on Zabbix server or Zabbix proxy.
  See Microsoft documentation for instructions: https://docs.microsoft.com/en-us/sql/connect/odbc/linux-mac/installing-the-microsoft-odbc-driver-for-sql-server?view=sql-server-ver15.
  Note! Credentials in the odbc.ini do not work for MSSQL.
3. For named instance set the value of {$MSSQL.INSTANCE} macro as MSSQL$instance name.
The "Service''s TCP port state" item uses {HOST.CONN} and {$MSSQL.PORT} macros to check the availability of the MSSQL instance.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10328',NULL,'Template DB PostgreSQL Agent 2','3','-1','2','','','Template DB PostgreSQL Agent 2','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10330',NULL,'Template VM VMware macros','3','-1','2','','','Template VM VMware macros','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10331',NULL,'{#HV.UUID}','0','-1','2','','','{#HV.NAME}','2',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10332',NULL,'{#VM.UUID}','0','-1','2','','','{#VM.NAME}','2',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10333',NULL,'Template DB Oracle by Zabbix Agent 2','3','-1','2','','','Template DB Oracle by Zabbix Agent 2','0',NULL,'Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10334',NULL,'Template App Ceph by Zabbix Agent2','3','-1','2','','','Template App Ceph by Zabbix Agent2','0',NULL,'You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/410059-discussion-thread-for-official-zabbix-template-ceph

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10335',NULL,'Template App PHP-FPM by Zabbix agent','3','-1','2','','','Template App PHP-FPM by Zabbix agent','0',NULL,'Get PHP-FPM metrics using Zabbix agent running on Linux.

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10336',NULL,'Template App PHP-FPM by HTTP','3','-1','2','','','Template App PHP-FPM by HTTP','0',NULL,'Get PHP-FPM metrics using the Zabbix HTTP agent.

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10337',NULL,'Template App Squid SNMP','3','-1','2','','','Template App Squid SNMP','0',NULL,'Template for monitoring Squid caching proxy via SNMP

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/409339-discussion-thread-for-official-zabbix-template-squid

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10339',NULL,'Template App Hadoop by HTTP','3','-1','2','','','Template App Hadoop by HTTP','0',NULL,'The template gets the Hadoop metrics from cluster''s hosts (ResourceManager, NodeManagers, NameNode, DataNodes) by HTTP agent. You should define the IP address (or FQDN) and Web-UI port for the ResourceManager in {$HADOOP.RESOURCEMANAGER.HOST} and {$HADOOP.RESOURCEMANAGER.PORT} macros and for the NameNode in {$HADOOP.NAMENODE.HOST} and {$HADOOP.NAMENODE.PORT} macros respectively. Macros can be set in the template or overridden at the host level.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/413459-discussion-thread-for-official-zabbix-template-hadoop

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10340',NULL,'Template APP Apache Kafka by JMX','3','-1','2','','','Template APP Apache Kafka by JMX','0',NULL,'Official JMX Template for Apache Kafka.
  The metrics are collected by JMX.
  You can set {$KAFKA.USER} and {$KAFKA.PASSWORD} macros in the template for using on the host level.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10341',NULL,'Template App Zookeeper by HTTP','3','-1','2','','','Template App Zookeeper by HTTP','0',NULL,'Get Apache Zookeeper metrics by HTTP agent.
  This template works with standalone and cluster instances. Metrics are collected from each Zookeper node by requests to AdminServer.  
  Don''t forget to change macros {$ZOOKEEPER.COMMAND_URL}, {$ZOOKEEPER.PORT}, {$ZOOKEEPER.SCHEME}.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10342',NULL,'Template DB Apache Cassandra by JMX','3','-1','2','','','Template DB Apache Cassandra by JMX','0',NULL,'The template to monitor Apache Cassandra by Zabbix that work without any external scripts.
It works with both standalone and cluster instances.
The metrics are collected by JMX.
You can set {$CASSANDRA.USER} and {$CASSANDRA.PASSWORD} macros in the template for using on the host level.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/410057-discussion-thread-for-official-zabbix-template-apache-cassandra

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10343',NULL,'Template Net Morningstar ProStar MPPT SNMP','3','-1','2','','','Template Net Morningstar ProStar MPPT SNMP','0',NULL,'MIBs used:
PROSTAR-MPPT

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10344',NULL,'Template Net Morningstar ProStar PWM SNMP','3','-1','2','','','Template Net Morningstar ProStar PWM SNMP','0',NULL,'MIBs used:
PROSTAR-PWM

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10345',NULL,'Template Net Morningstar SunSaver MPPT SNMP','3','-1','2','','','Template Net Morningstar SunSaver MPPT SNMP','0',NULL,'MIBs used:
SUNSAVER-MPPT

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10346',NULL,'Template Net Morningstar SureSine SNMP','3','-1','2','','','Template Net Morningstar SureSine SNMP','0',NULL,'MIBs used:
SURESINE

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10347',NULL,'Template Net Morningstar TriStar MPPT 600V SNMP','3','-1','2','','','Template Net Morningstar TriStar MPPT 600V SNMP','0',NULL,'MIBs used:
TRISTAR-MPPT

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10348',NULL,'Template Net Morningstar TriStar MPPT SNMP','3','-1','2','','','Template Net Morningstar TriStar MPPT SNMP','0',NULL,'MIBs used:
TRISTAR-MPPT

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10349',NULL,'Template Net Morningstar TriStar PWM SNMP','3','-1','2','','','Template Net Morningstar TriStar PWM SNMP','0',NULL,'MIBs used:
TRISTAR

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10350',NULL,'Template App Apache ActiveMQ by JMX','3','-1','2','','','Template App Apache ActiveMQ by JMX','0',NULL,'The template to monitor Apache ActiveMQ by Zabbix that work without any external scripts.
The metrics are collected by JMX.
You can set macro values and add macros with context for specific brokers or destinations following macro description.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/411049-discussion-thread-for-official-zabbix-template-amq

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10351',NULL,'Template App Microsoft Exchange Server 2016 by Zabbix agent','3','-1','2','','','Template App Microsoft Exchange Server 2016 by Zabbix agent','0',NULL,'The template to monitor Microsoft Exchange Server 2016 by Zabbix that works without any external scripts.
The metrics are collected by Zabbix agent.
Recommended to use it with "OS Windows by Zabbix agent" template.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/415007-discussion-thread-for-official-zabbix-template-microsoft-exchange

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10352',NULL,'Template App Microsoft Exchange Server 2016 by Zabbix agent active','3','-1','2','','','Template App Microsoft Exchange Server 2016 by Zabbix agent active','0',NULL,'The template to monitor Microsoft Exchange Server 2016 by Zabbix that works without any external scripts.
The metrics are collected by Zabbix agent active.
Recommended to use it with "OS Windows by Zabbix agent active" template.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/415007-discussion-thread-for-official-zabbix-template-microsoft-exchange

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10353',NULL,'Template SAN NetApp FAS3220 SNMP','3','-1','2','','','Template SAN NetApp FAS3220 SNMP','0',NULL,'The template to monitor SAN NetApp FAS3220 cluster by Zabbix SNMP agent.

MIBs used:
NETAPP-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/416694-discussion-thread-for-official-zabbix-template-netapp-fas3220

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10354',NULL,'Template DB Ignite by JMX','3','-1','2','','','Template DB Ignite by JMX','0',NULL,'The template to monitor Apache Ignite by Zabbix that work without any external scripts.
  It works with both standalone and cluster instances.
  The metrics are discoverable and collected by JMX.  
  Current JMX tree hierarchy contains classloader by default. Add the following jvm option `-DIGNITE_MBEAN_APPEND_CLASS_LOADER_ID=false`to will exclude one level with Classloader name.
  You can set {$IGNITE.USER} and {$IGNITE.PASSWORD} macros in the template for using on the host level.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10355',NULL,'Template Module SMART by Zabbix agent 2','3','-1','2','','','Template Module SMART by Zabbix agent 2','0',NULL,'The template for monitoring S.M.A.R.T. attributes of physical disk that works without any external scripts. It collects metrics by Zabbix agent 2 version 5.0 and later with Smartmontools version 7.1 and later. Disk discovery LLD rule finds all HDD, SSD, NVMe disks with S.M.A.R.T. enabled. Attribute discovery LLD rule finds all Vendor Specific Attributes for each disk. If you want to skip some attributes, please set regular expressions with disk names in {$SMART.DISK.NAME.MATCHES} and with attribute IDs in {$SMART.ATTRIBUTE.ID.MATCHES} macros on the host level.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/415662-discussion-thread-for-official-zabbix-smart-disk-monitoring

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10356',NULL,'Template Module SMART by Zabbix agent active 2','3','-1','2','','','Template Module SMART by Zabbix agent active 2','0',NULL,'The template for monitoring S.M.A.R.T. attributes of physical disk that works without any external scripts. It collects metrics by Zabbix agent active 2 version 5.0 and later with Smartmontools version 7.1 and later. Disk discovery LLD rule finds all HDD, SSD, NVMe disks with S.M.A.R.T. enabled. Attribute discovery LLD rule finds all Vendor Specific Attributes for each disk. If you want to skip some attributes, please set regular expressions with disk names in {$SMART.DISK.NAME.MATCHES} and with attribute IDs in {$SMART.ATTRIBUTE.ID.MATCHES} macros on the host level.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/415662-discussion-thread-for-official-zabbix-smart-disk-monitoring

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10357',NULL,'Template SAN Huawei OceanStor 5300 V5 SNMP','3','-1','2','','','Template SAN Huawei OceanStor 5300 V5 SNMP','0',NULL,'The template to monitor SAN Huawei OceanStor 5300 V5 by Zabbix SNMP agent.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/418855-discussion-thread-for-official-zabbix-template-huawei-oceanstor

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10358',NULL,'RabbitMQ cluster by Zabbix agent','3','-1','2','','','RabbitMQ cluster by Zabbix agent','0',NULL,'Get cluster metrics from RabbitMQ management plugin provided an HTTP-based API using Zabbix agent.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387226-discussion-thread-for-official-zabbix-template-rabbitmq

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10359',NULL,'RabbitMQ node by Zabbix agent','3','-1','2','','','RabbitMQ node by Zabbix agent','0',NULL,'Get node metrics from RabbitMQ management plugin provided an HTTP-based API using Zabbix agent.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387226-discussion-thread-for-official-zabbix-template-rabbitmq

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10360',NULL,'RabbitMQ cluster by HTTP','3','-1','2','','','RabbitMQ cluster by HTTP','0',NULL,'Get cluster metrics from RabbitMQ management plugin provided an HTTP-based API using HTTP agent.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387226-discussion-thread-for-official-zabbix-template-rabbitmq

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10361',NULL,'RabbitMQ node by HTTP','3','-1','2','','','RabbitMQ node by HTTP','0',NULL,'Get node metrics from RabbitMQ management plugin provided an HTTP-based API using HTTP agent.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/387226-discussion-thread-for-official-zabbix-template-rabbitmq

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10362',NULL,'Template DB MongoDB node by Zabbix Agent 2','3','-1','2','','','Template DB MongoDB node by Zabbix Agent 2','0',NULL,'Get MongoDB metrics from plugin for the zabbix-agent2.
  1. Setup and configure zabbix-agent2 compiled with the MongoDB monitoring plugin.
  2. Set the {$MONGODB.CONNSTRING} such as <protocol(host:port)> or named session.
  3. Set the user name and password in host macros ({$MONGODB.USER}, {$MONGODB.PASSWORD}) if you want to override parameters from the Zabbix agent configuration file.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420659-discussion-thread-for-official-zabbix-template-db-mongodb

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10363',NULL,'Template DB MongoDB cluster by Zabbix Agent 2','3','-1','2','','','Template DB MongoDB cluster by Zabbix Agent 2','0',NULL,'Get MongoDB metrics from plugin for the zabbix-agent2.
  1. Setup and configure zabbix-agent2 compiled with the MongoDB monitoring plugin.
  2. Set the {$MONGODB.CONNSTRING} such as <protocol(host:port)> or named session.
  3. Set the user name and password in host macros ({$MONGODB.USER}, {$MONGODB.PASSWORD}) if you want to override parameters from the Zabbix agent configuration file.

  All sharded Mongodb nodes (mongod) will be discovered with attached template "MongoDB node".

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420659-discussion-thread-for-official-zabbix-template-db-mongodb

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10364',NULL,'{#HOSTNAME}','0','-1','2','','','{#HOSTNAME}','2',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10365',NULL,'{#HOSTNAME}','0','-1','2','','','{#HOSTNAME}','2',NULL,'','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10366',NULL,'Cisco Catalyst 3750V2-24FS SNMP','3','-1','2','','','Cisco Catalyst 3750V2-24FS SNMP','0',NULL,'Template Cisco Catalyst 3750V2-24FS

MIBs used:
CISCO-MEMORY-POOL-MIB
IF-MIB
EtherLike-MIB
SNMPv2-MIB
CISCO-PROCESS-MIB
CISCO-ENVMON-MIB
ENTITY-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10367',NULL,'Cisco Catalyst 3750V2-24PS SNMP','3','-1','2','','','Cisco Catalyst 3750V2-24PS SNMP','0',NULL,'Template Cisco Catalyst 3750V2-24PS

MIBs used:
CISCO-MEMORY-POOL-MIB
IF-MIB
EtherLike-MIB
SNMPv2-MIB
CISCO-PROCESS-MIB
CISCO-ENVMON-MIB
ENTITY-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10368',NULL,'Cisco Catalyst 3750V2-24TS SNMP','3','-1','2','','','Cisco Catalyst 3750V2-24TS SNMP','0',NULL,'Template Cisco Catalyst 3750V2-24TS

MIBs used:
CISCO-MEMORY-POOL-MIB
IF-MIB
EtherLike-MIB
SNMPv2-MIB
CISCO-PROCESS-MIB
CISCO-ENVMON-MIB
ENTITY-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10369',NULL,'Cisco Catalyst 3750V2-48PS SNMP','3','-1','2','','','Cisco Catalyst 3750V2-48PS SNMP','0',NULL,'Template Cisco Catalyst 3750V2-48PS

MIBs used:
CISCO-MEMORY-POOL-MIB
IF-MIB
EtherLike-MIB
SNMPv2-MIB
CISCO-PROCESS-MIB
CISCO-ENVMON-MIB
ENTITY-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10370',NULL,'Cisco Catalyst 3750V2-48TS SNMP','3','-1','2','','','Cisco Catalyst 3750V2-48TS SNMP','0',NULL,'Template Cisco Catalyst 3750V2-48TS

MIBs used:
CISCO-MEMORY-POOL-MIB
IF-MIB
EtherLike-MIB
SNMPv2-MIB
CISCO-PROCESS-MIB
CISCO-ENVMON-MIB
ENTITY-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10371',NULL,'Template Power APC UPS SNMP','3','-1','2','','','Template Power APC UPS SNMP','0',NULL,'Template Power APC UPS

MIBs used:
PowerNet-MIB
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420730-discussion-thread-for-official-zabbix-template-apc-ups

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10372',NULL,'Template SAN NetApp AFF A700 by HTTP','3','-1','2','','','Template SAN NetApp AFF A700 by HTTP','0',NULL,'The template to monitor SAN NetApp AFF A700 cluster by Zabbix HTTP agent.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10373',NULL,'Template Power APC UPS Galaxy 3500 SNMP','3','-1','2','','','Template Power APC UPS Galaxy 3500 SNMP','0',NULL,'Template Power APC UPS Galaxy 3500

MIBs used:
PowerNet-MIB
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420730-discussion-thread-for-official-zabbix-template-apc-ups

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10374',NULL,'Template Power APC Smart-UPS 2200 RM SNMP','3','-1','2','','','Template Power APC Smart-UPS 2200 RM SNMP','0',NULL,'Template Power APC Smart-UPS 2200 RM

MIBs used:
PowerNet-MIB
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420730-discussion-thread-for-official-zabbix-template-apc-ups

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10375',NULL,'Template Power APC Smart-UPS 3000 XLM SNMP','3','-1','2','','','Template Power APC Smart-UPS 3000 XLM SNMP','0',NULL,'Template Power APC Smart-UPS 3000 XLM

MIBs used:
PowerNet-MIB
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420730-discussion-thread-for-official-zabbix-template-apc-ups

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10376',NULL,'Template Power APC Smart-UPS RT 1000 RM XL SNMP','3','-1','2','','','Template Power APC Smart-UPS RT 1000 RM XL SNMP','0',NULL,'Template Power APC Smart-UPS RT 1000 RM XL

MIBs used:
PowerNet-MIB
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420730-discussion-thread-for-official-zabbix-template-apc-ups

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10377',NULL,'Template Power APC Smart-UPS RT 1000 XL SNMP','3','-1','2','','','Template Power APC Smart-UPS RT 1000 XL SNMP','0',NULL,'Template Power APC Smart-UPS RT 1000 XL

MIBs used:
PowerNet-MIB
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420730-discussion-thread-for-official-zabbix-template-apc-ups

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10378',NULL,'Template Power APC Smart-UPS SRT 5000 SNMP','3','-1','2','','','Template Power APC Smart-UPS SRT 5000 SNMP','0',NULL,'Template Power APC Smart-UPS SRT 5000

MIBs used:
PowerNet-MIB
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420730-discussion-thread-for-official-zabbix-template-apc-ups

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10379',NULL,'Template Power APC Smart-UPS SRT 8000 SNMP','3','-1','2','','','Template Power APC Smart-UPS SRT 8000 SNMP','0',NULL,'Template Power APC Smart-UPS SRT 8000

MIBs used:
PowerNet-MIB
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420730-discussion-thread-for-official-zabbix-template-apc-ups

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10380',NULL,'Template Power APC UPS Symmetra LX SNMP','3','-1','2','','','Template Power APC UPS Symmetra LX SNMP','0',NULL,'Template Power APC UPS Symmetra LX

MIBs used:
PowerNet-MIB
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420730-discussion-thread-for-official-zabbix-template-apc-ups

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10381',NULL,'Template Power APC UPS Symmetra RM SNMP','3','-1','2','','','Template Power APC UPS Symmetra RM SNMP','0',NULL,'Template Power APC UPS Symmetra RM

MIBs used:
PowerNet-MIB
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420730-discussion-thread-for-official-zabbix-template-apc-ups

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10382',NULL,'Template Power APC UPS Symmetra RX SNMP','3','-1','2','','','Template Power APC UPS Symmetra RX SNMP','0',NULL,'Template Power APC UPS Symmetra RX

MIBs used:
PowerNet-MIB
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/420730-discussion-thread-for-official-zabbix-template-apc-ups

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10383',NULL,'Template APP WildFly Domain by JMX','3','-1','2','','','Template APP WildFly Domain by JMX','0',NULL,'Official JMX Template for WildFly.
The metrics are collected by JMX. This template works with Domain Controller.
You can set {$WILDFLY.USER} and {$WILDFLY.PASSWORD} macros in the template for using on the host level.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10384',NULL,'Template APP WildFly Server by JMX','3','-1','2','','','Template APP WildFly Server by JMX','0',NULL,'Official JMX Template for WildFly.
The metrics are collected by JMX. This template works with standalone and domain instances.
You can set {$WILDFLY.USER} and {$WILDFLY.PASSWORD} macros in the template for using on the host level.


You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10385',NULL,'Template ZYXEL AAM1212-51 IES-612 SNMP','3','-1','2','','','Template ZYXEL AAM1212-51 IES-612 SNMP','0',NULL,'ZYXEL AAM1212-51 / IES-612

MIBs used:
RFC1213-MIB
ADSL-LINE-MIB
ZYXEL-IESCOMMON-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL AAM1212-51 / IES-612

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10386',NULL,'Template ZYXEL ES3500-8PD SNMP','3','-1','2','','','Template ZYXEL ES3500-8PD SNMP','0',NULL,'ZYXEL ES3500-8PD

MIBs used:
RFC1213-MIB
 ZYXEL-ES3500-8PD-MIB
IF-MIB
ZYXEL-ES3500-8PD-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL ES3500-8PD

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10387',NULL,'Template ZYXEL GS-4012F SNMP','3','-1','2','','','Template ZYXEL GS-4012F SNMP','0',NULL,'ZYXEL GS-4012F

MIBs used:
ZYXEL-GS4012F-MIB
RFC1213-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL GS-4012F

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10388',NULL,'Template ZYXEL IES-500x SNMP','3','-1','2','','','Template ZYXEL IES-500x SNMP','0',NULL,'ZYXEL IES-500x

MIBs used:
RFC1213-MIB
ADSL-LINE-MIB
ZYXEL-IES5000-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL IES-500x

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10389',NULL,'Template ZYXEL IES-6000 SNMP','3','-1','2','','','Template ZYXEL IES-6000 SNMP','0',NULL,'ZYXEL IES-6000

MIBs used:
RFC1213-MIB
ADSL-LINE-MIB
ZYXEL-IES5000-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL IES-6000

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10390',NULL,'Template ZYXEL IES1248-51 SNMP','3','-1','2','','','Template ZYXEL IES1248-51 SNMP','0',NULL,'ZYXEL IES1248-51

MIBs used:
RFC1213-MIB
ADSL-LINE-MIB
ZYXEL-IESCOMMON-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL IES1248-51

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10391',NULL,'Template ZYXEL MES-3528 SNMP','3','-1','2','','','Template ZYXEL MES-3528 SNMP','0',NULL,'ZYXEL MES-3528

MIBs used:
RFC1213-MIB
 ZYXEL-MES3528-MIB
ZYXEL-MES3528-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MES-3528

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10392',NULL,'Template ZYXEL MES3500-10 SNMP','3','-1','2','','','Template ZYXEL MES3500-10 SNMP','0',NULL,'ZYXEL MES3500-10

MIBs used:
RFC1213-MIB
ZYXEL-MES3500-10-MIB
 ZYXEL-MES3500-10-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MES3500-10

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10393',NULL,'Template ZYXEL MES3500-24 SNMP','3','-1','2','','','Template ZYXEL MES3500-24 SNMP','0',NULL,'ZYXEL MES3500-24

MIBs used:
RFC1213-MIB
 ZYXEL-MES3500-24-MIB
ZYXEL-MES3500-24-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MES3500-24

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10394',NULL,'Template ZYXEL MGS-3712 SNMP','3','-1','2','','','Template ZYXEL MGS-3712 SNMP','0',NULL,'ZYXEL MGS-3712

MIBs used:
ZYXEL-MGS3712F-MIB
RFC1213-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MGS-3712

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10395',NULL,'Template ZYXEL MGS-3712F SNMP','3','-1','2','','','Template ZYXEL MGS-3712F SNMP','0',NULL,'ZYXEL MGS-3712F

MIBs used:
ZYXEL-MGS3712F-MIB
RFC1213-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MGS-3712F

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10396',NULL,'Template ZYXEL MES3500-24S SNMP','3','-1','2','','','Template ZYXEL MES3500-24S SNMP','0',NULL,'ZYXEL MES3500-24S

MIBs used:
RFC1213-MIB
ZYXEL-HW-MONITOR-MIB
ZYXEL-PORT-MIB
ZYXEL-ES-COMMON
ZYXEL-TRANSCEIVER-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MGS3520-28

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10397',NULL,'Template ZYXEL MGS3520-28x SNMP','3','-1','2','','','Template ZYXEL MGS3520-28x SNMP','0',NULL,'ZYXEL MGS3520-28x

MIBs used:
RFC1213-MIB
ZYXEL-HW-MONITOR-MIB
ZYXEL-PORT-MIB
ZYXEL-ES-COMMON
ZYXEL-TRANSCEIVER-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MGS3520-28

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10398',NULL,'Template ZYXEL XGS-4728F SNMP','3','-1','2','','','Template ZYXEL XGS-4728F SNMP','0',NULL,'ZYXEL XGS-4728F

MIBs used:
RFC1213-MIB
ZYXEL-XGS4728F-MIB
IF-MIB
 ZYXEL-XGS4728F-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL XGS-4728F

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10399',NULL,'Template App Nginx Plus by HTTP','3','-1','2','','','Template App Nginx Plus by HTTP','0',NULL,'Get Nginx Plus metrics by HTTP agent.
Metrics are collected by requests to Nginx Plus API.
Don''t forget to change macros {$NGINX.API.ENDPOINT}.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10400',NULL,'Template Server Cisco UCS Manager SNMP','3','-1','2','','','Template Server Cisco UCS Manager SNMP','0',NULL,'This is a template for Cisco UCS Manager monitoring via Zabbix SNMP Agent that works without any external scripts.


MIBs used:
CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
SNMPv2-MIB
CISCO-UNIFIED-COMPUTING-PROCESSOR-MIB
CISCO-UNIFIED-COMPUTING-EQUIPMENT-MIB
CISCO-UNIFIED-COMPUTING-STORAGE-MIB
IF-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/418396-discussion-thread-for-official-zabbix-templates-for-cisco

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10402',NULL,'Template Server DELL PowerEdge R720 SNMP','3','-1','2','','','Template Server DELL PowerEdge R720 SNMP','0',NULL,'Template for DELL PowerEdge R720 servers with iDRAC version 7 and later.

MIBs used:
IDRAC-MIB-SMIv2
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/426752-discussion-thread-for-official-zabbix-dell-templates

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10404',NULL,'Template Server DELL PowerEdge R740 SNMP','3','-1','2','','','Template Server DELL PowerEdge R740 SNMP','0',NULL,'Template for DELL PowerEdge R740 servers with iDRAC version 7 and later.

MIBs used:
IDRAC-MIB-SMIv2
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/426752-discussion-thread-for-official-zabbix-dell-templates

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10406',NULL,'Template Server DELL PowerEdge R820 SNMP','3','-1','2','','','Template Server DELL PowerEdge R820 SNMP','0',NULL,'Template for DELL PowerEdge R820 servers with iDRAC version 7 and later.

MIBs used:
IDRAC-MIB-SMIv2
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/426752-discussion-thread-for-official-zabbix-dell-templates

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10408',NULL,'Template Server DELL PowerEdge R840 SNMP','3','-1','2','','','Template Server DELL PowerEdge R840 SNMP','0',NULL,'Template for DELL PowerEdge R840 servers with iDRAC version 7 and later.

MIBs used:
IDRAC-MIB-SMIv2
SNMPv2-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/426752-discussion-thread-for-official-zabbix-dell-templates

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10409',NULL,'Template Server HPE ProLiant BL460 SNMP','3','-1','2','','','Template Server HPE ProLiant BL460 SNMP','0',NULL,'Template for HPE ProLiant BL460 servers with HP iLO version 4 and later.

MIBs used:
CPQHLTH-MIB
SNMPv2-MIB
CPQNIC-MIB
CPQSINFO-MIB
CPQIDA-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10410',NULL,'Template Server HPE ProLiant BL920 SNMP','3','-1','2','','','Template Server HPE ProLiant BL920 SNMP','0',NULL,'Template for HPE ProLiant BL920 servers with HP iLO version 4 and later.

MIBs used:
CPQHLTH-MIB
SNMPv2-MIB
CPQNIC-MIB
CPQSINFO-MIB
CPQIDA-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10411',NULL,'Template Server HPE ProLiant DL360 SNMP','3','-1','2','','','Template Server HPE ProLiant DL360 SNMP','0',NULL,'Template for HPE ProLiant DL360 servers with HP iLO version 4 and later.

MIBs used:
CPQHLTH-MIB
SNMPv2-MIB
CPQNIC-MIB
CPQSINFO-MIB
CPQIDA-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10412',NULL,'Template Server HPE ProLiant DL380 SNMP','3','-1','2','','','Template Server HPE ProLiant DL380 SNMP','0',NULL,'Template for HPE ProLiant DL380 servers with HP iLO version 4 and later.

MIBs used:
CPQHLTH-MIB
SNMPv2-MIB
CPQNIC-MIB
CPQSINFO-MIB
CPQIDA-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10413',NULL,'Template APP Systemd by Zabbix agent 2','3','-1','2','','','Template APP Systemd by Zabbix agent 2','0',NULL,'Get systemd units metrics from plugin for the zabbix-agent2.
  1. Setup and configure zabbix-agent2 compiled with the Systemd monitoring plugin.
  2. Set filters with macros if you want to override default filter parameters.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10414',NULL,'Template DB GridGain by JMX','3','-1','2','','','Template DB GridGain by JMX','0',NULL,'The template to monitor GridGain In-Memory Computing Platform by Zabbix that work without any external scripts.
  It works with both standalone and cluster instances.
  The metrics are discoverable and collected by JMX.  
  Current JMX tree hierarchy contains classloader by default. Add the following jvm option `-DIGNITE_MBEAN_APPEND_CLASS_LOADER_ID=false`to will exclude one level with Classloader name.
  You can set {$GRIDGAIN.USER} and {$GRIDGAIN.PASSWORD} macros in the template for using on the host level.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10415',NULL,'Template F5 Big-IP SNMP','3','-1','2','','','Template F5 Big-IP SNMP','0',NULL,'MIBs used:
RFC1213-MIB
F5-BIGIP-LOCAL-MIB
F5-BIGIP-SYSTEM-MIB

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10416',NULL,'Template App Website certificate by Zabbix agent 2','3','-1','2','','','Template App Website certificate by Zabbix agent 2','0',NULL,'The template to monitor TLS/SSL certificate on the website by Zabbix agent 2 that works without any external scripts.
Zabbix agent 2 with the WebCertificate plugin requests certificate using the web.certificate.get key and returns JSON with certificate attributes.

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/428309-discussion-thread-for-official-zabbix-template-tls-ssl-certificates-monitoring

Template tooling version used: 0.39','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10417',NULL,'Template Net Cisco ASAv SNMP','3','-1','2','','','Template Net Cisco ASAv SNMP','0',NULL,'Template Net Cisco ASAv

MIBs used:
CISCO-PORT-MIB
CISCO-MEMORY-POOL-MIB
CISCO-REMOTE-ACCESS-MONITOR-MIB
IF-MIB
RFC1213-MIB
CISCO-PROCESS-MIB
ENTITY-MIB
 CISCO-REMOTE-ACCESS-MONITOR-MIB

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/418396-discussion-thread-for-official-zabbix-templates-for-cisco

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10418',NULL,'Template Net ZYXEL AAM1212-51 IES-612 SNMP','3','-1','2','','','Template Net ZYXEL AAM1212-51 IES-612 SNMP','0',NULL,'ZYXEL AAM1212-51 / IES-612

MIBs used:
RFC1213-MIB
ADSL-LINE-MIB
ZYXEL-IESCOMMON-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL AAM1212-51 / IES-612

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10419',NULL,'Template Net ZYXEL ES3500-8PD SNMP','3','-1','2','','','Template Net ZYXEL ES3500-8PD SNMP','0',NULL,'ZYXEL ES3500-8PD

MIBs used:
RFC1213-MIB
 ZYXEL-ES3500-8PD-MIB
IF-MIB
ZYXEL-ES3500-8PD-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL ES3500-8PD

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10420',NULL,'Template Net ZYXEL GS-4012F SNMP','3','-1','2','','','Template Net ZYXEL GS-4012F SNMP','0',NULL,'ZYXEL GS-4012F

MIBs used:
ZYXEL-GS4012F-MIB
RFC1213-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL GS-4012F

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10421',NULL,'Template Net ZYXEL IES-500x SNMP','3','-1','2','','','Template Net ZYXEL IES-500x SNMP','0',NULL,'ZYXEL IES-500x

MIBs used:
RFC1213-MIB
ADSL-LINE-MIB
ZYXEL-IES5000-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL IES-500x

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10422',NULL,'Template Net ZYXEL IES-6000 SNMP','3','-1','2','','','Template Net ZYXEL IES-6000 SNMP','0',NULL,'ZYXEL IES-6000

MIBs used:
RFC1213-MIB
ADSL-LINE-MIB
ZYXEL-IES5000-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL IES-6000

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10423',NULL,'Template Net ZYXEL IES1248-51 SNMP','3','-1','2','','','Template Net ZYXEL IES1248-51 SNMP','0',NULL,'ZYXEL IES1248-51

MIBs used:
RFC1213-MIB
ADSL-LINE-MIB
ZYXEL-IESCOMMON-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL IES1248-51

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10424',NULL,'Template Net ZYXEL MES-3528 SNMP','3','-1','2','','','Template Net ZYXEL MES-3528 SNMP','0',NULL,'ZYXEL MES-3528

MIBs used:
RFC1213-MIB
 ZYXEL-MES3528-MIB
ZYXEL-MES3528-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MES-3528

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10425',NULL,'Template Net ZYXEL MES3500-10 SNMP','3','-1','2','','','Template Net ZYXEL MES3500-10 SNMP','0',NULL,'ZYXEL MES3500-10

MIBs used:
RFC1213-MIB
ZYXEL-MES3500-10-MIB
 ZYXEL-MES3500-10-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MES3500-10

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10426',NULL,'Template Net ZYXEL MES3500-24 SNMP','3','-1','2','','','Template Net ZYXEL MES3500-24 SNMP','0',NULL,'ZYXEL MES3500-24

MIBs used:
RFC1213-MIB
 ZYXEL-MES3500-24-MIB
ZYXEL-MES3500-24-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MES3500-24

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10427',NULL,'Template Net ZYXEL MGS-3712 SNMP','3','-1','2','','','Template Net ZYXEL MGS-3712 SNMP','0',NULL,'ZYXEL MGS-3712

MIBs used:
ZYXEL-MGS3712F-MIB
RFC1213-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MGS-3712

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10428',NULL,'Template Net ZYXEL MGS-3712F SNMP','3','-1','2','','','Template Net ZYXEL MGS-3712F SNMP','0',NULL,'ZYXEL MGS-3712F

MIBs used:
ZYXEL-MGS3712F-MIB
RFC1213-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MGS-3712F

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10429',NULL,'Template Net ZYXEL MES3500-24S SNMP','3','-1','2','','','Template Net ZYXEL MES3500-24S SNMP','0',NULL,'ZYXEL MES3500-24S

MIBs used:
RFC1213-MIB
ZYXEL-HW-MONITOR-MIB
ZYXEL-PORT-MIB
ZYXEL-ES-COMMON
ZYXEL-TRANSCEIVER-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MGS3520-28

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10430',NULL,'Template Net ZYXEL MGS3520-28x SNMP','3','-1','2','','','Template Net ZYXEL MGS3520-28x SNMP','0',NULL,'ZYXEL MGS3520-28x

MIBs used:
RFC1213-MIB
ZYXEL-HW-MONITOR-MIB
ZYXEL-PORT-MIB
ZYXEL-ES-COMMON
ZYXEL-TRANSCEIVER-MIB
IF-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL MGS3520-28

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO hosts (hostid,proxy_hostid,host,status,ipmi_authtype,ipmi_privilege,ipmi_username,ipmi_password,name,flags,templateid,description,tls_connect,tls_accept,tls_issuer,tls_subject,tls_psk_identity,tls_psk,proxy_address,auto_compress,discover) values ('10431',NULL,'Template Net ZYXEL XGS-4728F SNMP','3','-1','2','','','Template Net ZYXEL XGS-4728F SNMP','0',NULL,'ZYXEL XGS-4728F

MIBs used:
RFC1213-MIB
ZYXEL-XGS4728F-MIB
IF-MIB
 ZYXEL-XGS4728F-MIB

Known Issues:

  Description: Incorrect handling of SNMP bulk requests. Disable the use of bulk requests in the SNMP interface settings.
  Version: all versions firmware
  Device: ZYXEL XGS-4728F

You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback/422668-discussion-thread-for-official-zabbix-templates-for-zyxel

Template tooling version used: 0.38','1','1','','','','','','1','0');
INSERT INTO group_prototype (group_prototypeid,hostid,name,groupid,templateid) values ('1','10331','{#CLUSTER.NAME}',NULL,NULL);
INSERT INTO group_prototype (group_prototypeid,hostid,name,groupid,templateid) values ('2','10331','{#DATACENTER.NAME}',NULL,NULL);
INSERT INTO group_prototype (group_prototypeid,hostid,name,groupid,templateid) values ('4','10332','{#CLUSTER.NAME} (vm)',NULL,NULL);
INSERT INTO group_prototype (group_prototypeid,hostid,name,groupid,templateid) values ('5','10332','{#DATACENTER.NAME} (vm)',NULL,NULL);
INSERT INTO group_prototype (group_prototypeid,hostid,name,groupid,templateid) values ('6','10332','{#HV.NAME}',NULL,NULL);
INSERT INTO group_prototype (group_prototypeid,hostid,name,groupid,templateid) values ('24','10364','MongoDB sharded cluster/{#REPLICASET}',NULL,NULL);
INSERT INTO group_prototype (group_prototypeid,hostid,name,groupid,templateid) values ('26','10365','MongoDB sharded cluster/{#ID}',NULL,NULL);
INSERT INTO group_prototype (group_prototypeid,hostid,name,groupid,templateid) values ('52','10331','','12',NULL);
INSERT INTO group_prototype (group_prototypeid,hostid,name,groupid,templateid) values ('53','10332','','12',NULL);
INSERT INTO group_prototype (group_prototypeid,hostid,name,groupid,templateid) values ('54','10364','','13',NULL);
INSERT INTO group_prototype (group_prototypeid,hostid,name,groupid,templateid) values ('55','10365','','13',NULL);
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('3','System performance','2','7','10001',NULL,'0');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('4','Zabbix server health','2','3','10047',NULL,'0');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('5','System performance','2','2','10076',NULL,'0');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('6','System performance','2','2','10077',NULL,'0');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('7','System performance','2','2','10075',NULL,'0');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('9','System performance','2','3','10074',NULL,'0');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('10','System performance','2','3','10078',NULL,'0');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('16','Zabbix server','2','2',NULL,'1','0');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('17','Zabbix proxy health','2','2','10048',NULL,'0');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('18','System performance','1','2','10079',NULL,'0');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('19','System performance','2','6','10081',NULL,'0');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('20','MySQL performance','2','4','10170',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('21','Zabbix server health','2','3','10261',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('22','Zabbix proxy health','2','2','10262',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('23','PostgreSQL databases','2','4','10263',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('24','PostgreSQL stat','2','4','10263',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('25','Apache performance','2','3','10264',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('26','Apache performance','2','3','10265',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('27','Nginx performance','2','2','10266',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('28','Nginx performance','2','2','10267',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('29','System performance','2','6','10248',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('30','Network interfaces','1','1','10276',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('31','Network interfaces','1','1','10282',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('32','System performance','2','7','10284',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('33','System performance','2','7','10285',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('34','Network interfaces','1','1','10285',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('37','System performance','2','6','10299',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('38','RabbitMQ overview','2','3','10300',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('39','RabbitMQ node status','2','3','10301',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('40','RabbitMQ overview','2','3','10302',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('41','RabbitMQ node status','2','3','10303',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('43','Network interfaces','1','1','10190',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('45','Network interfaces','1','1','10188',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('46','Network interfaces','1','1','10192',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('47','System performance','2','3','10185',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('48','HAProxy Backend performance','1','3','10308',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('49','HAProxy Frontend performance','1','4','10308',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('50','HAProxy Server performance','1','3','10308',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('51','HAProxy Backend performance','1','3','10309',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('52','HAProxy Frontend performance','1','4','10309',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('53','HAProxy Server performance','1','3','10309',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('54','Redis overview','2','5','10310',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('55','Redis performance','2','2','10310',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('57','MySQL performance','2','3','10316',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('58','MySQL performance','2','3','10317',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('59','Docker overview','2','5','10318',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('60','MySQL performance','2','3','10320',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('61','PostgreSQL databases','2','5','10328',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('62','RabbitMQ overview','2','3','10358',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('63','RabbitMQ node status','2','3','10359',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('64','RabbitMQ overview','2','3','10360',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('65','RabbitMQ node status','2','3','10361',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('66','Network interfaces','1','1','10251',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('67','System performance','2','3','10251',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('68','UPS Summary','3','4','10371',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('69','UPS Summary','3','4','10373',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('70','UPS Summary','3','4','10374',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('71','UPS Summary','3','4','10375',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('72','UPS Summary','3','4','10376',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('73','UPS Summary','3','4','10377',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('74','UPS Summary','3','4','10378',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('75','UPS Summary','3','4','10379',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('76','UPS Summary','3','4','10380',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('77','UPS Summary','3','4','10381',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('78','UPS Summary','3','4','10382',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('79','Zabbix server processes','2','2','10047',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('80','Zabbix server processes','2','2','10261',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('81','Network interfaces','1','1','10400',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('82','Network interfaces','1','1','10291',NULL,'1');
INSERT INTO screens (screenid,name,hsize,vsize,templateid,userid,private) values ('83','Network interfaces','1','1','10298',NULL,'1');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('44','16','2','1','500','100','0','0','2','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('1954','20','0','862','750','200','0','0','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('1955','20','0','863','750','200','1','0','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('1956','20','0','860','750','200','0','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('1957','20','0','859','750','200','1','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('1958','20','0','861','750','200','0','2','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('1959','20','0','864','750','200','1','2','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5526','38','0','1029','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5527','38','0','1027','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5528','38','0','1030','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5529','38','0','1028','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5530','38','0','1031','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5531','39','0','1011','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5532','39','0','1012','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5533','39','0','1008','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5534','39','0','1009','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5535','39','0','1007','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5536','39','0','1010','500','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5537','40','0','1018','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5538','40','0','1016','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5539','40','0','1019','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5540','40','0','1017','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5541','40','0','1020','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5542','41','0','1025','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5543','41','0','1026','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5544','41','0','1022','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5545','41','0','1023','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5546','41','0','1021','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('5547','41','0','1024','500','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7854','25','0','1174','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7855','25','0','1176','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7856','25','20','1172','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7857','25','20','1173','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7858','25','0','1175','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7859','26','0','838','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7860','26','0','839','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7861','26','20','836','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7862','26','20','837','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7863','26','0','840','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7864','59','0','1125','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7865','59','0','1129','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7866','59','0','1128','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7867','59','0','1126','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7868','59','0','1127','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7869','48','20','1710','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7870','48','20','1711','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7871','48','20','1709','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7872','49','20','1714','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7873','49','20','1712','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7874','49','20','1715','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7875','49','20','1713','500','100','0','3','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7876','50','20','1718','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7877','50','20','1717','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7878','50','20','1716','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7879','51','20','1720','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7880','51','20','1721','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7881','51','20','1719','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7882','52','20','1724','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7883','52','20','1722','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7884','52','20','1725','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7885','52','20','1723','500','100','0','3','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7886','53','20','1728','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7887','53','20','1727','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7888','53','20','1726','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7889','27','0','841','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7890','27','0','843','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7891','27','0','842','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7892','28','0','845','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7893','28','0','847','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7894','28','0','846','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7895','62','0','1419','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7896','62','0','1414','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7897','62','0','1421','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7898','62','0','1423','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7899','62','0','1420','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7900','63','0','1422','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7901','63','0','1425','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7902','63','0','1415','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7903','63','0','1418','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7904','63','0','1416','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7905','63','0','1424','500','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7906','64','0','1432','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7907','64','0','1428','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7908','64','0','1434','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7909','64','0','1436','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7910','64','0','1433','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7911','65','0','1435','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7912','65','0','1438','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7913','65','0','1429','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7914','65','0','1431','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7915','65','0','1430','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7916','65','0','1437','500','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7917','4','0','1545','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7918','4','0','1539','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7919','4','0','1541','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7920','4','0','1537','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7921','4','0','1535','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7922','4','0','1543','500','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7923','79','0','1527','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7924','79','0','1531','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7925','79','0','1529','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7926','79','0','1525','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7927','21','0','1557','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7928','21','0','1554','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7929','21','0','1555','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7930','21','0','1553','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7931','21','0','1552','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7932','21','0','1556','500','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7933','80','0','1548','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7934','80','0','1550','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7935','80','0','1549','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7936','80','0','1547','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7937','22','0','806','500','212','0','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7938','22','0','804','500','100','1','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7939','22','0','805','500','100','0','1','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7940','22','0','803','500','128','1','1','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7941','17','0','532','500','212','0','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7942','17','0','530','500','100','1','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7943','17','0','531','500','100','0','1','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7944','17','0','529','500','128','1','1','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7945','5','0','469','500','148','0','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7946','5','0','471','500','100','1','0','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7947','5','0','498','500','100','0','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7948','5','0','540','500','100','1','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7949','7','0','463','500','120','0','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7950','7','0','462','500','106','1','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7951','7','0','541','500','100','0','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7952','7','0','464','500','300','1','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7953','6','0','475','500','114','0','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7954','6','0','474','500','100','1','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7955','6','0','542','500','100','0','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7956','18','0','487','750','100','0','0','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7957','18','0','543','750','100','0','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7958','9','0','457','500','120','0','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7959','9','0','456','500','106','1','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7960','9','0','544','500','100','0','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7961','9','0','458','500','300','1','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7962','9','1','22838','500','100','0','2','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7963','9','1','22837','500','100','1','2','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7964','10','0','481','500','114','0','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7965','10','0','480','500','100','1','0','1','1','0','1','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7966','10','0','545','500','100','0','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7967','10','0','482','500','300','1','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7968','10','1','22998','500','100','0','2','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7969','10','1','22997','500','100','1','2','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7970','57','0','1112','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7971','57','0','1113','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7972','57','0','1110','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7973','57','0','1109','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7974','57','0','1111','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7975','57','0','1114','500','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7976','60','0','1139','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7977','60','0','1140','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7978','60','0','1137','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7979','60','0','1136','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7980','60','0','1138','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7981','60','0','1141','500','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7982','58','0','1118','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7983','58','0','1119','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7984','58','0','1116','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7985','58','0','1115','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7986','58','0','1117','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7987','58','0','1120','500','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7988','23','20','821','500','200','0','0','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7989','23','20','816','500','200','1','0','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7990','23','20','814','500','200','0','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7991','23','20','820','500','200','1','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7992','23','20','817','500','200','0','2','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7993','23','20','815','500','200','1','2','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7994','23','20','818','500','200','0','3','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7995','23','20','819','500','200','1','3','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7996','24','0','824','500','200','0','0','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7997','24','0','827','500','200','1','0','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7998','24','0','825','500','200','0','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('7999','24','0','828','500','200','1','1','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8000','24','0','826','500','200','0','2','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8001','24','0','829','500','200','1','2','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8002','24','0','822','500','200','0','3','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8003','24','0','823','500','200','1','3','1','1','0','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8004','61','20','1212','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8005','61','20','1210','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8006','61','20','1213','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8007','61','20','1211','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8008','54','0','1091','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8009','54','0','1095','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8010','54','0','1092','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8011','54','0','1094','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8012','54','0','1099','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8013','54','0','1100','500','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8014','54','0','1101','500','100','0','3','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8015','54','0','1102','500','100','1','3','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8016','54','20','1090','500','100','0','4','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8017','55','0','1093','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8018','55','0','1098','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8019','55','0','1096','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8020','55','0','1097','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8021','47','0','1071','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8022','47','20','1061','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8023','47','20','1066','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8024','45','20','741','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8025','43','20','745','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8026','46','20','766','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8027','66','20','1476','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8028','67','0','1479','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8029','67','20','1478','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8030','67','20','1477','500','100','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8031','3','0','903','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8032','3','0','909','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8033','3','0','918','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8034','3','0','921','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8035','3','20','888','500','100','0','2','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8036','3','20','1218','500','100','0','3','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8037','3','20','1215','500','100','0','4','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8038','3','20','1221','500','100','0','5','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8039','3','20','900','500','100','0','6','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8040','30','20','899','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8041','31','20','934','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8042','32','0','937','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8043','32','0','941','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8044','32','0','947','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8045','32','0','949','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8046','32','20','927','500','100','0','2','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8047','32','20','1226','500','100','0','3','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8048','32','20','1224','500','100','0','4','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8049','32','20','1228','500','100','0','5','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8050','32','20','935','500','100','0','6','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8051','33','0','957','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8052','33','0','959','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8053','33','0','962','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8054','33','0','963','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8055','33','20','953','500','100','0','2','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8056','33','20','954','500','100','0','3','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8057','33','20','955','500','100','0','4','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8058','33','20','956','500','100','0','5','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8059','33','20','952','500','100','0','6','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8060','34','20','952','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8061','29','0','881','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8062','29','20','869','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8063','29','0','877','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8064','29','0','879','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8065','29','20','873','500','100','0','2','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8066','29','20','867','500','100','0','3','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8067','29','19','29033','500','100','0','4','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8068','29','20','865','500','100','0','5','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8069','19','0','977','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8070','19','1','29485','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8071','19','0','979','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8072','19','0','981','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8073','19','20','965','500','100','0','2','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8074','19','20','1230','500','100','0','3','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8075','19','20','1232','500','100','0','4','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8076','19','20','1840','500','100','0','5','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8077','82','20','1839','750','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8078','37','0','995','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8079','37','1','29592','500','100','1','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8080','37','0','997','500','100','0','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8081','37','0','999','500','100','1','1','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8082','37','20','983','500','100','0','2','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8083','37','20','1234','500','100','0','3','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8084','37','20','1236','500','100','0','4','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8085','37','20','1842','500','100','0','5','2','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8086','83','20','1841','750','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8087','69','3','33570','500','100','0','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8088','69','3','33585','500','100','1','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8089','69','3','33580','500','100','2','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8090','69','3','33591','500','100','0','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8091','69','3','33592','500','100','1','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8092','69','3','33594','500','100','2','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8093','69','0','1489','300','300','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8094','69','0','1491','400','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8095','69','0','1490','400','100','2','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8096','70','3','33621','500','100','0','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8097','70','3','33636','500','100','1','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8098','70','3','33631','500','100','2','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8099','70','3','33642','500','100','0','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8100','70','3','33643','500','100','1','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8101','70','3','33645','500','100','2','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8102','70','0','1492','300','300','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8103','70','0','1494','400','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8104','70','0','1493','400','100','2','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8105','71','3','33672','500','100','0','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8106','71','3','33687','500','100','1','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8107','71','3','33682','500','100','2','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8108','71','3','33693','500','100','0','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8109','71','3','33694','500','100','1','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8110','71','3','33696','500','100','2','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8111','71','0','1495','300','300','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8112','71','0','1497','400','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8113','71','0','1496','400','100','2','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8114','72','3','33723','500','100','0','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8115','72','3','33738','500','100','1','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8116','72','3','33733','500','100','2','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8117','72','3','33744','500','100','0','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8118','72','3','33745','500','100','1','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8119','72','3','33747','500','100','2','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8120','72','0','1498','300','300','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8121','72','0','1500','400','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8122','72','0','1499','400','100','2','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8123','73','3','33774','500','100','0','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8124','73','3','33789','500','100','1','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8125','73','3','33784','500','100','2','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8126','73','3','33795','500','100','0','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8127','73','3','33796','500','100','1','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8128','73','3','33798','500','100','2','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8129','73','0','1501','300','300','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8130','73','0','1503','400','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8131','73','0','1502','400','100','2','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8132','74','3','33825','500','100','0','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8133','74','3','33840','500','100','1','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8134','74','3','33835','500','100','2','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8135','74','3','33846','500','100','0','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8136','74','3','33847','500','100','1','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8137','74','3','33849','500','100','2','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8138','74','0','1504','300','300','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8139','74','0','1506','400','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8140','74','0','1505','400','100','2','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8141','75','3','33876','500','100','0','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8142','75','3','33891','500','100','1','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8143','75','3','33886','500','100','2','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8144','75','3','33897','500','100','0','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8145','75','3','33898','500','100','1','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8146','75','3','33900','500','100','2','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8147','75','0','1507','300','300','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8148','75','0','1509','400','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8149','75','0','1508','400','100','2','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8150','68','3','33434','500','100','0','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8151','68','3','33449','500','100','1','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8152','68','3','33444','500','100','2','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8153','68','3','33455','500','100','0','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8154','68','3','33456','500','100','1','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8155','68','3','33458','500','100','2','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8156','68','0','1510','300','300','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8157','68','0','1482','400','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8158','68','0','1481','400','100','2','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8159','76','3','33932','500','100','0','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8160','76','3','33947','500','100','1','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8161','76','3','33942','500','100','2','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8162','76','3','33953','500','100','0','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8163','76','3','33954','500','100','1','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8164','76','3','33956','500','100','2','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8165','76','0','1511','300','300','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8166','76','0','1513','400','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8167','76','0','1512','400','100','2','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8168','77','3','33983','500','100','0','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8169','77','3','33998','500','100','1','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8170','77','3','33993','500','100','2','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8171','77','3','34004','500','100','0','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8172','77','3','34005','500','100','1','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8173','77','3','34007','500','100','2','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8174','77','0','1514','300','300','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8175','77','0','1516','400','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8176','77','0','1515','400','100','2','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8177','78','3','34034','500','100','0','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8178','78','3','34049','500','100','1','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8179','78','3','34044','500','100','2','0','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8180','78','3','34055','500','100','0','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8181','78','3','34056','500','100','1','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8182','78','3','34058','500','100','2','1','1','1','1','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8183','78','0','1517','300','300','0','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8184','78','0','1519','400','100','1','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8185','78','0','1518','400','100','2','2','1','1','25','0','0','0','','0','0','','3');
INSERT INTO screens_items (screenitemid,screenid,resourcetype,resourceid,width,height,x,y,colspan,rowspan,elements,valign,halign,style,url,dynamic,sort_triggers,application,max_columns) values ('8186','81','20','1676','500','100','0','0','1','1','25','0','0','0','','0','0','','3');
INSERT INTO applications (applicationid,hostid,name,flags) values ('179','10047','Zabbix server','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('253','10074','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('254','10074','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('255','10074','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('256','10074','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('257','10074','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('258','10074','OS','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('259','10074','Performance','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('260','10074','Processes','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('261','10074','Security','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('263','10075','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('264','10075','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('265','10075','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('266','10075','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('267','10075','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('268','10075','OS','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('269','10075','Performance','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('270','10075','Processes','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('271','10075','Security','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('273','10076','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('274','10076','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('275','10076','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('276','10076','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('277','10076','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('278','10076','OS','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('279','10076','Performance','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('280','10076','Processes','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('281','10076','Security','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('283','10077','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('284','10077','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('285','10077','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('286','10077','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('287','10077','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('288','10077','OS','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('289','10077','Performance','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('290','10077','Processes','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('291','10077','Security','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('293','10078','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('294','10078','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('295','10078','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('296','10078','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('297','10078','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('298','10078','OS','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('299','10078','Performance','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('300','10078','Processes','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('301','10078','Security','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('303','10079','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('304','10079','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('305','10079','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('306','10079','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('307','10079','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('308','10079','OS','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('309','10079','Performance','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('310','10079','Processes','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('311','10079','Security','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('331','10076','Logical partitions','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('345','10084','Zabbix server','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('356','10048','Zabbix proxy','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('446','10093','FTP service','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('447','10094','HTTP service','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('448','10095','HTTPS service','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('449','10096','IMAP service','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('450','10097','LDAP service','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('451','10098','NNTP service','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('452','10099','NTP service','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('453','10100','POP service','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('454','10101','SMTP service','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('455','10102','SSH service','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('456','10103','Telnet service','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('740','10170','MySQL','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('741','10171','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('742','10171','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('743','10171','Voltage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('744','10172','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('745','10172','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('746','10172','Voltage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('771','10183','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('780','10186','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('782','10188','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('784','10190','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('786','10192','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('799','10204','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('800','10204','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('803','10207','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('804','10207','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('805','10207','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('806','10207','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('807','10207','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('808','10207','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('809','10207','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('810','10207','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('811','10208','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('812','10208','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('813','10208','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('814','10208','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('815','10208','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('816','10208','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('817','10208','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('818','10208','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('819','10208','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('820','10210','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('821','10210','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('822','10210','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('823','10211','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('824','10211','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('825','10211','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('826','10209','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('827','10209','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('828','10210','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('829','10210','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('830','10210','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('831','10210','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('832','10211','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('833','10211','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('834','10211','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('835','10211','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('836','10210','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('837','10210','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('838','10211','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('839','10211','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('840','10218','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('841','10218','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('842','10218','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('846','10220','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('847','10220','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('848','10212','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('849','10213','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('851','10215','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('852','10216','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('853','10217','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('854','10217','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('855','10217','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('856','10218','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('857','10218','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('858','10218','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('859','10218','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('860','10218','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('861','10218','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('868','10220','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('869','10220','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('870','10220','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('871','10220','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('872','10220','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('873','10220','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('874','10221','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('875','10221','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('876','10221','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('877','10221','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('878','10221','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('879','10221','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('880','10221','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('881','10221','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('882','10221','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('883','10222','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('884','10222','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('885','10222','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('886','10222','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('887','10222','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('888','10222','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('889','10222','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('890','10222','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('891','10222','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('892','10223','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('893','10223','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('894','10223','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('895','10223','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('896','10223','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('897','10223','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('898','10223','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('899','10223','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('900','10223','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('901','10224','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('902','10224','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('903','10224','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('904','10224','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('905','10224','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('906','10224','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('907','10224','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('908','10224','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('909','10224','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('913','10226','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('914','10226','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('915','10226','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('916','10227','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('917','10227','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('918','10227','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('919','10227','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('920','10227','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('921','10227','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('922','10227','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('923','10227','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('924','10227','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('934','10229','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('935','10229','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('936','10229','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('937','10229','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('938','10229','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('939','10229','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('940','10229','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('941','10229','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('942','10230','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('943','10230','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('944','10230','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('945','10230','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('946','10230','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('947','10230','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('948','10230','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('949','10231','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('950','10231','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('951','10231','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('952','10231','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('953','10231','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('954','10231','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('955','10231','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('956','10231','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('957','10231','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('969','10233','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('970','10233','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('971','10233','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('972','10233','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('973','10233','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('974','10233','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('975','10233','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('976','10233','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('977','10234','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('978','10234','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('979','10234','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('980','10234','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('981','10234','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('982','10234','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('983','10234','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('984','10234','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('985','10234','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('986','10235','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('987','10235','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('988','10235','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('989','10235','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('990','10235','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('991','10235','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('992','10236','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('993','10236','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('994','10236','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('995','10236','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('996','10236','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('997','10236','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('998','10237','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('999','10237','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1000','10237','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1001','10237','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1002','10237','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1003','10237','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1028','10250','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1029','10250','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1030','10250','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1031','10250','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1032','10250','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1033','10250','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1034','10250','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1035','10250','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1036','10250','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1044','10251','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1045','10251','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1046','10251','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1047','10251','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1048','10253','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1049','10253','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1050','10253','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1051','10253','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1052','10253','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1053','10253','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1054','10253','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1055','10253','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1056','10252','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1057','10253','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1058','10254','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1059','10254','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1060','10254','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1062','10254','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1064','10254','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1066','10254','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1068','10254','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1069','10255','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1070','10255','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1071','10255','Disk arrays','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1072','10255','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1073','10255','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1074','10255','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1075','10255','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1076','10255','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1077','10255','Virtual disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1078','10256','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1079','10256','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1080','10256','Disk arrays','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1081','10256','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1082','10256','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1083','10256','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1084','10256','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1085','10256','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1086','10256','Virtual disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1094','10258','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1095','10258','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1096','10258','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1097','10258','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1098','10258','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1099','10258','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1100','10258','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1101','10259','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1102','10259','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1103','10259','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1104','10259','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1109','10260','Tomcat','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1110','10261','Zabbix server','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1111','10262','Zabbix proxy','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1114','10263','PostgreSQL','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1115','10263','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1116','10264','Apache','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1117','10264','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1118','10265','Apache','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1119','10265','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1120','10266','Nginx','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1121','10266','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1122','10267','Nginx','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1123','10267','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1124','10170','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1125','10248','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1126','10248','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1127','10248','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1128','10268','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1129','10269','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1130','10270','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1131','10271','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1132','10248','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1133','10248','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1134','10248','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1135','10249','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1136','10249','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1141','10249','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1142','10272','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1143','10273','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1144','10274','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1145','10275','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1146','10275','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1147','10276','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1148','10277','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1149','10277','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1150','10277','Security','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1151','10277','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1152','10001','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1153','10001','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1154','10001','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1155','10001','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1156','10001','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1157','10001','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1158','10001','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1159','10001','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1160','10001','Security','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1161','10001','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1162','10084','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1163','10084','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1164','10084','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1165','10084','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1166','10084','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1167','10084','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1168','10084','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1169','10084','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1170','10084','Security','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1171','10084','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1173','10278','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1174','10279','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1175','10280','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1176','10281','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1177','10281','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1178','10282','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1179','10283','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1180','10283','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1181','10283','Security','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1182','10283','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1183','10284','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1184','10284','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1185','10284','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1186','10284','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1187','10284','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1188','10284','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1189','10284','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1190','10284','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1191','10284','Security','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1192','10284','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1193','10285','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1194','10285','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1195','10285','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1196','10285','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1197','10285','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1198','10285','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1199','10285','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1200','10285','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1201','10285','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1202','10286','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1203','10287','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1204','10288','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1205','10289','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1207','10290','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1208','10290','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1209','10290','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1210','10291','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1211','10291','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1212','10081','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1213','10081','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1214','10081','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1215','10081','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1216','10081','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1217','10081','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1218','10081','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1219','10081','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1220','10081','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1221','10050','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1222','10050','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1223','10292','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1224','10292','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1225','10001','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1226','10074','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1227','10074','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1228','10075','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1229','10075','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1230','10076','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1231','10076','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1232','10077','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1233','10077','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1234','10078','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1235','10078','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1236','10079','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1237','10079','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1238','10081','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1240','10084','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1241','10299','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1242','10299','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1243','10293','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1244','10294','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1245','10295','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1246','10296','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1248','10297','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1249','10297','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1250','10297','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1251','10298','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1252','10298','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1253','10299','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1254','10299','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1255','10299','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1256','10299','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1257','10299','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1258','10299','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1259','10299','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1260','10299','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1261','10300','RabbitMQ','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1262','10300','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1263','10301','RabbitMQ','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1264','10301','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1265','10302','RabbitMQ','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1266','10302','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1267','10303','RabbitMQ','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1268','10303','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1269','10284','Monitoring agent','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1270','10304','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1271','10304','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1272','10304','Disk arrays','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1273','10304','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1274','10304','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1275','10304','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1276','10304','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1277','10304','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1278','10304','Virtual disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1279','10207','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1280','10235','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1281','10235','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1282','10235','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1283','10305','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1284','10306','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1285','10307','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1286','10185','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1287','10185','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1288','10185','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1292','10249','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1293','10249','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1294','10249','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1295','10254','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1296','10254','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1297','10254','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1298','10308','HAProxy','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1299','10308','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1300','10309','HAProxy','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1301','10309','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1302','10310','Redis','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1303','10310','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1310','10314','Services','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1311','10081','Services','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1312','10315','Services','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1313','10299','Services','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1314','10316','MySQL','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1315','10316','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1316','10317','MySQL','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1317','10317','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1318','10318','Docker','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1319','10318','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1320','10319','Memcached','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1321','10319','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1322','10320','MySQL','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1323','10320','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1324','10321','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1325','10321','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1326','10322','ES cluster','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1327','10322','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1328','10323','ClickHouse','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1329','10323','ClickHouse ZooKeeper','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1330','10323','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1331','10324','Etcd','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1332','10324','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1333','10325','IIS','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1334','10326','IIS','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1335','10327','MSSQL','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1336','10327','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1337','10328','PostgreSQL','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1338','10328','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1341','10169','JMX','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1342','10173','VMware','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1343','10174','VMware','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1344','10175','VMware','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1345','10333','Oracle','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1346','10333','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1347','10233','Wireless','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1348','10334','Ceph','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1349','10334','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1350','10335','PHP-FPM','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1351','10335','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1352','10336','PHP-FPM','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1353','10336','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1354','10337','Squid','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1357','10339','Hadoop','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1358','10339','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1359','10340','Kafka','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1360','10341','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1361','10341','Zookeeper','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1362','10342','Cassandra','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1363','10254','Voltage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1364','10254','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1365','10343','Array','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1366','10343','Battery','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1367','10343','Counter','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1368','10343','Load','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1369','10343','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1370','10343','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1371','10343','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1372','10344','Array','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1373','10344','Battery','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1374','10344','Counter','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1375','10344','Load','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1376','10344','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1377','10344','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1378','10344','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1379','10345','Array','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1380','10345','Battery','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1381','10345','Counter','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1382','10345','Load','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1383','10345','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1384','10345','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1385','10345','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1386','10346','Battery','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1387','10346','Load','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1388','10346','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1389','10346','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1390','10346','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1391','10347','Array','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1392','10347','Battery','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1393','10347','Counter','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1394','10347','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1395','10347','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1396','10347','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1397','10348','Array','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1398','10348','Battery','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1399','10348','Counter','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1400','10348','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1401','10348','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1402','10348','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1403','10349','Array','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1404','10349','Battery','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1405','10349','Counter','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1406','10349','Load','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1407','10349','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1408','10349','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1409','10349','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1410','10350','ActiveMQ','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1411','10351','MS Exchange','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1412','10352','MS Exchange','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1413','10353','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1414','10353','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1415','10353','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1416','10353','NetApp FAS3220','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1417','10353','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1418','10354','Ignite','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1419','10355','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1420','10356','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1421','10357','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1422','10357','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1423','10357','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1424','10357','Huawei','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1425','10358','RabbitMQ','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1426','10358','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1427','10359','RabbitMQ','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1428','10359','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1429','10360','RabbitMQ','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1430','10360','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1431','10361','RabbitMQ','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1432','10361','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1433','10362','MongoDB','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1434','10362','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1435','10363','MongoDB sharded cluster','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1436','10363','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1437','10366','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1438','10366','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1439','10366','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1440','10366','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1441','10366','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1442','10366','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1443','10366','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1444','10366','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1445','10366','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1446','10367','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1447','10367','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1448','10367','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1449','10367','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1450','10367','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1451','10367','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1452','10367','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1453','10367','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1454','10367','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1455','10368','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1456','10368','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1457','10368','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1458','10368','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1459','10368','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1460','10368','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1461','10368','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1462','10368','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1463','10368','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1464','10369','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1465','10369','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1466','10369','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1467','10369','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1468','10369','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1469','10369','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1470','10369','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1471','10369','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1472','10369','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1473','10370','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1474','10370','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1475','10370','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1476','10370','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1477','10370','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1478','10370','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1479','10370','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1480','10370','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1481','10370','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1482','10251','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1483','10251','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1484','10251','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1485','10251','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1486','10251','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1487','10251','Storage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1488','10371','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1489','10371','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1490','10372','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1491','10372','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1492','10373','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1493','10373','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1494','10374','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1495','10374','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1496','10375','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1497','10375','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1498','10376','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1499','10376','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1500','10377','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1501','10377','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1502','10378','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1503','10378','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1504','10379','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1505','10379','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1506','10380','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1507','10380','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1508','10381','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1509','10381','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1510','10382','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1511','10382','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1512','10383','WildFly','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1513','10384','WildFly','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1514','10261','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1515','10385','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1516','10385','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1517','10385','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1518','10385','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1519','10385','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1520','10386','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1521','10386','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1522','10386','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1523','10386','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1524','10386','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1525','10386','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1526','10386','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1527','10387','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1528','10387','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1529','10387','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1530','10387','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1531','10387','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1532','10387','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1533','10387','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1534','10388','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1535','10388','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1536','10388','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1537','10388','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1538','10388','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1539','10388','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1540','10388','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1541','10388','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1542','10389','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1543','10389','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1544','10389','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1545','10389','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1546','10389','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1547','10389','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1548','10389','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1549','10389','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1550','10390','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1551','10390','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1552','10390','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1553','10390','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1554','10390','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1555','10390','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1556','10391','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1557','10391','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1558','10391','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1559','10391','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1560','10392','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1561','10392','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1562','10392','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1563','10392','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1564','10392','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1565','10392','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1566','10392','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1567','10393','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1568','10393','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1569','10393','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1570','10393','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1571','10393','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1572','10393','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1573','10393','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1574','10394','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1575','10394','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1576','10394','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1577','10394','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1578','10394','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1579','10394','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1580','10394','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1581','10395','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1582','10395','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1583','10395','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1584','10395','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1585','10395','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1586','10395','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1587','10395','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1588','10396','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1589','10396','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1590','10396','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1591','10396','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1592','10396','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1593','10396','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1594','10396','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1595','10396','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1596','10397','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1597','10397','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1598','10397','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1599','10397','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1600','10397','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1601','10397','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1602','10397','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1603','10397','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1604','10398','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1605','10398','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1606','10398','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1607','10398','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1608','10398','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1609','10398','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1610','10398','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1611','10398','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1612','10399','Nginx','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1613','10399','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1614','10400','Disk arrays','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1615','10400','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1616','10400','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1617','10400','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1618','10400','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1619','10400','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1620','10400','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1621','10400','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1622','10400','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1623','10400','Virtual disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1633','10402','Disk arrays','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1634','10402','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1635','10402','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1636','10402','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1637','10402','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1638','10402','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1639','10402','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1640','10402','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1641','10402','Virtual disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1651','10404','Disk arrays','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1652','10404','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1653','10404','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1654','10404','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1655','10404','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1656','10404','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1657','10404','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1658','10404','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1659','10404','Virtual disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1669','10406','Disk arrays','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1670','10406','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1671','10406','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1672','10406','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1673','10406','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1674','10406','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1675','10406','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1676','10406','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1677','10406','Virtual disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1687','10408','Disk arrays','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1688','10408','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1689','10408','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1690','10408','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1691','10408','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1692','10408','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1693','10408','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1694','10408','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1695','10408','Virtual disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1696','10409','Disk arrays','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1697','10409','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1698','10409','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1699','10409','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1700','10409','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1701','10409','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1702','10409','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1703','10409','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1704','10409','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1705','10409','Virtual disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1706','10410','Disk arrays','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1707','10410','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1708','10410','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1709','10410','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1710','10410','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1711','10410','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1712','10410','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1713','10410','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1714','10410','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1715','10410','Virtual disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1716','10411','Disk arrays','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1717','10411','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1718','10411','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1719','10411','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1720','10411','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1721','10411','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1722','10411','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1723','10411','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1724','10411','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1725','10411','Virtual disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1726','10412','Disk arrays','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1727','10412','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1728','10412','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1729','10412','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1730','10412','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1731','10412','Physical disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1732','10412','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1733','10412','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1734','10412','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1735','10412','Virtual disks','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1736','10413','Systemd','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1737','10413','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1738','10414','GridGain','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1739','10415','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1740','10415','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1741','10415','Filesystems','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1742','10415','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1743','10415','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1744','10415','Modules','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1745','10415','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1746','10415','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1747','10415','Security','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1748','10415','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1749','10415','TCP/UDP stat','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1750','10415','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1751','10415','Voltage','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1752','10416','General','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1753','10416','Zabbix raw items','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1754','10417','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1755','10417','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1756','10417','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1757','10417','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1758','10418','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1759','10418','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1760','10418','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1761','10418','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1762','10418','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1763','10419','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1764','10419','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1765','10419','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1766','10419','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1767','10419','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1768','10419','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1769','10419','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1770','10420','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1771','10420','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1772','10420','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1773','10420','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1774','10420','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1775','10420','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1776','10420','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1777','10421','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1778','10421','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1779','10421','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1780','10421','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1781','10421','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1782','10421','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1783','10421','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1784','10421','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1785','10422','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1786','10422','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1787','10422','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1788','10422','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1789','10422','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1790','10422','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1791','10422','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1792','10422','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1793','10423','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1794','10423','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1795','10423','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1796','10423','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1797','10423','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1798','10423','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1799','10424','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1800','10424','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1801','10424','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1802','10424','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1803','10425','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1804','10425','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1805','10425','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1806','10425','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1807','10425','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1808','10425','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1809','10425','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1810','10426','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1811','10426','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1812','10426','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1813','10426','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1814','10426','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1815','10426','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1816','10426','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1817','10427','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1818','10427','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1819','10427','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1820','10427','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1821','10427','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1822','10427','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1823','10427','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1824','10428','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1825','10428','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1826','10428','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1827','10428','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1828','10428','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1829','10428','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1830','10428','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1831','10429','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1832','10429','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1833','10429','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1834','10429','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1835','10429','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1836','10429','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1837','10429','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1838','10429','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1839','10430','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1840','10430','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1841','10430','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1842','10430','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1843','10430','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1844','10430','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1845','10430','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1846','10430','Temperature','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1847','10431','CPU','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1848','10431','Fans','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1849','10431','Inventory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1850','10431','Memory','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1851','10431','Network interfaces','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1852','10431','Power supply','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1853','10431','Status','0');
INSERT INTO applications (applicationid,hostid,name,flags) values ('1854','10431','Temperature','0');
INSERT INTO interface (interfaceid,hostid,main,type,useip,ip,dns,port) values ('1','10084','1','1','1','127.0.0.1','','10050');
INSERT INTO valuemaps (valuemapid,name) values ('1','Service state');
INSERT INTO valuemaps (valuemapid,name) values ('2','Host availability');
INSERT INTO valuemaps (valuemapid,name) values ('3','Windows service state');
INSERT INTO valuemaps (valuemapid,name) values ('4','APC Battery Replacement Status');
INSERT INTO valuemaps (valuemapid,name) values ('5','APC Battery Status');
INSERT INTO valuemaps (valuemapid,name) values ('6','HP Insight System Status');
INSERT INTO valuemaps (valuemapid,name) values ('7','Dell Open Manage System Status');
INSERT INTO valuemaps (valuemapid,name) values ('8','SNMP interface status (ifOperStatus)');
INSERT INTO valuemaps (valuemapid,name) values ('9','SNMP device status (hrDeviceStatus)');
INSERT INTO valuemaps (valuemapid,name) values ('10','Zabbix agent ping status');
INSERT INTO valuemaps (valuemapid,name) values ('11','SNMP interface status (ifAdminStatus)');
INSERT INTO valuemaps (valuemapid,name) values ('12','VMware VirtualMachinePowerState');
INSERT INTO valuemaps (valuemapid,name) values ('13','VMware status');
INSERT INTO valuemaps (valuemapid,name) values ('14','Maintenance status');
INSERT INTO valuemaps (valuemapid,name) values ('15','Value cache operating mode');
INSERT INTO valuemaps (valuemapid,name) values ('16','Windows service startup type');
INSERT INTO valuemaps (valuemapid,name) values ('17','HTTP response status code');
INSERT INTO valuemaps (valuemapid,name) values ('18','ENTITY-SENSORS-MIB::EntitySensorStatus');
INSERT INTO valuemaps (valuemapid,name) values ('19','EtherLike-MIB::dot3StatsDuplexStatus');
INSERT INTO valuemaps (valuemapid,name) values ('20','IF-MIB::ifOperStatus');
INSERT INTO valuemaps (valuemapid,name) values ('21','IF-MIB::ifType');
INSERT INTO valuemaps (valuemapid,name) values ('22','zabbix.host.available');
INSERT INTO valuemaps (valuemapid,name) values ('23','TIMETRA-CHASSIS-MIB::TmnxDeviceState');
INSERT INTO valuemaps (valuemapid,name) values ('24','SW-MIB::swSensorStatus');
INSERT INTO valuemaps (valuemapid,name) values ('25','SW-MIB::swOperStatus');
INSERT INTO valuemaps (valuemapid,name) values ('26','FOUNDRY-SN-AGENT-MIB::snChasPwrSupplyOperStatus');
INSERT INTO valuemaps (valuemapid,name) values ('27','FOUNDRY-SN-AGENT-MIB::snChasFanOperStatus');
INSERT INTO valuemaps (valuemapid,name) values ('28','CISCO-ENVMON-MIB::CiscoEnvMonState');
INSERT INTO valuemaps (valuemapid,name) values ('29','F10-S-SERIES-CHASSIS-MIB::extremeFanOperational');
INSERT INTO valuemaps (valuemapid,name) values ('30','F10-S-SERIES-CHASSIS-MIB::chSysFanTrayOperStatus');
INSERT INTO valuemaps (valuemapid,name) values ('31','F10-S-SERIES-CHASSIS-MIB::chSysPowerSupplyOperStatus');
INSERT INTO valuemaps (valuemapid,name) values ('32','MY-SYSTEM-MIB::mySystemFanIsNormal');
INSERT INTO valuemaps (valuemapid,name) values ('33','EQUIPMENT-MIB::swFanStatus');
INSERT INTO valuemaps (valuemapid,name) values ('34','EQUIPMENT-MIB::swPowerStatus');
INSERT INTO valuemaps (valuemapid,name) values ('35','TruthValue');
INSERT INTO valuemaps (valuemapid,name) values ('36','EXTREME-SYSTEM-MIB::extremeFanOperational');
INSERT INTO valuemaps (valuemapid,name) values ('37','EXTREME-SYSTEM-MIB::extremeOverTemperatureAlarm');
INSERT INTO valuemaps (valuemapid,name) values ('38','EXTREME-SYSTEM-MIB::extremePowerSupplyStatus');
INSERT INTO valuemaps (valuemapid,name) values ('39','HH3C-ENTITY-EXT-MIB::hh3cEntityExtErrorStatus');
INSERT INTO valuemaps (valuemapid,name) values ('40','HP-ICF-CHASSIS::hpicfSensorStatus');
INSERT INTO valuemaps (valuemapid,name) values ('41','HUAWEI-ENTITY-EXTENT-MIB::hwEntityFanState');
INSERT INTO valuemaps (valuemapid,name) values ('42','ICS-CHASSIS-MIB::icsChassisFanOperStatus');
INSERT INTO valuemaps (valuemapid,name) values ('43','ICS-CHASSIS-MIB::icsChassisSensorSlotOperStatus');
INSERT INTO valuemaps (valuemapid,name) values ('44','ICS-CHASSIS-MIB::icsChassisPowerSupplyOperStatus');
INSERT INTO valuemaps (valuemapid,name) values ('45','ICS-CHASSIS-MIB::icsChassisTemperatureStatus');
INSERT INTO valuemaps (valuemapid,name) values ('46','JUNIPER-ALARM-MIB::jnxRedAlarmState');
INSERT INTO valuemaps (valuemapid,name) values ('47','JUNIPER-ALARM-MIB::jnxOperatingState');
INSERT INTO valuemaps (valuemapid,name) values ('48','ENTITY-STATE-MIB::EntityOperState');
INSERT INTO valuemaps (valuemapid,name) values ('49','FASTPATH-BOXSERVICES-PRIVATE-MIB::boxServicesPowSupplyItemState');
INSERT INTO valuemaps (valuemapid,name) values ('50','FASTPATH-BOXSERVICES-PRIVATE-MIB::boxServicesFanItemState');
INSERT INTO valuemaps (valuemapid,name) values ('51','FASTPATH-BOXSERVICES-PRIVATE-MIB::boxServicesTempSensorState');
INSERT INTO valuemaps (valuemapid,name) values ('52','QTECH-MIB::sysFanStatus');
INSERT INTO valuemaps (valuemapid,name) values ('53','QTECH-MIB::sysPowerStatus');
INSERT INTO valuemaps (valuemapid,name) values ('54','CPQSINFO-MIB::status');
INSERT INTO valuemaps (valuemapid,name) values ('55','CPQHLTH-MIB::cpqHeTemperatureLocale');
INSERT INTO valuemaps (valuemapid,name) values ('56','CPQIDA-MIB::cpqDaCntlrModel');
INSERT INTO valuemaps (valuemapid,name) values ('57','CPQIDA-MIB::cpqDaPhyDrvStatus');
INSERT INTO valuemaps (valuemapid,name) values ('58','IMM-MIB::systemHealthStat');
INSERT INTO valuemaps (valuemapid,name) values ('59','IDRAC-MIB-SMIv2::ObjectStatusEnum');
INSERT INTO valuemaps (valuemapid,name) values ('60','IDRAC-MIB-SMIv2::StatusProbeEnum');
INSERT INTO valuemaps (valuemapid,name) values ('61','IDRAC-MIB-SMIv2::physicalDiskComponentStatus');
INSERT INTO valuemaps (valuemapid,name) values ('62','IDRAC-MIB-SMIv2::BooleanType');
INSERT INTO valuemaps (valuemapid,name) values ('63','IDRAC-MIB-SMIv2::physicalDiskMediaType');
INSERT INTO valuemaps (valuemapid,name) values ('64','IDRAC-MIB-SMIv2::batteryState');
INSERT INTO valuemaps (valuemapid,name) values ('65','IDRAC-MIB-SMIv2::virtualDiskLayout');
INSERT INTO valuemaps (valuemapid,name) values ('66','IDRAC-MIB-SMIv2::virtualDiskOperationalState');
INSERT INTO valuemaps (valuemapid,name) values ('67','IDRAC-MIB-SMIv2::virtualDiskWritePolicy');
INSERT INTO valuemaps (valuemapid,name) values ('68','IDRAC-MIB-SMIv2::virtualDiskReadPolicy');
INSERT INTO valuemaps (valuemapid,name) values ('69','IDRAC-MIB-SMIv2::virtualDiskState');
INSERT INTO valuemaps (valuemapid,name) values ('70','CPQIDA-MIB::cpqDaPhyDrvSmartStatus');
INSERT INTO valuemaps (valuemapid,name) values ('71','CPQIDA-MIB::cpqDaAccelStatus');
INSERT INTO valuemaps (valuemapid,name) values ('72','CPQIDA-MIB::cpqDaAccelBattery');
INSERT INTO valuemaps (valuemapid,name) values ('73','CPQIDA-MIB::cpqDaPhyDrvMediaType');
INSERT INTO valuemaps (valuemapid,name) values ('74','CPQIDA-MIB::cpqDaLogDrvFaultTol');
INSERT INTO valuemaps (valuemapid,name) values ('75','CPQIDA-MIB::cpqDaLogDrvStatus');
INSERT INTO valuemaps (valuemapid,name) values ('76','PostgreSQL recovery role');
INSERT INTO valuemaps (valuemapid,name) values ('77','PostgreSQL replication status');
INSERT INTO valuemaps (valuemapid,name) values ('78','Linux::Interface protocol types');
INSERT INTO valuemaps (valuemapid,name) values ('79','Win32_NetworkAdapter::AdapterTypeId');
INSERT INTO valuemaps (valuemapid,name) values ('80','CIM_LogicalDevice::Availability');
INSERT INTO valuemaps (valuemapid,name) values ('81','Win32_NetworkAdapter::NetConnectionStatus');
INSERT INTO valuemaps (valuemapid,name) values ('82','RabbitMQ healthcheck');
INSERT INTO valuemaps (valuemapid,name) values ('83','Alarm state');
INSERT INTO valuemaps (valuemapid,name) values ('84','CISCO-UNIFIED-COMPUTING-TC-MIB::CucsEquipmentOperability');
INSERT INTO valuemaps (valuemapid,name) values ('85','CISCO-UNIFIED-COMPUTING-TC-MIB::CucsLsOperState');
INSERT INTO valuemaps (valuemapid,name) values ('86','CISCO-UNIFIED-COMPUTING-TC-MIB::CucsStoragePDriveStatus');
INSERT INTO valuemaps (valuemapid,name) values ('87','CISCO-UNIFIED-COMPUTING-TC-MIB::CucsStorageLunType');
INSERT INTO valuemaps (valuemapid,name) values ('88','CISCO-UNIFIED-COMPUTING-TC-MIB::CucsEquipmentPresence');
INSERT INTO valuemaps (valuemapid,name) values ('89','Redis bgwrite status');
INSERT INTO valuemaps (valuemapid,name) values ('90','Redis flag');
INSERT INTO valuemaps (valuemapid,name) values ('91','Redis repl offset');
INSERT INTO valuemaps (valuemapid,name) values ('92','Redis bgsave time');
INSERT INTO valuemaps (valuemapid,name) values ('93','Docker flag');
INSERT INTO valuemaps (valuemapid,name) values ('94','ES cluster state');
INSERT INTO valuemaps (valuemapid,name) values ('95','Replicas state');
INSERT INTO valuemaps (valuemapid,name) values ('96','Etcd healthcheck');
INSERT INTO valuemaps (valuemapid,name) values ('97','Etcd leader');
INSERT INTO valuemaps (valuemapid,name) values ('98','Application pool state');
INSERT INTO valuemaps (valuemapid,name) values ('99','MSSQL DB state');
INSERT INTO valuemaps (valuemapid,name) values ('100','MSSQL AG Connected state');
INSERT INTO valuemaps (valuemapid,name) values ('101','MSSQL AG Join state');
INSERT INTO valuemaps (valuemapid,name) values ('102','MSSQL AG Operational state');
INSERT INTO valuemaps (valuemapid,name) values ('103','MSSQL AG Recovery health');
INSERT INTO valuemaps (valuemapid,name) values ('104','MSSQL AG Role');
INSERT INTO valuemaps (valuemapid,name) values ('105','MSSQL AG Suspend state');
INSERT INTO valuemaps (valuemapid,name) values ('106','MSSQL AG Synchronization health');
INSERT INTO valuemaps (valuemapid,name) values ('107','MSSQL - Yes / No');
INSERT INTO valuemaps (valuemapid,name) values ('108','MSSQL Mirroring State');
INSERT INTO valuemaps (valuemapid,name) values ('109','MSSQL Mirroring Role');
INSERT INTO valuemaps (valuemapid,name) values ('110','MSSQL Safety level');
INSERT INTO valuemaps (valuemapid,name) values ('111','MSSQL Witness state');
INSERT INTO valuemaps (valuemapid,name) values ('112','Oracle DB open status');
INSERT INTO valuemaps (valuemapid,name) values ('113','Oracle DB role');
INSERT INTO valuemaps (valuemapid,name) values ('114','Oracle instance status');
INSERT INTO valuemaps (valuemapid,name) values ('115','Oracle instance role');
INSERT INTO valuemaps (valuemapid,name) values ('116','Oracle archiver state');
INSERT INTO valuemaps (valuemapid,name) values ('117','Oracle tablespace status');
INSERT INTO valuemaps (valuemapid,name) values ('118','Oracle Archivelog status');
INSERT INTO valuemaps (valuemapid,name) values ('119','Oracle force log status');
INSERT INTO valuemaps (valuemapid,name) values ('120','Oracle log mode');
INSERT INTO valuemaps (valuemapid,name) values ('121','Ceph cluster status');
INSERT INTO valuemaps (valuemapid,name) values ('122','Kafka controller state');
INSERT INTO valuemaps (valuemapid,name) values ('123','ProStar MPPT charge state');
INSERT INTO valuemaps (valuemapid,name) values ('124','ProStar MPPT load state');
INSERT INTO valuemaps (valuemapid,name) values ('125','ProStar PWM charge state');
INSERT INTO valuemaps (valuemapid,name) values ('126','ProStar PWM load state');
INSERT INTO valuemaps (valuemapid,name) values ('127','Morningstar flags');
INSERT INTO valuemaps (valuemapid,name) values ('128','SunSaver MPPT charge state');
INSERT INTO valuemaps (valuemapid,name) values ('129','SunSaver MPPT load state');
INSERT INTO valuemaps (valuemapid,name) values ('130','SureSine load state');
INSERT INTO valuemaps (valuemapid,name) values ('131','TriStar MPPT 600V charge state');
INSERT INTO valuemaps (valuemapid,name) values ('132','TriStar MPPT charge state');
INSERT INTO valuemaps (valuemapid,name) values ('133','TriStar PWM charge state');
INSERT INTO valuemaps (valuemapid,name) values ('134','TriStar PWM load state');
INSERT INTO valuemaps (valuemapid,name) values ('135','TriStar PWM control mode');
INSERT INTO valuemaps (valuemapid,name) values ('136','Exchange database copy role');
INSERT INTO valuemaps (valuemapid,name) values ('137','Exchange database state');
INSERT INTO valuemaps (valuemapid,name) values ('138','FAS3220 Over-temperature');
INSERT INTO valuemaps (valuemapid,name) values ('139','FAS3220 NVRAM battery status');
INSERT INTO valuemaps (valuemapid,name) values ('140','FAS3220 HA cannot takeover cause');
INSERT INTO valuemaps (valuemapid,name) values ('141','FAS3220 HA settings');
INSERT INTO valuemaps (valuemapid,name) values ('142','FAS3220 Port link state');
INSERT INTO valuemaps (valuemapid,name) values ('143','FAS3220 Port health');
INSERT INTO valuemaps (valuemapid,name) values ('144','FAS3220 Port UP by administrator');
INSERT INTO valuemaps (valuemapid,name) values ('145','FAS3220 Port role');
INSERT INTO valuemaps (valuemapid,name) values ('146','FAS3220 Port type');
INSERT INTO valuemaps (valuemapid,name) values ('147','FAS3220 Port speed');
INSERT INTO valuemaps (valuemapid,name) values ('148','CPQHLTH-MIB::cpqHeTemperatureCondition');
INSERT INTO valuemaps (valuemapid,name) values ('149','Huawei storage: Controller role');
INSERT INTO valuemaps (valuemapid,name) values ('150','Huawei storage: Health status');
INSERT INTO valuemaps (valuemapid,name) values ('151','Huawei storage: LUN status');
INSERT INTO valuemaps (valuemapid,name) values ('152','Huawei storage: Running status');
INSERT INTO valuemaps (valuemapid,name) values ('153','MongoDB flag');
INSERT INTO valuemaps (valuemapid,name) values ('154','ReplicaSet node state');
INSERT INTO valuemaps (valuemapid,name) values ('155','PowerNet-MIB::uioSensorStatusAlarmStatus');
INSERT INTO valuemaps (valuemapid,name) values ('156','PowerNet-MIB::upsAdvBatteryReplaceIndicator');
INSERT INTO valuemaps (valuemapid,name) values ('157','PowerNet-MIB::upsAdvInputLineFailCause');
INSERT INTO valuemaps (valuemapid,name) values ('158','PowerNet-MIB::upsBasicBatteryStatus');
INSERT INTO valuemaps (valuemapid,name) values ('159','PowerNet-MIB::upsBasicOutputStatus');
INSERT INTO valuemaps (valuemapid,name) values ('160','WildFly flag');
INSERT INTO valuemaps (valuemapid,name) values ('161','MSSQL Job Run Status');
INSERT INTO valuemaps (valuemapid,name) values ('162','SNMP available');
INSERT INTO valuemaps (valuemapid,name) values ('163','ZYXEL AAM1212-51 / IES-612 module status');
INSERT INTO valuemaps (valuemapid,name) values ('164','ZYXEL AAM1212-51 / IES-612 operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('165','ZYXEL AAM1212-51 / IES-612 operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('166','ZYXEL AAM1212-51 / IES-612 port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('167','ZYXEL AAM1212-51 / IES-612 port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('168','ZYXEL ES3500-8PD operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('169','ZYXEL ES3500-8PD operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('170','ZYXEL ES3500-8PD port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('171','ZYXEL ES3500-8PD port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('172','ZYXEL ES3500-8PD SFP status');
INSERT INTO valuemaps (valuemapid,name) values ('173','ZYXEL GS-4012F operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('174','ZYXEL GS-4012F operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('175','ZYXEL GS-4012F port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('176','ZYXEL GS-4012F port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('177','ZYXEL GS-4012F SFP status');
INSERT INTO valuemaps (valuemapid,name) values ('178','ZYXEL IES-500x module status');
INSERT INTO valuemaps (valuemapid,name) values ('179','ZYXEL IES-500x module type');
INSERT INTO valuemaps (valuemapid,name) values ('180','ZYXEL IES-500x operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('181','ZYXEL IES-500x operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('182','ZYXEL IES-500x port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('183','ZYXEL IES-500x port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('184','ZYXEL IES-6000 module status');
INSERT INTO valuemaps (valuemapid,name) values ('185','ZYXEL IES-6000 module type');
INSERT INTO valuemaps (valuemapid,name) values ('186','ZYXEL IES-6000 operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('187','ZYXEL IES-6000 operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('188','ZYXEL IES-6000 port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('189','ZYXEL IES-6000 port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('190','ZYXEL IES1248-51 module status');
INSERT INTO valuemaps (valuemapid,name) values ('191','ZYXEL IES1248-51 operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('192','ZYXEL IES1248-51 operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('193','ZYXEL IES1248-51 port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('194','ZYXEL IES1248-51 port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('195','ZYXEL MES-3528 operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('196','ZYXEL MES-3528 operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('197','ZYXEL MES-3528 port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('198','ZYXEL MES-3528 port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('199','ZYXEL MES-3528 SFP status');
INSERT INTO valuemaps (valuemapid,name) values ('200','ZYXEL MES3500-10 operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('201','ZYXEL MES3500-10 operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('202','ZYXEL MES3500-10 port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('203','ZYXEL MES3500-10 port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('204','ZYXEL MES3500-10 SFP status');
INSERT INTO valuemaps (valuemapid,name) values ('205','ZYXEL MES3500-24 operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('206','ZYXEL MES3500-24 operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('207','ZYXEL MES3500-24 port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('208','ZYXEL MES3500-24 port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('209','ZYXEL MES3500-24 SFP status');
INSERT INTO valuemaps (valuemapid,name) values ('210','ZYXEL MGS-3712 operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('211','ZYXEL MGS-3712 operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('212','ZYXEL MGS-3712 port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('213','ZYXEL MGS-3712 port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('214','ZYXEL MGS-3712 SFP status');
INSERT INTO valuemaps (valuemapid,name) values ('215','ZYXEL MGS-3712F operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('216','ZYXEL MGS-3712F operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('217','ZYXEL MGS-3712F port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('218','ZYXEL MGS-3712F port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('219','ZYXEL MGS-3712F SFP status');
INSERT INTO valuemaps (valuemapid,name) values ('220','ZYXEL MES3500-24S operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('221','ZYXEL MES3500-24S operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('222','ZYXEL MES3500-24S port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('223','ZYXEL MES3500-24S port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('224','ZYXEL MES3500-24S SFP status');
INSERT INTO valuemaps (valuemapid,name) values ('225','ZYXEL MGS3520-28x operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('226','ZYXEL MGS3520-28x operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('227','ZYXEL MGS3520-28x port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('228','ZYXEL MGS3520-28x port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('229','ZYXEL MGS3520-28x SFP status');
INSERT INTO valuemaps (valuemapid,name) values ('230','ZYXEL XGS-4728F operational mode port speed duplex');
INSERT INTO valuemaps (valuemapid,name) values ('231','ZYXEL XGS-4728F operational mode port link up type');
INSERT INTO valuemaps (valuemapid,name) values ('232','ZYXEL XGS-4728F port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('233','ZYXEL XGS-4728F port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('234','ZYXEL XGS-4728F SFP status');
INSERT INTO valuemaps (valuemapid,name) values ('235','CISCO-UNIFIED-COMPUTING-TC-MIB::CucsStorageTechnology');
INSERT INTO valuemaps (valuemapid,name) values ('236','CPQNIC-MIB::cpqNicIfPhysAdapterStatus');
INSERT INTO valuemaps (valuemapid,name) values ('237','Unit Load State');
INSERT INTO valuemaps (valuemapid,name) values ('238','Unit Active State');
INSERT INTO valuemaps (valuemapid,name) values ('239','Unit File State');
INSERT INTO valuemaps (valuemapid,name) values ('240','Chassis status');
INSERT INTO valuemaps (valuemapid,name) values ('241','Module provision level');
INSERT INTO valuemaps (valuemapid,name) values ('242','Pause state');
INSERT INTO valuemaps (valuemapid,name) values ('243','Server mode');
INSERT INTO valuemaps (valuemapid,name) values ('244','Cisco ASAv algorithm validate packets');
INSERT INTO valuemaps (valuemapid,name) values ('245','Cisco ASAv encryption algorithm');
INSERT INTO valuemaps (valuemapid,name) values ('246','Cisco ASAv port admin status');
INSERT INTO valuemaps (valuemapid,name) values ('247','Cisco ASAv port operational status');
INSERT INTO valuemaps (valuemapid,name) values ('248','Cisco ASAv session protocol');
INSERT INTO valuemaps (valuemapid,name) values ('249','Cisco ASAv user authenticate method');
INSERT INTO valuemaps (valuemapid,name) values ('250','Physical class');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10061','5','','10047','Zabbix server: Number of processed numeric (float) values per second','zabbix[wcache,values,float]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed float values.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10062','5','','10047','Zabbix server: Number of processed character values per second','zabbix[wcache,values,str]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed character/string values.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10063','5','','10047','Zabbix server: Number of processed log values per second','zabbix[wcache,values,log]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed log values.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10064','5','','10047','Zabbix server: Number of processed numeric (unsigned) values per second','zabbix[wcache,values,uint]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed numeric (unsigned) values.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10065','5','','10047','Zabbix server: Number of processed text values per second','zabbix[wcache,values,text]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed text values.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10066','5','','10047','Zabbix server: Number of processed not supported values per second','zabbix[wcache,values,not supported]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of times item processing resulted in item becoming unsupported or keeping that state.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10067','5','','10048','Number of processed numeric (float) values per second','zabbix[wcache,values,float]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10068','5','','10048','Number of processed character values per second','zabbix[wcache,values,str]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10069','5','','10048','Number of processed log values per second','zabbix[wcache,values,log]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10070','5','','10048','Number of processed numeric (unsigned) values per second','zabbix[wcache,values,uint]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10071','5','','10048','Number of processed text values per second','zabbix[wcache,values,text]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10072','5','','10048','Number of processed not supported values per second','zabbix[wcache,values,not supported]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22183','5','','10047','Zabbix server: History write cache, % used','zabbix[wcache,history,pused]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache. Percentage of used history buffer.
History cache is used to store item values. A high number indicates performance problems on the database side.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22185','5','','10047','Zabbix server: Trend write cache, % used','zabbix[wcache,trend,pused]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache. Percentage of used trend buffer.
Trend cache stores aggregate for the current hour for all items that receive data.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22187','5','','10047','Zabbix server: Number of processed values per second','zabbix[wcache,values]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Total number of values processed by Zabbix server or Zabbix proxy, except unsupported items.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22189','5','','10047','Zabbix server: Configuration cache, % used','zabbix[rcache,buffer,pused]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Availability statistics of Zabbix configuration cache. Percentage of used buffer','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22191','5','','10047','Zabbix server: Value cache, % used','zabbix[vcache,buffer,pused]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Availability statistics of Zabbix value cache. Percentage of used buffer','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22196','5','','10047','Zabbix server: Value cache hits','zabbix[vcache,cache,hits]','1m','1w','365d','0','0','','vps','','',NULL,NULL,'','','0','','','','','0',NULL,'Effectiveness statistics of Zabbix value cache. Number of cache hits (history values taken from the cache)','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22199','5','','10047','Zabbix server: Value cache misses','zabbix[vcache,cache,misses]','1m','1w','365d','0','0','','vps','','',NULL,NULL,'','','0','','','','','0',NULL,'Effectiveness statistics of Zabbix value cache. Number of cache misses (history values taken from the database)','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22219','5','','10047','Zabbix server: Queue over 10 minutes','zabbix[queue,10m]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of monitored items in the queue which are delayed at least by 10 minutes','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22231','0','','10050','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22232','0','','10050','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','',NULL,'10','','','0','','','','','0',NULL,'The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22396','5','','10047','Zabbix server: History index cache, % used','zabbix[wcache,index,pused]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache. Percentage of used history index buffer.
History index cache is used to index values stored in history cache.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22399','5','','10047','Zabbix server: Utilization of poller data collector processes, in %','zabbix[process,poller,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time poller processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22400','5','','10047','Zabbix server: Utilization of unreachable poller data collector processes, in %','zabbix[process,unreachable poller,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time unreachable poller processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22401','5','','10047','Zabbix server: Utilization of vmware data collector processes, in %','zabbix[process,vmware collector,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time vmware collector processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22402','5','','10047','Zabbix server: Utilization of http poller data collector processes, in %','zabbix[process,http poller,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time http poller processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22404','5','','10047','Zabbix server: Utilization of trapper data collector processes, in %','zabbix[process,trapper,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time trapper processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22406','5','','10047','Zabbix server: Utilization of history syncer internal processes, in %','zabbix[process,history syncer,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time history syncer processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22408','5','','10047','Zabbix server: Utilization of housekeeper internal processes, in %','zabbix[process,housekeeper,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time housekeeper processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22412','5','','10047','Zabbix server: Utilization of configuration syncer internal processes, in %','zabbix[process,configuration syncer,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time configuration syncer processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22414','5','','10047','Zabbix server: Utilization of self-monitoring internal processes, in %','zabbix[process,self-monitoring,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time self-monitoring processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22416','5','','10047','Zabbix server: Utilization of ipmi poller data collector processes, in %','zabbix[process,ipmi poller,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time ipmi poller processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22418','5','','10047','Zabbix server: Utilization of icmp pinger data collector processes, in %','zabbix[process,icmp pinger,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time icmp pinger processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22420','5','','10047','Zabbix server: Utilization of proxy poller data collector processes, in %','zabbix[process,proxy poller,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time proxy poller processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22422','5','','10047','Zabbix server: Utilization of escalator internal processes, in %','zabbix[process,escalator,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time escalator processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22424','5','','10047','Zabbix server: Utilization of alerter internal processes, in %','zabbix[process,alerter,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time alerter processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22426','5','','10047','Zabbix server: Utilization of timer internal processes, in %','zabbix[process,timer,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time timer processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22430','5','','10047','Zabbix server: Utilization of discoverer data collector processes, in %','zabbix[process,discoverer,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time discoverer processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22689','5','','10047','Zabbix server: Utilization of java poller data collector processes, in %','zabbix[process,java poller,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time java poller processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22835','0','','10074','Maximum number of opened files','kernel.maxfiles','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22836','0','','10074','Maximum number of processes','kernel.maxproc','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22837','0','','10074','Number of running processes','proc.num[,,run]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of processes in running state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22838','0','','10074','Number of processes','proc.num[]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of processes in any state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22839','0','','10074','Host boot time','system.boottime','10m','1w','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22840','0','','10074','Interrupts per second','system.cpu.intr','1m','1w','365d','0','3','','ips','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22841','0','','10074','Processor load (15 min average per core)','system.cpu.load[percpu,avg15]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22842','0','','10074','Processor load (1 min average per core)','system.cpu.load[percpu,avg1]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22843','0','','10074','Processor load (5 min average per core)','system.cpu.load[percpu,avg5]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22844','0','','10074','Context switches per second','system.cpu.switches','1m','1w','365d','0','3','','sps','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22845','0','','10074','CPU idle time','system.cpu.util[,idle]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent doing nothing.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22846','0','','10074','CPU interrupt time','system.cpu.util[,interrupt]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of time the CPU has been servicing hardware interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22848','0','','10074','CPU nice time','system.cpu.util[,nice]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that have been niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22851','0','','10074','CPU system time','system.cpu.util[,system]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running the kernel and its processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22852','0','','10074','CPU user time','system.cpu.util[,user]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that are not niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22853','0','','10074','Host name','system.hostname','1h','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22854','0','','10074','Host local time','system.localtime','1m','1w','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22855','0','','10074','Free swap space','system.swap.size[,free]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22856','0','','10074','Free swap space in %','system.swap.size[,pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22857','0','','10074','Total swap space','system.swap.size[,total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22858','0','','10074','System information','system.uname','1h','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The information as normally returned by ''uname -a''.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22859','0','','10074','System uptime','system.uptime','10m','1w','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22860','0','','10074','Number of logged in users','system.users.num','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of users who are currently logged in.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22861','0','','10074','Checksum of /etc/passwd','vfs.file.cksum[/etc/passwd]','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22862','0','','10074','Available memory','vm.memory.size[available]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Available memory is defined as free+cached+buffers memory.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22863','0','','10074','Total memory','vm.memory.size[total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22867','0','','10074','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types as defined in global regular expression "File systems for discovery".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22868','0','','10074','Free disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},free]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22869','0','','10074','Free inodes on {#FSNAME} (percentage)','vfs.fs.inode[{#FSNAME},pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22870','0','','10074','Total disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22871','0','','10074','Used disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},used]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22872','0','','10074','Free disk space on {#FSNAME} (percentage)','vfs.fs.size[{#FSNAME},pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22875','0','','10075','Maximum number of opened files','kernel.maxfiles','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22876','0','','10075','Maximum number of processes','kernel.maxproc','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22877','0','','10075','Number of running processes','proc.num[,,run]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of processes in running state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22878','0','','10075','Number of processes','proc.num[]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of processes in any state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22879','0','','10075','Host boot time','system.boottime','10m','1w','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22880','0','','10075','Interrupts per second','system.cpu.intr','1m','1w','365d','0','3','','ips','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22881','0','','10075','Processor load (15 min average per core)','system.cpu.load[percpu,avg15]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22882','0','','10075','Processor load (1 min average per core)','system.cpu.load[percpu,avg1]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22883','0','','10075','Processor load (5 min average per core)','system.cpu.load[percpu,avg5]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22884','0','','10075','Context switches per second','system.cpu.switches','1m','1w','365d','0','3','','sps','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22885','0','','10075','CPU idle time','system.cpu.util[,idle]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent doing nothing.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22886','0','','10075','CPU interrupt time','system.cpu.util[,interrupt]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of time the CPU has been servicing hardware interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22888','0','','10075','CPU nice time','system.cpu.util[,nice]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that have been niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22891','0','','10075','CPU system time','system.cpu.util[,system]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running the kernel and its processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22892','0','','10075','CPU user time','system.cpu.util[,user]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that are not niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22893','0','','10075','Host name','system.hostname','1h','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22894','0','','10075','Host local time','system.localtime','1m','1w','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22895','0','','10075','Free swap space','system.swap.size[,free]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22896','0','','10075','Free swap space in %','system.swap.size[,pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22897','0','','10075','Total swap space','system.swap.size[,total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22898','0','','10075','System information','system.uname','1h','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The information as normally returned by ''uname -a''.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22899','0','','10075','System uptime','system.uptime','10m','1w','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22900','0','','10075','Number of logged in users','system.users.num','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of users who are currently logged in.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22901','0','','10075','Checksum of /etc/passwd','vfs.file.cksum[/etc/passwd]','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22902','0','','10075','Available memory','vm.memory.size[available]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Available memory is defined as free+cached+buffers memory.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22903','0','','10075','Total memory','vm.memory.size[total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22907','0','','10075','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types as defined in global regular expression "File systems for discovery".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22908','0','','10075','Free disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},free]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22909','0','','10075','Free inodes on {#FSNAME} (percentage)','vfs.fs.inode[{#FSNAME},pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22910','0','','10075','Total disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22911','0','','10075','Used disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},used]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22912','0','','10075','Free disk space on {#FSNAME} (percentage)','vfs.fs.size[{#FSNAME},pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22917','0','','10076','Number of running processes','proc.num[,,run]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of processes in running state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22918','0','','10076','Number of processes','proc.num[]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of processes in any state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22920','0','','10076','Interrupts per second','system.cpu.intr','1m','1w','365d','0','3','','ips','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22921','0','','10076','Processor load (15 min average per core)','system.cpu.load[percpu,avg15]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22922','0','','10076','Processor load (1 min average per core)','system.cpu.load[percpu,avg1]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22923','0','','10076','Processor load (5 min average per core)','system.cpu.load[percpu,avg5]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22924','0','','10076','Context switches per second','system.cpu.switches','1m','1w','365d','0','3','','sps','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22933','0','','10076','Host name','system.hostname','1h','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22934','0','','10076','Host local time','system.localtime','1m','1w','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22938','0','','10076','System information','system.uname','1h','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The information as normally returned by ''uname -a''.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22939','0','','10076','System uptime','system.uptime','10m','1w','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22940','0','','10076','Number of logged in users','system.users.num','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of users who are currently logged in.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22941','0','','10076','Checksum of /etc/passwd','vfs.file.cksum[/etc/passwd]','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22942','0','','10076','Available memory','vm.memory.size[available]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Available memory is defined as free+cached+buffers memory.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22943','0','','10076','Total memory','vm.memory.size[total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22944','0','','10076','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of network interfaces as defined in global regular expression "Network interfaces for discovery".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22945','0','','10076','Incoming network traffic on {#IFNAME}','net.if.in[{#IFNAME}]','1m','1w','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22946','0','','10076','Outgoing network traffic on {#IFNAME}','net.if.out[{#IFNAME}]','1m','1w','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22947','0','','10076','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types as defined in global regular expression "File systems for discovery".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22948','0','','10076','Free disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},free]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22949','0','','10076','Free inodes on {#FSNAME} (percentage)','vfs.fs.inode[{#FSNAME},pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22950','0','','10076','Total disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22951','0','','10076','Used disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},used]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22952','0','','10076','Free disk space on {#FSNAME} (percentage)','vfs.fs.size[{#FSNAME},pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22961','0','','10077','Processor load (15 min average per core)','system.cpu.load[percpu,avg15]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22962','0','','10077','Processor load (1 min average per core)','system.cpu.load[percpu,avg1]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22963','0','','10077','Processor load (5 min average per core)','system.cpu.load[percpu,avg5]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22965','0','','10077','CPU idle time','system.cpu.util[,idle]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent doing nothing.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22968','0','','10077','CPU nice time','system.cpu.util[,nice]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that have been niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22971','0','','10077','CPU system time','system.cpu.util[,system]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running the kernel and its processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22972','0','','10077','CPU user time','system.cpu.util[,user]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that are not niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22973','0','','10077','Host name','system.hostname','1h','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22974','0','','10077','Host local time','system.localtime','1m','1w','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22978','0','','10077','System information','system.uname','1h','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The information as normally returned by ''uname -a''.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22980','0','','10077','Number of logged in users','system.users.num','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of users who are currently logged in.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22981','0','','10077','Checksum of /etc/passwd','vfs.file.cksum[/etc/passwd]','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22982','0','','10077','Available memory','vm.memory.size[available]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Available memory is defined as free+cached+buffers memory.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22983','0','','10077','Total memory','vm.memory.size[total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22984','0','','10077','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of network interfaces as defined in global regular expression "Network interfaces for discovery".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22985','0','','10077','Incoming network traffic on {#IFNAME}','net.if.in[{#IFNAME}]','1m','1w','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22986','0','','10077','Outgoing network traffic on {#IFNAME}','net.if.out[{#IFNAME}]','1m','1w','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22987','0','','10077','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types as defined in global regular expression "File systems for discovery".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22988','0','','10077','Free disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},free]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22989','0','','10077','Free inodes on {#FSNAME} (percentage)','vfs.fs.inode[{#FSNAME},pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22990','0','','10077','Total disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22991','0','','10077','Used disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},used]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22992','0','','10077','Free disk space on {#FSNAME} (percentage)','vfs.fs.size[{#FSNAME},pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22996','0','','10078','Maximum number of processes','kernel.maxproc','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22997','0','','10078','Number of running processes','proc.num[,,run]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of processes in running state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22998','0','','10078','Number of processes','proc.num[]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of processes in any state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22999','0','','10078','Host boot time','system.boottime','10m','1w','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23000','0','','10078','Interrupts per second','system.cpu.intr','1m','1w','365d','0','3','','ips','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23001','0','','10078','Processor load (15 min average per core)','system.cpu.load[percpu,avg15]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23002','0','','10078','Processor load (1 min average per core)','system.cpu.load[percpu,avg1]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23003','0','','10078','Processor load (5 min average per core)','system.cpu.load[percpu,avg5]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23004','0','','10078','Context switches per second','system.cpu.switches','1m','1w','365d','0','3','','sps','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23005','0','','10078','CPU idle time','system.cpu.util[,idle]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent doing nothing.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23007','0','','10078','CPU iowait time','system.cpu.util[,iowait]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Amount of time the CPU has been waiting for I/O to complete.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23011','0','','10078','CPU system time','system.cpu.util[,system]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running the kernel and its processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23012','0','','10078','CPU user time','system.cpu.util[,user]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that are not niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23013','0','','10078','Host name','system.hostname','1h','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23014','0','','10078','Host local time','system.localtime','1m','1w','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23015','0','','10078','Free swap space','system.swap.size[,free]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23016','0','','10078','Free swap space in %','system.swap.size[,pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23017','0','','10078','Total swap space','system.swap.size[,total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23018','0','','10078','System information','system.uname','1h','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The information as normally returned by ''uname -a''.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23019','0','','10078','System uptime','system.uptime','10m','1w','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23020','0','','10078','Number of logged in users','system.users.num','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of users who are currently logged in.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23021','0','','10078','Checksum of /etc/passwd','vfs.file.cksum[/etc/passwd]','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23022','0','','10078','Available memory','vm.memory.size[available]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Available memory is defined as free+cached+buffers memory.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23023','0','','10078','Total memory','vm.memory.size[total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23024','0','','10078','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of network interfaces as defined in global regular expression "Network interfaces for discovery".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23025','0','','10078','Incoming network traffic on {#IFNAME}','net.if.in[{#IFNAME}]','1m','1w','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23026','0','','10078','Outgoing network traffic on {#IFNAME}','net.if.out[{#IFNAME}]','1m','1w','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23027','0','','10078','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types as defined in global regular expression "File systems for discovery".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23028','0','','10078','Free disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},free]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23029','0','','10078','Free inodes on {#FSNAME} (percentage)','vfs.fs.inode[{#FSNAME},pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23030','0','','10078','Total disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23031','0','','10078','Used disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},used]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23032','0','','10078','Free disk space on {#FSNAME} (percentage)','vfs.fs.size[{#FSNAME},pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23035','0','','10079','Maximum number of opened files','kernel.maxfiles','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23036','0','','10079','Maximum number of processes','kernel.maxproc','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23039','0','','10079','Host boot time','system.boottime','10m','1w','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23041','0','','10079','Processor load (15 min average per core)','system.cpu.load[percpu,avg15]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23042','0','','10079','Processor load (1 min average per core)','system.cpu.load[percpu,avg1]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23043','0','','10079','Processor load (5 min average per core)','system.cpu.load[percpu,avg5]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The processor load is calculated as system CPU load divided by number of CPU cores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23053','0','','10079','Host name','system.hostname','1h','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23054','0','','10079','Host local time','system.localtime','1m','1w','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23058','0','','10079','System information','system.uname','1h','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The information as normally returned by ''uname -a''.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23059','0','','10079','System uptime','system.uptime','10m','1w','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23060','0','','10079','Number of logged in users','system.users.num','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of users who are currently logged in.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23061','0','','10079','Checksum of /etc/passwd','vfs.file.cksum[/etc/passwd]','1h','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23062','0','','10079','Available memory','vm.memory.size[available]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Available memory is defined as free+cached+buffers memory.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23063','0','','10079','Total memory','vm.memory.size[total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23067','0','','10079','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types as defined in global regular expression "File systems for discovery".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23068','0','','10079','Free disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},free]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23069','0','','10079','Free inodes on {#FSNAME} (percentage)','vfs.fs.inode[{#FSNAME},pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23070','0','','10079','Total disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},total]','1h','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23071','0','','10079','Used disk space on {#FSNAME}','vfs.fs.size[{#FSNAME},used]','1m','1w','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23072','0','','10079','Free disk space on {#FSNAME} (percentage)','vfs.fs.size[{#FSNAME},pfree]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23073','0','','10075','Incoming network traffic on {#IFNAME}','net.if.in[{#IFNAME}]','1m','1w','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23074','0','','10075','Outgoing network traffic on {#IFNAME}','net.if.out[{#IFNAME}]','1m','1w','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23075','0','','10074','Incoming network traffic on {#IFNAME}','net.if.in[{#IFNAME}]','1m','1w','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23076','0','','10074','Outgoing network traffic on {#IFNAME}','net.if.out[{#IFNAME}]','1m','1w','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23077','0','','10079','Incoming network traffic on en0','net.if.in[en0]','1m','1w','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23078','0','','10079','Outgoing network traffic on en0','net.if.out[en0]','1m','1w','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23108','0','','10076','CPU available physical processors in the shared pool','system.stat[cpu,app]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23109','0','','10076','CPU entitled capacity consumed','system.stat[cpu,ec]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23110','0','','10076','CPU idle time','system.stat[cpu,id]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23111','0','','10076','CPU logical processor utilization','system.stat[cpu,lbusy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23112','0','','10076','CPU number of physical processors consumed','system.stat[cpu,pc]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23113','0','','10076','CPU system time','system.stat[cpu,sy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23114','0','','10076','CPU user time','system.stat[cpu,us]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23115','0','','10076','CPU iowait time','system.stat[cpu,wa]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23116','0','','10076','Amount of data transferred','system.stat[disk,bps]','1m','1w','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23117','0','','10076','Number of transfers','system.stat[disk,tps]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23118','0','','10076','Processor units is entitled to receive','system.stat[ent]','1h','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23119','0','','10076','Kernel thread context switches','system.stat[faults,cs]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23120','0','','10076','Device interrupts','system.stat[faults,in]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23121','0','','10076','System calls','system.stat[faults,sy]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23122','0','','10076','Length of the swap queue','system.stat[kthr,b]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23123','0','','10076','Length of the run queue','system.stat[kthr,r]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23124','0','','10076','Active virtual pages','system.stat[memory,avm]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23125','0','','10076','Free real memory','system.stat[memory,fre]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23126','0','','10076','File page-ins per second','system.stat[page,fi]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23127','0','','10076','File page-outs per second','system.stat[page,fo]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23128','0','','10076','Pages freed (page replacement)','system.stat[page,fr]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23129','0','','10076','Pages paged in from paging space','system.stat[page,pi]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23130','0','','10076','Pages paged out to paging space','system.stat[page,po]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23131','0','','10076','Pages scanned by page-replacement algorithm','system.stat[page,sr]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23171','5','','10047','Zabbix server: Utilization of snmp trapper data collector processes, in %','zabbix[process,snmp trapper,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time snmp trapper processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23251','5','','10047','Zabbix server: Queue','zabbix[queue]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of monitored items in the queue which are delayed at least by 6 seconds','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23318','0','','10050','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23329','0','','10074','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of network interfaces as defined in global regular expression "Network interfaces for discovery".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23340','5','','10048','Number of processed values per second','zabbix[wcache,values]','1m','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23341','5','','10048','Zabbix history index cache, % used','zabbix[wcache,index,pused]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23342','5','','10048','Zabbix history write cache, % used','zabbix[wcache,history,pused]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23343','5','','10048','Utilization of self-monitoring internal processes, in %','zabbix[process,self-monitoring,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23344','5','','10048','Utilization of snmp trapper data collector processes, in %','zabbix[process,snmp trapper,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23345','5','','10048','Utilization of trapper data collector processes, in %','zabbix[process,trapper,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23346','5','','10048','Utilization of unreachable poller data collector processes, in %','zabbix[process,unreachable poller,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23347','5','','10048','Utilization of configuration syncer internal processes, in %','zabbix[process,configuration syncer,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23348','5','','10048','Utilization of poller data collector processes, in %','zabbix[process,poller,avg,busy]','1m','1w','365d','0','0','localhost','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23349','5','','10048','Utilization of java poller data collector processes, in %','zabbix[process,java poller,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23350','5','','10048','Utilization of history syncer internal processes, in %','zabbix[process,history syncer,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23351','5','','10048','Utilization of heartbeat sender internal processes, in %','zabbix[process,heartbeat sender,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23352','5','','10048','Utilization of discoverer data collector processes, in %','zabbix[process,discoverer,avg,busy]','1m','1w','365d','0','0','localhost','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23353','5','','10048','Utilization of housekeeper internal processes, in %','zabbix[process,housekeeper,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23354','5','','10048','Utilization of http poller data collector processes, in %','zabbix[process,http poller,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23355','5','','10048','Utilization of ipmi poller data collector processes, in %','zabbix[process,ipmi poller,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23356','5','','10048','Utilization of icmp pinger data collector processes, in %','zabbix[process,icmp pinger,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23357','5','','10048','Zabbix configuration cache, % used','zabbix[rcache,buffer,pused]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23358','5','','10048','Zabbix queue','zabbix[queue]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23359','5','','10048','Zabbix queue over 10 minutes','zabbix[queue,10m]','10m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23360','5','','10048','Utilization of data sender internal processes, in %','zabbix[process,data sender,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23540','0','','10075','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of network interfaces as defined in global regular expression "Network interfaces for discovery".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23634','5','','10047','Zabbix server: VMware cache, % used','zabbix[vmware,buffer,pused]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Availability statistics of Zabbix vmware cache. Percentage of used buffer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23644','3','','10093','FTP service is running','net.tcp.service[ftp]','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23645','3','','10094','HTTP service is running','net.tcp.service[http]','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23646','3','','10095','HTTPS service is running','net.tcp.service[https]','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23647','3','','10096','IMAP service is running','net.tcp.service[imap]','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23648','3','','10097','LDAP service is running','net.tcp.service[ldap]','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23649','3','','10098','NNTP service is running','net.tcp.service[nntp]','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23650','3','','10099','NTP service is running','net.udp.service[ntp]','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23651','3','','10100','POP service is running','net.tcp.service[pop]','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23652','3','','10101','SMTP service is running','net.tcp.service[smtp]','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23653','3','','10102','SSH service is running','net.tcp.service[ssh]','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23654','3','','10103','Telnet service is running','net.tcp.service[telnet]','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23661','5','','10047','Zabbix server: Value cache operating mode','zabbix[vcache,cache,mode]','1m','1w','365d','0','3','','','','',NULL,'15','','','0','','','','','0',NULL,'Value cache operating mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23663','5','','10047','Zabbix server: Utilization of task manager internal processes, in %','zabbix[process,task manager,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time task manager processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('25366','5','','10047','Zabbix server: Utilization of ipmi manager internal processes, in %','zabbix[process,ipmi manager,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time ipmi manager processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('25368','5','','10048','Utilization of ipmi manager internal processes, in %','zabbix[process,ipmi manager,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('25369','5','','10048','Utilization of task manager internal processes, in %','zabbix[process,task manager,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('25370','5','','10047','Zabbix server: Utilization of alert manager internal processes, in %','zabbix[process,alert manager,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time alert manager processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('25665','5','','10047','Zabbix server: Utilization of preprocessing manager internal processes, in %','zabbix[process,preprocessing manager,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time preprocessing manager processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('25666','5','','10047','Zabbix server: Utilization of preprocessing worker internal processes, in %','zabbix[process,preprocessing worker,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time preprocessing worker processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26925','12','','10171','Power','power','1m','1w','365d','0','3','','','','',NULL,NULL,'','power','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26926','12','','10171','Processor Vcc','processor_vcc','1m','1w','365d','0','0','','V','','',NULL,NULL,'','Processor Vcc','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26927','12','','10171','System Fan 3','system_fan_3','1m','1w','365d','0','0','','RPM','','',NULL,NULL,'','System Fan 3','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26928','12','','10171','BB Ambient Temp','bb_ambient_temp','1m','1w','365d','0','0','','C','','',NULL,NULL,'','BB Ambient Temp','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26929','12','','10171','BB +5.0V','bb_5.0v','1m','1w','365d','0','0','','V','','',NULL,NULL,'','BB +5.0V','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26930','12','','10171','BB +3.3V','bb_3.3v','1m','1w','365d','0','0','','V','','',NULL,NULL,'','BB +3.3V','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26931','12','','10171','BB +3.3V STBY','bb_3.3v_stby','1m','1w','365d','0','0','','V','','',NULL,NULL,'','BB +3.3V STBY','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26932','12','','10171','BB +1.8V SM','bb_1.8v_sm','1m','1w','365d','0','0','','V','','',NULL,NULL,'','BB +1.8V SM','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26933','12','','10172','Front Panel Temp','front_panel_temp','1m','1w','365d','0','0','','C','','',NULL,NULL,'','Front Panel Temp','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26934','12','','10172','Power','power','1m','1w','365d','0','3','','','','',NULL,NULL,'','power','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26935','12','','10172','System Fan 2','system_fan_2','1m','1w','365d','0','0','','RPM','','',NULL,NULL,'','System Fan 2','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26936','12','','10172','System Fan 3','system_fan_3','1m','1w','365d','0','0','','RPM','','',NULL,NULL,'','System Fan 3','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26937','12','','10172','BB +5.0V','bb_5.0v','1m','1w','365d','0','0','','V','','',NULL,NULL,'','BB +5.0V','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26938','12','','10172','BB +3.3V STBY','bb_3.3v_stby','1m','1w','365d','0','0','','V','','',NULL,NULL,'','BB +3.3V STBY','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26939','12','','10172','BB +1.05V PCH','bb_1.05v_pch','1m','1w','365d','0','0','','V','','',NULL,NULL,'','BB +1.05V PCH','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26940','12','','10172','BB +1.1V P1 Vccp','bb_1.1v_p1_vccp','1m','1w','365d','0','0','','V','','',NULL,NULL,'','BB +1.1V P1 Vccp','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26941','12','','10172','BB +1.5V P1 DDR3','bb_1.5v_p1_ddr3','1m','1w','365d','0','0','','V','','',NULL,NULL,'','BB +1.5V P1 DDR3','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26942','12','','10172','BB +3.3V','bb_3.3v','1m','1w','365d','0','0','','V','','',NULL,NULL,'','BB +3.3V','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('26943','12','','10172','Baseboard Temp','baseboard_temp','1m','1w','365d','0','0','','C','','',NULL,NULL,'','Baseboard Temp','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27031','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10183','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27032','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10183','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27065','3','','10186','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27066','3','','10186','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27067','3','','10186','ICMP ping','icmpping','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27078','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFNAME},1.3.6.1.2.1.2.2.1.2,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10188','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27079','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10188','Interface {#IFDESCR}: Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27080','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10188','Interface {#IFDESCR}: Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','',NULL,'21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27081','20','1.3.6.1.2.1.2.2.1.5.{#SNMPINDEX}','10188','Interface {#IFDESCR}: Speed','net.if.speed[ifSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second.
For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made,
this object should contain the nominal bandwidth.
If the bandwidth of the interface is greater than the maximum value reportable by this object then
this object should report its maximum value (4,294,967,295) and ifHighSpeed must be used to report the interace''s speed.
For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27082','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10188','Interface {#IFDESCR}: Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27083','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10188','Interface {#IFDESCR}: Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27084','20','1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10188','Interface {#IFDESCR}: Bits received','net.if.in[ifInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,including framing characters. Discontinuities in the value of this counter can occurat re-initialization of the management system, and atother times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27085','20','1.3.6.1.2.1.2.2.1.16.{#SNMPINDEX}','10188','Interface {#IFDESCR}: Bits sent','net.if.out[ifOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. Discontinuities in the value of this counter can occurat re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27086','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10188','Interface {#IFDESCR}: Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27087','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10188','Interface {#IFDESCR}: Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27098','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10190','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27099','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10190','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27100','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10190','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','',NULL,'21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27101','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10190','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27102','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10190','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27103','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10190','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27104','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10190','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27105','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10190','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27106','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10190','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27107','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10190','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27118','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10192','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27119','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10192','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27120','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10192','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','',NULL,'21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27121','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10192','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27122','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10192','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27123','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10192','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27124','20','1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10192','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,including framing characters. Discontinuities in the value of this counter can occur at re-initialization of the management system, and atother times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27125','20','1.3.6.1.2.1.2.2.1.16.{#SNMPINDEX}','10192','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27126','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10192','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27127','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10192','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27152','20','1.3.6.1.2.1.1.5.0','10204','System name','system.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27154','5','','10204','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27157','17','','10204','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27203','20','1.3.6.1.2.1.1.1.0','10207','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27207','20','1.3.6.1.4.1.6527.3.1.2.1.1.9.0','10207','Used memory','vm.memory.used[sgiKbMemoryUsed.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TIMETRA-SYSTEM-MIB
The value of sgiKbMemoryUsed indicates the total pre-allocated pool memory, in kilobytes, currently in use on the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27208','20','1.3.6.1.4.1.6527.3.1.2.1.1.1.0','10207','CPU utilization','system.cpu.util[sgiCpuUsage.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TIMETRA-SYSTEM-MIB
The value of sgiCpuUsage indicates the current CPU utilization for the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27209','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.6527.3.1.2.2.1.8.1.8,{#TEMP_SENSOR},1.3.6.1.4.1.6527.3.1.2.2.1.8.1.17]','10207','Temperature Discovery','temperature.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27210','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.6527.3.1.2.2.1.4.1.2]','10207','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27211','20','discovery[{#ENT_NAME},1.3.6.1.4.1.6527.3.1.2.2.1.8.1.8,{#ENT_CLASS},1.3.6.1.4.1.6527.3.1.2.2.1.8.1.7,{#ENT_SN},1.3.6.1.4.1.6527.3.1.2.2.1.8.1.5]','10207','Entity Serial Numbers Discovery','entity_sn.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27212','20','1.3.6.1.4.1.6527.3.1.2.2.1.8.1.18.{#SNMPINDEX}','10207','{#SNMPVALUE}: Temperature','sensor.temp.value[tmnxHwTemperature.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TIMETRA-SYSTEM-MIB
The current temperature reading in degrees celsius from this hardware component''s temperature sensor.  If this component does not contain a temperature sensor, then the value -1 is returned.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27213','20','1.3.6.1.4.1.6527.3.1.2.2.1.4.1.2.{#SNMPINDEX}','10207','#{#SNMPINDEX}: Fan status','sensor.fan.status[tmnxChassisFanOperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'23','','','0','','','','','2',NULL,'MIB: TIMETRA-SYSTEM-MIB
Current status of the Fan tray.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27214','20','1.3.6.1.4.1.6527.3.1.2.2.1.8.1.5.{#SNMPINDEX}','10207','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[tmnxHwSerialNumber.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TIMETRA-CHASSIS-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27236','20','1.3.6.1.4.1.1588.2.1.1.1.1.6.0','10208','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SW-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27237','20','1.3.6.1.4.1.1588.2.1.1.1.1.10.0','10208','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SW-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27238','20','1.3.6.1.4.1.1588.2.1.1.1.1.7.0','10208','Overall system health status','system.status[swOperStatus.0]','30s','2w','0d','0','3','','','','',NULL,'25','','','0','','','','','0',NULL,'MIB: SW-MIB
The current operational status of the switch.The states are as follow:
online(1) means the switch is accessible by an external Fibre Channel port
offline(2) means the switch is not accessible
testing(3) means the switch is in a built-in test mode and is not accessible by an external Fibre Channel port
faulty(4) means the switch is not operational.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27240','20','1.3.6.1.4.1.1588.2.1.1.1.26.1.0','10208','CPU utilization','system.cpu.util[swCpuUsage.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SW-MIB
System''s CPU usage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27242','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.1588.2.1.1.1.1.22.1.1,{#SENSOR_TYPE},1.3.6.1.4.1.1588.2.1.1.1.1.22.1.2,{#SENSOR_INFO},1.3.6.1.4.1.1588.2.1.1.1.1.22.1.5]','10208','Temperature Discovery','temperature.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27243','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.1588.2.1.1.1.1.22.1.1,{#SENSOR_TYPE},1.3.6.1.4.1.1588.2.1.1.1.1.22.1.2,{#SENSOR_INFO},1.3.6.1.4.1.1588.2.1.1.1.1.22.1.5]','10208','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27244','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.1588.2.1.1.1.1.22.1.1,{#SENSOR_TYPE},1.3.6.1.4.1.1588.2.1.1.1.1.22.1.2,{#SENSOR_INFO},1.3.6.1.4.1.1588.2.1.1.1.1.22.1.5]','10208','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27246','20','1.3.6.1.4.1.1588.2.1.1.1.1.22.1.3.{#SNMPINDEX}','10208','{#SENSOR_INFO}: Temperature status','sensor.temp.status[swSensorStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'24','','','0','','','','','2',NULL,'MIB: SW-MIB
Temperature status of testpoint: {#SENSOR_INFO}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27247','20','1.3.6.1.4.1.1588.2.1.1.1.1.22.1.4.{#SNMPINDEX}','10208','{#SENSOR_INFO}: Temperature','sensor.temp.value[swSensorValue.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: SW-MIB
Temperature readings of testpoint: {#SENSOR_INFO}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27248','20','1.3.6.1.4.1.1588.2.1.1.1.1.22.1.3.{#SNMPINDEX}','10208','{#SENSOR_INFO}: Power supply status','sensor.psu.status[swSensorStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'24','','','0','','','','','2',NULL,'MIB: SW-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27249','20','1.3.6.1.4.1.1588.2.1.1.1.1.22.1.4.{#SNMPINDEX}','10208','{#SENSOR_INFO}: Fan speed','sensor.fan.speed[swSensorValue.{#SNMPINDEX}]','1m','90d','365d','0','3','','rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: SW-MIB
The current value (reading) of the sensor.
The value, -2147483648, represents an unknown quantity.
The fan value will be in RPM(revolution per minute)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27250','20','1.3.6.1.4.1.1588.2.1.1.1.1.22.1.3.{#SNMPINDEX}','10208','{#SENSOR_INFO}: Fan status','sensor.fan.status[swSensorStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'24','','','0','','','','','2',NULL,'MIB: SW-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27294','20','1.3.6.1.4.1.1991.1.1.2.1.52.0','10209','CPU utilization','system.cpu.util[snAgGblCpuUtil1MinAvg.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FOUNDRY-SN-AGENT-MIB
The statistics collection of 1 minute CPU utilization.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27295','20','1.3.6.1.4.1.1991.1.1.2.1.11.0','10210','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FOUNDRY-SN-AGENT-MIB
The version of the running software in the form''major.minor.maintenance[letters]''','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27296','20','1.3.6.1.4.1.1991.1.1.1.1.2.0','10210','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FOUNDRY-SN-AGENT-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27297','20','1.3.6.1.4.1.1991.1.1.2.1.11.0','10211','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FOUNDRY-SN-AGENT-MIB
The version of the running software in the form ''major.minor.maintenance[letters]''','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27302','20','discovery[{#PSU_INDEX},1.3.6.1.4.1.1991.1.1.1.2.1.1.1]','10210','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'snChasPwrSupplyTable: A table of each power supply information. Only installed power supply appears in a table row.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27303','20','discovery[{#FAN_INDEX},1.3.6.1.4.1.1991.1.1.1.3.1.1.1]','10210','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'snChasFanTable: A table of each fan information. Only installed fan appears in a table row.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27304','20','discovery[{#SENSOR_DESCR},1.3.6.1.4.1.1991.1.1.2.13.1.1.3]','10210','Temperature Discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'snAgentTempTable:Table to list temperatures of the modules in the device. This table is applicable to only those modules with temperature sensors.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27306','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.1991.1.1.1.1.18]','10210','Temperature Discovery Chassis','temp.chassis.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Since temperature of the chassis is not available on all Brocade/Foundry hardware, this LLD is here to avoid unsupported items.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27307','20','discovery[{#PSU_UNIT},1.3.6.1.4.1.1991.1.1.1.2.2.1.1,{#PSU_INDEX},1.3.6.1.4.1.1991.1.1.1.2.2.1.2]','10211','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'snChasPwrSupply2Table: A table of each power supply information for each unit. Only installed power supply appears in a table row.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27308','20','discovery[{#FAN_UNIT},1.3.6.1.4.1.1991.1.1.1.3.2.1.1,{#FAN_INDEX},1.3.6.1.4.1.1991.1.1.1.3.2.1.2]','10211','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'snChasFan2Table: A table of each fan information for each unit. Only installed fan appears in a table row.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27309','20','discovery[{#SENSOR_DESCR},1.3.6.1.4.1.1991.1.1.2.13.3.1.4]','10211','Temperature Discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'snAgentTemp2Table:Table to list temperatures of the modules in the device for each unit. This table is applicable to only those modules with temperature sensors.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27310','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.1991.1.1.3.31.2.1.1.5]','10211','Stack Discovery','stack.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering snStackingConfigUnitTable for Model names','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27311','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.1991.1.1.1.4.1.1.1]','10211','Chassis Discovery','chassis.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'snChasUnitIndex: The index to chassis table.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27312','20','1.3.6.1.4.1.1991.1.1.1.2.1.1.3.{#SNMPINDEX}','10210','PSU {#PSU_INDEX}: Power supply status','sensor.psu.status[snChasPwrSupplyOperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'26','','','0','','','','','2',NULL,'MIB: FOUNDRY-SN-AGENT-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27313','20','1.3.6.1.4.1.1991.1.1.1.3.1.1.3.{#SNMPINDEX}','10210','Fan {#FAN_INDEX}: Fan status','sensor.fan.status[snChasFanOperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'27','','','0','','','','','2',NULL,'MIB: FOUNDRY-SN-AGENT-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27314','20','1.3.6.1.4.1.1991.1.1.2.13.1.1.4.{#SNMPINDEX}','10210','{#SENSOR_DESCR}: Temperature','sensor.temp.value[snAgentTempValue.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: FOUNDRY-SN-AGENT-MIB
Temperature of the sensor represented by this row. Each unit is 0.5 degrees Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27315','20','1.3.6.1.4.1.1991.1.1.1.1.18.{#SNMPINDEX}','10210','Chassis #{#SNMPINDEX}: Temperature','sensor.temp.value[snChasActualTemperature.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: FOUNDRY-SN-AGENT-MIB
Temperature of the chassis. Each unit is 0.5 degrees Celsius.
Only management module built with temperature sensor hardware is applicable.
For those non-applicable management module, it returns no-such-name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27316','20','1.3.6.1.4.1.1991.1.1.1.2.2.1.4.{#SNMPINDEX}','10211','Unit {#PSU_UNIT} PSU {#PSU_INDEX}: Power supply status','sensor.psu.status[snChasPwrSupply2OperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'26','','','0','','','','','2',NULL,'MIB: FOUNDRY-SN-AGENT-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27317','20','1.3.6.1.4.1.1991.1.1.1.3.2.1.4.{#SNMPINDEX}','10211','Unit {#FAN_UNIT} Fan {#FAN_INDEX}: Fan status','sensor.fan.status[snChasFan2OperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'27','','','0','','','','','2',NULL,'MIB: FOUNDRY-SN-AGENT-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27318','20','1.3.6.1.4.1.1991.1.1.2.13.3.1.5.{#SNMPINDEX}','10211','{#SENSOR_DESCR}: Temperature','sensor.temp.value[snAgentTemp2Value.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: FOUNDRY-SN-AGENT-MIB
Temperature of the sensor represented by this row. Each unit is 0.5 degrees Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27319','20','1.3.6.1.4.1.1991.1.1.3.31.2.1.1.5.{#SNMPINDEX}','10211','Unit {#SNMPINDEX}: Hardware model name','system.hw.model[snStackingConfigUnitType.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: FOUNDRY-SN-STACKING-MIB
A description of the configured/active system type for each unit.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27320','20','1.3.6.1.4.1.1991.1.1.1.4.1.1.2.{#SNMPINDEX}','10211','Unit {#SNMPVALUE}: Hardware serial number','system.hw.serialnumber[snChasUnitSerNum.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: FOUNDRY-SN-AGENT-MIB
The serial number of the chassis for each unit. If the serial number is unknown or unavailable then the value should be a zero length string.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27376','20','1.3.6.1.4.1.9.2.1.58','10215','CPU utilization','system.cpu.util[avgBusy5]','5m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: OLD-CISCO-CPU-MIB
5 minute exponentially-decayed moving average of the CPU busy percentage.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15215-collect-cpu-util-snmp.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27378','20','1.3.6.1.2.1.47.1.1.1.1.11.1','10216','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27379','20','1.3.6.1.2.1.47.1.1.1.1.13.1','10216','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27390','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.48.1.1.1.2]','10212','Memory Discovery','memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoMemoryPoolTable, a table of memory pool monitoring entries.
http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27391','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.109.1.1.1.1.5]','10213','CPU Discovery','cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If your IOS device has several CPUs, you must use CISCO-PROCESS-MIB and its object cpmCPUTotal5minRev from the table called cpmCPUTotalTable ,
indexed with cpmCPUTotalIndex .
This table allows CISCO-PROCESS-MIB to keep CPU statistics for different physical entities in the router,
like different CPU chips, group of CPUs, or CPUs in different modules/cards.
In case of a single CPU, cpmCPUTotalTable has only one entry.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27393','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7,{#ENT_SN},1.3.6.1.2.1.47.1.1.1.1.11]','10216','Entity Serial Numbers Discovery','entity_sn.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27394','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.3.1.2]','10217','Temperature Discovery','temperature.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoEnvMonTemperatureTable (ciscoEnvMonTemperatureDescr), a table of ambient temperature status
maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27395','20','discovery[{#SENSOR_INFO},1.3.6.1.4.1.9.9.13.1.5.1.2]','10217','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table of power supply status maintained by the environmental monitor card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27396','20','discovery[{#SENSOR_INFO},1.3.6.1.4.1.9.9.13.1.4.1.2]','10217','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table of fan status maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27415','20','1.3.6.1.4.1.9.9.48.1.1.1.6.{#SNMPINDEX}','10212','{#SNMPVALUE}: Free memory','vm.memory.free[ciscoMemoryPoolFree.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Indicates the number of bytes from the memory pool that are currently unused on the managed device. Note that the sum of ciscoMemoryPoolUsed and ciscoMemoryPoolFree is the total amount of memory in the pool
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27416','20','1.3.6.1.4.1.9.9.48.1.1.1.5.{#SNMPINDEX}','10212','{#SNMPVALUE}: Used memory','vm.memory.used[ciscoMemoryPoolUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Indicates the number of bytes from the memory pool that are currently in use by applications on the managed device.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27417','20','1.3.6.1.4.1.9.9.109.1.1.1.1.8.{#SNMPINDEX}','10213','#{#SNMPINDEX}: CPU utilization','system.cpu.util[cpmCPUTotal5minRev.{#SNMPINDEX}]','5m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-PROCESS-MIB
The cpmCPUTotal5minRev MIB object provides a more accurate view of the performance of the router over time than the MIB objects cpmCPUTotal1minRev and cpmCPUTotal5secRev . These MIB objects are not accurate because they look at CPU at one minute and five second intervals, respectively. These MIBs enable you to monitor the trends and plan the capacity of your network. The recommended baseline rising threshold for cpmCPUTotal5minRev is 90 percent. Depending on the platform, some routers that run at 90 percent, for example, 2500s, can exhibit performance degradation versus a high-end router, for example, the 7500 series, which can operate fine.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15215-collect-cpu-util-snmp.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27419','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10216','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[entPhysicalSerialNum.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27420','20','1.3.6.1.4.1.9.9.13.1.3.1.6.{#SNMPINDEX}','10217','{#SNMPVALUE}: Temperature status','sensor.temp.status[ciscoEnvMonTemperatureState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
The current state of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27421','20','1.3.6.1.4.1.9.9.13.1.3.1.3.{#SNMPINDEX}','10217','{#SNMPVALUE}: Temperature','sensor.temp.value[ciscoEnvMonTemperatureValue.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
The current measurement of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27422','20','1.3.6.1.4.1.9.9.13.1.5.1.3.{#SNMPINDEX}','10217','{#SENSOR_INFO}: Power supply status','sensor.psu.status[ciscoEnvMonSupplyState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27423','20','1.3.6.1.4.1.9.9.13.1.4.1.3.{#SNMPINDEX}','10217','{#SENSOR_INFO}: Fan status','sensor.fan.status[ciscoEnvMonFanState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27473','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.6027.3.10.1.2.9.1.1]','10221','CPU and Memory and Flash Discovery','module.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27474','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.6027.3.10.1.2.3.1.1]','10221','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A list of power supply residents in the S-series chassis.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27475','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.6027.3.10.1.2.4.1.1]','10221','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27476','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.6027.3.10.1.2.2.1.2]','10221','Stack Unit Discovery','stack.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27478','20','1.3.6.1.4.1.6027.3.10.1.2.9.1.3.{#SNMPINDEX}','10221','#{#SNMPINDEX}: CPU utilization','system.cpu.util[chStackUnitCpuUtil1Min.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F10-S-SERIES-CHASSIS-MIB
CPU utilization in percentage for last 1 minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27479','20','1.3.6.1.4.1.6027.3.10.1.2.3.1.2.{#SNMPINDEX}','10221','PSU {#SNMPVALUE}: Power supply status','sensor.psu.status[chSysPowerSupplyOperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'31','','','0','','','','','2',NULL,'MIB: F10-S-SERIES-CHASSIS-MIB
The status of the power supply {#SNMPVALUE}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27480','20','1.3.6.1.4.1.6027.3.10.1.2.4.1.2.{#SNMPINDEX}','10221','Fan {#SNMPVALUE}: Fan status','sensor.fan.status[chSysFanTrayOperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'30','','','0','','','','','2',NULL,'MIB: F10-S-SERIES-CHASSIS-MIB
The status of the fan tray {#SNMPVALUE}.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27481','20','1.3.6.1.4.1.6027.3.10.1.2.2.1.10.{#SNMPINDEX}','10221','#{#SNMPVALUE}: Operating system','system.sw.os[chStackUnitCodeVersion.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F10-S-SERIES-CHASSIS-MIB
Current code version of this unit.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27482','20','1.3.6.1.4.1.6027.3.10.1.2.2.1.21.{#SNMPINDEX}','10221','#{#SNMPVALUE}: Hardware version(revision)','system.hw.version[chStackUnitProductRev.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F10-S-SERIES-CHASSIS-MIB
The unit manufacturer''s product revision','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27483','20','1.3.6.1.4.1.6027.3.10.1.2.2.1.12.{#SNMPINDEX}','10221','#{#SNMPVALUE}: Hardware serial number','system.hw.serialnumber[chStackUnitSerialNumber.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F10-S-SERIES-CHASSIS-MIB
The unit''s serial number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27484','20','1.3.6.1.4.1.6027.3.10.1.2.2.1.7.{#SNMPINDEX}','10221','#{#SNMPVALUE}: Hardware model name','system.hw.model[chStackUnitModelID.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F10-S-SERIES-CHASSIS-MIB
The plugged-in model ID for this unit.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27485','20','1.3.6.1.4.1.6027.3.10.1.2.2.1.14.{#SNMPINDEX}','10221','Device {#SNMPVALUE}: Temperature','sensor.temp.value[chStackUnitTemp.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F10-S-SERIES-CHASSIS-MIB
The temperature of the unit.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27508','20','1.3.6.1.2.1.47.1.1.1.1.8.1','10222','Hardware version(revision)','system.hw.version','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27509','20','1.3.6.1.2.1.47.1.1.1.1.9.1','10222','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27510','20','1.3.6.1.2.1.1.1.0','10222','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27511','20','1.3.6.1.4.1.171.10.97.2.36.1.1.3.0','10222','CPU utilization','system.cpu.util[myCPUUtilization5Min.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: MY-PROCESS-MIB
CPU utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27512','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.171.10.97.2.35.1.1.1.2]','10222','Memory Discovery','memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27513','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.171.10.97.2.1.1.23.1.2]','10222','Temperature Discovery','temperature.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27514','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.171.10.97.2.1.1.18.1.3]','10222','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27515','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.171.10.97.2.1.1.21.1.3]','10222','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27517','20','1.3.6.1.4.1.171.10.97.2.1.1.23.1.3.{#SNMPINDEX}','10222','{#SNMPVALUE}: Temperature','sensor.temp.value[mySystemTemperatureCurrent.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MY-SYSTEM-MIB
Return the current temperature of the FastSwitch.The temperature display is not supported for the current temperature returns to 0.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27518','20','1.3.6.1.4.1.171.10.97.2.1.1.18.1.2.{#SNMPINDEX}','10222','{#SNMPVALUE}: Power supply status','sensor.psu.status[mySystemElectricalSourceIsNormal.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'32','','','0','','','','','2',NULL,'MIB: MY-SYSTEM-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27519','20','1.3.6.1.4.1.171.10.97.2.1.1.21.1.2.{#SNMPINDEX}','10222','{#SNMPVALUE}: Fan status','sensor.fan.status[mySystemFanIsNormal.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'32','','','0','','','','','2',NULL,'MIB: MY-SYSTEM-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27543','20','1.3.6.1.2.1.47.1.1.1.1.8.1','10223','Hardware version(revision)','system.hw.version','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27544','20','1.3.6.1.2.1.47.1.1.1.1.9.1','10223','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27545','20','1.3.6.1.4.1.171.12.1.1.12.0','10223','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: DLINK-AGENT-MIB
A text string containing the serial number of this device.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27546','20','1.3.6.1.2.1.1.1.0','10223','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity.  This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27547','20','1.3.6.1.4.1.171.12.1.1.6.2.0','10223','CPU utilization','system.cpu.util[agentCPUutilizationIn1min.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: DLINK-AGENT-MIB
The unit of time is 1 minute. The value will be between 0% (idle) and 100%(very busy).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27548','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.171.12.1.1.9.1.1]','10223','Memory Discovery','memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27549','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.171.12.11.1.8.1.1]','10223','Temperature Discovery','temperature.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27550','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.171.12.11.1.6.1.2,{#STATUS},1.3.6.1.4.1.171.12.11.1.6.1.3]','10223','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'swPowerID of EQUIPMENT-MIB::swPowerTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27551','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.171.12.11.1.7.1.2,{#STATUS},1.3.6.1.4.1.171.12.11.1.7.1.3]','10223','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'swFanID of EQUIPMENT-MIB::swFanTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27553','20','1.3.6.1.4.1.171.12.11.1.8.1.2.{#SNMPINDEX}','10223','#{#SNMPVALUE}: Temperature','sensor.temp.value[swTemperatureCurrent.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: EQUIPMENT-MIB
The shelf current temperature.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27554','20','1.3.6.1.4.1.171.12.11.1.6.1.3.{#SNMPINDEX}','10223','#{#SNMPVALUE}: Power supply status','sensor.psu.status[swPowerStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'34','','','0','','','','','2',NULL,'MIB: EQUIPMENT-MIB
Indicates the current power status.
lowVoltage : The voltage of the power unit is too low.
overCurrent: The current of the power unit is too high.
working    : The power unit is working normally.
fail       : The power unit has failed.
connect    : The power unit is connected but not powered on.
disconnect : The power unit is not connected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27555','20','1.3.6.1.4.1.171.12.11.1.7.1.3.{#SNMPINDEX}','10223','#{#SNMPVALUE}: Fan status','sensor.fan.status[swFanStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'33','','','0','','','','','2',NULL,'MIB: EQUIPMENT-MIB
Indicates the current fan status.
speed-0     : If the fan function is normal and the fan does not spin            due to the temperature not  reaching the threshold, the status of the fan is speed 0.
speed-low   : Fan spin using the lowest speed.
speed-middle: Fan spin using the middle speed.
speed-high  : Fan spin using the highest speed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27579','20','1.3.6.1.2.1.47.1.1.1.1.9.1','10224','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27580','20','1.3.6.1.2.1.47.1.1.1.1.9.1','10224','Hardware version(revision)','system.hw.version','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27582','20','1.3.6.1.2.1.47.1.1.1.1.11.1','10224','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27583','20','1.3.6.1.2.1.47.1.1.1.1.2.1','10224','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27584','20','1.3.6.1.4.1.1916.1.1.1.8.0','10224','Device: Temperature','sensor.temp.value[extremeCurrentTemperature.0]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: EXTREME-SYSTEM-MIB
Temperature readings of testpoint: Device
Reference: https://gtacknowledge.extremenetworks.com/articles/Q_A/Does-EXOS-support-temperature-polling-via-SNMP-on-all-nodes-in-a-stack','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27585','20','1.3.6.1.4.1.1916.1.1.1.7.0','10224','Device: Temperature status','sensor.temp.status[extremeOverTemperatureAlarm.0]','3m','2w','0d','0','3','','','','',NULL,'37','','','0','','','','','0',NULL,'MIB: EXTREME-SYSTEM-MIB
Temperature status of testpoint: Device','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27586','20','1.3.6.1.4.1.1916.1.32.1.2.0','10224','CPU utilization','system.cpu.util[extremeCpuMonitorTotalUtilization.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: EXTREME-SOFTWARE-MONITOR-MIB
Total CPU utlization (percentage) as of last sampling.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27587','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.1916.1.32.2.2.1.1]','10224','Memory Discovery','memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27588','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.1916.1.1.1.27.1.1]','10224','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Table of status of all power supplies in the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27589','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.1916.1.1.1.9.1.1]','10224','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27591','20','1.3.6.1.4.1.1916.1.32.2.2.1.2.{#SNMPINDEX}','10224','#{#SNMPVALUE}: Total memory','vm.memory.total[extremeMemoryMonitorSystemTotal.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: EXTREME-SOFTWARE-MONITOR-MIB
Total amount of DRAM in Kbytes in the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27593','20','1.3.6.1.4.1.1916.1.1.1.27.1.2.{#SNMPINDEX}','10224','PSU {#SNMPVALUE}: Power supply status','sensor.psu.status[extremePowerSupplyStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'38','','','0','','','','','2',NULL,'MIB: EXTREME-SYSTEM-MIB
Status of the power supply {#SNMPVALUE}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27594','20','1.3.6.1.4.1.1916.1.1.1.9.1.4.{#SNMPINDEX}','10224','Fan {#SNMPVALUE}: Fan speed','sensor.fan.speed[extremeFanSpeed.{#SNMPINDEX}]','1m','90d','365d','0','3','','rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: EXTREME-SYSTEM-MIB
The speed (RPM) of a cooling fan in the fantray {#SNMPVALUE}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27595','20','1.3.6.1.4.1.1916.1.1.1.9.1.2.{#SNMPINDEX}','10224','Fan {#SNMPVALUE}: Fan status','sensor.fan.status[extremeFanOperational.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'36','','','0','','','','','2',NULL,'MIB: EXTREME-SYSTEM-MIB
Operational status of a cooling fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27665','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.47.1.1.1.1.2,{#MODULE_NAME},1.3.6.1.2.1.47.1.1.1.1.7]','10227','Module Discovery','module.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Filter limits results to ''Module level1'' or Fabric Modules','0','30d','2','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27666','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.47.1.1.1.1.2,{#MODULE_NAME},1.3.6.1.2.1.47.1.1.1.1.7]','10227','Temperature Discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering modules temperature (same filter as in Module Discovery) plus and temperature sensors','0','30d','2','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27667','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7,{#ENT_DESCR},1.3.6.1.2.1.47.1.1.1.1.2]','10227','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering all entities of PhysicalClass - 7: fan(7)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27668','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7,{#ENT_DESCR},1.3.6.1.2.1.47.1.1.1.1.2]','10227','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering all entities of PhysicalClass - 6: powerSupply(6)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27669','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7]','10227','Entity Discovery','entity.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27671','20','1.3.6.1.4.1.25506.2.6.1.1.1.1.6.{#SNMPINDEX}','10227','{#MODULE_NAME}: CPU utilization','system.cpu.util[hh3cEntityExtCpuUsage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HH3C-ENTITY-EXT-MIB
The CPU usage for this entity. Generally, the CPU usage
will calculate the overall CPU usage on the entity, and it
is not sensible with the number of CPU on the entity','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27672','20','1.3.6.1.4.1.25506.2.6.1.1.1.1.12.{#SNMPINDEX}','10227','{#SNMPVALUE}: Temperature','sensor.temp.value[hh3cEntityExtTemperature.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HH3C-ENTITY-EXT-MIB
The temperature for the {#SNMPVALUE}.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27673','20','1.3.6.1.4.1.25506.2.6.1.1.1.1.19.{#SNMPINDEX}','10227','{#ENT_NAME}: Fan status','sensor.fan.status[hh3cEntityExtErrorStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'39','','','0','','','','','2',NULL,'MIB: HH3C-ENTITY-EXT-MIB
Indicate the error state of this entity object.
fanError(41) means that the fan stops working.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27674','20','1.3.6.1.4.1.25506.2.6.1.1.1.1.19.{#SNMPINDEX}','10227','{#ENT_NAME}: Power supply status','sensor.psu.status[hh3cEntityExtErrorStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'39','','','0','','','','','2',NULL,'MIB: HH3C-ENTITY-EXT-MIB
Indicate the error state of this entity object.
psuError(51) means that the Power Supply Unit is in the state of fault.
rpsError(61) means the Redundant Power Supply is in the state of fault.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27675','20','1.3.6.1.2.1.47.1.1.1.1.10.{#SNMPINDEX}','10227','{#ENT_NAME}: Operating system','system.sw.os[entPhysicalSoftwareRev.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27676','20','1.3.6.1.2.1.47.1.1.1.1.8.{#SNMPINDEX}','10227','{#ENT_NAME}: Hardware version(revision)','system.hw.version[entPhysicalHardwareRev.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27677','20','1.3.6.1.2.1.47.1.1.1.1.9.{#SNMPINDEX}','10227','{#ENT_NAME}: Firmware version','system.hw.firmware[entPhysicalFirmwareRev.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27678','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10227','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[entPhysicalSerialNum.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27679','20','1.3.6.1.2.1.47.1.1.1.1.2.{#SNMPINDEX}','10227','{#ENT_NAME}: Hardware model name','system.hw.model[entPhysicalDescr.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27745','20','discovery[{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7]','10229','MPU Discovery','mpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'http://support.huawei.com/enterprise/KnowledgebaseReadAction.action?contentId=KB1000090234. Filter limits results to Main Processing Units','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27746','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7]','10229','Entity Discovery','entity.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27747','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.2011.5.25.31.1.1.10.1.1]','10229','FAN Discovery','discovery.fans','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27748','20','1.3.6.1.2.1.47.1.1.1.1.8.{#SNMPINDEX}','10229','{#ENT_NAME}: Hardware version(revision)','system.hw.version[entPhysicalHardwareRev.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27749','20','1.3.6.1.2.1.47.1.1.1.1.10.{#SNMPINDEX}','10229','{#ENT_NAME}: Operating system','system.sw.os[entPhysicalSoftwareRev.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27750','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10229','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[entPhysicalSerialNum.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27751','20','1.3.6.1.4.1.2011.5.25.31.1.1.1.1.11.{#SNMPINDEX}','10229','{#ENT_NAME}: Temperature','sensor.temp.value[hwEntityTemperature.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HUAWEI-ENTITY-EXTENT-MIB
The temperature for the {#SNMPVALUE}.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27753','20','1.3.6.1.4.1.2011.5.25.31.1.1.1.1.5.{#SNMPINDEX}','10229','{#ENT_NAME}: CPU utilization','system.cpu.util[hwEntityCpuUsage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HUAWEI-ENTITY-EXTENT-MIB
The CPU usage for this entity. Generally, the CPU usage will calculate the overall CPU usage on the entity, and itis not sensible with the number of CPU on the entity.
Reference: http://support.huawei.com/enterprise/KnowledgebaseReadAction.action?contentId=KB1000090234','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27754','20','1.3.6.1.2.1.47.1.1.1.1.2.{#SNMPINDEX}','10229','{#ENT_NAME}: Hardware model name','system.hw.model[entPhysicalDescr.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27755','20','1.3.6.1.4.1.2011.5.25.31.1.1.10.1.7.{#SNMPINDEX}','10229','#{#SNMPVALUE}: Fan status','sensor.fan.status[hwEntityFanState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'41','','','0','','','','','2',NULL,'MIB: HUAWEI-ENTITY-EXTENT-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27777','20','1.3.6.1.4.1.10222.2.1.1.1.0','10230','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ICS-CHASSIS-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27778','20','1.3.6.1.4.1.10222.2.1.1.1.0','10230','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ICS-CHASSIS-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27779','20','discovery[{#SENSOR_TYPE},1.3.6.1.4.1.10222.2.1.9.8.1.2,{#SENSOR_INFO},1.3.6.1.4.1.10222.2.1.9.8.1.7]','10230','Temperature Discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering sensor''s table with temperature filter','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27780','20','discovery[{#ENT_CLASS},1.3.6.1.4.1.10222.2.1.1.9.1.3,{#ENT_NAME},1.3.6.1.4.1.10222.2.1.1.9.1.2]','10230','Unit Discovery','unit.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27781','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.10222.2.1.4.7.1.2]','10230','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A textual description of the power supply, that can be assigned by the administrator.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27782','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.10222.2.1.6.5.1.2]','10230','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'icsChassisFanDescription of icsChassisFanTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27783','20','1.3.6.1.4.1.10222.2.1.9.8.1.3.{#SNMPINDEX}','10230','{#SENSOR_INFO}: Temperature status','sensor.temp.status[icsChassisSensorSlotOperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'43','','','0','','','','','2',NULL,'MIB: ICS-CHASSIS-MIB
The operational status of the sensor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27784','20','1.3.6.1.4.1.10222.2.1.9.8.1.8.{#SNMPINDEX}','10230','{#SENSOR_INFO}: Temperature','sensor.temp.value[icsChassisSensorSlotValue.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ICS-CHASSIS-MIB
The current value read from the sensor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27785','20','1.3.6.1.4.1.10222.2.1.1.10.1.1.{#SNMPINDEX}','10230','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[icsChassisSystemUnitFruSerialNumber.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ICS-CHASSIS-MIB
The serial number of the FRU.  If not available, this value is a zero-length string.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27786','20','1.3.6.1.4.1.10222.2.1.4.7.1.3.{#SNMPINDEX}','10230','{#SNMPVALUE}: Power supply status','sensor.psu.status[icsChassisPowerSupplyEntry.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'44','','','0','','','','','2',NULL,'MIB: ICS-CHASSIS-MIB
Actual status of the power supply:
(1) unknown: status not known.
(2) disabled: power supply is disabled.
(3) failed - power supply is unable to supply power due to failure.
(4) warning - power supply is supplying power, but an output or sensor is bad or warning.
(5) standby - power supply believed usable,but not supplying power.
(6) engaged - power supply is supplying power.
(7) redundant - power supply is supplying power, but not needed.
(8) notPresent - power supply is supplying power is not present.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27787','20','1.3.6.1.4.1.10222.2.1.6.5.1.3.{#SNMPINDEX}','10230','{#SNMPVALUE}: Fan status','sensor.fan.status[icsChassisFanOperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'42','','','0','','','','','2',NULL,'MIB: ICS-CHASSIS-MIB
The operational status of the fan unit.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27812','20','1.3.6.1.4.1.2636.3.1.2.0','10231','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: JUNIPER-MIB
The name, model, or detailed description of the box,indicating which product the box is about, for example ''M40''.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27813','20','1.3.6.1.4.1.2636.3.1.3.0','10231','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: JUNIPER-MIB
The serial number of this subject, blank if unknown or unavailable.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27814','20','1.3.6.1.4.1.2636.3.4.2.3.1.0','10231','Overall system health status','system.status[jnxRedAlarmState.0]','30s','2w','0d','0','3','','','','',NULL,'46','','','0','','','','','0',NULL,'MIB: JUNIPER-ALARM-MIB
The red alarm indication on the craft interface panel.
The red alarm is on when there is some system
failure or power supply failure or the system
is experiencing a hardware malfunction or some
threshold is being exceeded.

This red alarm state could be turned off by the
ACO/LT (Alarm Cut Off / Lamp Test) button on the
front panel module.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27815','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.2636.3.1.13.1.5]','10231','CPU and Memory Discovery','jnxOperatingTable.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning JUNIPER-MIB::jnxOperatingTable for CPU and Memory
http://kb.juniper.net/InfoCenter/index?page=content&id=KB17526&actp=search. Filter limits results to Routing Engines','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27816','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.2636.3.1.13.1.7,{#SENSOR_INFO},1.3.6.1.4.1.2636.3.1.13.1.5]','10231','Temperature discovery','jnxOperatingTable.discovery.temp','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning JUNIPER-MIB::jnxOperatingTable for Temperature
http://kb.juniper.net/InfoCenter/index?page=content&id=KB17526&actp=search. Filter limits results to Routing Engines','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27817','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.2636.3.1.13.1.5.4]','10231','FAN Discovery','jnxOperatingTable.discovery.fans','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning JUNIPER-MIB::jnxOperatingTable for Fans','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27818','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.2636.3.1.13.1.5.2]','10231','PSU Discovery','jnxOperatingTable.discovery.psu','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning JUNIPER-MIB::jnxOperatingTable for Power Supplies','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27821','20','1.3.6.1.4.1.2636.3.1.13.1.7.{#SNMPINDEX}','10231','{#SENSOR_INFO}: Temperature','sensor.temp.value[jnxOperatingTemp.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: JUNIPER-MIB
The temperature in Celsius (degrees C) of {#SENSOR_INFO}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27822','20','1.3.6.1.4.1.2636.3.1.13.1.6.4.{#SNMPINDEX}','10231','{#SNMPVALUE}: Fan status','sensor.fan.status[jnxOperatingState.4.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'47','','','0','','','','','2',NULL,'MIB: JUNIPER-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27823','20','1.3.6.1.4.1.2636.3.1.13.1.6.2.{#SNMPINDEX}','10231','{#SNMPVALUE}: Power supply status','sensor.psu.status[jnxOperatingState.2.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'47','','','0','','','','','2',NULL,'MIB: JUNIPER-MIB
If they are using DC power supplies there is a known issue on PR 1064039 where the fans do not detect the temperature correctly and fail to cool the power supply causing the shutdown to occur.
This is fixed in Junos 13.3R7 https://forums.juniper.net/t5/Routing/PEM-0-not-OK-MX104/m-p/289644#M14122','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27893','20','1.3.6.1.2.1.1.1.0','10233','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27894','20','1.3.6.1.4.1.14988.1.1.7.3.0','10233','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: MIKROTIK-MIB
RouterBOARD serial number.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27895','20','1.3.6.1.4.1.14988.1.1.7.4.0','10233','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: MIKROTIK-MIB
Current firmware version.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27898','20','1.3.6.1.2.1.25.2.3.1.5.65536','10233','Total memory','vm.memory.total[hrStorageSize.Memory]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in
units of hrStorageAllocationUnits. This object is
writable to allow remote configuration of the size of
the storage area in those cases where such an
operation makes sense and is possible on the
underlying system. For example, the amount of main
memory allocated to a buffer pool might be modified or
the amount of disk space allocated to virtual memory
might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27900','20','1.3.6.1.2.1.25.2.3.1.6.65536','10233','Used memory','vm.memory.used[hrStorageUsed.Memory]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27901','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.25.3.3.1.1]','10233','CPU discovery','hrProcessorLoad.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrProcessorTable discovery','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27902','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.14988.1.1.3.11]','10233','Temperature CPU discovery','mtxrHlProcessorTemperature.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'MIKROTIK-MIB::mtxrHlProcessorTemperature
Since temperature of CPU is not available on all Mikrotik hardware, this is done to avoid unsupported items.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27903','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.25.2.3.1.3,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4,{#STORAGE_TYPE},1.3.6.1.2.1.25.2.3.1.2]','10233','Storage discovery','storage.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with storage filter','0','30d','2','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27904','20','1.3.6.1.2.1.25.3.3.1.2.{#SNMPINDEX}','10233','#{#SNMPINDEX}: CPU utilization','system.cpu.util[hrProcessorLoad.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The average, over the last minute, of the percentage of time that this processor was not idle. Implementations may approximate this one minute smoothing period if necessary.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27905','20','1.3.6.1.4.1.14988.1.1.3.11.{#SNMPINDEX}','10233','CPU: Temperature','sensor.temp.value[mtxrHlProcessorTemperature.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrHlProcessorTemperature Processor temperature in Celsius (degrees C).
Might be missing in entry models (RB750, RB450G..).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27906','15','','10233','Disk-{#SNMPINDEX}: Space utilization','vfs.fs.pused[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'(last("vfs.fs.used[hrStorageSize.{#SNMPINDEX}]")/last("vfs.fs.total[hrStorageSize.{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Space utilization in % for Disk-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27907','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10233','Disk-{#SNMPINDEX}: Total space','vfs.fs.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in
units of hrStorageAllocationUnits. This object is
writable to allow remote configuration of the size of
the storage area in those cases where such an
operation makes sense and is possible on the
underlying system. For example, the amount of main
memory allocated to a buffer pool might be modified or
the amount of disk space allocated to virtual memory
might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27908','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10233','Disk-{#SNMPINDEX}: Used space','vfs.fs.used[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27930','20','1.3.6.1.4.1.4526.10.1.1.1.3.0','10234','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FASTPATH-SWITCHING-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27931','20','1.3.6.1.4.1.4526.10.1.1.1.4.0','10234','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FASTPATH-SWITCHING-MIB
Serial number of the switch','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27935','20','1.3.6.1.4.1.4526.10.1.1.5.2.0','10234','Total memory','vm.memory.total[agentSwitchCpuProcessMemAvailable.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FASTPATH-SWITCHING-MIB
The total Memory allocated for the tasks','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27936','20','1.3.6.1.4.1.4526.10.1.1.4.9.0','10234','CPU utilization','system.cpu.util[agentSwitchCpuProcessTotalUtilization.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FASTPATH-SWITCHING-MIB
CPU utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27937','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.4526.10.43.1.8.1.1]','10234','Temperature Discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'FASTPATH-BOXSERVICES-PRIVATE-MIB::boxServicesTempSensorsTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27938','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.4526.10.43.1.6.1.1]','10234','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'FASTPATH-BOXSERVICES-PRIVATE-MIB::1.3.6.1.4.1.4526.10.43.1.6.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27939','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.4526.10.43.1.7.1.1]','10234','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'FASTPATH-BOXSERVICES-PRIVATE-MIB::boxServicesPowSupplyIndex','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27940','20','1.3.6.1.4.1.4526.10.43.1.8.1.3.{#SNMPINDEX}','10234','#{#SNMPVALUE}: Temperature status','sensor.temp.status[boxServicesTempSensorState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'51','','','0','','','','','2',NULL,'MIB: FASTPATH-BOXSERVICES-PRIVATE-MIB
The state of temperature sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27941','20','1.3.6.1.4.1.4526.10.43.1.8.1.5.{#SNMPINDEX}','10234','#{#SNMPVALUE}: Temperature','sensor.temp.value[boxServicesTempSensorTemperature.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: FASTPATH-BOXSERVICES-PRIVATE-MIB
The temperature value reported by sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27942','20','1.3.6.1.4.1.4526.10.43.1.6.1.3.{#SNMPINDEX}','10234','#{#SNMPVALUE}: Fan status','sensor.fan.status[boxServicesFanItemState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'50','','','0','','','','','2',NULL,'MIB: FASTPATH-BOXSERVICES-PRIVATE-MIB
The status of fan','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27943','20','1.3.6.1.4.1.4526.10.43.1.7.1.3.{#SNMPINDEX}','10234','#{#SNMPVALUE}: Power supply status','sensor.psu.status[boxServicesPowSupplyItemState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'49','','','0','','','','','2',NULL,'MIB: FASTPATH-BOXSERVICES-PRIVATE-MIB
The status of power supply','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27967','20','1.3.6.1.2.1.47.1.1.1.1.9.1','10235','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27968','20','1.3.6.1.2.1.47.1.1.1.1.8.1','10235','Hardware version(revision)','system.hw.version','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27970','20','1.3.6.1.2.1.47.1.1.1.1.11.1','10235','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27971','20','1.3.6.1.2.1.47.1.1.1.1.13.1','10235','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27972','20','1.3.6.1.4.1.27514.100.1.11.7.0','10235','Used memory','vm.memory.used[switchMemoryBusy.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: QTECH-MIB
Used memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27973','20','1.3.6.1.4.1.27514.100.1.11.6.0','10235','Total memory','vm.memory.total[switchMemorySize.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: QTECH-MIB
Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27975','20','1.3.6.1.4.1.27514.100.1.11.10.0','10235','CPU utilization','system.cpu.util[switchCpuUsage.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: QTECH-MIB
CPU utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27997','20','1.3.6.1.4.1.11863.6.1.1.5.0','10236','Hardware version(revision)','system.hw.version','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TPLINK-SYSINFO-MIB
The hardware version of the product.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27998','20','1.3.6.1.4.1.11863.6.1.1.6.0','10236','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TPLINK-SYSINFO-MIB
The software version of the product.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27999','20','1.3.6.1.4.1.11863.6.1.1.8.0','10236','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TPLINK-SYSINFO-MIB
The Serial number of the product.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28000','20','1.3.6.1.4.1.11863.6.1.1.5.0','10236','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TPLINK-SYSINFO-MIB
The hardware version of the product.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28001','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.11863.6.4.1.1.1.1.1]','10236','CPU Discovery','cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering TPLINK-SYSMONITOR-MIB::tpSysMonitorCpuTable, displays the CPU utilization of all UNITs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28002','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.11863.6.4.1.2.1.1.1]','10236','Memory Discovery','memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering TPLINK-SYSMONITOR-MIB::tpSysMonitorMemoryTable, displays the memory utilization of all UNITs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28003','20','1.3.6.1.4.1.11863.6.4.1.1.1.1.3.{#SNMPINDEX}','10236','#{#SNMPVALUE}: CPU utilization','system.cpu.util[tpSysMonitorCpu1Minute.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TPLINK-SYSMONITOR-MIB
Displays the CPU utilization in 1 minute.
Reference: http://www.tp-link.com/faq-1330.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28026','20','1.2.840.10036.3.1.2.1.3.5','10237','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IEEE802dot11-MIB
A printable string used to identify the manufacturer''s product name of the resource. Maximum string length is 128 octets.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28027','20','1.2.840.10036.3.1.2.1.4.5','10237','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IEEE802dot11-MIB
Printable string used to identify the manufacturer''s product version of the resource. Maximum string length is 128 octets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28031','20','1.3.6.1.4.1.10002.1.1.1.4.2.1.3.2','10237','CPU utilization','system.cpu.util[loadValue.2]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FROGFOOT-RESOURCES-MIB
5 minute load average of processor load.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28141','20','1.3.6.1.4.1.11.2.14.11.5.1.1.3.0','10250','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: NETSWITCH-MIB
Contains the operating code version number (also known as software or firmware).
For example, a software version such as A.08.01 is described as follows:
A    the function set available in your router
08   the common release number
01   updates to the current common release','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28142','20','1.3.6.1.4.1.11.2.36.1.1.2.9.0','10250','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SEMI-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28143','20','1.3.6.1.4.1.11.2.14.11.5.1.9.6.1.0','10250','CPU utilization','system.cpu.util[hpSwitchCpuStat.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: STATISTICS-MIB
The CPU utilization in percent(%).
Reference: http://h20564.www2.hpe.com/hpsc/doc/public/display?docId=emr_na-c02597344&sp4ts.oid=51079','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28144','20','discovery[{#SENSOR_TYPE},1.3.6.1.2.1.99.1.1.1.1,{#SENSOR_INFO},1.3.6.1.2.1.47.1.1.1.1.2,{#SENSOR_PRECISION},1.3.6.1.2.1.99.1.1.1.3]','10250','Temperature Discovery','temp.precision0.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'ENTITY-SENSORS-MIB::EntitySensorDataType discovery with celsius filter','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28145','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.11.2.14.11.5.1.1.2.1.1.1.1]','10250','Memory Discovery','memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of NETSWITCH-MIB::hpLocalMemTable, A table that contains information on all the local memory for each slot.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28146','20','discovery[{#ENT_CLASS},1.3.6.1.4.1.11.2.14.11.1.2.6.1.2,{#ENT_DESCR},1.3.6.1.4.1.11.2.14.11.1.2.6.1.7,{#ENT_STATUS},1.3.6.1.4.1.11.2.14.11.1.2.6.1.4]','10250','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering all entities of hpicfSensorObjectId that ends with: 11.2.3.7.8.3.2 - fans and are present','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28147','20','discovery[{#ENT_CLASS},1.3.6.1.4.1.11.2.14.11.1.2.6.1.2,{#ENT_DESCR},1.3.6.1.4.1.11.2.14.11.1.2.6.1.7,{#ENT_STATUS},1.3.6.1.4.1.11.2.14.11.1.2.6.1.4]','10250','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering all entities of hpicfSensorObjectId that ends with: 11.2.3.7.8.3.1 - power supplies and are present','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28148','20','discovery[{#ENT_CLASS},1.3.6.1.4.1.11.2.14.11.1.2.6.1.2,{#ENT_DESCR},1.3.6.1.4.1.11.2.14.11.1.2.6.1.7,{#ENT_STATUS},1.3.6.1.4.1.11.2.14.11.1.2.6.1.4]','10250','Temp Status Discovery','temp.status.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering all entities of hpicfSensorObjectId that ends with: 11.2.3.7.8.3.3 - over temp status and are present','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28149','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7]','10250','Entity Discovery','entity.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28150','20','1.3.6.1.2.1.99.1.1.1.4.{#SNMPINDEX}','10250','{#SENSOR_INFO}: Temperature','sensor.temp.value[entPhySensorValue.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-SENSORS-MIB
The most recent measurement obtained by the agent for this sensor.
To correctly interpret the value of this object, the associated entPhySensorType,
entPhySensorScale, and entPhySensorPrecision objects must also be examined.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28153','20','1.3.6.1.4.1.11.2.14.11.5.1.1.2.1.1.1.7.{#SNMPINDEX}','10250','#{#SNMPVALUE}: Used memory','vm.memory.used[hpLocalMemAllocBytes.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: NETSWITCH-MIB
The number of currently allocated bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28154','20','1.3.6.1.4.1.11.2.14.11.1.2.6.1.4.{#SNMPINDEX}','10250','{#ENT_DESCR}: Fan status','sensor.fan.status[hpicfSensorStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'40','','','0','','','','','2',NULL,'MIB: HP-ICF-CHASSIS
Actual status indicated by the sensor: {#ENT_DESCR}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28155','20','1.3.6.1.4.1.11.2.14.11.1.2.6.1.4.{#SNMPINDEX}','10250','{#ENT_DESCR}: Power supply status','sensor.psu.status[hpicfSensorStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'40','','','0','','','','','2',NULL,'MIB: HP-ICF-CHASSIS
Actual status indicated by the sensor: {#ENT_DESCR}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28156','20','1.3.6.1.4.1.11.2.14.11.1.2.6.1.4.{#SNMPINDEX}','10250','{#ENT_DESCR}: Temperature status','sensor.temp.status[hpicfSensorStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'40','','','0','','','','','2',NULL,'MIB: HP-ICF-CHASSIS
Actual status indicated by the sensor: {#ENT_DESCR}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28157','20','1.3.6.1.2.1.47.1.1.1.1.8.{#SNMPINDEX}','10250','{#ENT_NAME}: Hardware version(revision)','system.hw.version[entPhysicalHardwareRev.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28158','20','1.3.6.1.2.1.47.1.1.1.1.2.{#SNMPINDEX}','10250','{#ENT_NAME}: Hardware model name','system.hw.model[entPhysicalDescr.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28196','20','discovery[{#SENSOR_TYPE},1.3.6.1.2.1.99.1.1.1.1,{#SENSOR_INFO},1.3.6.1.2.1.47.1.1.1.1.2,{#SENSOR_PRECISION},1.3.6.1.2.1.99.1.1.1.3]','10251','Temperature Discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'ENTITY-SENSORS-MIB::EntitySensorDataType discovery with celsius filter','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28197','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.99.1.1.1.1,{#SENSOR_INFO},1.3.6.1.2.1.47.1.1.1.1.2]','10251','Fan Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'ENTITY-SENSORS-MIB::EntitySensorDataType discovery with rpm filter','0','30d','2','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28198','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7]','10251','Entity Discovery','entity.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28199','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7]','10251','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28200','20','1.3.6.1.2.1.99.1.1.1.5.{#SNMPINDEX}','10251','{#SENSOR_INFO}: Temperature status','sensor.temp.status[entPhySensorOperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'18','','','0','','','','','2',NULL,'MIB: ENTITY-SENSORS-MIB
The operational status of the sensor {#SENSOR_INFO}. Possible values:
- ok(1) indicates that the agent can obtain the sensor value.
- unavailable(2) indicates that the agent presently cannot obtain the sensor value.
- nonoperational(3) indicates that the agent believes the sensor is broken. The sensor could have a hard failure (disconnected wire), or a soft failure such as out-of-range, jittery, or wildly fluctuating readings.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28201','20','1.3.6.1.2.1.99.1.1.1.4.{#SNMPINDEX}','10251','{#SENSOR_INFO}: Temperature','sensor.temp.value[entPhySensorValue.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-SENSORS-MIB
The most recent measurement obtained by the agent for this sensor.
To correctly interpret the value of this object, the associated entPhySensorType,
entPhySensorScale, and entPhySensorPrecision objects must also be examined.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28202','20','1.3.6.1.2.1.99.1.1.1.5.{#SNMPINDEX}','10251','{#SENSOR_INFO}: Fan status','sensor.fan.status[entPhySensorOperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'18','','','0','','','','','2',NULL,'MIB: ENTITY-SENSORS-MIB
The operational status of the sensor {#SENSOR_INFO}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28203','20','1.3.6.1.2.1.99.1.1.1.4.{#SNMPINDEX}','10251','{#SENSOR_INFO}: Fan speed','sensor.fan.speed[entPhySensorValue.{#SNMPINDEX}]','1m','90d','365d','0','3','','rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-SENSORS-MIB
The most recent measurement obtained by the agent for this sensor.
To correctly interpret the value of this object, the associated entPhySensorType,
entPhySensorScale, and entPhySensorPrecision objects must also be examined.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28204','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10251','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[entPhysicalSerialNum.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28205','20','1.3.6.1.2.1.47.1.1.1.1.13.{#SNMPINDEX}','10251','{#ENT_NAME}: Hardware model name','system.hw.model[entPhysicalModelName.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28206','20','1.3.6.1.2.1.131.1.1.1.3.{#SNMPINDEX}','10251','{#ENT_NAME}: Power supply status','sensor.psu.status[entStateOper.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'48','','','0','','','','','2',NULL,'MIB: ENTITY-STATE-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28244','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.109.1.1.1.1.5]','10252','CPU Discovery','cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If your IOS device has several CPUs, you must use CISCO-PROCESS-MIB and its object cpmCPUTotal5minRev from the table called cpmCPUTotalTable ,
indexed with cpmCPUTotalIndex .
This table allows CISCO-PROCESS-MIB to keep CPU statistics for different physical entities in the router,
like different CPU chips, group of CPUs, or CPUs in different modules/cards.
In case of a single CPU, cpmCPUTotalTable has only one entry.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28246','20','1.3.6.1.4.1.9.9.109.1.1.1.1.5.{#SNMPINDEX}','10252','{#SNMPVALUE}: CPU utilization','system.cpu.util[cpmCPUTotal5min.{#SNMPINDEX}]','5m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-PROCESS-MIB
The overall CPU busy percentage in the last 5 minute
period. This object deprecates the avgBusy5 object from
the OLD-CISCO-SYSTEM-MIB. This object is deprecated
by cpmCPUTotal5minRev which has the changed range
of value (0..100)
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15215-collect-cpu-util-snmp.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28248','5','','10047','Zabbix server: Preprocessing queue','zabbix[preprocessing_queue]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of values enqueued in the preprocessing queue.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28250','5','','10048','Utilization of vmware data collector processes, in %','zabbix[process,vmware collector,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28251','5','','10048','Zabbix vmware cache, % used','zabbix[vmware,buffer,pused]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','1','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28305','20','discovery[{#SENSOR_TYPE},1.3.6.1.2.1.99.1.1.1.1,{#SENSOR_INFO},1.3.6.1.2.1.47.1.1.1.1.2,{#SENSOR_PRECISION},1.3.6.1.2.1.99.1.1.1.3,{#THRESHOLD_LO_WARN},1.3.6.1.4.1.30065.3.12.1.1.1.1,{#THRESHOLD_LO_CRIT},1.3.6.1.4.1.30065.3.12.1.1.1.2,{#THRESHOLD_HI_WARN},1.3.6.1.4.1.30065.3.12.1.1.1.3,{#THRESHOLD_HI_CRIT},1.3.6.1.4.1.30065.3.12.1.1.1.4]','10254','Get sensors','sensors.get','1h','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Gets sensors with type, description, and thresholds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28308','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7]','10254','Entity discovery','entity.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28309','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7]','10254','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28323','20','1.3.6.1.2.1.99.1.1.1.4.{#SNMPINDEX}','10254','{#SENSOR_INFO}: Temperature','sensor.temp.value[entPhySensorValue.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-SENSORS-MIB
The most recent measurement obtained by the agent for this sensor.
To correctly interpret the value of this object, the associated entPhySensorType,
entPhySensorScale, and entPhySensorPrecision objects must also be examined.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28324','20','1.3.6.1.2.1.99.1.1.1.5.{#SNMPINDEX}','10254','{#SENSOR_INFO}: Temperature status','sensor.temp.status[entPhySensorOperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'18','','','0','','','','','2',NULL,'MIB: ENTITY-SENSORS-MIB
The operational status of the sensor {#SENSOR_INFO}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28325','20','1.3.6.1.2.1.99.1.1.1.4.{#SNMPINDEX}','10254','{#SENSOR_INFO}: Fan speed','sensor.fan.speed[entPhySensorValue.{#SNMPINDEX}]','1m','90d','365d','0','3','','rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-SENSORS-MIB
The most recent measurement obtained by the agent for this sensor.
To correctly interpret the value of this object, the associated entPhySensorType,
entPhySensorScale, and entPhySensorPrecision objects must also be examined.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28326','20','1.3.6.1.2.1.99.1.1.1.5.{#SNMPINDEX}','10254','{#SENSOR_INFO}: Fan status','sensor.fan.status[entPhySensorOperStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'18','','','0','','','','','2',NULL,'MIB: ENTITY-SENSORS-MIB
The operational status of the sensor {#SENSOR_INFO}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28327','20','1.3.6.1.2.1.47.1.1.1.1.13.{#SNMPINDEX}','10254','{#ENT_NAME}: Hardware model name','system.hw.model[entPhysicalModelName.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28328','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10254','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[entPhysicalSerialNum.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28329','20','1.3.6.1.2.1.131.1.1.1.3.{#SNMPINDEX}','10254','{#ENT_NAME}: Power supply status','sensor.psu.status[entStateOper.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'48','','','0','','','','','2',NULL,'MIB: ENTITY-STATE-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28341','20','1.3.6.1.4.1.674.10892.5.2.1.0','10255','Overall system health status','system.status[globalSystemStatus.0]','30s','2w','0d','0','3','','','','',NULL,'59','','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the overall rollup status of all components in the system being monitored by the remote access card. Includes system, storage, IO devices, iDRAC, CPU, memory, etc.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28342','20','1.3.6.1.4.1.674.10892.5.1.3.12.0','10255','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the model name of the system.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28344','20','1.3.6.1.4.1.674.10892.5.1.3.2.0','10255','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the service tag of the system.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28345','20','1.3.6.1.4.1.674.10892.5.1.1.8.0','10255','Firmware version','system.hw.firmware','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the firmware version of a remote access card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28346','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.700.20.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.674.10892.5.4.700.20.1.8]','10255','Temperature CPU Discovery','temp.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Probe Table IDRAC-MIB-SMIv2::temperatureProbeTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28347','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.700.20.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.674.10892.5.4.700.20.1.8]','10255','Temperature Ambient Discovery','temp.ambient.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Probe Table IDRAC-MIB-SMIv2::temperatureProbeTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28348','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.600.12.1.5,{#PSU_DESCR},1.3.6.1.4.1.674.10892.5.4.600.12.1.8]','10255','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::powerSupplyTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28349','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.700.12.1.5,{#FAN_DESCR},1.3.6.1.4.1.674.10892.5.4.700.12.1.8,{#TYPE},1.3.6.1.4.1.674.10892.5.4.700.12.1.7]','10255','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::coolingDeviceTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28350','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.1,{#DISK_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.2]','10255','Physical Disk Discovery','physicaldisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::physicalDiskTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28351','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.1,{#DISK_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.2]','10255','Virtual Disk Discovery','virtualdisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::virtualDiskTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28352','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.38,{#CNTLR_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.79]','10255','Array Controller Discovery','physicaldisk.arr.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::controllerTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28353','20','discovery[{#BATTERY_NUM},1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.1]','10255','Array Controller Cache Discovery','array.cache.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::batteryTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28354','20','1.3.6.1.4.1.674.10892.5.4.700.20.1.6.{#SNMPINDEX}','10255','{#SENSOR_LOCALE}: Temperature','sensor.temp.value[temperatureProbeReading.CPU.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
0700.0020.0001.0006 This attribute defines the reading for a temperature probe of type other than temperatureProbeTypeIsDiscrete.  When the value for temperatureProbeType is other than temperatureProbeTypeIsDiscrete,the value returned for this attribute is the temperature that the probeis reading in tenths of degrees Centigrade. When the value for temperatureProbeType is temperatureProbeTypeIsDiscrete, a value is not returned for this attribute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28355','20','1.3.6.1.4.1.674.10892.5.4.700.20.1.5.{#SNMPINDEX}','10255','{#SENSOR_LOCALE}: Temperature status','sensor.temp.status[temperatureProbeStatus.CPU.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
0700.0020.0001.0005 This attribute defines the probe status of the temperature probe.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28356','20','1.3.6.1.4.1.674.10892.5.4.700.20.1.6.{#SNMPINDEX}','10255','{#SENSOR_LOCALE}: Temperature','sensor.temp.value[temperatureProbeReading.Ambient.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
0700.0020.0001.0006 This attribute defines the reading for a temperature probe of type other than temperatureProbeTypeIsDiscrete.  When the value for temperatureProbeType is other than temperatureProbeTypeIsDiscrete,the value returned for this attribute is the temperature that the probeis reading in tenths of degrees Centigrade. When the value for temperatureProbeType is temperatureProbeTypeIsDiscrete, a value is not returned for this attribute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28357','20','1.3.6.1.4.1.674.10892.5.4.700.20.1.5.{#SNMPINDEX}','10255','{#SENSOR_LOCALE}: Temperature status','sensor.temp.status[temperatureProbeStatus.Ambient.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
0700.0020.0001.0005 This attribute defines the probe status of the temperature probe.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28358','20','1.3.6.1.4.1.674.10892.5.4.600.12.1.5.{#SNMPINDEX}','10255','{#PSU_DESCR}: Power supply status','sensor.psu.status[powerSupplyStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'59','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
0600.0012.0001.0005 This attribute defines the status of the power supply.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28359','20','1.3.6.1.4.1.674.10892.5.4.700.12.1.5.{#SNMPINDEX}','10255','{#FAN_DESCR}: Fan status','sensor.fan.status[coolingDeviceStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
0700.0012.0001.0005 This attribute defines the probe status of the cooling device.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28360','20','1.3.6.1.4.1.674.10892.5.4.700.12.1.6.{#SNMPINDEX}','10255','{#FAN_DESCR}: Fan speed','sensor.fan.speed[coolingDeviceReading.{#SNMPINDEX}]','1m','90d','365d','0','3','','rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
0700.0012.0001.0006 This attribute defines the reading for a cooling device
of subtype other than coolingDeviceSubTypeIsDiscrete.  When the value
for coolingDeviceSubType is other than coolingDeviceSubTypeIsDiscrete, the
value returned for this attribute is the speed in RPM or the OFF/ON value
of the cooling device.  When the value for coolingDeviceSubType is
coolingDeviceSubTypeIsDiscrete, a value is not returned for this attribute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28361','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.24.{#SNMPINDEX}','10255','{#DISK_NAME}: Physical disk status','system.hw.physicaldisk.status[physicalDiskComponentStatus.{#SNMPINDEX}]','3m','90d','0d','0','3','','','','',NULL,'61','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The status of the physical disk itself without the propagation of any contained component status.
Possible values:
1: Other
2: Unknown
3: OK
4: Non-critical
5: Critical
6: Non-recoverable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28362','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.7.{#SNMPINDEX}','10255','{#DISK_NAME}: Physical disk serial number','system.hw.physicaldisk.serialnumber[physicalDiskSerialNo.{#SNMPINDEX}]','1d','90d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The physical disk''s unique identification number from the manufacturer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28363','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.31.{#SNMPINDEX}','10255','{#DISK_NAME}: Physical disk S.M.A.R.T. status','system.hw.physicaldisk.smart_status[physicalDiskSmartAlertIndication.{#SNMPINDEX}]','3m','90d','0d','0','3','','','','',NULL,'62','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
Indicates whether the physical disk has received a predictive failure alert.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28364','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.6.{#SNMPINDEX}','10255','{#DISK_NAME}: Physical disk model name','system.hw.physicaldisk.model[physicalDiskProductID.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The model number of the physical disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28365','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.27.{#SNMPINDEX}','10255','{#DISK_NAME}: Physical disk part number','system.hw.physicaldisk.part_number[physicalDiskPartNumber.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The part number of the disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28366','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.35.{#SNMPINDEX}','10255','{#DISK_NAME}: Physical disk media type','system.hw.physicaldisk.media_type[physicalDiskMediaType.{#SNMPINDEX}]','1h','2w','0d','0','3','','','','',NULL,'63','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The media type of the physical disk. Possible Values:
1: The media type could not be determined.
2: Hard Disk Drive (HDD).
3: Solid State Drive (SSD).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28367','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.11.{#SNMPINDEX}','10255','{#DISK_NAME}: Disk size','system.hw.physicaldisk.size[physicalDiskCapacityInMB.{#SNMPINDEX}]','1h','2w','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The size of the physical disk in megabytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28368','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.13.{#SNMPINDEX}','10255','Disk {#SNMPVALUE}({#DISK_NAME}): Layout type','system.hw.virtualdisk.layout[virtualDiskLayout.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,'65','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The virtual disk''s RAID type.
Possible values:
1: Not one of the following
2: RAID-0
3: RAID-1
4: RAID-5
5: RAID-6
6: RAID-10
7: RAID-50
8: RAID-60
9: Concatenated RAID 1
10: Concatenated RAID 5','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28369','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.30.{#SNMPINDEX}','10255','Disk {#SNMPVALUE}({#DISK_NAME}): Current state','system.hw.virtualdisk.state[virtualDiskOperationalState.{#SNMPINDEX}]','3m','2w','365d','0','3','','','','',NULL,'66','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The state of the virtual disk when there are progressive operations ongoing.
Possible values:
1: There is no active operation running.
2: The virtual disk configuration has changed. The physical disks included in the virtual disk are being modified to support the new configuration.
3: A Consistency Check (CC) is being performed on the virtual disk.
4: The virtual disk is being initialized.
5: BackGround Initialization (BGI) is being performed on the virtual disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28370','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.11.{#SNMPINDEX}','10255','Disk {#SNMPVALUE}({#DISK_NAME}): Read policy','system.hw.virtualdisk.readpolicy[virtualDiskReadPolicy.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The read policy used by the controller for read operations on this virtual disk.
Possible values:
1: No Read Ahead.
2: Read Ahead.
3: Adaptive Read Ahead.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28371','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.10.{#SNMPINDEX}','10255','Disk {#SNMPVALUE}({#DISK_NAME}): Write policy','system.hw.virtualdisk.writepolicy[virtualDiskWritePolicy.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,'67','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The write policy used by the controller for write operations on this virtual disk.
Possible values:
1: Write Through.
2: Write Back.
3: Force Write Back.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28372','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.6.{#SNMPINDEX}','10255','Disk {#SNMPVALUE}({#DISK_NAME}): Disk size','system.hw.virtualdisk.size[virtualDiskSizeInMB.{#SNMPINDEX}]','1h','2w','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The size of the virtual disk in megabytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28373','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.4.{#SNMPINDEX}','10255','Disk {#SNMPVALUE}({#DISK_NAME}): Status','system.hw.virtualdisk.status[virtualDiskState.{#SNMPINDEX}]','3m','2w','365d','0','3','','','','',NULL,'69','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The current state of this virtual disk (which includes any member physical disks.)
Possible states:
1: The current state could not be determined.
2: The virtual disk is operating normally or optimally.
3: The virtual disk has encountered a failure. The data on disk is lost or is about to be lost.
4: The virtual disk encountered a failure with one or all of the constituent redundant physical disks.
The data on the virtual disk might no longer be fault tolerant.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28374','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.38.{#SNMPINDEX}','10255','{#CNTLR_NAME}: Disk array controller status','system.hw.diskarray.status[controllerComponentStatus.{#SNMPINDEX}]','1m','1w','0d','0','3','','','','',NULL,'59','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The status of the controller itself without the propagation of any contained component status.
Possible values:
1: Other
2: Unknown
3: OK
4: Non-critical
5: Critical
6: Non-recoverable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28375','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.2.{#SNMPINDEX}','10255','{#CNTLR_NAME}: Disk array controller model','system.hw.diskarray.model[controllerName.{#SNMPINDEX}]','1d','90d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The controller''s name as represented in Storage Management.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28376','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.4.{#SNMPINDEX}','10255','Battery {#BATTERY_NUM}: Disk array cache controller battery status','system.hw.diskarray.cache.battery.status[batteryState.{#SNMPINDEX}]','1m','1w','0d','0','3','','','','',NULL,'64','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
Current state of battery.
Possible values:
1: The current state could not be determined.
2: The battery is operating normally.
3: The battery has failed and needs to be replaced.
4: The battery temperature is high or charge level is depleting.
5: The battery is missing or not detected.
6: The battery is undergoing the re-charge phase.
7: The battery voltage or charge level is below the threshold.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28388','20','1.3.6.1.4.1.232.6.2.6.1.0','10256','System: Temperature status','sensor.temp.status[cpqHeThermalCondition.0]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','0',NULL,'MIB: CPQHLTH-MIB
This value specifies the overall condition of the system''s thermal environment.
This value will be one of the following:
other(1)  Temperature could not be determined.
ok(2)  The temperature sensor is within normal operating range.
degraded(3)  The temperature sensor is outside of normal operating range.
failed(4)  The temperature sensor detects a condition that could  permanently damage the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28390','20','1.3.6.1.4.1.232.2.2.4.2.0','10256','Hardware model name','system.hw.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: CPQSINFO-MIB
The machine product name.The name of the machine used in this system.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28391','20','1.3.6.1.4.1.232.2.2.2.1.0','10256','Hardware serial number','system.hw.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: CPQSINFO-MIB
The serial number of the physical system unit. The string will be empty if the system does not report the serial number function.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28392','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10256','Temperature Discovery','tempDescr.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries: CPQHLTH-MIB::cpqHeTemperatureTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28393','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10256','Temperature Discovery Ambient','tempDescr.discovery.ambient','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries: CPQHLTH-MIB::cpqHeTemperatureTable with ambient(11) and 0.1 index filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28394','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10256','Temperature Discovery CPU','tempDescr.discovery.cpu','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries: CPQHLTH-MIB::cpqHeTemperatureTable with cpu(6) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28395','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10256','Temperature Discovery Memory','tempDescr.discovery.memory','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries: CPQHLTH-MIB::cpqHeTemperatureTable with memory(7) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28396','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10256','Temperature Discovery PSU','tempDescr.discovery.psu','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries: CPQHLTH-MIB::cpqHeTemperatureTable with powerSupply(10) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28397','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10256','Temperature Discovery I/O','tempDescr.discovery.io','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries: CPQHLTH-MIB::cpqHeTemperatureTable with ioBoard(5) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28398','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.9.3.1.5,{#CHASSIS_NUM},1.3.6.1.4.1.232.6.2.9.3.1.1,{#BAY_NUM},1.3.6.1.4.1.232.6.2.9.3.1.2]','10256','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQHLTH-MIB::cpqHeFltTolPowerSupplyStatus','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28399','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.7.1.9]','10256','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQHLTH-MIB::cpqHeFltTolFanCondition','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28400','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.2.1.1.1,{#CNTLR_SLOT},1.3.6.1.4.1.232.3.2.2.1.1.5,{#CNTLR_LOCATION},1.3.6.1.4.1.232.3.2.2.1.1.20]','10256','Array Controller Discovery','array.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CPQIDA-MIB::cpqDaCntlrTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28401','20','discovery[{#CACHE_STATUS},1.3.6.1.4.1.232.3.2.2.2.1.2,{#CACHE_CNTRL_INDEX},1.3.6.1.4.1.232.3.2.2.2.1.1]','10256','Array Controller Cache Discovery','array.cache.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CPQIDA-MIB::cpqDaAccelTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28402','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.5.1.1.5,{#DISK_LOCATION},1.3.6.1.4.1.232.3.2.5.1.1.64]','10256','Physical Disk Discovery','physicalDisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning  table of physical drive entries CPQIDA-MIB::cpqDaPhyDrvTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28403','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.3.1.1.2,{#DISK_NAME},1.3.6.1.4.1.232.3.2.3.1.1.14]','10256','Virtual Disk Discovery','virtualdisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQIDA-MIB::cpqDaLogDrvTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28404','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10256','{#SNMPINDEX}: Temperature','sensor.temp.value[cpqHeTemperatureCelsius.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: {#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28405','20','1.3.6.1.4.1.232.6.2.6.8.1.3.{#SNMPINDEX}','10256','{#SNMPINDEX}: Temperature sensor location','sensor.temp.locale[cpqHeTemperatureLocale.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'55','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
This specifies the location of the temperature sensor present in the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28406','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10256','Ambient: Temperature','sensor.temp.value[cpqHeTemperatureCelsius.Ambient.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: Ambient','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28407','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10256','CPU-{#SNMPINDEX}: Temperature','sensor.temp.value[cpqHeTemperatureCelsius.CPU.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: CPU-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28408','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10256','Memory-{#SNMPINDEX}: Temperature','sensor.temp.value[cpqHeTemperatureCelsius.Memory.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: Memory-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28409','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10256','PSU-{#SNMPINDEX}: Temperature','sensor.temp.value[cpqHeTemperatureCelsius.PSU.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: PSU-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28411','20','1.3.6.1.4.1.232.6.2.9.3.1.4.{#SNMPINDEX}','10256','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply status','sensor.psu.status[cpqHeFltTolPowerSupplyCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The condition of the power supply. This value will be one of the following:
other(1)  The status could not be determined or not present.
ok(2)  The power supply is operating normally.
degraded(3)  A temperature sensor, fan or other power supply component is  outside of normal operating range.
failed(4)  A power supply component detects a condition that could  permanently damage the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28412','20','1.3.6.1.4.1.232.6.2.6.7.1.9.{#SNMPINDEX}','10256','Fan {#SNMPINDEX}: Fan status','sensor.fan.status[cpqHeFltTolFanCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The condition of the fan.
This value will be one of the following:
other(1)  Fan status detection is not supported by this system or driver.
ok(2)  The fan is operating properly.
degraded(2)  A redundant fan is not operating properly.
failed(4)  A non-redundant fan is not operating properly.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28413','20','1.3.6.1.4.1.232.3.2.2.1.1.6.{#SNMPINDEX}','10256','{#CNTLR_LOCATION}: Disk array controller status','system.hw.diskarray.status[cpqDaCntlrCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
This value represents the overall condition of this controller,
and any associated logical drives,physical drives, and array accelerators.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28414','20','1.3.6.1.4.1.232.3.2.2.1.1.2.{#SNMPINDEX}','10256','{#CNTLR_LOCATION}: Disk array controller model','system.hw.diskarray.model[cpqDaCntlrModel.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'56','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Array Controller Model. The type of controller card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28415','20','1.3.6.1.4.1.232.3.2.2.2.1.2.{#SNMPINDEX}','10256','#{#CACHE_CNTRL_INDEX}: Disk array cache controller status','system.hw.diskarray.cache.status[cpqDaAccelStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'71','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Other (1)
 Indicates that the instrument agent does not recognize the status of the cache module.
Invalid (2)
 Indicates that a cache module board has not been installed in this system or is present but not configured.
Enabled (3)
 Indicates that cache operations are currently configured and enabled for at least one logical drive.
Temporarily Disabled (4)
 Indicates that cache operations have been temporarily disabled.
Permanently Disabled (5)
 Indicates that cache operations have been permanently disabled.
Cache Module Flash Memory Not Attached (6)
 Indicates that the flash memory component of the flash backed cache module is not attached.
Cache Module Degraded Failsafe Speed (7)
 Indicates that the cache module board is currently degraded and operating at a failsafe speed.
Cache Module Critical Failure (8)
 Indicates that the cache module board has encountered a critical failure. The controller is currently operating in Zero Memory Raid mode.
Read Cache Could Not Be Mapped (9)
 Indicates that the read cache memory in a split cache configuration could not be mapped by the operating system and as a result is not available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28416','20','1.3.6.1.4.1.232.3.2.2.2.1.6.{#SNMPINDEX}','10256','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery status','system.hw.diskarray.cache.battery.status[cpqDaAccelBattery.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'72','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Cache Module Board Backup Power Status. This monitors the status of each backup power source on the board.
The backup power source can only recharge when the system has power applied. The type of backup power source used is indicated by cpqDaAccelBackupPowerSource.
The following values are valid:
Other (1)  Indicates that the instrument agent does not recognize  backup power status.  You may need to update your software.

Ok (2)  The backup power source is fully charged.

Recharging (3)  The array controller has one or more cache module backup power  sources that are recharging.
Cache module operations such as Battery/Flash Backed Write Cache, Expansion, Extension and Migration are temporarily suspended until the backup power source is fully charged.
Cache module operations will automatically resume  when charging is complete.

Failed (4)  The battery pack is below the sufficient voltage level and  has not recharged in 36 hours.
Your Cache Module board  needs to be serviced.

Degraded (5)  The battery is still operating, however, one of the batteries  in the pack has failed to recharge properly.
Your Cache  Module board should be serviced as soon as possible.

NotPresent (6)  A backup power source is not present on the cache module board. Some controllers do not have backup power sources.

Capacitor Failed (7)  The flash backed cache module capacitor is below the sufficient voltage level and has not recharged in 10 minutes.  Your Cache Module board needs to be serviced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28417','20','1.3.6.1.4.1.232.3.2.5.1.1.6.{#SNMPINDEX}','10256','{#DISK_LOCATION}: Physical disk status','system.hw.physicaldisk.status[cpqDaPhyDrvStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'57','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Status. This shows the status of the physical drive. The following values are valid for the physical drive status:
other (1)  Indicates that the instrument agent does not recognize  the drive.
You may need to upgrade your instrument agent  and/or driver software.
ok (2)  Indicates the drive is functioning properly.
failed (3)  Indicates that the drive is no longer operating and  should be replaced.
predictiveFailure(4)  Indicates that the drive has a predictive failure error and  should be replaced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28418','20','1.3.6.1.4.1.232.3.2.5.1.1.57.{#SNMPINDEX}','10256','{#DISK_LOCATION}: Physical disk S.M.A.R.T. status','system.hw.physicaldisk.smart_status[cpqDaPhyDrvSmartStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'70','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive S.M.A.R.T Status.The following values are defined:
other(1)  The agent is unable to determine if the status of S.M.A.R.T  predictive failure monitoring for this drive.
ok(2)  Indicates the drive is functioning properly.
replaceDrive(3)  Indicates that the drive has a S.M.A.R.T predictive failure  error and should be replaced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28419','20','1.3.6.1.4.1.232.3.2.5.1.1.51.{#SNMPINDEX}','10256','{#DISK_LOCATION}: Physical disk serial number','system.hw.physicaldisk.serialnumber[cpqDaPhyDrvSerialNum.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Serial Number.
This is the serial number assigned to the physical drive.
This value is based upon the serial number as returned by the SCSI inquiry command
but may have been modified due to space limitations.  This can be used for identification purposes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28420','20','1.3.6.1.4.1.232.3.2.5.1.1.3.{#SNMPINDEX}','10256','{#DISK_LOCATION}: Physical disk model name','system.hw.physicaldisk.model[cpqDaPhyDrvModel.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Model.This is a text description of the physical drive.
The text that appears depends upon who manufactured the drive and the drive type.
If a drive fails, note the model to identify the type of drive necessary for replacement.
If a model number is not present, you may not have properly initialized the drive array to which the physical drive is attached for monitoring.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28421','20','1.3.6.1.4.1.232.3.2.5.1.1.69.{#SNMPINDEX}','10256','{#DISK_LOCATION}: Physical disk media type','system.hw.physicaldisk.media_type[cpqDaPhyDrvMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'73','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Drive Array Physical Drive Media Type.The following values are defined:
other(1)  The instrument agent is unable to determine the physical drive’s media type.
rotatingPlatters(2)  The physical drive media is composed of rotating platters.
solidState(3)  The physical drive media is composed of solid state electronics.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28422','20','1.3.6.1.4.1.232.3.2.5.1.1.45.{#SNMPINDEX}','10256','{#DISK_LOCATION}: Disk size','system.hw.physicaldisk.size[cpqDaPhyDrvMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Size in MB.
This is the size of the physical drive in megabytes.
This value is calculated using the value 1,048,576 (2^20) as a megabyte.
Drive manufacturers sometimes use the number 1,000,000 as a megabyte when giving drive capacities so this value may differ
from the advertised size of a drive. This field is only applicable for controllers which support SCSI drives,
and therefore is not supported by the IDA or IDA-2 controllers. The field will contain 0xFFFFFFFF if the drive capacity cannot be calculated
or if the controller does not support SCSI drives.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28423','20','1.3.6.1.4.1.232.3.2.3.1.1.4.{#SNMPINDEX}','10256','Disk {#SNMPINDEX}({#DISK_NAME}): Status','system.hw.virtualdisk.status[cpqDaLogDrvStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'75','','','0','','','','','2',NULL,'Logical Drive Status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28424','20','1.3.6.1.4.1.232.3.2.3.1.1.3.{#SNMPINDEX}','10256','Disk {#SNMPINDEX}({#DISK_NAME}): Layout type','system.hw.virtualdisk.layout[cpqDaLogDrvFaultTol.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'74','','','0','','','','','2',NULL,'Logical Drive Fault Tolerance.
This shows the fault tolerance mode of the logical drive.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28425','20','1.3.6.1.4.1.232.3.2.3.1.1.9.{#SNMPINDEX}','10256','Disk {#SNMPINDEX}({#DISK_NAME}): Disk size','system.hw.virtualdisk.size[cpqDaLogDrvSize.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Logical Drive Size.
This is the size of the logical drive in megabytes.  This value
is calculated using the value 1,048,576 (2^20) as a megabyte.
Drive manufacturers sometimes use the number 1,000,000 as a
megabyte when giving drive capacities so this value may
differ from the advertised size of a drive.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28465','20','1.3.6.1.4.1.2.3.51.3.1.4.1.0','10258','Overall system health status','system.status[systemHealthStat.0]','30s','2w','0d','0','3','','','','',NULL,'58','','','0','','','','','0',NULL,'MIB: IMM-MIB
Indicates status of system health for the system in which the IMM resides. Value of ''nonRecoverable'' indicates a severe error has occurred and the system may not be functioning. A value of ''critical'' indicates that a error has occurred but the system is currently functioning properly. A value of ''nonCritical'' indicates that a condition has occurred that may change the state of the system in the future but currently the system is working properly. A value of ''normal'' indicates that the system is operating normally.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28466','20','1.3.6.1.4.1.2.3.51.3.1.5.2.1.5.0','10258','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IMM-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28467','20','1.3.6.1.4.1.2.3.51.3.1.5.2.1.3.0','10258','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IMM-MIB
Machine serial number VPD information','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28468','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.2.3.51.3.1.1.2.1.2]','10258','Temperature Discovery','tempDescr.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning IMM-MIB::tempTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28469','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.2.3.51.3.1.1.2.1.2]','10258','Temperature Discovery Ambient','tempDescr.discovery.ambient','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning IMM-MIB::tempTable with Ambient filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28470','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.2.3.51.3.1.1.2.1.2]','10258','Temperature Discovery CPU','tempDescr.discovery.cpu','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning IMM-MIB::tempTable with CPU filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28471','20','discovery[{#PSU_DESCR},1.3.6.1.4.1.2.3.51.3.1.11.2.1.2]','10258','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IMM-MIB::powerFruName','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28472','20','discovery[{#FAN_DESCR},1.3.6.1.4.1.2.3.51.3.1.3.2.1.2]','10258','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IMM-MIB::fanDescr','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28473','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.2.3.51.3.1.12.2.1.1]','10258','Physical Disk Discovery','physicalDisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28474','20','1.3.6.1.4.1.2.3.51.3.1.1.2.1.3.{#SNMPINDEX}','10258','{#SNMPVALUE}: Temperature','sensor.temp.value[tempReading.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IMM-MIB
Temperature readings of testpoint: {#SNMPVALUE}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28475','20','1.3.6.1.4.1.2.3.51.3.1.1.2.1.3.{#SNMPINDEX}','10258','Ambient: Temperature','sensor.temp.value[tempReading.Ambient.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IMM-MIB
Temperature readings of testpoint: Ambient','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28476','20','1.3.6.1.4.1.2.3.51.3.1.1.2.1.3.{#SNMPINDEX}','10258','CPU: Temperature','sensor.temp.value[tempReading.CPU.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IMM-MIB
Temperature readings of testpoint: CPU','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28477','20','1.3.6.1.4.1.2.3.51.3.1.11.2.1.6.{#SNMPINDEX}','10258','{#PSU_DESCR}: Power supply status','sensor.psu.status[powerHealthStatus.{#SNMPINDEX}]','3m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IMM-MIB
A description of the power module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28478','20','1.3.6.1.4.1.2.3.51.3.1.3.2.1.10.{#SNMPINDEX}','10258','{#FAN_DESCR}: Fan status','sensor.fan.status[fanHealthStatus.{#SNMPINDEX}]','3m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IMM-MIB
A description of the fan component status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28479','20','1.3.6.1.4.1.2.3.51.3.1.3.2.1.3.{#SNMPINDEX}','10258','{#FAN_DESCR}: Fan speed, %','sensor.fan.speed.percentage[fanSpeed.{#SNMPINDEX}]','1m','90d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IMM-MIB
Fan speed expressed in percent(%) of maximum RPM.
An octet string expressed as ''ddd% of maximum'' where:d is a decimal digit or blank space for a leading zero.
If the fan is determined not to be running or the fan speed cannot be determined, the string will indicate ''Offline''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28480','20','1.3.6.1.4.1.2.3.51.3.1.12.2.1.3.{#SNMPINDEX}','10258','{#SNMPINDEX}: Physical disk status','system.hw.physicaldisk.status[diskHealthStatus.{#SNMPINDEX}]','3m','90d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IMM-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28481','20','1.3.6.1.4.1.2.3.51.3.1.12.2.1.2.{#SNMPINDEX}','10258','{#SNMPINDEX}: Physical disk part number','system.hw.physicaldisk.part_number[diskFruName.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IMM-MIB
disk module FRU name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28493','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.21317.1.3.1.2,{#SENSOR_DESCR},1.3.6.1.4.1.21317.1.3.1.13]','10259','Temperature Discovery','tempDescr.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning ATEN-IPMI-MIB::sensorTable with filter: not connected temp sensors (Value = 0)','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28494','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.21317.1.3.1.2,{#SENSOR_DESCR},1.3.6.1.4.1.21317.1.3.1.13]','10259','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning ATEN-IPMI-MIB::sensorTable with filter: not connected FAN sensors (Value = 0)','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28495','20','1.3.6.1.4.1.21317.1.3.1.2.{#SNMPINDEX}','10259','{#SENSOR_DESCR}: Temperature','sensor.temp.value[sensorReading.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ATEN-IPMI-MIB
A textual string containing information about the interface.
This string should include the name of the manufacturer, the product name and the version of the interface hardware/software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28496','20','1.3.6.1.4.1.21317.1.3.1.2.{#SNMPINDEX}','10259','{#SENSOR_DESCR}: Fan speed, %','sensor.fan.speed.percentage[sensorReading.{#SNMPINDEX}]','1m','90d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ATEN-IPMI-MIB
A textual string containing information about the interface.
This string should include the name of the manufacturer, the product name and the version of the interface hardware/software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28511','16','','10260','Tomcat: Version','jmx["Catalina:type=Server",serverInfo]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','0',NULL,'The version of the Tomcat.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28533','5','','10047','Zabbix server: LLD queue','zabbix[lld_queue]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of values enqueued in the low-level discovery processing queue.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28535','5','','10047','Zabbix server: Utilization of LLD manager internal processes, in %','zabbix[process,lld manager,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time lld manager processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28537','5','','10047','Zabbix server: Utilization of LLD worker internal processes, in %','zabbix[process,lld worker,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time lld worker processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28539','5','','10261','Remote Zabbix server: Zabbix stats','zabbix[stats,{$ADDRESS},{$PORT}]','1m','0d','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Zabbix server statistics master item.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28540','5','','10261','Remote Zabbix server: Zabbix stats queue','zabbix[stats,{$ADDRESS},{$PORT},queue]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of monitored items in the queue which are delayed at least by 6 seconds','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28541','5','','10261','Remote Zabbix server: Zabbix stats queue over 10m','zabbix[stats,{$ADDRESS},{$PORT},queue,10m]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of monitored items in the queue which are delayed at least by 10 minutes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28585','5','','10262','Zabbix stats','zabbix[stats,{$ADDRESS},{$PORT}]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Zabbix proxy statistics master item.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28586','5','','10262','Zabbix stats queue','zabbix[stats,{$ADDRESS},{$PORT},queue]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28587','5','','10262','Zabbix stats queue over $5','zabbix[stats,{$ADDRESS},{$PORT},queue,10m]','10m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28617','5','','10048','Zabbix preprocessing queue','zabbix[preprocessing_queue]','1m','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of values enqueued in the preprocessing queue.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28618','5','','10048','Utilization of preprocessing manager internal processes, in %','zabbix[process,preprocessing manager,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28619','5','','10048','Utilization of preprocessing worker internal processes, in %','zabbix[process,preprocessing worker,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28671','0','','10263','PostgreSQL: Get connections sum','pgsql.connections.sum["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect all metrics from pg_stat_activity
https://www.postgresql.org/docs/current/monitoring-stats.html#PG-STAT-ACTIVITY-VIEW','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28672','0','','10263','PostgreSQL: Get locks','pgsql.locks["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect all metrics from pg_locks per database
https://www.postgresql.org/docs/current/explicit-locking.html#LOCKING-TABLES','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28673','0','','10263','Status: Ping time','pgsql.ping.time["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28674','0','','10263','Status: Ping','pgsql.ping["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28675','0','','10263','PostgreSQL: Get queries','pgsql.queries["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}","{$PG.QUERY_ETIME.MAX.WARN}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect all metrics by query execution time','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28676','0','','10263','Replication: standby count','pgsql.replication.count["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of standby servers','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28677','0','','10263','Replication: lag in seconds','pgsql.replication.lag.sec["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Replication lag with Master in seconds','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28678','0','','10263','Replication: recovery role','pgsql.replication.recovery_role["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','7d','365d','0','3','','','','',NULL,'76','','','0','','','','','0',NULL,'Replication role: 1 — recovery is still in progress (standby mode), 0 — master mode.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28679','0','','10263','Replication: status','pgsql.replication.status["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','7d','365d','0','3','','','','',NULL,'77','','','0','','','','','0',NULL,'Replication status: 0 — streaming is down, 1 — streaming is up, 2 — master mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28680','0','','10263','Status: Config hash','pgsql.config.hash["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','15m','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'PostgreSQL configuration hash','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28681','0','','10263','Status: Cache hit ratio %','pgsql.cache.hit["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Cache hit ratio','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28682','0','','10263','PostgreSQL: Get bgwriter','pgsql.bgwriter["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics about the background writer process''s activity','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28683','0','','10263','PostgreSQL: Get transactions','pgsql.transactions["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect metrics by transaction execution time','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28684','0','','10263','Status: Uptime','pgsql.uptime["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28685','0','','10263','Status: Version','pgsql.version["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'PostgreSQL version','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28686','0','','10263','PostgreSQL: Get WAL','pgsql.wal.stat["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','5m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Master item to collect WAL metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28687','0','','10263','PostgreSQL: Get dbstat','pgsql.dbstat["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect all metrics from pg_stat_database per database
https://www.postgresql.org/docs/current/monitoring-stats.html#PG-STAT-DATABASE-VIEW','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28711','0','','10263','Database discovery','pgsql.discovery.db["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28712','0','','10263','DB {#DBNAME}: Database size','pgsql.db.size["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{$PG.DB}","{#DBNAME}"]','15m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Database size','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28713','0','','10263','DB {#DBNAME}: Get frozen XID','pgsql.frozenxid["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{#DBNAME}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28714','0','','10263','DB {#DBNAME}: Get scans','pgsql.scans["{$PG.HOST}","{$PG.PORT}","{$PG.USER}","{#DBNAME}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of scans done for table/index in the database','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28743','0','','10264','Apache: Service ping','net.tcp.service[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28744','0','','10264','Apache: Memory usage (vsize)','proc.mem["{$APACHE.PROCESS_NAME}",,,,vsize]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Virtual memory size used by process in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28745','0','','10264','Apache: Memory usage (rss)','proc.mem["{$APACHE.PROCESS_NAME}",,,,rss]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Resident set size memory used by process in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28746','0','','10264','Apache: Number of processes running','proc.num["{$APACHE.PROCESS_NAME}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28747','0','','10264','Apache: CPU utilization','proc.cpu.util["{$APACHE.PROCESS_NAME}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Process CPU utilization percentage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28748','0','','10264','Apache: Service response time','net.tcp.service.perf[http,"{$APACHE.STATUS.HOST}","{$APACHE.STATUS.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28775','19','','10265','Apache: Get status','apache.get_status','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Getting data from a machine-readable version of the Apache status page.
https://httpd.apache.org/docs/current/mod/mod_status.html','0','30d','0','',NULL,'3s','{$APACHE.STATUS.SCHEME}://{HOST.CONN}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}','','','200','1','0','','2','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28776','3','','10265','Apache: Service ping','net.tcp.service[http,"{HOST.CONN}","{$APACHE.STATUS.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28777','3','','10265','Apache: Service response time','net.tcp.service.perf[http,"{HOST.CONN}","{$APACHE.STATUS.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28804','0','','10266','Nginx: Get stub status page','web.page.get["{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PATH}","{$NGINX.STUB_STATUS.PORT}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The following status information is provided:
Active connections - the current number of active client connections including Waiting connections.
Accepts - the total number of accepted client connections.
Handled - the total number of handled connections. Generally, the parameter value is the same as accepts unless some resource limits have been reached (for example, the worker_connections limit).
Requests - the total number of client requests.
Reading - the current number of connections where nginx is reading the request header.
Writing - the current number of connections where nginx is writing the response back to the client.
Waiting - the current number of idle client connections waiting for a request.
https://nginx.org/en/docs/http/ngx_http_stub_status_module.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28805','0','','10266','Nginx: Service response time','net.tcp.service.perf[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28806','0','','10266','Nginx: CPU utilization','proc.cpu.util[nginx]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Process CPU utilization percentage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28807','0','','10266','Nginx: Memory usage (rss)','proc.mem[nginx,,,,rss]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Resident set size memory used by process in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28808','0','','10266','Nginx: Memory usage (vsize)','proc.mem[nginx,,,,vsize]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Virtual memory size used by process in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28809','0','','10266','Nginx: Number of processes running','proc.num[nginx]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of the Nginx processes running.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28810','0','','10266','Nginx: Service status','net.tcp.service[http,"{$NGINX.STUB_STATUS.HOST}","{$NGINX.STUB_STATUS.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28821','19','','10267','Nginx: Get stub status page','nginx.get_stub_status','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The following status information is provided:
Active connections - the current number of active client connections including Waiting connections.
Accepts - the total number of accepted client connections.
Handled - the total number of handled connections. Generally, the parameter value is the same as accepts unless some resource limits have been reached (for example, the worker_connections limit).
Requests - the total number of client requests.
Reading - the current number of connections where nginx is reading the request header.
Writing - the current number of connections where nginx is writing the response back to the client.
Waiting - the current number of idle client connections waiting for a request.
https://nginx.org/en/docs/http/ngx_http_stub_status_module.html','0','30d','0','',NULL,'3s','{$NGINX.STUB_STATUS.SCHEME}://{HOST.CONN}:{$NGINX.STUB_STATUS.PORT}/{$NGINX.STUB_STATUS.PATH}','','','200','1','0','','2','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28822','3','','10267','Nginx: Service status','net.tcp.service[http,"{HOST.CONN}","{$NGINX.STUB_STATUS.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28823','3','','10267','Nginx: Service response time','net.tcp.service.perf[http,"{HOST.CONN}","{$NGINX.STUB_STATUS.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28894','20','1.3.6.1.4.1.2636.3.1.13.1.8.{#SNMPINDEX}','10231','{#SNMPVALUE}: CPU utilization','system.cpu.util[jnxOperatingCPU.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: JUNIPER-MIB
The CPU utilization in percentage of this subject. Zero if unavailable or inapplicable.
Reference: http://kb.juniper.net/library/CUSTOMERSERVICE/GLOBAL_JTAC/BK26199/SRX%20SNMP%20Monitoring%20Guide_v1.1.pdf','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28909','0','','10170','Info: MySQL version','mysql.version["{$MYSQL.HOST}","{$MYSQL.PORT}"]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28910','0','','10170','Availability: MySQL status','mysql.ping["{$MYSQL.HOST}","{$MYSQL.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28911','15','','10170','Performance: Buffer pool efficiency','mysql.buffer_pool_efficiency','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(mysql.innodb_buffer_pool_reads) / 
( last(mysql.innodb_buffer_pool_read_requests) + 
( last(mysql.innodb_buffer_pool_read_requests) = 0 ) ) * 100 * 
( last(mysql.innodb_buffer_pool_read_requests) > 0 )','','0','','','','','0',NULL,'The item shows how effectively the buffer pool is serving reads.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28912','15','','10170','Performance: Buffer pool utilization','mysql.buffer_pool_utilization','1m','7d','365d','0','0','','%','','',NULL,NULL,'( last(mysql.innodb_buffer_pool_pages_total) - 
last(mysql.innodb_buffer_pool_pages_free) ) / 
( last(mysql.innodb_buffer_pool_pages_total) + 
( last(mysql.innodb_buffer_pool_pages_total) = 0 ) ) * 100 *
( last(mysql.innodb_buffer_pool_pages_total) > 0 )','','0','','','','','0',NULL,'Ratio of used to total pages in the buffer pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28913','0','','10170','Availability: Get status variables','mysql.get_status_variables["{$MYSQL.HOST}","{$MYSQL.PORT}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The item gets server global status information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28948','0','','10170','Databases discovery','mysql.db.discovery["{$MYSQL.HOST}","{$MYSQL.PORT}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning databases in DBMS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28949','0','','10170','Replication discovery','mysql.replication.discovery["{$MYSQL.HOST}","{$MYSQL.PORT}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If ''show slave status'' returns Master_Host, "Replication: *" items are created.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28950','0','','10170','Info: Size of database {#DBNAME}','mysql.dbsize["{$MYSQL.HOST}","{$MYSQL.PORT}","{#DBNAME}"]','5m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28951','0','','10170','Replication: Slave status {#MASTERHOST}','mysql.slave_status["{$MYSQL.HOST}","{$MYSQL.PORT}","{#MASTERHOST}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The item gets status information on essential parameters of the slave threads.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28978','15','','10268','Memory utilization','vm.memory.util[snmp]','1m','7d','365d','0','0','','%','','',NULL,NULL,'(last("vm.memory.total[memTotalReal.0]")-(last("vm.memory.free[memAvailReal.0]")+last("vm.memory.buffers[memBuffer.0]")+last("vm.memory.cached[memCached.0]")))/last("vm.memory.total[memTotalReal.0]")*100','','0','','','','','0',NULL,'Please note that memory utilization is a rough estimate, since memory available is calculated as free+buffers+cached, which is not 100% accurate, but the best we can get using SNMP.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28979','20','1.3.6.1.4.1.2021.4.6.0','10268','Free memory','vm.memory.free[memAvailReal.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28980','20','1.3.6.1.4.1.2021.4.14.0','10268','Memory (buffers)','vm.memory.buffers[memBuffer.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB
Memory used by kernel buffers (Buffers in /proc/meminfo)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28981','20','1.3.6.1.4.1.2021.4.15.0','10268','Memory (cached)','vm.memory.cached[memCached.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB
Memory used by the page cache and slabs (Cached and Slab in /proc/meminfo)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28982','20','1.3.6.1.4.1.2021.4.5.0','10268','Total memory','vm.memory.total[memTotalReal.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB
Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28983','15','','10268','Available memory','vm.memory.available[snmp]','1m','7d','365d','0','3','','B','','',NULL,NULL,'last("vm.memory.free[memAvailReal.0]")+last("vm.memory.buffers[memBuffer.0]")+last("vm.memory.cached[memCached.0]")','','0','','','','','0',NULL,'Please note that memory utilization is a rough estimate, since memory available is calculated as free+buffers+cached, which is not 100% accurate, but the best we can get using SNMP.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28984','20','1.3.6.1.4.1.2021.4.3.0','10268','Total swap space','system.swap.total[memTotalSwap.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB
The total amount of swap space configured for this host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28985','20','1.3.6.1.4.1.2021.4.4.0','10268','Free swap space','system.swap.free[memAvailSwap.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB
The amount of swap space currently unused or available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28986','15','','10268','Free swap space in %','system.swap.pfree[snmp]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("system.swap.free[memAvailSwap.0]")/last("system.swap.total[memTotalSwap.0]")*100','','0','','','','','0',NULL,'The free space of swap volume/file in percent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28987','20','1.3.6.1.4.1.2021.10.1.3["index","1.3.6.1.4.1.2021.10.1.2", "Load-1"]','10270','Load average (1m avg)','system.cpu.load.avg1[laLoad.1]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28988','20','1.3.6.1.4.1.2021.10.1.3["index","1.3.6.1.4.1.2021.10.1.2", "Load-5"]','10270','Load average (5m avg)','system.cpu.load.avg5[laLoad.2]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28989','20','1.3.6.1.4.1.2021.10.1.3["index","1.3.6.1.4.1.2021.10.1.2", "Load-15"]','10270','Load average (15m avg)','system.cpu.load.avg15[laLoad.3]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28990','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.25.3.3.1.1]','10270','Number of CPUs','system.cpu.num[snmp]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: HOST-RESOURCES-MIB
Count the number of CPU cores by counting number of cores discovered in hrProcessorTable using LLD','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28991','20','1.3.6.1.4.1.2021.11.59.0','10270','Interrupts per second','system.cpu.intr[ssRawInterrupts.0]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28992','20','1.3.6.1.4.1.2021.11.60.0','10270','Context switches per second','system.cpu.switches[ssRawContexts.0]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29008','20','discovery[{#DEVNAME},1.3.6.1.4.1.2021.13.15.1.1.2]','10269','Block devices discovery','vfs.dev.discovery[snmp]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Block devices are discovered from UCD-DISKIO-MIB::diskIOTable (http://net-snmp.sourceforge.net/docs/mibs/ucdDiskIOMIB.html#diskIOTable)','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29010','20','discovery[{#FSNAME},1.3.6.1.2.1.25.2.3.1.3,{#FSTYPE},1.3.6.1.2.1.25.2.3.1.2,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4]','10271','Mounted filesystem discovery','vfs.fs.discovery[snmp]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with storage filter','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29014','20','1.3.6.1.4.1.2021.13.15.1.1.5.{#SNMPINDEX}','10269','{#DEVNAME}: Disk read rate','vfs.dev.read.rate[diskIOReads.{#SNMPINDEX}]','1m','7d','365d','0','0','','!r/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-DISKIO-MIB
The number of read accesses from this device since boot.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29015','20','1.3.6.1.4.1.2021.13.15.1.1.6.{#SNMPINDEX}','10269','{#DEVNAME}: Disk write rate','vfs.dev.write.rate[diskIOWrites.{#SNMPINDEX}]','1m','7d','365d','0','0','','!w/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-DISKIO-MIB
The number of write accesses from this device since boot.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29016','20','1.3.6.1.4.1.2021.13.15.1.1.9.{#SNMPINDEX}','10269','{#DEVNAME}: Disk utilization','vfs.dev.util[diskIOLA1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-DISKIO-MIB
The 1 minute average load of disk (%)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29017','20','1.3.6.1.4.1.2021.11.53.0','10270','CPU idle time','system.cpu.idle[ssCpuRawIdle.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The time the CPU has spent doing nothing.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29018','20','1.3.6.1.4.1.2021.11.52.0','10270','CPU system time','system.cpu.system[ssCpuRawSystem.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The time the CPU has spent running the kernel and its processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29019','20','1.3.6.1.4.1.2021.11.50.0','10270','CPU user time','system.cpu.user[ssCpuRawUser.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The time the CPU has spent running users'' processes that are not niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29020','20','1.3.6.1.4.1.2021.11.64.0','10270','CPU steal time','system.cpu.steal[ssCpuRawSteal.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The amount of CPU ''stolen'' from this virtual machine by the hypervisor for other tasks (such as running another virtual machine).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29021','20','1.3.6.1.4.1.2021.11.61.0','10270','CPU softirq time','system.cpu.softirq[ssCpuRawSoftIRQ.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The amount of time the CPU has been servicing software interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29022','20','1.3.6.1.4.1.2021.11.51.0','10270','CPU nice time','system.cpu.nice[ssCpuRawNice.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The time the CPU has spent running users'' processes that have been niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29023','20','1.3.6.1.4.1.2021.11.54.0','10270','CPU iowait time','system.cpu.iowait[ssCpuRawWait.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
Amount of time the CPU has been waiting for I/O to complete.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29024','20','1.3.6.1.4.1.2021.11.56.0','10270','CPU interrupt time','system.cpu.interrupt[ssCpuRawInterrupt.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The amount of time the CPU has been servicing hardware interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29025','20','1.3.6.1.4.1.2021.11.65.0','10270','CPU guest time','system.cpu.guest[ssCpuRawGuest.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
Guest  time (time  spent  running  a  virtual  CPU  for  a  guest  operating  system)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29026','20','1.3.6.1.4.1.2021.11.66.0','10270','CPU guest nice time','system.cpu.guest_nice[ssCpuRawGuestNice.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
Time spent running a niced guest (virtual CPU for guest operating systems under the control of the Linux kernel)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29027','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10271','{#FSNAME}: Used space','vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29028','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10271','{#FSNAME}: Total space','vfs.fs.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in units of hrStorageAllocationUnits.
This object is writable to allow remote configuration of the size of the storage area in those cases where such an operation makes sense and is possible on the underlying system.
For example, the amount of main storage allocated to a buffer pool might be modified or the amount of disk space allocated to virtual storage might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29029','15','','10271','{#FSNAME}: Space utilization','vfs.fs.pused[storageUsedPercentage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'(last("vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]")/last("vfs.fs.total[hrStorageSize.{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29030','20','1.3.6.1.4.1.2021.9.1.10["index","1.3.6.1.4.1.2021.9.1.2", "{#FSNAME}"]','10271','{#FSNAME}: Free inodes in %','vfs.fs.inode.pfree[dskPercentNode.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
If having problems collecting this item make sure access to UCD-SNMP-MIB is allowed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29087','0','','10272','Number of CPUs','system.cpu.num','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29088','0','','10272','CPU iowait time','system.cpu.util[,iowait]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Amount of time the CPU has been waiting for I/O to complete.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29089','0','','10272','Context switches per second','system.cpu.switches','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29090','0','','10272','CPU guest nice time','system.cpu.util[,guest_nice]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Time spent running a niced guest (virtual CPU for guest operating systems under the control of the Linux kernel)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29091','0','','10272','CPU guest time','system.cpu.util[,guest]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Guest  time (time  spent  running  a  virtual  CPU  for  a  guest  operating  system)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29092','0','','10272','CPU softirq time','system.cpu.util[,softirq]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of time the CPU has been servicing software interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29093','0','','10272','CPU interrupt time','system.cpu.util[,interrupt]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of time the CPU has been servicing hardware interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29094','0','','10272','CPU steal time','system.cpu.util[,steal]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of CPU ''stolen'' from this virtual machine by the hypervisor for other tasks (such as running another virtual machine).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29095','0','','10272','CPU nice time','system.cpu.util[,nice]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that have been niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29096','0','','10272','Load average (1m avg)','system.cpu.load[all,avg1]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29097','0','','10272','CPU user time','system.cpu.util[,user]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that are not niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29098','0','','10272','CPU system time','system.cpu.util[,system]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running the kernel and its processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29099','0','','10272','CPU idle time','system.cpu.util[,idle]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent doing nothing.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29100','0','','10272','Load average (15m avg)','system.cpu.load[all,avg15]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29101','0','','10272','Load average (5m avg)','system.cpu.load[all,avg5]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29102','0','','10272','Interrupts per second','system.cpu.intr','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29103','0','','10274','Available memory in %','vm.memory.size[pavailable]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Available memory as percentage of total. See also: https://www.zabbix.com/documentation/5.0/manual/appendix/items/vm.memory.size_params','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29104','0','','10274','Total memory','vm.memory.size[total]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29105','0','','10274','Available memory','vm.memory.size[available]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Available memory, in Linux, available = free + buffers + cache. On other platforms calculation may vary. See also: https://www.zabbix.com/documentation/5.0/manual/appendix/items/vm.memory.size_params','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29106','0','','10274','Total swap space','system.swap.size[,total]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The total space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29107','0','','10274','Free swap space','system.swap.size[,free]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29108','0','','10274','Free swap space in %','system.swap.size[,pfree]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in percent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29110','0','','10277','System uptime','system.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'System uptime in ''N days, hh:mm:ss'' format.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29111','0','','10277','System boot time','system.boottime','15m','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29112','0','','10277','System local time','system.localtime','1m','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'System local time of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29113','0','','10277','System name','system.hostname','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29114','0','','10277','System description','system.uname','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The information as normally returned by ''uname -a''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29115','0','','10277','Number of logged in users','system.users.num','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of users who are currently logged in.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29116','0','','10277','Maximum number of open file descriptors','kernel.maxfiles','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29117','0','','10277','Maximum number of processes','kernel.maxproc','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29118','0','','10277','Number of processes','proc.num','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29119','0','','10277','Number of running processes','proc.num[,,run]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29120','0','','10277','Checksum of /etc/passwd','vfs.file.cksum[/etc/passwd]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29121','0','','10277','Operating system','system.sw.os','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29122','0','','10277','Operating system architecture','system.sw.arch','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Operating system architecture of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29123','0','','10277','Software installed','system.sw.packages','1h','2w','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29201','0','','10273','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29203','0','','10276','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of network interfaces.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29210','0','','10273','{#FSNAME}: Used space','vfs.fs.size[{#FSNAME},used]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Used storage in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29211','0','','10273','{#FSNAME}: Total space','vfs.fs.size[{#FSNAME},total]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total space in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29212','0','','10273','{#FSNAME}: Space utilization','vfs.fs.size[{#FSNAME},pused]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29213','0','','10273','{#FSNAME}: Free inodes in %','vfs.fs.inode[{#FSNAME},pfree]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29216','0','','10276','Interface {#IFNAME}: Bits received','net.if.in["{#IFNAME}"]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29217','0','','10276','Interface {#IFNAME}: Bits sent','net.if.out["{#IFNAME}"]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29218','0','','10276','Interface {#IFNAME}: Outbound packets with errors','net.if.out["{#IFNAME}",errors]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29219','0','','10276','Interface {#IFNAME}: Inbound packets with errors','net.if.in["{#IFNAME}",errors]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29220','0','','10276','Interface {#IFNAME}: Outbound packets discarded','net.if.out["{#IFNAME}",dropped]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29221','0','','10276','Interface {#IFNAME}: Inbound packets discarded','net.if.in["{#IFNAME}",dropped]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29222','0','','10276','Interface {#IFNAME}: Operational status','vfs.file.contents["/sys/class/net/{#IFNAME}/operstate"]','1m','7d','0','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'Indicates the interface RFC2863 operational state as a string.
Possible values are:"unknown", "notpresent", "down", "lowerlayerdown", "testing","dormant", "up".
Reference: https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-class-net','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29223','0','','10276','Interface {#IFNAME}: Interface type','vfs.file.contents["/sys/class/net/{#IFNAME}/type"]','1h','7d','0d','0','3','','','','',NULL,'78','','','0','','','','','2',NULL,'Indicates the interface protocol type as a decimal value.
See include/uapi/linux/if_arp.h for all possible values.
Reference: https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-class-net','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29273','7','','10278','Number of CPUs','system.cpu.num','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29274','7','','10278','CPU iowait time','system.cpu.util[,iowait]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Amount of time the CPU has been waiting for I/O to complete.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29275','7','','10278','Context switches per second','system.cpu.switches','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29276','7','','10278','CPU guest nice time','system.cpu.util[,guest_nice]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Time spent running a niced guest (virtual CPU for guest operating systems under the control of the Linux kernel)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29277','7','','10278','CPU guest time','system.cpu.util[,guest]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Guest  time (time  spent  running  a  virtual  CPU  for  a  guest  operating  system)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29278','7','','10278','CPU softirq time','system.cpu.util[,softirq]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of time the CPU has been servicing software interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29279','7','','10278','CPU interrupt time','system.cpu.util[,interrupt]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of time the CPU has been servicing hardware interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29280','7','','10278','CPU steal time','system.cpu.util[,steal]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of CPU ''stolen'' from this virtual machine by the hypervisor for other tasks (such as running another virtual machine).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29281','7','','10278','CPU nice time','system.cpu.util[,nice]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that have been niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29282','7','','10278','Load average (1m avg)','system.cpu.load[all,avg1]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29283','7','','10278','CPU user time','system.cpu.util[,user]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that are not niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29284','7','','10278','CPU system time','system.cpu.util[,system]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running the kernel and its processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29285','7','','10278','CPU idle time','system.cpu.util[,idle]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent doing nothing.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29286','7','','10278','Load average (15m avg)','system.cpu.load[all,avg15]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29287','7','','10278','Load average (5m avg)','system.cpu.load[all,avg5]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29288','7','','10278','Interrupts per second','system.cpu.intr','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29289','7','','10280','Available memory in %','vm.memory.size[pavailable]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Available memory as percentage of total. See also: https://www.zabbix.com/documentation/5.0/manual/appendix/items/vm.memory.size_params','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29290','7','','10280','Total memory','vm.memory.size[total]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29291','7','','10280','Available memory','vm.memory.size[available]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Available memory, in Linux, available = free + buffers + cache. On other platforms calculation may vary. See also: https://www.zabbix.com/documentation/5.0/manual/appendix/items/vm.memory.size_params','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29292','7','','10280','Total swap space','system.swap.size[,total]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The total space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29293','7','','10280','Free swap space','system.swap.size[,free]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29294','7','','10280','Free swap space in %','system.swap.size[,pfree]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in percent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29296','7','','10283','System uptime','system.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'System uptime in ''N days, hh:mm:ss'' format.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29297','7','','10283','System boot time','system.boottime','15m','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29298','0','','10283','System local time','system.localtime','1m','7d','365d','1','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'System local time of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29299','7','','10283','System name','system.hostname','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29300','7','','10283','System description','system.uname','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The information as normally returned by ''uname -a''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29301','7','','10283','Number of logged in users','system.users.num','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of users who are currently logged in.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29302','7','','10283','Maximum number of open file descriptors','kernel.maxfiles','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29303','7','','10283','Maximum number of processes','kernel.maxproc','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29304','7','','10283','Number of processes','proc.num','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29305','7','','10283','Number of running processes','proc.num[,,run]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29306','7','','10283','Checksum of /etc/passwd','vfs.file.cksum[/etc/passwd]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29307','7','','10283','Operating system','system.sw.os','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29308','7','','10283','Operating system architecture','system.sw.arch','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Operating system architecture of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29309','7','','10283','Software installed','system.sw.packages','1h','2w','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29349','7','','10279','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29351','7','','10282','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of network interfaces.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29355','7','','10279','{#FSNAME}: Used space','vfs.fs.size[{#FSNAME},used]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Used storage in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29356','7','','10279','{#FSNAME}: Total space','vfs.fs.size[{#FSNAME},total]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total space in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29357','7','','10279','{#FSNAME}: Space utilization','vfs.fs.size[{#FSNAME},pused]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29358','7','','10279','{#FSNAME}: Free inodes in %','vfs.fs.inode[{#FSNAME},pfree]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29361','7','','10282','Interface {#IFNAME}: Bits received','net.if.in["{#IFNAME}"]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29362','7','','10282','Interface {#IFNAME}: Bits sent','net.if.out["{#IFNAME}"]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29363','7','','10282','Interface {#IFNAME}: Outbound packets with errors','net.if.out["{#IFNAME}",errors]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29364','7','','10282','Interface {#IFNAME}: Inbound packets with errors','net.if.in["{#IFNAME}",errors]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29365','7','','10282','Interface {#IFNAME}: Outbound packets discarded','net.if.out["{#IFNAME}",dropped]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29366','7','','10282','Interface {#IFNAME}: Inbound packets discarded','net.if.in["{#IFNAME}",dropped]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29367','7','','10282','Interface {#IFNAME}: Operational status','vfs.file.contents["/sys/class/net/{#IFNAME}/operstate"]','1m','7d','0','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'Indicates the interface RFC2863 operational state as a string.
Possible values are:"unknown", "notpresent", "down", "lowerlayerdown", "testing","dormant", "up".
Reference: https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-class-net','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29368','7','','10282','Interface {#IFNAME}: Interface type','vfs.file.contents["/sys/class/net/{#IFNAME}/type"]','1h','7d','0d','0','3','','','','',NULL,'78','','','0','','','','','2',NULL,'Indicates the interface protocol type as a decimal value.
See include/uapi/linux/if_arp.h for all possible values.
Reference: https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-class-net','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29395','19','','10285','Get node_exporter metrics','node_exporter.get','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','http://{HOST.CONN}:{$NODE_EXPORTER_PORT}/metrics','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29396','15','','10285','Memory utilization','vm.memory.util[node_exporter]','1m','7d','365d','0','0','','%','','',NULL,NULL,'(last("vm.memory.total[node_exporter]")-last("vm.memory.available[node_exporter]"))/last("vm.memory.total[node_exporter]")*100','','0','','','','','0',NULL,'Memory used percentage is calculated as (total-available)/total*100','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29397','15','','10285','Free swap space in %','system.swap.pfree[node_exporter]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("system.swap.free[node_exporter]")/last("system.swap.total[node_exporter]")*100','','0','','','','','0',NULL,'The free space of swap volume/file in percent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29432','15','','10285','{#FSNAME}: Used space','vfs.fs.used[node_exporter,"{#FSNAME}"]','1m','7d','365d','0','0','','B','','',NULL,NULL,'(last("vfs.fs.total[node_exporter,\"{#FSNAME}\"]")-last("vfs.fs.free[node_exporter,\"{#FSNAME}\"]"))','','0','','','','','2',NULL,'Used storage in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29433','15','','10285','{#FSNAME}: Space utilization','vfs.fs.pused[node_exporter,"{#FSNAME}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'(last("vfs.fs.used[node_exporter,\"{#FSNAME}\"]")/last("vfs.fs.total[node_exporter,\"{#FSNAME}\"]"))*100','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29434','15','','10285','{#DEVNAME}: Disk read request avg waiting time (r_await)','vfs.dev.read.await[node_exporter,"{#DEVNAME}"]','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last("vfs.dev.read.time.rate[node_exporter,\"{#DEVNAME}\"]")/(last("vfs.dev.read.rate[node_exporter,\"{#DEVNAME}\"]")+(last("vfs.dev.read.rate[node_exporter,\"{#DEVNAME}\"]")=0)))*1000*(last("vfs.dev.read.rate[node_exporter,\"{#DEVNAME}\"]") > 0)','','0','','','','','2',NULL,'This formula contains two boolean expressions that evaluates to 1 or 0 in order to set calculated metric to zero and to avoid division by zero exception.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29435','15','','10285','{#DEVNAME}: Disk write request avg waiting time (w_await)','vfs.dev.write.await[node_exporter,"{#DEVNAME}"]','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last("vfs.dev.write.time.rate[node_exporter,\"{#DEVNAME}\"]")/(last("vfs.dev.write.rate[node_exporter,\"{#DEVNAME}\"]")+(last("vfs.dev.write.rate[node_exporter,\"{#DEVNAME}\"]")=0)))*1000*(last("vfs.dev.write.rate[node_exporter,\"{#DEVNAME}\"]") > 0)','','0','','','','','2',NULL,'This formula contains two boolean expressions that evaluates to 1 or 0 in order to set calculated metric to zero and to avoid division by zero exception.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29454','0','','10286','CPU utilization','system.cpu.util','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'CPU utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29455','0','','10286','CPU interrupt time','perf_counter_en["\Processor Information(_total)\% Interrupt Time"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The Processor Information\% Interrupt Time is the time the processor spends receiving and servicing 
hardware interrupts during sample intervals. This value is an indirect indicator of the activity of 
devices that generate interrupts, such as the system clock, the mouse, disk drivers, data communication 
lines, network interface cards and other peripheral devices. This is an easy way to identify a potential 
hardware failure. This should never be higher than 20%.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29456','0','','10286','Context switches per second','perf_counter_en["\System\Context Switches/sec"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Context Switches/sec is the combined rate at which all processors on the computer are switched from one thread to another.
Context switches occur when a running thread voluntarily relinquishes the processor, is preempted by a higher priority ready thread, or switches between user-mode and privileged (kernel) mode to use an Executive or subsystem service.
It is the sum of Thread\\Context Switches/sec for all threads running on all processors in the computer and is measured in numbers of switches.
There are context switch counters on the System and Thread objects. This counter displays the difference between the values observed in the last two samples, divided by the duration of the sample interval.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29457','0','','10286','CPU privileged time','perf_counter_en["\Processor Information(_total)\% Privileged Time"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The Processor Information\% Privileged Time counter shows the percent of time that the processor is spent 
executing in Kernel (or Privileged) mode. Privileged mode includes services interrupts inside Interrupt 
Service Routines (ISRs), executing Deferred Procedure Calls (DPCs), Device Driver calls and other kernel-mode 
functions of the Windows® Operating System.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29458','0','','10286','CPU user time','perf_counter_en["\Processor Information(_total)\% User Time"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The Processor Information\% User Time counter shows the percent of time that the processor(s) is spent executing 
in User mode.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29459','0','','10286','CPU queue length','perf_counter_en["\System\Processor Queue Length"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Processor Queue Length shows the number of threads that are observed as delayed in the processor Ready Queue 
and are waiting to be executed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29460','0','','10287','Used memory','vm.memory.size[used]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Used memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29461','0','','10287','Total memory','vm.memory.size[total]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29462','15','','10287','Memory utilization','vm.memory.util','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.size[used]") / last("vm.memory.size[total]") * 100','','0','','','','','0',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29463','0','','10287','Cache bytes','perf_counter_en["\Memory\Cache Bytes"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Cache Bytes is the sum of the Memory\\System Cache Resident Bytes, Memory\\System Driver Resident Bytes, 
Memory\\System Code Resident Bytes, and Memory\\Pool Paged Resident Bytes counters. This counter displays 
the last observed value only; it is not an average.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29466','0','','10287','Total swap space','system.swap.size[,total]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The total space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29467','0','','10287','Free system page table entries','perf_counter_en["\Memory\Free System Page Table Entries"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'This indicates the number of page table entries not currently in use by the system. If the number is less 
than 5,000, there may well be a memory leak or you running out of memory.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29468','0','','10287','Memory page faults per second','perf_counter_en["\Memory\Page Faults/sec"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Page Faults/sec is the average number of pages faulted per second. It is measured in number of pages 
faulted per second because only one page is faulted in each fault operation, hence this is also equal 
to the number of page fault operations. This counter includes both hard faults (those that require 
disk access) and soft faults (where the faulted page is found elsewhere in physical memory.) Most 
processors can handle large numbers of soft faults without significant consequence. However, hard faults, 
which require disk access, can cause significant delays.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29469','0','','10287','Memory pages per second','perf_counter_en["\Memory\Pages/sec"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'This measures the rate at which pages are read from or written to disk to resolve hard page faults. 
If the value is greater than 1,000, as a result of excessive paging, there may be a memory leak.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29470','0','','10287','Memory pool non-paged','perf_counter_en["\Memory\Pool Nonpaged Bytes"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'This measures the size, in bytes, of the non-paged pool. This is an area of system memory for objects 
that cannot be written to disk but instead must remain in physical memory as long as they are allocated. 
There is a possible memory leak if the value is greater than 175MB (or 100MB with the /3GB switch). 
A typical Event ID 2019 is recorded in the system event log.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29472','0','','10290','Uptime','system.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'System uptime in ''N days, hh:mm:ss'' format.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29473','0','','10290','System local time','system.localtime','1m','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'System local time of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29474','0','','10290','System name','system.hostname','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29475','0','','10290','System description','system.uname','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System description of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29476','0','','10290','Number of processes','proc.num[]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29477','0','','10290','Number of threads','perf_counter_en["\System\Threads"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of threads used by all running processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29478','0','','10290','Operating system architecture','system.sw.arch','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Operating system architecture of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29506','0','','10288','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29512','0','','10288','{#FSNAME}: Used space','vfs.fs.size[{#FSNAME},used]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Used storage in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29513','0','','10288','{#FSNAME}: Total space','vfs.fs.size[{#FSNAME},total]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total space in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29514','0','','10288','{#FSNAME}: Space utilization','vfs.fs.size[{#FSNAME},pused]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29544','5','','10050','Zabbix agent availability','zabbix[host,agent,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'Monitoring agent availability status','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29545','7','','10292','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29546','7','','10292','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29547','7','','10292','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','',NULL,'10','','','0','','','','','0',NULL,'The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29561','7','','10293','CPU utilization','system.cpu.util','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'CPU utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29562','7','','10293','CPU interrupt time','perf_counter_en["\Processor Information(_total)\% Interrupt Time"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The Processor Information\% Interrupt Time is the time the processor spends receiving and servicing 
hardware interrupts during sample intervals. This value is an indirect indicator of the activity of 
devices that generate interrupts, such as the system clock, the mouse, disk drivers, data communication 
lines, network interface cards and other peripheral devices. This is an easy way to identify a potential 
hardware failure. This should never be higher than 20%.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29563','7','','10293','Context switches per second','perf_counter_en["\System\Context Switches/sec"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Context Switches/sec is the combined rate at which all processors on the computer are switched from one thread to another.
Context switches occur when a running thread voluntarily relinquishes the processor, is preempted by a higher priority ready thread, or switches between user-mode and privileged (kernel) mode to use an Executive or subsystem service.
It is the sum of Thread\\Context Switches/sec for all threads running on all processors in the computer and is measured in numbers of switches.
There are context switch counters on the System and Thread objects. This counter displays the difference between the values observed in the last two samples, divided by the duration of the sample interval.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29564','7','','10293','CPU privileged time','perf_counter_en["\Processor Information(_total)\% Privileged Time"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The Processor Information\% Privileged Time counter shows the percent of time that the processor is spent 
executing in Kernel (or Privileged) mode. Privileged mode includes services interrupts inside Interrupt 
Service Routines (ISRs), executing Deferred Procedure Calls (DPCs), Device Driver calls and other kernel-mode 
functions of the Windows® Operating System.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29565','7','','10293','CPU user time','perf_counter_en["\Processor Information(_total)\% User Time"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The Processor Information\% User Time counter shows the percent of time that the processor(s) is spent executing 
in User mode.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29566','7','','10293','CPU queue length','perf_counter_en["\System\Processor Queue Length"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Processor Queue Length shows the number of threads that are observed as delayed in the processor Ready Queue 
and are waiting to be executed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29567','7','','10294','Used memory','vm.memory.size[used]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Used memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29568','7','','10294','Total memory','vm.memory.size[total]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29569','15','','10294','Memory utilization','vm.memory.util','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.size[used]") / last("vm.memory.size[total]") * 100','','0','','','','','0',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29570','7','','10294','Cache bytes','perf_counter_en["\Memory\Cache Bytes"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Cache Bytes is the sum of the Memory\\System Cache Resident Bytes, Memory\\System Driver Resident Bytes, 
Memory\\System Code Resident Bytes, and Memory\\Pool Paged Resident Bytes counters. This counter displays 
the last observed value only; it is not an average.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29573','7','','10294','Total swap space','system.swap.size[,total]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The total space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29574','7','','10294','Free system page table entries','perf_counter_en["\Memory\Free System Page Table Entries"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'This indicates the number of page table entries not currently in use by the system. If the number is less 
than 5,000, there may well be a memory leak or you running out of memory.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29575','7','','10294','Memory page faults per second','perf_counter_en["\Memory\Page Faults/sec"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Page Faults/sec is the average number of pages faulted per second. It is measured in number of pages 
faulted per second because only one page is faulted in each fault operation, hence this is also equal 
to the number of page fault operations. This counter includes both hard faults (those that require 
disk access) and soft faults (where the faulted page is found elsewhere in physical memory.) Most 
processors can handle large numbers of soft faults without significant consequence. However, hard faults, 
which require disk access, can cause significant delays.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29576','7','','10294','Memory pages per second','perf_counter_en["\Memory\Pages/sec"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'This measures the rate at which pages are read from or written to disk to resolve hard page faults. 
If the value is greater than 1,000, as a result of excessive paging, there may be a memory leak.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29577','7','','10294','Memory pool non-paged','perf_counter_en["\Memory\Pool Nonpaged Bytes"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'This measures the size, in bytes, of the non-paged pool. This is an area of system memory for objects 
that cannot be written to disk but instead must remain in physical memory as long as they are allocated. 
There is a possible memory leak if the value is greater than 175MB (or 100MB with the /3GB switch). 
A typical Event ID 2019 is recorded in the system event log.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29579','7','','10297','Uptime','system.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'System uptime in ''N days, hh:mm:ss'' format.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29580','0','','10297','System local time','system.localtime','1m','7d','365d','1','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'System local time of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29581','7','','10297','System name','system.hostname','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29582','7','','10297','System description','system.uname','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System description of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29583','7','','10297','Number of processes','proc.num[]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29584','7','','10297','Number of threads','perf_counter_en["\System\Threads"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of threads used by all running processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29585','7','','10297','Operating system architecture','system.sw.arch','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Operating system architecture of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29613','7','','10295','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29619','7','','10295','{#FSNAME}: Used space','vfs.fs.size[{#FSNAME},used]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Used storage in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29620','7','','10295','{#FSNAME}: Total space','vfs.fs.size[{#FSNAME},total]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total space in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29621','7','','10295','{#FSNAME}: Space utilization','vfs.fs.size[{#FSNAME},pused]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29653','0','','10301','RabbitMQ: Get node overview','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/overview"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The HTTP API endpoint that returns cluster-wide metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29654','0','','10301','RabbitMQ: Get nodes','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/nodes/{$RABBITMQ.CLUSTER.NAME}@{HOST.NAME}?memory=true"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The HTTP API endpoint that returns nodes metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29655','0','','10301','RabbitMQ: Service ping','net.tcp.service[http,"{$RABBITMQ.API.HOST}","{$RABBITMQ.API.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29656','0','','10301','RabbitMQ: CPU utilization','proc.cpu.util["{$RABBITMQ.PROCESS_NAME}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Process CPU utilization percentage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29657','0','','10301','RabbitMQ: Memory usage (vsize)','proc.mem["{$RABBITMQ.PROCESS_NAME}",,,,vsize]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Virtual memory size used by process in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29658','0','','10301','RabbitMQ: Memory usage (rss)','proc.mem["{$RABBITMQ.PROCESS_NAME}",,,,rss]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Resident set size memory used by process in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29659','0','','10301','RabbitMQ: Number of processes running','proc.num["{$RABBITMQ.PROCESS_NAME}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29660','0','','10301','RabbitMQ: Service response time','net.tcp.service.perf[http,"{$RABBITMQ.API.HOST}","{$RABBITMQ.API.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29661','0','','10301','RabbitMQ: Get queues','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/queues"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The HTTP API endpoint that returns queues metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29662','0','','10301','RabbitMQ: Healthcheck','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/healthchecks/node"]','1m','7h','365d','0','3','','','','',NULL,'82','','','0','','','','','0',NULL,'Runs basic healthchecks in the current node. Checks that the rabbit application is running, channels and queues can be listed successfully, and that no alarms are in effect.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29738','19','','10302','RabbitMQ: Get overview','rabbitmq.get_overview','1m','1h','0','0','4','','','','',NULL,NULL,'','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','0',NULL,'The HTTP API endpoint that returns cluster-wide metrics','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/overview','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29739','19','','10302','RabbitMQ: Get exchanges','rabbitmq.get_exchanges','1m','1h','0','0','4','','','','',NULL,NULL,'','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','0',NULL,'The HTTP API endpoint that returns exchanges metrics','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/exchanges','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29741','19','','10303','RabbitMQ: Get nodes','rabbitmq.get_nodes','1m','1h','0','0','4','','','','',NULL,NULL,'','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','0',NULL,'The HTTP API endpoint that returns nodes metrics','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/nodes/{$RABBITMQ.CLUSTER.NAME}@{HOST.NAME}?memory=true','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29742','3','','10303','RabbitMQ: Service ping','net.tcp.service[http,"{HOST.CONN}","{$RABBITMQ.API.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29743','3','','10303','RabbitMQ: Service response time','net.tcp.service.perf[http,"{HOST.CONN}","{$RABBITMQ.API.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29744','19','','10303','RabbitMQ: Healthcheck','rabbitmq.healthcheck','1m','7h','365d','0','3','','','','',NULL,'82','','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','0',NULL,'Runs basic healthchecks in the current node. Checks that the rabbit application is running, channels and queues can be listed successfully, and that no alarms are in effect.','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/healthchecks/node','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29745','19','','10303','RabbitMQ: Get queues','rabbitmq.get_queues','1m','1h','0','0','4','','','','',NULL,NULL,'','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','0',NULL,'The HTTP API endpoint that returns queues metrics','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/queues','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29822','5','','10047','Zabbix server: Utilization of alert syncer internal processes, in %','zabbix[process,alert syncer,avg,busy]','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time alert syncer processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29844','20','1.3.6.1.2.1.1.3.0','10204','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29845','20','1.3.6.1.2.1.1.6.0','10204','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29846','20','1.3.6.1.2.1.1.4.0','10204','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29847','20','1.3.6.1.2.1.1.2.0','10204','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29848','20','1.3.6.1.2.1.1.1.0','10204','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29994','20','1.3.6.1.4.1.232.6.1.3.0','10256','Overall system health status','system.status[cpqHeMibCondition.0]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','0',NULL,'MIB: CPQHLTH-MIB
The overall condition. This object represents the overall status of the server information represented by this MIB.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29998','0','','10300','RabbitMQ: Get overview','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.CLUSTER_HOST}:{$RABBITMQ.API.PORT}/api/overview"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The HTTP API endpoint that returns cluster-wide metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29999','0','','10300','RabbitMQ: Get exchanges','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.CLUSTER_HOST}:{$RABBITMQ.API.PORT}/api/exchanges"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The HTTP API endpoint that returns exchanges metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30043','19','','10303','RabbitMQ: Get node overview','rabbitmq.get_node_overview','1m','1h','0','0','4','','','','',NULL,NULL,'','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','0',NULL,'The HTTP API endpoint that returns cluster-wide metrics','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/overview','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30057','20','discovery[{#SENSOR_LOCATION},1.3.6.1.4.1.9.9.719.1.9.44.1.2]','10304','Temperature Discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30058','20','discovery[{#SENSOR_LOCATION},1.3.6.1.4.1.9.9.719.1.41.2.1.2]','10304','Temperature CPU Discovery','temp.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30059','20','discovery[{#PSU_LOCATION},1.3.6.1.4.1.9.9.719.1.15.56.1.2]','10304','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30060','20','discovery[{#UNIT_LOCATION},1.3.6.1.4.1.9.9.719.1.9.35.1.2]','10304','Unit Discovery','unit.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30061','20','discovery[{#FAN_LOCATION},1.3.6.1.4.1.9.9.719.1.15.12.1.2]','10304','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30062','20','discovery[{#DISK_LOCATION},1.3.6.1.4.1.9.9.719.1.45.4.1.2]','10304','Physical Disk Discovery','physicalDisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of physical drive entries CISCO-UNIFIED-COMPUTING-STORAGE-MIB::cucsStorageLocalDiskTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30063','20','discovery[{#VDISK_LOCATION},1.3.6.1.4.1.9.9.719.1.45.8.1.2]','10304','Virtual Disk Discovery','virtualdisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CISCO-UNIFIED-COMPUTING-STORAGE-MIB::cucsStorageLocalLunTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30064','20','discovery[{#DISKARRAY_LOCATION},1.3.6.1.4.1.9.9.719.1.45.1.1.2]','10304','Array Controller Discovery','array.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CISCO-UNIFIED-COMPUTING-STORAGE-MIB::cucsStorageControllerTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30065','20','discovery[{#DISKARRAY_CACHE_LOCATION},1.3.6.1.4.1.9.9.719.1.45.11.1.2]','10304','Array Controller Cache Discovery','array.cache.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CISCO-UNIFIED-COMPUTING-STORAGE-MIB::cucsStorageControllerTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30066','20','1.3.6.1.4.1.9.9.719.1.9.44.1.4.{#SNMPINDEX}','10304','{#SENSOR_LOCATION}.Ambient: Temperature','sensor.temp.value[cucsComputeRackUnitMbTempStatsAmbientTemp.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Temperature readings of testpoint: {#SENSOR_LOCATION}.Ambient','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30067','20','1.3.6.1.4.1.9.9.719.1.9.44.1.8.{#SNMPINDEX}','10304','{#SENSOR_LOCATION}.Front: Temperature','sensor.temp.value[cucsComputeRackUnitMbTempStatsFrontTemp.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Cisco UCS compute:RackUnitMbTempStats:frontTemp managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30068','20','1.3.6.1.4.1.9.9.719.1.9.44.1.21.{#SNMPINDEX}','10304','{#SENSOR_LOCATION}.Rear: Temperature','sensor.temp.value[cucsComputeRackUnitMbTempStatsRearTemp.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Cisco UCS compute:RackUnitMbTempStats:rearTemp managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30069','20','1.3.6.1.4.1.9.9.719.1.9.44.1.13.{#SNMPINDEX}','10304','{#SENSOR_LOCATION}.IOH: Temperature','sensor.temp.value[cucsComputeRackUnitMbTempSltatsIoh1Temp.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Cisco UCS compute:RackUnitMbTempStats:ioh1Temp managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30070','20','1.3.6.1.4.1.9.9.719.1.41.2.1.10.{#SNMPINDEX}','10304','{#SENSOR_LOCATION}: Temperature','sensor.temp.value[cucsProcessorEnvStatsTemperature.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-PROCESSOR-MIB
Cisco UCS processor:EnvStats:temperature managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30071','20','1.3.6.1.4.1.9.9.719.1.15.56.1.7.{#SNMPINDEX}','10304','{#PSU_LOCATION}: Power supply status','sensor.psu.status[cucsEquipmentPsuOperState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'84','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-EQUIPMENT-MIB
Cisco UCS equipment:Psu:operState managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30072','20','1.3.6.1.4.1.9.9.719.1.9.35.1.42.{#SNMPINDEX}','10304','{#UNIT_LOCATION}: Overall system health status','system.status[cucsComputeRackUnitOperState.{#SNMPINDEX}]','30s','2w','0d','0','3','','','','',NULL,'85','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Cisco UCS compute:RackUnit:operState managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30073','20','1.3.6.1.4.1.9.9.719.1.9.35.1.32.{#SNMPINDEX}','10304','{#UNIT_LOCATION}: Hardware model name','system.hw.model[cucsComputeRackUnitModel.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Cisco UCS compute:RackUnit:model managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30074','20','1.3.6.1.4.1.9.9.719.1.9.35.1.47.{#SNMPINDEX}','10304','{#UNIT_LOCATION}: Hardware serial number','system.hw.serialnumber[cucsComputeRackUnitSerial.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Cisco UCS compute:RackUnit:serial managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30075','20','1.3.6.1.4.1.9.9.719.1.15.12.1.9.{#SNMPINDEX}','10304','{#FAN_LOCATION}: Fan status','sensor.fan.status[cucsEquipmentFanOperState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'84','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-EQUIPMENT-MIB
Cisco UCS equipment:Fan:operState managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30076','20','1.3.6.1.4.1.9.9.719.1.45.4.1.18.{#SNMPINDEX}','10304','{#DISK_LOCATION}: Physical disk status','system.hw.physicaldisk.status[cucsStorageLocalDiskDiskState.{#SNMPINDEX}]','3m','90d','0d','0','3','','','','',NULL,'86','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalDisk:diskState managed object property.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30077','20','1.3.6.1.4.1.9.9.719.1.45.4.1.12.{#SNMPINDEX}','10304','{#DISK_LOCATION}: Physical disk model name','system.hw.physicaldisk.model[cucsStorageLocalDiskSerial.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalDisk:serial managed object property. Actually returns part number code','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30078','20','1.3.6.1.4.1.9.9.719.1.45.4.1.7.{#SNMPINDEX}','10304','{#DISK_LOCATION}: Physical disk media type','system.hw.physicaldisk.media_type[cucsStorageLocalDiskModel.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalDisk:model managed object property. Actually returns ''HDD'' or ''SSD''','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30079','20','1.3.6.1.4.1.9.9.719.1.45.4.1.13.{#SNMPINDEX}','10304','{#DISK_LOCATION}: Disk size','system.hw.physicaldisk.size[cucsStorageLocalDiskSize.{#SNMPINDEX}]','1h','2w','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalDisk:size managed object property. In MB.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30080','20','1.3.6.1.4.1.9.9.719.1.45.8.1.10.{#SNMPINDEX}','10304','{#VDISK_LOCATION}: Status','system.hw.virtualdisk.status[cucsStorageLocalLunPresence.{#SNMPINDEX}]','3m','2w','365d','0','3','','','','',NULL,'88','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalLun:presence managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30081','20','1.3.6.1.4.1.9.9.719.1.45.8.1.14.{#SNMPINDEX}','10304','{#VDISK_LOCATION}: Layout type','system.hw.virtualdisk.layout[cucsStorageLocalLunType.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,'87','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalLun:type managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30082','20','1.3.6.1.4.1.9.9.719.1.45.8.1.13.{#SNMPINDEX}','10304','{#VDISK_LOCATION}: Disk size','system.hw.virtualdisk.size[cucsStorageLocalLunSize.{#SNMPINDEX}]','1h','2w','0d','0','3','','B','','',NULL,'87','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalLun:size managed object property in MB.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30083','20','1.3.6.1.4.1.9.9.719.1.45.1.1.6.{#SNMPINDEX}','10304','{#DISKARRAY_LOCATION}: Disk array controller status','system.hw.diskarray.status[cucsStorageControllerOperState.{#SNMPINDEX}]','1m','1w','0d','0','3','','','','',NULL,'84','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30084','20','1.3.6.1.4.1.9.9.719.1.45.1.1.5.{#SNMPINDEX}','10304','{#DISKARRAY_LOCATION}: Disk array controller model','system.hw.diskarray.model[cucsStorageControllerModel.{#SNMPINDEX}]','1d','90d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30085','20','1.3.6.1.4.1.9.9.719.1.45.11.1.9.{#SNMPINDEX}','10304','{#DISKARRAY_CACHE_LOCATION}: Disk array cache controller battery status','system.hw.diskarray.cache.battery.status[cucsStorageRaidBatteryOperability.{#SNMPINDEX}]','1m','1w','0d','0','3','','','','',NULL,'84','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30086','20','1.3.6.1.2.1.1.1.0','10207','Operating system','system.sw.os[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30087','20','1.3.6.1.4.1.6527.3.1.2.1.1.10.0','10207','Available memory','vm.memory.available[sgiKbMemoryAvailable.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TIMETRA-SYSTEM-MIB
The value of sgiKbMemoryAvailable indicates the amount of free memory, in kilobytes, in the overall system that is not allocated to memory pools, but is available in case a memory pool needs to grow.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30088','15','','10207','Total memory','vm.memory.total[snmp]','1m','7d','365d','0','3','','B','','',NULL,NULL,'last("vm.memory.available[sgiKbMemoryAvailable.0]")+last("vm.memory.used[sgiKbMemoryUsed.0]")','','0','','','','','0',NULL,'Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30089','15','','10207','Memory utilization','vm.memory.util[vm.memory.util.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.used[sgiKbMemoryUsed.0]")/(last("vm.memory.available[sgiKbMemoryAvailable.0]")+last("vm.memory.used[sgiKbMemoryUsed.0]"))*100','','0','','','','','0',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30090','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.6527.3.1.2.2.1.5.1.6]','10207','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30091','20','1.3.6.1.4.1.6527.3.1.2.2.1.5.1.6.{#SNMPINDEX}','10207','#{#SNMPINDEX}: Power supply status','sensor.psu.status[tmnxChassisPowerSupply1Status.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'23','','','0','','','','','2',NULL,'MIB: TIMETRA-SYSTEM-MIB
The overall status of an equipped power supply. 
For AC multiple powersupplies, this represents the overall status of the first power supplyin the tray (or shelf).
For any other type, this represents the overall status of the power supply.
If tmnxChassisPowerSupply1Status is''deviceStateOk'', then all monitored statuses are ''deviceStateOk''.
A value of ''deviceStateFailed'' represents a condition where at least one monitored status is in a failed state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30092','20','1.3.6.1.4.1.6527.3.1.2.2.1.5.1.7.{#SNMPINDEX}','10207','#{#SNMPINDEX}: Power supply status','sensor.psu.status[tmnxChassisPowerSupply2Status.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'23','','','0','','','','','2',NULL,'MIB: TIMETRA-SYSTEM-MIB
The overall status of an equipped power supply.
For AC multiple powersupplies, this represents the overall status of the second power supplyin the tray (or shelf).
For any other type, this field is unused and set to ''deviceNotEquipped''.
If tmnxChassisPowerSupply2Status is ''deviceStateOk'', then all monitored statuses are ''deviceStateOk''.
A value of ''deviceStateFailed'' represents a condition where at least one monitored status is in a failed state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30093','20','1.3.6.1.4.1.1588.2.1.1.1.26.6.0','10208','Memory utilization','vm.memory.util[swMemUsage.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SW-MIB
Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30094','20','1.3.6.1.4.1.1991.1.1.2.1.53.0','10209','Memory utilization','vm.memory.util[snAgGblDynMemUtil.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FOUNDRY-SN-AGENT-MIB
The system dynamic memory utilization, in unit of percentage.
Deprecated: Refer to snAgSystemDRAMUtil.
For NI platforms, refer to snAgentBrdMemoryUtil100thPercent','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30097','20','1.3.6.1.2.1.1.1.0','10216','Operating system','system.sw.os[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30101','15','','10212','{#SNMPVALUE}: Memory utilization','vm.memory.util[vm.memory.util.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.used[ciscoMemoryPoolUsed.{#SNMPINDEX}]")/(last("vm.memory.free[ciscoMemoryPoolFree.{#SNMPINDEX}]")+last("vm.memory.used[ciscoMemoryPoolUsed.{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30105','20','1.3.6.1.4.1.6027.3.10.1.2.9.1.5.{#SNMPINDEX}','10221','#{#SNMPINDEX}: Memory utilization','vm.memory.util[chStackUnitMemUsageUtil.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F10-S-SERIES-CHASSIS-MIB
Total memory usage in percentage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30106','20','1.3.6.1.4.1.171.10.97.2.1.1.2.0','10222','Operating system','system.sw.os[mySystemSwVersion.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: MY-SYSTEM-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30107','20','1.3.6.1.4.1.171.10.97.2.35.1.1.1.3.{#SNMPINDEX}','10222','{#SNMPINDEX}: Memory utilization','vm.memory.util[myMemoryPoolCurrentUtilization.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MY-MEMORY-MIB
This is the memory pool utilization currently.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30108','20','1.3.6.1.4.1.171.12.1.1.9.1.4.{#SNMPINDEX}','10223','#{#SNMPVALUE}: Memory utilization','vm.memory.util[agentDRAMutilization.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: DLINK-AGENT-MIB
The percentage of used DRAM memory of the total DRAM memory available.The value will be between 0%(idle) and 100%(very busy)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30109','20','1.3.6.1.4.1.1916.1.1.1.13.0','10224','Operating system','system.sw.os[extremePrimarySoftwareRev.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: EXTREME-SYSTEM-MIB
The software revision of the primary image stored in this device.
This string will have a zero length if the revision is unknown, invalid or not present.
This will also be reported in RMON2 probeSoftwareRev if this is the software image currently running in the device.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30110','20','1.3.6.1.4.1.1916.1.32.2.2.1.3.{#SNMPINDEX}','10224','#{#SNMPVALUE}: Available memory','vm.memory.available[extremeMemoryMonitorSystemFree.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: EXTREME-SOFTWARE-MONITOR-MIB
Total amount of free memory in Kbytes in the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30111','15','','10224','#{#SNMPVALUE}: Memory utilization','vm.memory.util[{#SNMPVALUE}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'(last("vm.memory.total[extremeMemoryMonitorSystemTotal.{#SNMPINDEX}]") - last("vm.memory.available[extremeMemoryMonitorSystemFree.{#SNMPINDEX}]")) / last("vm.memory.total[extremeMemoryMonitorSystemTotal.{#SNMPINDEX}]") * 100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30112','20','1.3.6.1.4.1.25506.2.6.1.1.1.1.8.{#SNMPINDEX}','10227','{#MODULE_NAME}: Memory utilization','vm.memory.util[hh3cEntityExtMemUsage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HH3C-ENTITY-EXT-MIB
The memory usage for the entity. This object indicates what
percent of memory are used.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30113','20','1.3.6.1.4.1.11.2.14.11.5.1.1.2.1.1.1.6.{#SNMPINDEX}','10250','#{#SNMPVALUE}: Available memory','vm.memory.available[hpLocalMemFreeBytes.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: NETSWITCH-MIB
The number of available (unallocated) bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30114','20','1.3.6.1.4.1.11.2.14.11.5.1.1.2.1.1.1.5.{#SNMPINDEX}','10250','#{#SNMPVALUE}: Total memory','vm.memory.total[hpLocalMemTotalBytes.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: NETSWITCH-MIB
The number of currently installed bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30115','15','','10250','#{#SNMPVALUE}: Memory utilization','vm.memory.util[snmp.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.used[hpLocalMemAllocBytes.{#SNMPINDEX}]")/last("vm.memory.total[hpLocalMemTotalBytes.{#SNMPINDEX}]")*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30116','20','1.3.6.1.4.1.2011.5.25.31.1.1.1.1.7.{#SNMPINDEX}','10229','{#ENT_NAME}: Memory utilization','vm.memory.util[hwEntityMemUsage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HUAWEI-ENTITY-EXTENT-MIB
The memory usage for the entity. This object indicates what percent of memory are used.
Reference: http://support.huawei.com/enterprise/KnowledgebaseReadAction.action?contentId=KB1000090234','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30117','20','1.3.6.1.2.1.1.1.0','10231','Operating system','system.sw.os[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30118','20','1.3.6.1.4.1.2636.3.1.13.1.11.{#SNMPINDEX}','10231','{#SNMPVALUE}: Memory utilization','vm.memory.util[jnxOperatingBuffer.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: JUNIPER-MIB
The buffer pool utilization in percentage of this subject.  Zero if unavailable or inapplicable.
Reference: http://kb.juniper.net/library/CUSTOMERSERVICE/GLOBAL_JTAC/BK26199/SRX%20SNMP%20Monitoring%20Guide_v1.1.pdf','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30119','20','1.3.6.1.4.1.14988.1.1.4.4.0','10233','Operating system','system.sw.os[mtxrLicVersion.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: MIKROTIK-MIB
Software version.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30120','15','','10233','Memory utilization','vm.memory.util[memoryUsedPercentage.Memory]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.used[hrStorageUsed.Memory]")/last("vm.memory.total[hrStorageSize.Memory]")*100','','0','','','','','0',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30121','20','1.3.6.1.4.1.4526.10.1.1.1.10.0','10234','Operating system','system.sw.os[agentInventoryOperatingSystem.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FASTPATH-SWITCHING-MIB
Operating System running on this unit','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30122','20','1.3.6.1.4.1.4526.10.1.1.5.1.0','10234','Available memory','vm.memory.available[agentSwitchCpuProcessMemFree.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FASTPATH-SWITCHING-MIB
The total memory freed for utilization.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30123','15','','10234','Memory utilization','vm.memory.util[memoryUsedPercentage.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'(last("vm.memory.total[agentSwitchCpuProcessMemAvailable.0]")-last("vm.memory.available[agentSwitchCpuProcessMemFree.0]"))/last("vm.memory.total[agentSwitchCpuProcessMemAvailable.0]")*100','','0','','','','','0',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30124','20','1.3.6.1.4.1.27514.100.1.11.9.0','10235','Temperature','sensor.temp.value[switchTemperature.0]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: QTECH-MIB
Temperature readings of testpoint: __RESOURCE__','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30125','20','1.3.6.1.4.1.27514.100.1.3.0','10235','Operating system','system.sw.os[sysSoftwareVersion.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: QTECH-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30126','15','','10235','Memory utilization','vm.memory.util[vm.memory.util.0]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.used[switchMemoryBusy.0]")/last("vm.memory.total[switchMemorySize.0]")*100','','0','','','','','0',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30127','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.27514.100.1.12.1.3]','10235','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30128','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.27514.100.1.7.1.5]','10235','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30129','20','1.3.6.1.4.1.27514.100.1.12.1.3.{#SNMPINDEX}','10235','{#SNMPINDEX}: Fan status','sensor.fan.status[sysFanStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'52','','','0','','','','','2',NULL,'MIB: QTECH-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30130','20','1.3.6.1.4.1.27514.100.1.7.1.5.{#SNMPINDEX}','10235','{#SNMPINDEX}: Power supply status','sensor.psu.status[sysPowerStatus.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'53','','','0','','','','','2',NULL,'MIB: QTECH-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30131','20','1.3.6.1.4.1.11863.6.4.1.2.1.1.2.{#SNMPINDEX}','10236','#{#SNMPVALUE}: Memory utilization','vm.memory.util[tpSysMonitorMemoryUtilization.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TPLINK-SYSMONITOR-MIB
Displays the memory utilization.
Reference: http://www.tp-link.com/faq-1330.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30132','20','1.3.6.1.4.1.10002.1.1.1.1.3.0','10237','Memory (buffers)','vm.memory.buffers[memBuffer.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FROGFOOT-RESOURCES-MIB
Memory used by kernel buffers (Buffers in /proc/meminfo)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30133','20','1.3.6.1.4.1.10002.1.1.1.1.4.0','10237','Memory (cached)','vm.memory.cached[memCache.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FROGFOOT-RESOURCES-MIB
Memory used by the page cache and slabs (Cached and Slab in /proc/meminfo)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30134','20','1.3.6.1.4.1.10002.1.1.1.1.2.0','10237','Free memory','vm.memory.free[memFree.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FROGFOOT-RESOURCES-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30135','20','1.3.6.1.4.1.10002.1.1.1.1.1.0','10237','Total memory','vm.memory.total[memTotal.0]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: FROGFOOT-RESOURCES-MIB
Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30136','15','','10237','Memory utilization','vm.memory.util[memoryUsedPercentage]','1m','7d','365d','0','0','','%','','',NULL,NULL,'(last("vm.memory.total[memTotal.0]")-(last("vm.memory.free[memFree.0]")+last("vm.memory.buffers[memBuffer.0]")+last("vm.memory.cached[memCache.0]")))/last("vm.memory.total[memTotal.0]")*100','','0','','','','','0',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30137','0','','10286','CPU DPC time','perf_counter_en["\Processor Information(_total)\% DPC Time"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Processor DPC time is the time that a single processor spent receiving and servicing deferred procedure 
calls (DPCs). DPCs are interrupts that run at a lower priority than standard interrupts. % DPC Time is a 
component of % Privileged Time because DPCs are executed in privileged mode. If a high % DPC Time is 
sustained, there may be a processor bottleneck or an application or hardware related issue that can 
significantly diminish overall system performance.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30139','7','','10293','CPU DPC time','perf_counter_en["\Processor Information(_total)\% DPC Time"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Processor DPC time is the time that a single processor spent receiving and servicing deferred procedure 
calls (DPCs). DPCs are interrupts that run at a lower priority than standard interrupts. % DPC Time is a 
component of % Privileged Time because DPCs are executed in privileged mode. If a high % DPC Time is 
sustained, there may be a processor bottleneck or an application or hardware related issue that can 
significantly diminish overall system performance.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30141','20','1.3.6.1.4.1.674.10892.5.1.3.6.0','10255','Operating system','system.sw.os[systemOSName]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the name of the operating system that the hostis running.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30142','20','discovery[{#CPU.UTIL},1.3.6.1.2.1.25.3.3.1.2]','10305','CPU utilization','system.cpu.util','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: HOST-RESOURCES-MIB
The average, over the last minute, of the percentage of time that processors was not idle.
Implementations may approximate this one minute smoothing period if necessary.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30147','20','discovery[{#MEMNAME},1.3.6.1.2.1.25.2.3.1.3,{#MEMTYPE},1.3.6.1.2.1.25.2.3.1.2,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4]','10306','Memory discovery','vm.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with memory filter','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30148','20','discovery[{#FSNAME},1.3.6.1.2.1.25.2.3.1.3,{#FSTYPE},1.3.6.1.2.1.25.2.3.1.2,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4]','10307','Storage discovery','vfs.fs.discovery[snmp]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with storage filter.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30157','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10306','{#MEMNAME}: Total memory','vm.memory.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in units of hrStorageAllocationUnits.
This object is writable to allow remote configuration of the size of the storage area in those cases where such an operation makes sense and is possible on the underlying system.
For example, the amount of main memory allocated to a buffer pool might be modified or the amount of disk space allocated to virtual memory might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30158','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10306','{#MEMNAME}: Used memory','vm.memory.used[hrStorageUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30159','15','','10306','{#MEMNAME}: Memory utilization','vm.memory.util[memoryUsedPercentage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.used[hrStorageUsed.{#SNMPINDEX}]")/last("vm.memory.total[hrStorageSize.{#SNMPINDEX}]")*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30160','15','','10307','{#FSNAME}: Space utilization','vfs.fs.pused[storageUsedPercentage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'(last("vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]")/last("vfs.fs.total[hrStorageSize.{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30161','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10307','{#FSNAME}: Total space','vfs.fs.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in units of hrStorageAllocationUnits.
This object is writable to allow remote configuration of the size of the storage area in those cases where such an operation makes sense and is possible on the underlying system.
For example, the amount of main storage allocated to a buffer pool might be modified or the amount of disk space allocated to virtual storage might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30162','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10307','{#FSNAME}: Used space','vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30187','0','','10308','HAProxy: Service response time','net.tcp.service.perf["{$HAPROXY.STATS.SCHEME}","{HOST.CONN}","{$HAPROXY.STATS.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30188','0','','10308','HAProxy: Service status','net.tcp.service["{$HAPROXY.STATS.SCHEME}","{HOST.CONN}","{$HAPROXY.STATS.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30189','0','','10308','HAProxy: Get stats','web.page.get["{$HAPROXY.STATS.SCHEME}://{HOST.CONN}:{$HAPROXY.STATS.PORT}/{$HAPROXY.STATS.PATH};csv"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'HAProxy Statistics Report in CSV format','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30190','0','','10308','HAProxy: Get stats page','web.page.get["{$HAPROXY.STATS.SCHEME}://{HOST.CONN}:{$HAPROXY.STATS.PORT}/{$HAPROXY.STATS.PATH}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'HAProxy Statistics Report HTML','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30230','19','','10309','HAProxy: Get stats','haproxy.get','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$HAPROXY.USERNAME}','{$HAPROXY.PASSWORD}','','','0',NULL,'HAProxy Statistics Report in CSV format','0','30d','0','',NULL,'3s','{$HAPROXY.STATS.SCHEME}://{HOST.CONN}:{$HAPROXY.STATS.PORT}/{$HAPROXY.STATS.PATH};csv','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30231','19','','10309','HAProxy: Get stats page','haproxy.get_html','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$HAPROXY.USERNAME}','{$HAPROXY.PASSWORD}','','','0',NULL,'HAProxy Statistics Report HTML','0','30d','0','',NULL,'3s','{$HAPROXY.STATS.SCHEME}://{HOST.CONN}:{$HAPROXY.STATS.PORT}/{$HAPROXY.STATS.PATH}','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30273','0','','10310','Redis: Ping','redis.ping["{$REDIS.CONN.URI}"]','1m','7h','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30274','0','','10310','Redis: Slowlog entries per second','redis.slowlog.count["{$REDIS.CONN.URI}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30275','0','','10310','Redis: Get config','redis.config["{$REDIS.CONN.URI}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30276','0','','10310','Redis: Get info','redis.info["{$REDIS.CONN.URI}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30337','0','','10310','Process metrics discovery','proc.num["{$REDIS.LLD.PROCESS_NAME}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Collect metrics by Zabbix agent if it exists','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30344','0','','10310','Redis: CPU utilization','proc.cpu.util["{$REDIS.PROCESS_NAME}{#SINGLETON}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Process CPU utilization percentage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30345','0','','10310','Redis: Memory usage (rss)','proc.mem["{$REDIS.PROCESS_NAME}{#SINGLETON}",,,,rss]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Resident set size memory used by process in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30346','0','','10310','Redis: Memory usage (vsize)','proc.mem["{$REDIS.PROCESS_NAME}{#SINGLETON}",,,,vsize]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Virtual memory size used by process in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30347','0','','10310','Redis: Number of processes running','proc.num["{$REDIS.PROCESS_NAME}{#SINGLETON}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30423','0','','10314','Windows services discovery','service.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of Windows services of different types as defined in template''s macros.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30425','0','','10314','State of service "{#SERVICE.NAME}" ({#SERVICE.DISPLAYNAME})','service.info["{#SERVICE.NAME}",state]','1m','7d','365d','0','3','','','','',NULL,'3','','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30427','7','','10315','Windows services discovery','service.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of Windows services of different types as defined in template''s macros.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30429','7','','10315','State of service "{#SERVICE.NAME}" ({#SERVICE.DISPLAYNAME})','service.info["{#SERVICE.NAME}",state]','1m','7d','365d','0','3','','','','',NULL,'3','','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30431','0','','10316','MySQL: Version','mysql.version["{$MYSQL.HOST}","{$MYSQL.PORT}"]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30432','0','','10316','MySQL: Status','mysql.ping["{$MYSQL.HOST}","{$MYSQL.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30433','0','','10316','MySQL: Get status variables','mysql.get_status_variables["{$MYSQL.HOST}","{$MYSQL.PORT}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The item gets server global status information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30434','15','','10316','MySQL: Buffer pool utilization','mysql.buffer_pool_utilization','1m','7d','365d','0','0','','%','','',NULL,NULL,'( last(mysql.innodb_buffer_pool_pages_total) - 
last(mysql.innodb_buffer_pool_pages_free) ) / 
( last(mysql.innodb_buffer_pool_pages_total) + 
( last(mysql.innodb_buffer_pool_pages_total) = 0 ) ) * 100 * 
( last(mysql.innodb_buffer_pool_pages_total) > 0 )','','0','','','','','0',NULL,'Ratio of used to total pages in the buffer pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30435','15','','10316','MySQL: Buffer pool efficiency','mysql.buffer_pool_efficiency','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(mysql.innodb_buffer_pool_reads) / 
( last(mysql.innodb_buffer_pool_read_requests) + 
( last(mysql.innodb_buffer_pool_read_requests) = 0 ) ) * 100 * 
( last(mysql.innodb_buffer_pool_read_requests) > 0 )','','0','','','','','0',NULL,'The item shows how effectively the buffer pool is serving reads.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30472','0','','10316','Database discovery','mysql.db.discovery["{$MYSQL.HOST}","{$MYSQL.PORT}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning databases in DBMS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30473','0','','10316','Replication discovery','mysql.replication.discovery["{$MYSQL.HOST}","{$MYSQL.PORT}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If "show slave status" returns Master_Host, "Replication: *" items are created.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30474','0','','10316','MySQL: Size of database {#DBNAME}','mysql.dbsize["{$MYSQL.HOST}","{$MYSQL.PORT}","{#DBNAME}"]','5m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30475','0','','10316','MySQL: Replication Slave status {#MASTERHOST}','mysql.slave_status["{$MYSQL.HOST}","{$MYSQL.PORT}","{#MASTERHOST}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The item gets status information on the essential parameters of the slave threads.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30479','11','','10317','MySQL: Get status variables','db.odbc.get[get_status_variables,"{$MYSQL.DSN}"]','1m','0','0','0','4','','','','',NULL,NULL,'show global status','','0','{$MYSQL.USER}','{$MYSQL.PASSWORD}','','','0',NULL,'The item gets server global status information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30480','11','','10317','MySQL: Version','db.odbc.select[version,"{$MYSQL.DSN}"]','15m','7d','0','0','1','','','','',NULL,NULL,'select version()','','0','{$MYSQL.USER}','{$MYSQL.PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30481','11','','10317','MySQL: Status','db.odbc.select[ping,"{$MYSQL.DSN}"]','1m','7d','365d','0','3','','','','',NULL,'1','select "1"','','0','{$MYSQL.USER}','{$MYSQL.PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30482','15','','10317','MySQL: Buffer pool efficiency','mysql.buffer_pool_efficiency','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(mysql.innodb_buffer_pool_reads) / 
( last(mysql.innodb_buffer_pool_read_requests) + 
( last(mysql.innodb_buffer_pool_read_requests) = 0 ) ) * 100 * 
( last(mysql.innodb_buffer_pool_read_requests) > 0 )','','0','','','','','0',NULL,'The item shows how effectively the buffer pool is serving reads.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30483','15','','10317','MySQL: Buffer pool utilization','mysql.buffer_pool_utilization','1m','7d','365d','0','0','','%','','',NULL,NULL,'( last(mysql.innodb_buffer_pool_pages_total) - 
last(mysql.innodb_buffer_pool_pages_free) ) / 
( last(mysql.innodb_buffer_pool_pages_total) + 
( last(mysql.innodb_buffer_pool_pages_total) = 0 ) ) * 100 * 
( last(mysql.innodb_buffer_pool_pages_total) > 0 )','','0','','','','','0',NULL,'Ratio of used to total pages in the buffer pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30520','11','','10317','Database discovery','db.odbc.discovery[databases,"{$MYSQL.DSN}"]','1h','90d','0','0','4','','','','',NULL,NULL,'show databases','','0','{$MYSQL.USER}','{$MYSQL.PASSWORD}','','','1',NULL,'Scanning databases in DBMS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30521','11','','10317','Replication discovery','db.odbc.discovery[replication,"{$MYSQL.DSN}"]','1h','90d','0','0','4','','','','',NULL,NULL,'show slave status','','0','{$MYSQL.USER}','{$MYSQL.PASSWORD}','','','1',NULL,'If "show slave status" returns Master_Host, "Replication: *" items are created.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30522','11','','10317','MySQL: Size of database {#DATABASE}','db.odbc.select[{#DATABASE}_size,"{$MYSQL.DSN}"]','5m','7d','365d','0','3','','B','','',NULL,NULL,'SELECT COALESCE(SUM(DATA_LENGTH + INDEX_LENGTH),0) FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA="{#DATABASE}"','','0','{$MYSQL.USER}','{$MYSQL.PASSWORD}','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30523','11','','10317','MySQL: Replication Slave status {#MASTER_HOST}','db.odbc.get["{#MASTER_HOST}","{$MYSQL.DSN}"]','1m','0','0','0','4','','','','',NULL,NULL,'show slave status','','0','{$MYSQL.USER}','{$MYSQL.PASSWORD}','','','2',NULL,'The item gets status information on the essential parameters of the slave threads.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30527','0','','10318','Docker: Get data_usage','docker.data_usage','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30528','0','','10318','Docker: Get containers','docker.containers','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30529','0','','10318','Docker: Get info','docker.info','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30530','0','','10318','Docker: Ping','docker.ping','1m','7h','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30531','0','','10318','Docker: Get images','docker.images','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30571','0','','10318','Containers discovery','docker.containers.discovery[false]','15m','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for containers metrics

Parameter:
true  - Returns all containers
false - Returns only running containers','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30572','0','','10318','Images discovery','docker.images.discovery','15m','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for images metrics','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30573','0','','10318','Container {#NAME}: Get stats','docker.container_stats["{#NAME}"]','1m','0','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Get container stats based on resource usage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30574','0','','10318','Container {#NAME}: Get info','docker.container_info["{#NAME}"]','1m','0','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Return low-level information about a container','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30611','0','','10319','Memcached: Ping','memcached.ping["{$MEMCACHED.CONN.URI}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30612','0','','10319','Memcached: Get status','memcached.stats["{$MEMCACHED.CONN.URI}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30637','0','','10320','MySQL: Version','mysql.version["{$MYSQL.DSN}","{$MYSQL.USER}","{$MYSQL.PASSWORD}"]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30638','0','','10320','MySQL: Status','mysql.ping["{$MYSQL.DSN}","{$MYSQL.USER}","{$MYSQL.PASSWORD}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30639','0','','10320','MySQL: Get status variables','mysql.get_status_variables["{$MYSQL.DSN}","{$MYSQL.USER}","{$MYSQL.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The item gets server global status information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30640','15','','10320','MySQL: Buffer pool utilization','mysql.buffer_pool_utilization','1m','7d','365d','0','0','','%','','',NULL,NULL,'( last(mysql.innodb_buffer_pool_pages_total) - 
last(mysql.innodb_buffer_pool_pages_free) ) / 
( last(mysql.innodb_buffer_pool_pages_total) + 
( last(mysql.innodb_buffer_pool_pages_total) = 0 ) ) * 100 * 
( last(mysql.innodb_buffer_pool_pages_total) > 0 )','','0','','','','','0',NULL,'Ratio of used to total pages in the buffer pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30641','15','','10320','MySQL: Buffer pool efficiency','mysql.buffer_pool_efficiency','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(mysql.innodb_buffer_pool_reads) / 
( last(mysql.innodb_buffer_pool_read_requests) + 
( last(mysql.innodb_buffer_pool_read_requests) = 0 ) ) * 100 * 
( last(mysql.innodb_buffer_pool_read_requests) > 0 )','','0','','','','','0',NULL,'The item shows how effectively the buffer pool is serving reads.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30678','0','','10320','Database discovery','mysql.db.discovery["{$MYSQL.DSN}","{$MYSQL.USER}","{$MYSQL.PASSWORD}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning databases in DBMS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30679','0','','10320','Replication discovery','mysql.replication.discovery["{$MYSQL.DSN}","{$MYSQL.USER}","{$MYSQL.PASSWORD}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If "show slave status" returns Master_Host, "Replication: *" items are created.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30680','0','','10320','MySQL: Size of database {#DATABASE}','mysql.db.size["{$MYSQL.DSN}","{$MYSQL.USER}","{$MYSQL.PASSWORD}","{#DATABASE}"]','5m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30681','0','','10320','MySQL: Replication Slave status {#MASTER_HOST}','mysql.replication.get_slave_status["{$MYSQL.DSN}","{$MYSQL.USER}","{$MYSQL.PASSWORD}","{#MASTER_HOST}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The item gets status information on the essential parameters of the slave threads.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30685','12','','10321','Get IPMI sensors','ipmi.get','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The master item that receives all sensors with values for LLD and dependent elements from BMC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30690','3','','10322','ES: Service status','net.tcp.service["{$ELASTICSEARCH.SCHEME}","{HOST.CONN}","{$ELASTICSEARCH.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'Checks if the service is running and accepting TCP connections.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30691','19','','10322','ES: Get cluster stats','es.cluster.get_stats','1m','0h','0','0','4','','','','',NULL,NULL,'','','1','{$ELASTICSEARCH.USERNAME}','{$ELASTICSEARCH.PASSWORD}','','','0',NULL,'Returns cluster statistics.','0','30d','0','',NULL,'15s','{$ELASTICSEARCH.SCHEME}://{HOST.CONN}:{$ELASTICSEARCH.PORT}/_cluster/stats','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30692','3','','10322','ES: Service response time','net.tcp.service.perf["{$ELASTICSEARCH.SCHEME}","{HOST.CONN}","{$ELASTICSEARCH.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Checks performance of the TCP service.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30693','19','','10322','ES: Get nodes stats','es.nodes.get_stats','1m','0h','0','0','4','','','','',NULL,NULL,'','','1','{$ELASTICSEARCH.USERNAME}','{$ELASTICSEARCH.PASSWORD}','','','0',NULL,'Returns cluster nodes statistics.','0','30d','0','',NULL,'30s','{$ELASTICSEARCH.SCHEME}://{HOST.CONN}:{$ELASTICSEARCH.PORT}/_nodes/stats','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30694','19','','10322','ES: Get cluster health','es.cluster.get_health','1m','0h','0','0','4','','','','',NULL,NULL,'','','1','{$ELASTICSEARCH.USERNAME}','{$ELASTICSEARCH.PASSWORD}','','','0',NULL,'Returns the health status of a cluster.','0','30d','0','',NULL,'15s','{$ELASTICSEARCH.SCHEME}://{HOST.CONN}:{$ELASTICSEARCH.PORT}/_cluster/health?timeout=5s','','','','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30713','19','','10322','Cluster nodes discovery','es.nodes.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','1','{$ELASTICSEARCH.USERNAME}','{$ELASTICSEARCH.PASSWORD}','','','1',NULL,'Discovery ES cluster nodes.','0','30d','0','',NULL,'15s','{$ELASTICSEARCH.SCHEME}://{HOST.CONN}:{$ELASTICSEARCH.PORT}/_nodes/_all/nodes','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30714','15','','10322','ES {#ES.NODE}: Query latency','es.node.indices.search.query_latency[{#ES.NODE}]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'change(es.node.indices.search.query_time_in_millis[{#ES.NODE}]) / 
( change(es.node.indices.search.query_total[{#ES.NODE}]) + (change(es.node.indices.search.query_total[{#ES.NODE}]) = 0) )','','0','','','','','2',NULL,'The average query latency calculated by sampling the total number of queries and the total elapsed time at regular intervals.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30715','15','','10322','ES {#ES.NODE}: Flush latency','es.node.indices.flush.latency[{#ES.NODE}]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'change(es.node.indices.flush.total_time_in_millis[{#ES.NODE}]) / ( change(es.node.indices.flush.total[{#ES.NODE}]) + (change(es.node.indices.flush.total[{#ES.NODE}]) = 0) )','','0','','','','','2',NULL,'The average flush latency calculated from the available flush.total and flush.total_time_in_millis metrics.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30716','15','','10322','ES {#ES.NODE}: Indexing latency','es.node.indices.indexing.index_latency[{#ES.NODE}]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'change(es.node.indices.indexing.index_time_in_millis[{#ES.NODE}]) / ( change(es.node.indices.indexing.index_total[{#ES.NODE}]) + (change(es.node.indices.indexing.index_total[{#ES.NODE}]) = 0) )','','0','','','','','2',NULL,'The average indexing latency calculated from the available index_total and index_time_in_millis metrics.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30717','15','','10322','ES {#ES.NODE}: Fetch latency','es.node.indices.search.fetch_latency[{#ES.NODE}]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'change(es.node.indices.search.fetch_time_in_millis[{#ES.NODE}]) / ( change(es.node.indices.search.fetch_total[{#ES.NODE}]) + (change(es.node.indices.search.fetch_total[{#ES.NODE}]) = 0) )','','0','','','','','2',NULL,'The average fetch latency calculated by sampling the total number of fetches and the total elapsed time at regular intervals.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30789','3','','10309','HAProxy: Service response time','net.tcp.service.perf["{$HAPROXY.STATS.SCHEME}","{HOST.CONN}","{$HAPROXY.STATS.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30790','3','','10309','HAProxy: Service status','net.tcp.service["{$HAPROXY.STATS.SCHEME}","{HOST.CONN}","{$HAPROXY.STATS.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30821','19','','10323','ClickHouse: Ping','clickhouse.ping','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','{$CLICKHOUSE.SCHEME}://{HOST.CONN}:{$CLICKHOUSE.PORT}/ping','','','','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30822','19','','10323','ClickHouse: Version','clickhouse.version','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of the server','0','30d','0','',NULL,'3s','{$CLICKHOUSE.SCHEME}://{HOST.CONN}:{$CLICKHOUSE.PORT}/','[{"query":"SELECT version()"}]','','200','1','0','X-ClickHouse-User: {$CLICKHOUSE.USER}
X-ClickHouse-Key: {$CLICKHOUSE.PASSWORD}','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30823','19','','10323','ClickHouse: Get replicas info','clickhouse.replicas','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','{$CLICKHOUSE.SCHEME}://{HOST.CONN}:{$CLICKHOUSE.PORT}/','[{"query":"SELECT database, table, is_readonly, is_session_expired, future_parts, parts_to_check, queue_size, inserts_in_queue, merges_in_queue, log_max_index, log_pointer, total_replicas, active_replicas, log_max_index - log_pointer as replica_lag FROM system.replicas format JSON"}]','','200','1','0','X-ClickHouse-User: {$CLICKHOUSE.USER}
X-ClickHouse-Key: {$CLICKHOUSE.PASSWORD}','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30824','19','','10323','ClickHouse: Get system.asynchronous_metrics','clickhouse.system.asynchronous_metrics','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get metrics that are calculated periodically in the background','0','30d','0','',NULL,'3s','{$CLICKHOUSE.SCHEME}://{HOST.CONN}:{$CLICKHOUSE.PORT}/','[{"query":"select metric, value from system.asynchronous_metrics format JSON"}]','','200','1','0','X-ClickHouse-User: {$CLICKHOUSE.USER}
X-ClickHouse-Key: {$CLICKHOUSE.PASSWORD}','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30825','19','','10323','ClickHouse: Get system.events','clickhouse.system.events','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get information about the number of events that have occurred in the system.','0','30d','0','',NULL,'3s','{$CLICKHOUSE.SCHEME}://{HOST.CONN}:{$CLICKHOUSE.PORT}/','[{"query":"select event, value from system.events format JSON"}]','','200','1','0','X-ClickHouse-User: {$CLICKHOUSE.USER}
X-ClickHouse-Key: {$CLICKHOUSE.PASSWORD}','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30826','19','','10323','ClickHouse: Get system.metrics','clickhouse.system.metrics','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get metrics which can be calculated instantly, or have a current value format JSONEachRow','0','30d','0','',NULL,'3s','{$CLICKHOUSE.SCHEME}://{HOST.CONN}:{$CLICKHOUSE.PORT}/','[{"query":"select metric, value from system.metrics format JSON"}]','','200','1','0','X-ClickHouse-User: {$CLICKHOUSE.USER}
X-ClickHouse-Key: {$CLICKHOUSE.PASSWORD}','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30827','19','','10323','ClickHouse: Longest currently running query time','clickhouse.process.elapsed','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Get longest running query.','0','30d','0','',NULL,'3s','{$CLICKHOUSE.SCHEME}://{HOST.CONN}:{$CLICKHOUSE.PORT}/','[{"query":"SELECT max(elapsed) FROM system.processes"}]','','200','1','0','X-ClickHouse-User: {$CLICKHOUSE.USER}
X-ClickHouse-Key: {$CLICKHOUSE.PASSWORD}','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30828','19','','10323','ClickHouse: Get tables info','clickhouse.tables','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','{$CLICKHOUSE.SCHEME}://{HOST.CONN}:{$CLICKHOUSE.PORT}/','[{"query":"select database, table, sum(bytes) as bytes, count() as parts, sum(rows) as rows from system.parts where active = 1 group by database, table format JSON"}]','','200','1','0','X-ClickHouse-User: {$CLICKHOUSE.USER}
X-ClickHouse-Key: {$CLICKHOUSE.PASSWORD}','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30829','19','','10323','ClickHouse: Get system.settings','clickhouse.system.settings','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get information about settings that are currently in use.','0','30d','0','',NULL,'3s','{$CLICKHOUSE.SCHEME}://{HOST.CONN}:{$CLICKHOUSE.PORT}/','[{"query":"select name, value from system.settings format JSON"}]','','200','1','0','X-ClickHouse-User: {$CLICKHOUSE.USER}
X-ClickHouse-Key: {$CLICKHOUSE.PASSWORD}','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30830','19','','10323','ClickHouse: Get dictionaries info','clickhouse.dictionaries','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','{$CLICKHOUSE.SCHEME}://{HOST.CONN}:{$CLICKHOUSE.PORT}/','[{"query":"SELECT * FROM system.dictionaries format JSON"}]','','200','1','0','X-ClickHouse-User: {$CLICKHOUSE.USER}
X-ClickHouse-Key: {$CLICKHOUSE.PASSWORD}','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30896','0','','10264','Apache: Get status','web.page.get["{$APACHE.STATUS.SCHEME}://{$APACHE.STATUS.HOST}:{$APACHE.STATUS.PORT}/{$APACHE.STATUS.PATH}"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Getting data from a machine-readable version of the Apache status page.
https://httpd.apache.org/docs/current/mod/mod_status.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30923','3','','10324','Etcd: Service''s TCP port state','net.tcp.service["{$ETCD.SCHEME}","{HOST.CONN}","{$ETCD.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30924','19','','10324','Etcd: Node health','etcd.health','1m','7d','365d','0','3','','','','',NULL,'96','','','1','{$ETCD.USER}','{$ETCD.PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'3s','{$ETCD.SCHEME}://{HOST.CONN}:{$ETCD.PORT}/health','','','','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30925','19','','10324','Etcd: Get node metrics','etcd.get_metrics','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$ETCD.USER}','{$ETCD.PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'3s','{$ETCD.SCHEME}://{HOST.CONN}:{$ETCD.PORT}/metrics','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30926','19','','10324','Etcd: Get version','etcd.get_version','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','{$ETCD.SCHEME}://{HOST.CONN}:{$ETCD.PORT}/version','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30968','3','','10325','IIS: {$IIS.PORT} port ping','net.tcp.service[{$IIS.SERVICE},,{$IIS.PORT}]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30969','0','','10325','IIS: Total connection attempts','perf_counter_en["\Web Service(_Total)\Total Connection Attempts (all instances)"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of connections to the Web or FTP service that have been attempted since service startup. The count is the total for all Web sites or FTP sites combined.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30970','0','','10325','IIS: Method POST requests per second','perf_counter_en["\Web Service(_Total)\Post Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of HTTP requests using POST method. Generally used for forms or gateway requests. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30971','0','','10325','IIS: Method PROPFIND requests per second','perf_counter_en["\Web Service(_Total)\Propfind Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the PROPFIND method made. Propfind requests retrieve property values on files and directories. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30972','0','','10325','IIS: Method PROPPATCH requests per second','perf_counter_en["\Web Service(_Total)\Proppatch Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the PROPPATCH method made. Proppatch requests set property values on files and directories. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30973','0','','10325','IIS: Method PUT requests per second','perf_counter_en["\Web Service(_Total)\Put Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the PUT method made. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30974','0','','10325','IIS: Method MS-SEARCH requests per second','perf_counter_en["\Web Service(_Total)\Search Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the MS-SEARCH method made. Search requests are used to query the server to find resources that match a set of conditions provided by the client. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30975','0','','10325','IIS: Uptime','perf_counter_en["\Web Service(_Total)\Service Uptime"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Service uptime in seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30976','0','','10325','IIS: Method Total requests per second','perf_counter_en["\Web Service(_Total)\Total Method Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of all HTTP requests received. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30977','0','','10325','IIS: Method OPTIONS requests per second','perf_counter_en["\Web Service(_Total)\Options Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the OPTIONS method made. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30978','0','','10325','IIS: Method TRACE requests per second','perf_counter_en["\Web Service(_Total)\Trace Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the TRACE method made. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30979','0','','10325','IIS: Method TRACE requests per second','perf_counter_en["\Web Service(_Total)\Unlock Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the UNLOCK method made. Unlock requests are used to remove locks from files. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30980','0','','10325','IIS: Files cache hits percentage','perf_counter_en["\Web Service Cache\File Cache Hits %"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The ratio of user-mode file cache hits to total cache requests (since service startup). Note: This value might be low if the Kernel URI cache hits percentage is high.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30981','0','','10325','IIS: File cache misses','perf_counter_en["\Web Service Cache\File Cache Misses"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of unsuccessful lookups in the user-mode file cache since service startup.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30982','0','','10325','IIS: URIs cache hits percentage','perf_counter_en["\Web Service Cache\URI Cache Hits %"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The ratio of user-mode URI Cache Hits to total cache requests (since service startup)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30983','0','','10325','IIS: URI cache misses','perf_counter_en["\Web Service Cache\URI Cache Misses"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of unsuccessful lookups in the user-mode URI cache since service startup.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30984','0','','10325','IIS: World Wide Web Publishing Service (W3SVC) state','service_state[W3SVC]','1m','7d','365d','0','3','','','','',NULL,'3','','','0','','','','','0',NULL,'The World Wide Web Publishing Service (W3SVC) provides web connectivity and administration of websites through the IIS snap-in. If the World Wide Web Publishing Service stops, the operating system cannot serve any form of web request. This service was dependent on "Windows Process Activation Service".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30985','0','','10325','IIS: Method Total Other requests per second','perf_counter_en["\Web Service(_Total)\Other Request Methods/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total Other Request Methods is the number of HTTP requests that are not OPTIONS, GET, HEAD, POST, PUT, DELETE, TRACE, MOVE, COPY, MKCOL, PROPFIND, PROPPATCH, SEARCH, LOCK or UNLOCK methods (since service startup). Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30986','0','','10325','IIS: Not Found errors per second','perf_counter_en["\Web Service(_Total)\Not Found Errors/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of errors due to requests that couldn''t be satisfied by the server because the requested document could not be found. These are generally reported to the client with HTTP error code 404. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30987','0','','10325','IIS: Anonymous users per second','perf_counter_en["\Web Service(_Total)\Anonymous Users/sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of requests from users over an anonymous connection per second. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30988','0','','10325','IIS: Current connections','perf_counter_en["\Web Service(_Total)\Current Connections"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of active connections.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30989','0','','10325','IIS: Bytes Received per second','perf_counter_en["\Web Service(_Total)\Bytes Received/sec", 60]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The average rate per minute at which data bytes are received by the service at the Application Layer. Does not include protocol headers or control bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30990','0','','10325','IIS: Bytes Sent per second','perf_counter_en["\Web Service(_Total)\Bytes Sent/sec", 60]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The average rate per minute at which data bytes are sent by the service.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30991','0','','10325','IIS: Bytes Total per second','perf_counter_en["\Web Service(_Total)\Bytes Total/Sec", 60]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The average rate per minute of total bytes/sec transferred by the Web service (sum of bytes sent/sec and bytes received/sec).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30992','0','','10325','IIS: Method CGI requests per second','perf_counter_en["\Web Service(_Total)\CGI Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of CGI requests that are simultaneously being processed by the Web service. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30993','0','','10325','IIS: Connection attempts per second','perf_counter_en["\Web Service(_Total)\Connection Attempts/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The average rate per minute that connections using the Web service are being attempted. The count is the average for all Web sites combined.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30994','0','','10325','IIS: Method COPY requests per second','perf_counter_en["\Web Service(_Total)\Copy Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests made using the COPY method. Copy requests are used for copying files and directories. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30995','0','','10325','IIS: Method DELETE requests per second','perf_counter_en["\Web Service(_Total)\Delete Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the DELETE method made. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30996','0','','10325','IIS: NonAnonymous users per second','perf_counter_en["\Web Service(_Total)\NonAnonymous Users/sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of requests from users over a non-anonymous connection per second. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30997','0','','10325','IIS: Method Method GET requests per second','perf_counter_en["\Web Service(_Total)\Get Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests made using the GET method. GET requests are generally used for basic file retrievals or image maps, though they can be used with forms. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30998','0','','10325','IIS: Method HEAD requests per second','perf_counter_en["\Web Service(_Total)\Head Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the HEAD method made. HEAD requests generally indicate a client is querying the state of a document they already have to see if it needs to be refreshed. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30999','0','','10325','IIS: Method ISAPI requests per second','perf_counter_en["\Web Service(_Total)\ISAPI Extension Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of ISAPI Extension requests that are simultaneously being processed by the Web service. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31000','0','','10325','IIS: Locked errors per second','perf_counter_en["\Web Service(_Total)\Locked Errors/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of errors due to requests that couldn''t be satisfied by the server because the requested document was locked. These are generally reported as an HTTP 423 error code to the client. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31001','0','','10325','IIS: Method LOCK requests per second','perf_counter_en["\Web Service(_Total)\Lock Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests made using the LOCK method. Lock requests are used to lock a file for one user so that only that user can modify the file. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31002','0','','10325','IIS: Method MKCOL requests per second','perf_counter_en["\Web Service(_Total)\Mkcol Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the MKCOL method made. Mkcol requests are used to create directories on the server. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31003','0','','10325','IIS: Method MOVE requests per second','perf_counter_en["\Web Service(_Total)\Move Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the MOVE method made. Move requests are used for moving files and directories. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31004','0','','10325','IIS: Windows Process Activation Service (WAS) state','service_state[WAS]','1m','7d','365d','0','3','','','','',NULL,'3','','','0','','','','','0',NULL,'Windows Process Activation Service (WAS) is a tool for managing worker processes that contain applications that host Windows Communication Foundation (WCF) services. Worker processes handle requests that are sent to a Web Server for specific application pools. Each application pool sets boundaries for the applications it contains.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31005','0','','10325','Application pools discovery','wmi.getall[root\webAdministration, select Name from ApplicationPool]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31006','0','','10325','IIS: AppPool {#APPPOOL} state','perf_counter_en["\APP_POOL_WAS({#APPPOOL})\Current Application Pool State"]','1m','7d','365d','0','3','','','','',NULL,'98','','','0','','','','','2',NULL,'The state of the application pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31007','0','','10325','IIS: {#APPPOOL} Uptime','perf_counter_en["\APP_POOL_WAS({#APPPOOL})\Current Application Pool Uptime"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The web application uptime period since the last restart.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31008','0','','10325','IIS: AppPool {#APPPOOL} recycles','perf_counter_en["\APP_POOL_WAS({#APPPOOL})\Total Application Pool Recycles"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of times the application pool has been recycled since Windows Process Activation Service (WAS) started.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31009','0','','10325','IIS: AppPool {#APPPOOL} current queue size','perf_counter_en["\HTTP Service Request Queues({#APPPOOL})\CurrentQueueSize"]','30s','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of requests in the queue.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31010','3','','10326','IIS: {$IIS.PORT} port ping','net.tcp.service[{$IIS.SERVICE},,{$IIS.PORT}]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31011','7','','10326','IIS: Total connection attempts','perf_counter_en["\Web Service(_Total)\Total Connection Attempts (all instances)"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of connections to the Web or FTP service that have been attempted since service startup. The count is the total for all Web sites or FTP sites combined.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31012','7','','10326','IIS: Method POST requests per second','perf_counter_en["\Web Service(_Total)\Post Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of HTTP requests using POST method. Generally used for forms or gateway requests. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31013','7','','10326','IIS: Method PROPFIND requests per second','perf_counter_en["\Web Service(_Total)\Propfind Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the PROPFIND method made. Propfind requests retrieve property values on files and directories. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31014','7','','10326','IIS: Method PROPPATCH requests per second','perf_counter_en["\Web Service(_Total)\Proppatch Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the PROPPATCH method made. Proppatch requests set property values on files and directories. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31015','7','','10326','IIS: Method PUT requests per second','perf_counter_en["\Web Service(_Total)\Put Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the PUT method made. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31016','7','','10326','IIS: Method MS-SEARCH requests per second','perf_counter_en["\Web Service(_Total)\Search Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the MS-SEARCH method made. Search requests are used to query the server to find resources that match a set of conditions provided by the client. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31017','7','','10326','IIS: Uptime','perf_counter_en["\Web Service(_Total)\Service Uptime"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Service uptime in seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31018','7','','10326','IIS: Method Total requests per second','perf_counter_en["\Web Service(_Total)\Total Method Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of all HTTP requests received. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31019','7','','10326','IIS: Method OPTIONS requests per second','perf_counter_en["\Web Service(_Total)\Options Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the OPTIONS method made. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31020','7','','10326','IIS: Method TRACE requests per second','perf_counter_en["\Web Service(_Total)\Trace Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the TRACE method made. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31021','7','','10326','IIS: Method TRACE requests per second','perf_counter_en["\Web Service(_Total)\Unlock Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the UNLOCK method made. Unlock requests are used to remove locks from files. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31022','7','','10326','IIS: Files cache hits percentage','perf_counter_en["\Web Service Cache\File Cache Hits %"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The ratio of user-mode file cache hits to total cache requests (since service startup). Note: This value might be low if the Kernel URI cache hits percentage is high.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31023','7','','10326','IIS: File cache misses','perf_counter_en["\Web Service Cache\File Cache Misses"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of unsuccessful lookups in the user-mode file cache since service startup.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31024','7','','10326','IIS: URIs cache hits percentage','perf_counter_en["\Web Service Cache\URI Cache Hits %"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The ratio of user-mode URI Cache Hits to total cache requests (since service startup)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31025','7','','10326','IIS: URI cache misses','perf_counter_en["\Web Service Cache\URI Cache Misses"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of unsuccessful lookups in the user-mode URI cache since service startup.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31026','7','','10326','IIS: World Wide Web Publishing Service (W3SVC) state','service_state[W3SVC]','1m','7d','365d','0','3','','','','',NULL,'3','','','0','','','','','0',NULL,'The World Wide Web Publishing Service (W3SVC) provides web connectivity and administration of websites through the IIS snap-in. If the World Wide Web Publishing Service stops, the operating system cannot serve any form of web request. This service was dependent on "Windows Process Activation Service".','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31027','7','','10326','IIS: Method Total Other requests per second','perf_counter_en["\Web Service(_Total)\Other Request Methods/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total Other Request Methods is the number of HTTP requests that are not OPTIONS, GET, HEAD, POST, PUT, DELETE, TRACE, MOVE, COPY, MKCOL, PROPFIND, PROPPATCH, SEARCH, LOCK or UNLOCK methods (since service startup). Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31028','7','','10326','IIS: Not Found errors per second','perf_counter_en["\Web Service(_Total)\Not Found Errors/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of errors due to requests that couldn''t be satisfied by the server because the requested document could not be found. These are generally reported to the client with HTTP error code 404. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31029','7','','10326','IIS: Anonymous users per second','perf_counter_en["\Web Service(_Total)\Anonymous Users/sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of requests from users over an anonymous connection per second. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31030','7','','10326','IIS: Current connections','perf_counter_en["\Web Service(_Total)\Current Connections"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of active connections.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31031','7','','10326','IIS: Bytes Received per second','perf_counter_en["\Web Service(_Total)\Bytes Received/sec", 60]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The average rate per minute at which data bytes are received by the service at the Application Layer. Does not include protocol headers or control bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31032','7','','10326','IIS: Bytes Sent per second','perf_counter_en["\Web Service(_Total)\Bytes Sent/sec", 60]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The average rate per minute at which data bytes are sent by the service.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31033','7','','10326','IIS: Bytes Total per second','perf_counter_en["\Web Service(_Total)\Bytes Total/Sec", 60]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The average rate per minute of total bytes/sec transferred by the Web service (sum of bytes sent/sec and bytes received/sec).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31034','7','','10326','IIS: Method CGI requests per second','perf_counter_en["\Web Service(_Total)\CGI Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of CGI requests that are simultaneously being processed by the Web service. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31035','7','','10326','IIS: Connection attempts per second','perf_counter_en["\Web Service(_Total)\Connection Attempts/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The average rate per minute that connections using the Web service are being attempted. The count is the average for all Web sites combined.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31036','7','','10326','IIS: Method COPY requests per second','perf_counter_en["\Web Service(_Total)\Copy Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests made using the COPY method. Copy requests are used for copying files and directories. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31037','7','','10326','IIS: Method DELETE requests per second','perf_counter_en["\Web Service(_Total)\Delete Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the DELETE method made. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31038','7','','10326','IIS: NonAnonymous users per second','perf_counter_en["\Web Service(_Total)\NonAnonymous Users/sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of requests from users over a non-anonymous connection per second. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31039','7','','10326','IIS: Method Method GET requests per second','perf_counter_en["\Web Service(_Total)\Get Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests made using the GET method. GET requests are generally used for basic file retrievals or image maps, though they can be used with forms. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31040','7','','10326','IIS: Method HEAD requests per second','perf_counter_en["\Web Service(_Total)\Head Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the HEAD method made. HEAD requests generally indicate a client is querying the state of a document they already have to see if it needs to be refreshed. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31041','7','','10326','IIS: Method ISAPI requests per second','perf_counter_en["\Web Service(_Total)\ISAPI Extension Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of ISAPI Extension requests that are simultaneously being processed by the Web service. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31042','7','','10326','IIS: Locked errors per second','perf_counter_en["\Web Service(_Total)\Locked Errors/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of errors due to requests that couldn''t be satisfied by the server because the requested document was locked. These are generally reported as an HTTP 423 error code to the client. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31043','7','','10326','IIS: Method LOCK requests per second','perf_counter_en["\Web Service(_Total)\Lock Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests made using the LOCK method. Lock requests are used to lock a file for one user so that only that user can modify the file. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31044','7','','10326','IIS: Method MKCOL requests per second','perf_counter_en["\Web Service(_Total)\Mkcol Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the MKCOL method made. Mkcol requests are used to create directories on the server. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31045','7','','10326','IIS: Method MOVE requests per second','perf_counter_en["\Web Service(_Total)\Move Requests/Sec", 60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The rate of HTTP requests using the MOVE method made. Move requests are used for moving files and directories. Average per minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31046','7','','10326','IIS: Windows Process Activation Service (WAS) state','service_state[WAS]','1m','7d','365d','0','3','','','','',NULL,'3','','','0','','','','','0',NULL,'Windows Process Activation Service (WAS) is a tool for managing worker processes that contain applications that host Windows Communication Foundation (WCF) services. Worker processes handle requests that are sent to a Web Server for specific application pools. Each application pool sets boundaries for the applications it contains.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31047','7','','10326','Application pools discovery','wmi.getall[root\webAdministration, select Name from ApplicationPool]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31048','7','','10326','IIS: AppPool {#APPPOOL} state','perf_counter_en["\APP_POOL_WAS({#APPPOOL})\Current Application Pool State"]','1m','7d','365d','0','3','','','','',NULL,'98','','','0','','','','','2',NULL,'The state of the application pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31049','7','','10326','IIS: {#APPPOOL} Uptime','perf_counter_en["\APP_POOL_WAS({#APPPOOL})\Current Application Pool Uptime"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The web application uptime period since the last restart.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31050','7','','10326','IIS: AppPool {#APPPOOL} recycles','perf_counter_en["\APP_POOL_WAS({#APPPOOL})\Total Application Pool Recycles"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of times the application pool has been recycled since Windows Process Activation Service (WAS) started.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31051','7','','10326','IIS: AppPool {#APPPOOL} current queue size','perf_counter_en["\HTTP Service Request Queues({#APPPOOL})\CurrentQueueSize"]','30s','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of requests in the queue.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31054','3','','10323','ClickHouse: Check port availability','net.tcp.service[{$CLICKHOUSE.SCHEME},"{HOST.CONN}","{$CLICKHOUSE.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31055','11','','10327','MSSQL: Get performance counters','db.odbc.get[get_status_variables,"{$MSSQL.DSN}"]','0;m0-59','0','0','0','4','','','','',NULL,NULL,'SELECT object_name,counter_name,instance_name,cntr_value
FROM sys.dm_os_performance_counters
UNION
SELECT ''{$MSSQL.INSTANCE}'' as object_name,''Version'' as counter_name,@@version as instance_name,0 as cntr_value
UNION
SELECT ''{$MSSQL.INSTANCE}'' as object_name,''Uptime'' as counter_name,'''' as instance_name,DATEDIFF(second,sqlserver_start_time,GETDATE()) as cntr_value
FROM sys.dm_os_sys_info
UNION
SELECT ''{$MSSQL.INSTANCE}:Databases'' as object_name,''State'' as counter_name,name as instance_name,state as cntr_value
FROM sys.databases
UNION
SELECT a.object_name,''BufferCacheHitRatio'' as counter_name,'''' as instance_name,cast(a.cntr_value*100.0/b.cntr_value as dec(3,0)) as cntr_value
FROM sys.dm_os_performance_counters a
JOIN (SELECT cntr_value,OBJECT_NAME
FROM sys.dm_os_performance_counters
WHERE counter_name=''Buffer cache hit ratio base'' AND OBJECT_NAME=''{$MSSQL.INSTANCE}:Buffer Manager'') b
ON a.OBJECT_NAME=b.OBJECT_NAME
WHERE a.counter_name=''Buffer cache hit ratio'' AND a.OBJECT_NAME=''{$MSSQL.INSTANCE}:Buffer Manager''
UNION
SELECT a.object_name,''WorktablesFromCacheRatio'' as counter_name,'''' as instance_name,cast(a.cntr_value*100.0/b.cntr_value as dec(3,0)) as cntr_value
FROM sys.dm_os_performance_counters a
JOIN (SELECT cntr_value,OBJECT_NAME
FROM sys.dm_os_performance_counters
WHERE counter_name=''Worktables From Cache Base'' AND OBJECT_NAME=''{$MSSQL.INSTANCE}:Access Methods'') b
ON a.OBJECT_NAME=b.OBJECT_NAME
WHERE a.counter_name=''Worktables From Cache Ratio'' AND a.OBJECT_NAME=''{$MSSQL.INSTANCE}:Access Methods''
UNION
SELECT a.object_name,''CacheHitRatio'' as counter_name,''_Total'' as instance_name,cast(a.cntr_value*100.0/b.cntr_value as dec(3,0)) as cntr_value
FROM sys.dm_os_performance_counters a
JOIN (SELECT cntr_value,OBJECT_NAME
FROM sys.dm_os_performance_counters
WHERE counter_name=''Cache Hit Ratio base'' AND OBJECT_NAME=''{$MSSQL.INSTANCE}:Plan Cache'' AND instance_name=''_Total'') b
ON a.OBJECT_NAME=b.OBJECT_NAME
WHERE a.counter_name=''Cache Hit Ratio'' AND a.OBJECT_NAME=''{$MSSQL.INSTANCE}:Plan Cache'' AND instance_name=''_Total''','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','0',NULL,'The item gets server global status information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31056','15','','10327','MSSQL: Total average wait time','mssql.average_wait_time','0;m0-59s3','7d','365d','0','0','','ms','','',NULL,NULL,'(last(mssql.average_wait_time_raw) - prev(mssql.average_wait_time_raw)) /
(last(mssql.average_wait_time_base) - prev(mssql.average_wait_time_base) + 
(last(mssql.average_wait_time_base) - prev(mssql.average_wait_time_base)=0))','','0','','','','','0',NULL,'The average wait time, in milliseconds, for each lock request that had to wait.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31057','3','','10327','MSSQL: Service''s TCP port state','net.tcp.service[tcp,{HOST.CONN},{$MSSQL.PORT}]','30s','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'Test the availability of MS SQL Server on a TCP port.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31058','15','','10327','MSSQL: Average latch wait time','mssql.average_latch_wait_time','0;m0-59s3','7d','365d','0','0','','ms','','',NULL,NULL,'(last(mssql.average_latch_wait_time_raw) - prev(mssql.average_latch_wait_time_raw)) /
(last(mssql.average_latch_wait_time_base) - prev(mssql.average_latch_wait_time_base) + 
(last(mssql.average_latch_wait_time_base) - prev(mssql.average_latch_wait_time_base)=0))','','0','','','','','0',NULL,'Average latch wait time (in milliseconds) for latch requests that had to wait.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31122','11','','10327','Availability groups discovery','db.odbc.discovery[availability_groups,"{$MSSQL.DSN}"]','1h','90d','0','0','4','','','','',NULL,NULL,'SELECT name as group_name 
FROM sys.availability_groups','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','1',NULL,'Discovery of the existing availability groups.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31123','11','','10327','Database discovery','db.odbc.discovery[dbname,"{$MSSQL.DSN}"]','1h','90d','0','0','4','','','','',NULL,NULL,'SELECT name as dbname 
FROM sys.databases','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','1',NULL,'Scanning databases in DBMS.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31124','11','','10327','Local database discovery','db.odbc.discovery[local_db,"{$MSSQL.DSN}"]','1h','90d','0','0','4','','','','',NULL,NULL,'SELECT ag.name AS group_name, arcs.replica_server_name AS replica_name,
db_name(drs.database_id) AS dbname, drs.is_local
FROM sys.dm_hadr_database_replica_states drs JOIN sys.dm_hadr_availability_replica_cluster_states arcs
ON arcs.replica_id = drs.replica_id
JOIN sys.availability_groups ag ON ag.group_id = arcs.group_id
JOIN sys.dm_hadr_availability_replica_states ars ON ars.replica_id = arcs.replica_id
WHERE drs.is_local = 1','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','1',NULL,'Discovery of the local availability databases.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31125','11','','10327','Mirroring discovery','db.odbc.discovery[mirrors,"{$MSSQL.DSN}"]','1h','90d','0','0','4','','','','',NULL,NULL,'SELECT db_name(database_id) as dbname
FROM sys.database_mirroring
WHERE mirroring_state_desc IS NOT NULL','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','1',NULL,'To see the row for a database other than master or tempdb, you must
either be the database owner or have at least ALTER ANY DATABASE or VIEW ANY
DATABASE server-level permission or CREATE DATABASE permission in the master
database. To see non-NULL values on a mirror database, you must be a member
of the sysadmin fixed server role.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31126','11','','10327','Non-local database discovery','db.odbc.discovery[non-local_db,"{$MSSQL.DSN}"]','1h','90d','0','0','4','','','','',NULL,NULL,'SELECT ag.name AS group_name, arcs.replica_server_name AS replica_name,
db_name(drs.database_id) AS dbname, drs.is_local
FROM sys.dm_hadr_database_replica_states drs JOIN sys.dm_hadr_availability_replica_cluster_states arcs 
ON arcs.replica_id = drs.replica_id 
JOIN sys.availability_groups ag ON ag.group_id = arcs.group_id
JOIN sys.dm_hadr_availability_replica_states ars ON ars.replica_id = arcs.replica_id
WHERE drs.is_local = 0','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','1',NULL,'Discovery of the non-local (not local to the SQL Server instance) availability databases.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31127','11','','10327','Replication discovery','db.odbc.discovery[replicas,"{$MSSQL.DSN}"]','1h','90d','0','0','4','','','','',NULL,NULL,'SELECT ag.name as group_name, 
arcs.replica_server_name as replica_name
FROM sys.dm_hadr_availability_replica_cluster_states as arcs 
JOIN sys.availability_groups ag ON ag.group_id = arcs.group_id
JOIN sys.dm_hadr_availability_replica_states ars ON ars.replica_id = arcs.replica_id','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','1',NULL,'Discovery of the database replicas.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31128','11','','10327','MSSQL AG ''{#GROUP_NAME}'': Get replica states','db.odbc.get[{#GROUP_NAME}_replica_states,"{$MSSQL.DSN}"]','1m','0h','0','0','4','','','','',NULL,NULL,'SELECT ag.name as group_name,
ISNULL(ags.primary_recovery_health, 2) as primary_recovery_health,
ISNULL(ags.primary_replica, ''Unknown'') as primary_replica,
ISNULL(ags.secondary_recovery_health, 2) as secondary_recovery_health,
ags.synchronization_health as synchronization_health
FROM sys.dm_hadr_availability_group_states ags JOIN sys.availability_groups ag ON ag.group_id = ags.group_id','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','2',NULL,'Getting replica states - name, primary and secondary health, synchronization health.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31129','11','','10327','MSSQL AG ''{#GROUP_NAME}'' Local DB ''{#DBNAME}'': Get local DB states','db.odbc.get["{#GROUP_NAME}_{#DBNAME}_local_db.states","{$MSSQL.DSN}"]','1m','0h','0','0','4','','','','',NULL,NULL,'SELECT drs.database_state as database_state, 
drs.is_suspended as is_suspended, 
drs.synchronization_health as synchronization_health, 
ag.name as group_name,
arcs.replica_server_name as replica_name,
db_name(drs.database_id) as dbname
FROM sys.dm_hadr_database_replica_states drs 
JOIN sys.dm_hadr_availability_replica_cluster_states arcs ON arcs.replica_id = drs.replica_id 
JOIN sys.availability_groups ag ON ag.group_id = arcs.group_id 
JOIN sys.dm_hadr_availability_replica_states ars ON ars.replica_id = arcs.replica_id','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','2',NULL,'Getting the states of the local availability database.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31130','11','','10327','MSSQL Mirroring ''{#DBNAME}'': Get the mirror state','db.odbc.get["{#DBNAME}_mirroring_state","{$MSSQL.DSN}"]','1m','0h','0','0','4','','','','',NULL,NULL,'SELECT ISNULL(m.mirroring_role,0) as mirroring_role,
ISNULL(m.mirroring_role_sequence,0) as mirroring_role_sequence,
ISNULL(m.mirroring_state,7) as mirroring_state,
ISNULL(m.mirroring_witness_state,3) as mirroring_witness_state,
ISNULL(m.mirroring_safety_level,3) as mirroring_safety_level,
db_name(m.database_id) as dbname 
FROM sys.database_mirroring as m
WHERE m.mirroring_state_desc IS NOT NULL','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','2',NULL,'Getting mirrors state','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31132','11','','10327','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': Get the replica state','db.odbc.get["{#GROUP_NAME}_{#REPLICA_NAME}_replica.state","{$MSSQL.DSN}"]','1m','0h','0','0','4','','','','',NULL,NULL,'SELECT ars.connected_state as connected_state,
ars.is_local as is_local,
arcs.join_state as join_state,
ISNULL(ars.operational_state,6) as operational_state,
ISNULL(ars.recovery_health,2) as recovery_health,
ars.role as role,
ars.synchronization_health as synchronization_health,
ag.name as group_name, 
arcs.replica_server_name as replica_name
FROM sys.dm_hadr_availability_replica_cluster_states as arcs 
JOIN sys.availability_groups ag ON ag.group_id = arcs.group_id
JOIN sys.dm_hadr_availability_replica_states ars ON ars.replica_id = arcs.replica_id
WHERE ag.name = ''{#GROUP_NAME}'' AND arcs.replica_server_name = ''{#REPLICA_NAME}''','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','2',NULL,'Getting the database replica states.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31180','0','','10328','PostgreSQL: Get bgwriter','pgsql.bgwriter["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'https://www.postgresql.org/docs/12/monitoring-stats.html#PG-STAT-BGWRITER-VIEW','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31181','0','','10328','Replication: Lag in bytes','pgsql.replication.lag.b["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Replication lag with Master in byte.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31182','0','','10328','PostgreSQL: Get connections','pgsql.connections["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect all metrics from pg_stat_activity
https://www.postgresql.org/docs/current/monitoring-stats.html#PG-STAT-ACTIVITY-VIEW','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31183','0','','10328','PostgreSQL: Get dbstat sum','pgsql.dbstat.sum["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect all metrics from pg_stat_database per database
https://www.postgresql.org/docs/current/monitoring-stats.html#PG-STAT-DATABASE-VIEW','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31185','0','','10328','PostgreSQL: Get dbstat','pgsql.dbstat["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect all metrics from pg_stat_database per database
https://www.postgresql.org/docs/current/monitoring-stats.html#PG-STAT-DATABASE-VIEW','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31186','0','','10328','PostgreSQL: Get locks','pgsql.locks["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect all metrics from pg_locks per database
https://www.postgresql.org/docs/current/explicit-locking.html#LOCKING-TABLES','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31188','0','','10328','PostgreSQL: Ping','pgsql.ping["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31189','0','','10328','Replication: Standby count','pgsql.replication.count["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of standby servers','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31190','0','','10328','Replication: Lag in seconds','pgsql.replication.lag.sec["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Replication lag with Master in seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31191','0','','10328','Replication: Recovery role','pgsql.replication.recovery_role["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','7d','365d','0','3','','','','',NULL,'76','','','0','','','','','0',NULL,'Replication role: 1 — recovery is still in progress (standby mode), 0 — master mode.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31192','0','','10328','Replication: Status','pgsql.replication.status["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','7d','365d','0','3','','','','',NULL,'77','','','0','','','','','0',NULL,'Replication status: 0 — streaming is down, 1 — streaming is up, 2 — master mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31193','0','','10328','PostgreSQL: Uptime','pgsql.uptime["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31194','0','','10328','Autovacuum: Count of autovacuum workers','pgsql.autovacuum.count["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of autovacuum workers.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31195','0','','10328','PostgreSQL: Get archive','pgsql.archive["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect archive status metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31196','0','','10328','PostgreSQL: Get WAL','pgsql.wal.stat["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','5m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect WAL metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31240','0','','10328','Database discovery','pgsql.db.discovery["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31241','0','','10328','DB {#DBNAME}: Database age','pgsql.db.age["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}","{#DBNAME}"]','10m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Database age','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31242','0','','10328','DB {#DBNAME}: Database size','pgsql.db.size["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}","{#DBNAME}"]','5m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Database size','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31243','0','','10328','DB {#DBNAME}: Get bloating tables','pgsql.db.bloating_tables["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}","{#DBNAME}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bloating tables','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31273','0','','10275','Block devices discovery','vfs.dev.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31276','15','','10275','{#DEVNAME}: Disk read request avg waiting time (r_await)','vfs.dev.read.await[{#DEVNAME}]','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last("vfs.dev.read.time.rate[{#DEVNAME}]")/(last("vfs.dev.read.rate[{#DEVNAME}]")+(last("vfs.dev.read.rate[{#DEVNAME}]")=0)))*1000*(last("vfs.dev.read.rate[{#DEVNAME}]") > 0)','','0','','','','','2',NULL,'This formula contains two boolean expressions that evaluates to 1 or 0 in order to set calculated metric to zero and to avoid division by zero exception.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31277','15','','10275','{#DEVNAME}: Disk write request avg waiting time (w_await)','vfs.dev.write.await[{#DEVNAME}]','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last("vfs.dev.write.time.rate[{#DEVNAME}]")/(last("vfs.dev.write.rate[{#DEVNAME}]")+(last("vfs.dev.write.rate[{#DEVNAME}]")=0)))*1000*(last("vfs.dev.write.rate[{#DEVNAME}]") > 0)','','0','','','','','2',NULL,'This formula contains two boolean expressions that evaluates to 1 or 0 in order to set calculated metric to zero and to avoid division by zero exception.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31278','0','','10275','{#DEVNAME}: Get stats','vfs.file.contents[/sys/block/{#DEVNAME}/stat]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Get contents of /sys/block/{#DEVNAME}/stat for disk stats.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31305','7','','10281','Block devices discovery','vfs.dev.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31307','15','','10281','{#DEVNAME}: Disk read request avg waiting time (r_await)','vfs.dev.read.await[{#DEVNAME}]','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last("vfs.dev.read.time.rate[{#DEVNAME}]")/(last("vfs.dev.read.rate[{#DEVNAME}]")+(last("vfs.dev.read.rate[{#DEVNAME}]")=0)))*1000*(last("vfs.dev.read.rate[{#DEVNAME}]") > 0)','','0','','','','','2',NULL,'This formula contains two boolean expressions that evaluates to 1 or 0 in order to set calculated metric to zero and to avoid division by zero exception.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31308','15','','10281','{#DEVNAME}: Disk write request avg waiting time (w_await)','vfs.dev.write.await[{#DEVNAME}]','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last("vfs.dev.write.time.rate[{#DEVNAME}]")/(last("vfs.dev.write.rate[{#DEVNAME}]")+(last("vfs.dev.write.rate[{#DEVNAME}]")=0)))*1000*(last("vfs.dev.write.rate[{#DEVNAME}]") > 0)','','0','','','','','2',NULL,'This formula contains two boolean expressions that evaluates to 1 or 0 in order to set calculated metric to zero and to avoid division by zero exception.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31309','7','','10281','{#DEVNAME}: Get stats','vfs.file.contents[/sys/block/{#DEVNAME}/stat]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Get contents of /sys/block/{#DEVNAME}/stat for disk stats.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31325','0','','10286','Number of cores','wmi.get[root/cimv2,"Select NumberOfLogicalProcessors from Win32_ComputerSystem"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of logical processors available on the computer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31326','0','','10287','Used swap space in %','perf_counter_en["\Paging file(_Total)\% Usage"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The used space of swap volume/file in percent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31327','15','','10287','Free swap space','system.swap.free','1m','7d','365d','0','3','','B','','',NULL,NULL,'last("system.swap.size[,total]") - last("system.swap.size[,total]") / 100 * last("perf_counter_en[\"\Paging file(_Total)\% Usage\"]")','','0','','','','','0',NULL,'The free space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31333','0','','10289','Physical disks discovery','perf_instance_en.discovery[PhysicalDisk]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of installed physical disks.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31335','0','','10289','{#DEVNAME}: Disk utilization','perf_counter_en["\PhysicalDisk({#DEVNAME})\% Disk Time",60]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'This item is the percentage of elapsed time that the selected disk drive was busy servicing read or writes requests.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31336','0','','10289','{#DEVNAME}: Disk average queue size (avgqu-sz)','perf_counter_en["\PhysicalDisk({#DEVNAME})\Current Disk Queue Length",60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Current average disk queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31337','0','','10289','{#DEVNAME}: Disk read rate','perf_counter_en["\PhysicalDisk({#DEVNAME})\Disk Reads/sec",60]','1m','7d','365d','0','0','','!r/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of read operations on the disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31338','0','','10289','{#DEVNAME}: Disk write rate','perf_counter_en["\PhysicalDisk({#DEVNAME})\Disk Writes/sec",60]','1m','7d','365d','0','0','','!w/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of write operations on the disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31343','7','','10293','Number of cores','wmi.get[root/cimv2,"Select NumberOfLogicalProcessors from Win32_ComputerSystem"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of logical processors available on the computer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31344','7','','10294','Used swap space in %','perf_counter_en["\Paging file(_Total)\% Usage"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The used space of swap volume/file in percent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31345','15','','10294','Free swap space','system.swap.free','1m','7d','365d','0','3','','B','','',NULL,NULL,'last("system.swap.size[,total]") - last("system.swap.size[,total]") / 100 * last("perf_counter_en[\"\Paging file(_Total)\% Usage\"]")','','0','','','','','0',NULL,'The free space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31351','7','','10296','Physical disks discovery','perf_instance_en.discovery[PhysicalDisk]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of installed physical disks.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31353','7','','10296','{#DEVNAME}: Disk utilization','perf_counter_en["\PhysicalDisk({#DEVNAME})\% Disk Time",60]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'This item is the percentage of elapsed time that the selected disk drive was busy servicing read or writes requests.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31354','7','','10296','{#DEVNAME}: Disk average queue size (avgqu-sz)','perf_counter_en["\PhysicalDisk({#DEVNAME})\Current Disk Queue Length",60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Current average disk queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31355','7','','10296','{#DEVNAME}: Disk read rate','perf_counter_en["\PhysicalDisk({#DEVNAME})\Disk Reads/sec",60]','1m','7d','365d','0','0','','!r/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of read operations on the disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31356','7','','10296','{#DEVNAME}: Disk write rate','perf_counter_en["\PhysicalDisk({#DEVNAME})\Disk Writes/sec",60]','1m','7d','365d','0','0','','!w/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of write operations on the disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31499','16','','10169','ClassLoading: Loaded class count','jmx["java.lang:type=ClassLoading","LoadedClassCount"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays number of classes that are currently loaded in the Java virtual machine.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31500','16','','10169','MemoryPool: PS Perm Gen used','jmx["java.lang:type=MemoryPool,name=PS Perm Gen","Usage.used"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory usage','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31501','16','','10169','MemoryPool: Code Cache committed','jmx["java.lang:type=MemoryPool,name=Code Cache","Usage.committed"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory allocated','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31502','16','','10169','MemoryPool: CodeCache maximum size','jmx["java.lang:type=MemoryPool,name=Code Cache","Usage.max"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum amount of memory that can be used for memory management. This amount of memory is not guaranteed to be available if it is greater than the amount of committed memory. The Java virtual machine may fail to allocate memory even if the amount of used memory does not exceed this maximum size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31503','16','','10169','MemoryPool: Code Cache used','jmx["java.lang:type=MemoryPool,name=Code Cache","Usage.used"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory usage','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31504','16','','10169','MemoryPool: Perm Gen committed','jmx["java.lang:type=MemoryPool,name=Perm Gen","Usage.committed"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory allocated','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31505','16','','10169','MemoryPool: Perm Gen maximum size','jmx["java.lang:type=MemoryPool,name=Perm Gen","Usage.max"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum amount of memory that can be used for memory management. This amount of memory is not guaranteed to be available if it is greater than the amount of committed memory. The Java virtual machine may fail to allocate memory even if the amount of used memory does not exceed this maximum size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31506','16','','10169','MemoryPool: Perm Gen used','jmx["java.lang:type=MemoryPool,name=Perm Gen","Usage.used"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory usage','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31507','16','','10169','MemoryPool: PS Old Gen','jmx["java.lang:type=MemoryPool,name=PS Old Gen","Usage.committed"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory allocated','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31508','16','','10169','MemoryPool: PS Old Gen maximum size','jmx["java.lang:type=MemoryPool,name=PS Old Gen","Usage.max"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum amount of memory that can be used for memory management. This amount of memory is not guaranteed to be available if it is greater than the amount of committed memory. The Java virtual machine may fail to allocate memory even if the amount of used memory does not exceed this maximum size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31509','16','','10169','MemoryPool: PS Old Gen used','jmx["java.lang:type=MemoryPool,name=PS Old Gen","Usage.used"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory usage','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31510','16','','10169','MemoryPool: PS Perm Gen committed','jmx["java.lang:type=MemoryPool,name=PS Perm Gen","Usage.committed"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory allocated','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31511','16','','10169','MemoryPool: PS Perm Gen maximum size','jmx["java.lang:type=MemoryPool,name=PS Perm Gen","Usage.max"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum amount of memory that can be used for memory management. This amount of memory is not guaranteed to be available if it is greater than the amount of committed memory. The Java virtual machine may fail to allocate memory even if the amount of used memory does not exceed this maximum size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31512','16','','10169','MemoryPool: Tenured Gen committed','jmx["java.lang:type=MemoryPool,name=Tenured Gen","Usage.committed"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory allocated','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31513','16','','10169','MemoryPool: CMS Perm Gen maximum size','jmx["java.lang:type=MemoryPool,name=CMS Perm Gen","Usage.max"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum amount of memory that can be used for memory management. This amount of memory is not guaranteed to be available if it is greater than the amount of committed memory. The Java virtual machine may fail to allocate memory even if the amount of used memory does not exceed this maximum size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31514','16','','10169','MemoryPool: Tenured Gen maximum size','jmx["java.lang:type=MemoryPool,name=Tenured Gen","Usage.max"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum amount of memory that can be used for memory management. This amount of memory is not guaranteed to be available if it is greater than the amount of committed memory. The Java virtual machine may fail to allocate memory even if the amount of used memory does not exceed this maximum size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31515','16','','10169','MemoryPool: Tenured Gen used','jmx["java.lang:type=MemoryPool,name=Tenured Gen","Usage.used"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory usage','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31516','16','','10169','OperatingSystem: File descriptors maximum count','jmx["java.lang:type=OperatingSystem","MaxFileDescriptorCount"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'This is the number of file descriptors we can have opened in the same process, as determined by the operating system. You can never have more file descriptors than this number.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31517','16','','10169','OperatingSystem: File descriptors opened','jmx["java.lang:type=OperatingSystem","OpenFileDescriptorCount"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'This is the number of opened file descriptors at the moment, if this reaches the MaxFileDescriptorCount, the application will throw an IOException: Too many open files. This could mean you’re are opening file descriptors and never closing them.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31518','16','','10169','OperatingSystem: Process CPU Load','jmx["java.lang:type=OperatingSystem","ProcessCpuLoad"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'ProcessCpuLoad represents the CPU load in this process.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31519','16','','10169','Runtime: JVM uptime','jmx["java.lang:type=Runtime","Uptime"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31520','16','','10169','Runtime: JVM name','jmx["java.lang:type=Runtime","VmName"]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31521','16','','10169','Runtime: JVM version','jmx["java.lang:type=Runtime","VmVersion"]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31522','16','','10169','Threading: Daemon thread count','jmx["java.lang:type=Threading","DaemonThreadCount"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of daemon threads running.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31523','16','','10169','Threading: Peak thread count','jmx["java.lang:type=Threading","PeakThreadCount"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum number of threads being executed at the same time since the JVM was started or the peak was reset.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31524','16','','10169','Threading: Thread count','jmx["java.lang:type=Threading","ThreadCount"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of threads running at the current moment.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31525','16','','10169','MemoryPool: CMS Perm Gen used','jmx["java.lang:type=MemoryPool,name=CMS Perm Gen","Usage.used"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory usage','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31526','16','','10169','MemoryPool: CMS Perm Gen committed','jmx["java.lang:type=MemoryPool,name=CMS Perm Gen","Usage.committed"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory allocated','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31527','16','','10169','ClassLoading: Total loaded class count','jmx["java.lang:type=ClassLoading","TotalLoadedClassCount"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the total number of classes that have been loaded since the Java virtual machine has started execution.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31528','16','','10169','GarbageCollector: PS MarkSweep number of collections per second','jmx["java.lang:type=GarbageCollector,name=PS MarkSweep","CollectionCount"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the total number of collections that have occurred per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31529','16','','10169','ClassLoading: Unloaded class count','jmx["java.lang:type=ClassLoading","UnloadedClassCount"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the total number of classes that have been loaded since the Java virtual machine has started execution.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31530','16','','10169','Compilation: Name of the current JIT compiler','jmx["java.lang:type=Compilation","Name"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the total number of classes unloaded since the Java virtual machine has started execution.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31531','16','','10169','Compilation: Accumulated time spent','jmx["java.lang:type=Compilation","TotalCompilationTime"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the approximate accumulated elapsed time spent in compilation, in seconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31532','16','','10169','GarbageCollector: ConcurrentMarkSweep number of collections per second','jmx["java.lang:type=GarbageCollector,name=ConcurrentMarkSweep","CollectionCount"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the total number of collections that have occurred per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31533','16','','10169','GarbageCollector: ConcurrentMarkSweep accumulated time spent in collection','jmx["java.lang:type=GarbageCollector,name=ConcurrentMarkSweep","CollectionTime"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the approximate accumulated collection elapsed time, in seconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31534','16','','10169','GarbageCollector: Copy number of collections per second','jmx["java.lang:type=GarbageCollector,name=Copy","CollectionCount"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the total number of collections that have occurred per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31535','16','','10169','GarbageCollector: Copy accumulated time spent in collection','jmx["java.lang:type=GarbageCollector,name=Copy","CollectionTime"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the approximate accumulated collection elapsed time, in seconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31536','16','','10169','GarbageCollector: MarkSweepCompact number of collections per second','jmx["java.lang:type=GarbageCollector,name=MarkSweepCompact","CollectionCount"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the total number of collections that have occurred per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31537','16','','10169','GarbageCollector: MarkSweepCompact accumulated time spent in collection','jmx["java.lang:type=GarbageCollector,name=MarkSweepCompact","CollectionTime"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the approximate accumulated collection elapsed time, in seconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31538','16','','10169','GarbageCollector: ParNew number of collections per second','jmx["java.lang:type=GarbageCollector,name=ParNew","CollectionCount"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the total number of collections that have occurred per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31539','16','','10169','GarbageCollector: ParNew accumulated time spent in collection','jmx["java.lang:type=GarbageCollector,name=ParNew","CollectionTime"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the approximate accumulated collection elapsed time, in seconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31540','16','','10169','GarbageCollector: PS MarkSweep accumulated time spent in collection','jmx["java.lang:type=GarbageCollector,name=PS MarkSweep","CollectionTime"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the approximate accumulated collection elapsed time, in seconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31541','16','','10169','MemoryPool: CMS Old Gen used','jmx["java.lang:type=MemoryPool,name=CMS Old Gen","Usage.used"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory usage','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31542','16','','10169','GarbageCollector: PS Scavenge number of collections per second','jmx["java.lang:type=GarbageCollector,name=PS Scavenge","CollectionCount"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the total number of collections that have occurred per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31543','16','','10169','GarbageCollector: PS Scavenge accumulated time spent in collection','jmx["java.lang:type=GarbageCollector,name=PS Scavenge","CollectionTime"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Displays the approximate accumulated collection elapsed time, in seconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31544','16','','10169','Memory: Heap memory committed','jmx["java.lang:type=Memory","HeapMemoryUsage.committed"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current heap memory allocated. This amount of memory is guaranteed for the Java virtual machine to use.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31545','16','','10169','Memory: Heap memory maximum size','jmx["java.lang:type=Memory","HeapMemoryUsage.max"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum amount of heap that can be used for memory management. This amount of memory is not guaranteed to be available if it is greater than the amount of committed memory. The Java virtual machine may fail to allocate memory even if the amount of used memory does not exceed this maximum size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31546','16','','10169','Memory: Heap memory used','jmx["java.lang:type=Memory","HeapMemoryUsage.used"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory usage outside the heap.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31547','16','','10169','Memory: Non-Heap memory committed','jmx["java.lang:type=Memory","NonHeapMemoryUsage.committed"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory allocated outside the heap. This amount of memory is guaranteed for the Java virtual machine to use.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31548','16','','10169','Memory: Non-Heap memory maximum size','jmx["java.lang:type=Memory","NonHeapMemoryUsage.max"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum amount of non-heap memory that can be used for memory management. This amount of memory is not guaranteed to be available if it is greater than the amount of committed memory. The Java virtual machine may fail to allocate memory even if the amount of used memory does not exceed this maximum size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31549','16','','10169','Memory: Non-Heap memory used','jmx["java.lang:type=Memory","NonHeapMemoryUsage.used"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory usage outside the heap','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31550','16','','10169','Memory: Object pending finalization count','jmx["java.lang:type=Memory","ObjectPendingFinalizationCount"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The approximate number of objects for which finalization is pending.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31551','16','','10169','MemoryPool: CMS Old Gen committed','jmx["java.lang:type=MemoryPool,name=CMS Old Gen","Usage.committed"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current memory allocated','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31552','16','','10169','MemoryPool: CMS Old Gen maximum size','jmx["java.lang:type=MemoryPool,name=CMS Old Gen","Usage.max"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum amount of memory that can be used for memory management. This amount of memory is not guaranteed to be available if it is greater than the amount of committed memory. The Java virtual machine may fail to allocate memory even if the amount of used memory does not exceed this maximum size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31553','16','','10169','Threading: Total started thread count','jmx["java.lang:type=Threading","TotalStartedThreadCount"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of threads started since the JVM was launched.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31554','3','','10173','VMware: Event log','vmware.eventlog[{$VMWARE.URL},skip]','1m','7d','0','0','2','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Collect VMware event log. See also: https://www.zabbix.com/documentation/5.0/manual/config/items/preprocessing/examples#filtering_vmware_event_log_records','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31555','3','','10173','VMware: Full name','vmware.fullname[{$VMWARE.URL}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'VMware service full name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31556','3','','10173','VMware: Version','vmware.version[{$VMWARE.URL}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'VMware service version.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31557','3','','10174','VMware: Cluster name','vmware.vm.cluster.name[{$VMWARE.URL},{HOST.HOST}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Cluster name of the guest VM.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31558','3','','10174','VMware: Swapped memory','vmware.vm.memory.size.swapped[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The amount of guest physical memory swapped out to the VM''s swap device by ESX.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31559','3','','10174','VMware: Unshared storage space','vmware.vm.storage.unshared[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Total storage space, in bytes, occupied by the virtual machine across all datastores, that is not shared with any other virtual machine.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31560','3','','10174','VMware: Uncommitted storage space','vmware.vm.storage.uncommitted[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Additional storage space, in bytes, potentially used by this virtual machine on all datastores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31561','3','','10174','VMware: Committed storage space','vmware.vm.storage.committed[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Total storage space, in bytes, committed to this virtual machine across all datastores.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31562','3','','10174','VMware: Power state','vmware.vm.powerstate[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','','','',NULL,'12','','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The current power state of the virtual machine.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31563','3','','10174','VMware: Memory size','vmware.vm.memory.size[{$VMWARE.URL},{HOST.HOST}]','1h','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Total size of configured memory.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31564','3','','10174','VMware: Host memory usage','vmware.vm.memory.size.usage.host[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The amount of host physical memory allocated to the VM, accounting for saving from memory sharing with other VMs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31565','3','','10174','VMware: Guest memory usage','vmware.vm.memory.size.usage.guest[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The amount of guest physical memory that is being used by the VM.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31566','3','','10174','VMware: Shared memory','vmware.vm.memory.size.shared[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The amount of guest physical memory shared through transparent page sharing.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31567','3','','10174','VMware: Number of virtual CPUs','vmware.vm.cpu.num[{$VMWARE.URL},{HOST.HOST}]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Number of virtual CPUs assigned to the guest.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31568','3','','10174','VMware: Private memory','vmware.vm.memory.size.private[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Amount of memory backed by host memory and not being shared.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31569','3','','10174','VMware: Compressed memory','vmware.vm.memory.size.compressed[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The amount of memory currently in the compression cache for this VM.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31570','3','','10174','VMware: Ballooned memory','vmware.vm.memory.size.ballooned[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The amount of guest physical memory that is currently reclaimed through the balloon driver.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31571','3','','10174','VMware: Hypervisor name','vmware.vm.hv.name[{$VMWARE.URL},{HOST.HOST}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Hypervisor name of the guest VM.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31572','3','','10174','VMware: Datacenter name','vmware.vm.datacenter.name[{$VMWARE.URL},{HOST.HOST}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Datacenter name of the guest VM.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31573','3','','10174','VMware: CPU usage','vmware.vm.cpu.usage[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','Hz','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Current upper-bound on CPU usage. The upper-bound is based on the host the virtual machine is current running on, as well as limits configured on the virtual machine itself or any parent resource pool. Valid while the virtual machine is running.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31574','3','','10174','VMware: CPU ready','vmware.vm.cpu.ready[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','ms','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Time that the virtual machine was ready, but could not get scheduled to run on the physical CPU during last measurement interval (VMware vCenter/ESXi Server performance counter sampling interval - 20 seconds)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31575','3','','10174','VMware: Uptime','vmware.vm.uptime[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'System uptime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31576','3','','10175','VMware: Cluster name','vmware.hv.cluster.name[{$VMWARE.URL},{HOST.HOST}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Cluster name of the guest VM.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31577','3','','10175','VMware: Vendor','vmware.hv.hw.vendor[{$VMWARE.URL},{HOST.HOST}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The hardware vendor identification.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31578','3','','10175','VMware: Version','vmware.hv.version[{$VMWARE.URL},{HOST.HOST}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Dot-separated version string.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31579','3','','10175','VMware: Uptime','vmware.hv.uptime[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'System uptime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31580','3','','10175','VMware: Overall status','vmware.hv.status[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','','','',NULL,'13','','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The overall alarm status of the host: gray - unknown, green - ok, red - it has a problem, yellow - it might have a problem.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31581','3','','10175','VMware: Health state rollup','vmware.hv.sensor.health.state[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','','','',NULL,'13','','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The host health state rollup sensor value: gray - unknown, green - ok, red - it has a problem, yellow - it might have a problem.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31582','3','','10175','VMware: Number of bytes transmitted','vmware.hv.network.out[{$VMWARE.URL},{HOST.HOST},bps]','{$VMWARE_PERF_INTERVAL}','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'VMware hypervisor network output statistics (bytes per second).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31583','3','','10175','VMware: Number of bytes received','vmware.hv.network.in[{$VMWARE.URL},{HOST.HOST},bps]','{$VMWARE_PERF_INTERVAL}','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'VMware hypervisor network input statistics (bytes per second).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31584','3','','10175','VMware: Used memory','vmware.hv.memory.used[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Physical memory usage on the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31585','3','','10175','VMware: Ballooned memory','vmware.hv.memory.size.ballooned[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The amount of guest physical memory that is currently reclaimed through the balloon driver. Sum of all guest VMs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31586','3','','10175','VMware: Bios UUID','vmware.hv.hw.uuid[{$VMWARE.URL},{HOST.HOST}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The hardware BIOS identification.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31587','3','','10175','VMware: CPU usage','vmware.hv.cpu.usage[{$VMWARE.URL},{HOST.HOST}]','1m','7d','365d','0','3','','Hz','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Aggregated CPU usage across all cores on the host in Hz. This is only available if the host is connected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31588','3','','10175','VMware: Model','vmware.hv.hw.model[{$VMWARE.URL},{HOST.HOST}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The system model identification.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31589','3','','10175','VMware: Total memory','vmware.hv.hw.memory[{$VMWARE.URL},{HOST.HOST}]','1h','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The physical memory size.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31590','3','','10175','VMware: CPU threads','vmware.hv.hw.cpu.threads[{$VMWARE.URL},{HOST.HOST}]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Number of physical CPU threads on the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31591','3','','10175','VMware: CPU cores','vmware.hv.hw.cpu.num[{$VMWARE.URL},{HOST.HOST}]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Number of physical CPU cores on the host. Physical CPU cores are the processors contained by a CPU package.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31592','3','','10175','VMware: CPU model','vmware.hv.hw.cpu.model[{$VMWARE.URL},{HOST.HOST}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The CPU model.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31593','3','','10175','VMware: CPU frequency','vmware.hv.hw.cpu.freq[{$VMWARE.URL},{HOST.HOST}]','1h','7d','365d','0','3','','Hz','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The speed of the CPU cores. This is an average value if there are multiple speeds. The product of CPU frequency and number of cores is approximately equal to the sum of the MHz for all the individual cores on the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31594','3','','10175','VMware: Full name','vmware.hv.fullname[{$VMWARE.URL},{HOST.HOST}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'The complete product name, including the version information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31595','3','','10175','VMware: Datacenter name','vmware.hv.datacenter.name[{$VMWARE.URL},{HOST.HOST}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Datacenter name of the hypervisor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31596','3','','10175','VMware: Number of guest VMs','vmware.hv.vm.num[{$VMWARE.URL},{HOST.HOST}]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','0',NULL,'Number of guest virtual machines.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31597','3','','10173','Discover VMware clusters','vmware.cluster.discovery[{$VMWARE.URL}]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','1',NULL,'Discovery of clusters','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31598','3','','10173','Discover VMware datastores','vmware.datastore.discovery[{$VMWARE.URL}]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31599','3','','10173','Discover VMware hypervisors','vmware.hv.discovery[{$VMWARE.URL}]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','1',NULL,'Discovery of hypervisors.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31600','3','','10173','Discover VMware VMs','vmware.vm.discovery[{$VMWARE.URL}]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','1',NULL,'Discovery of guest virtual machines.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31601','3','','10174','Network device discovery','vmware.vm.net.if.discovery[{$VMWARE.URL},{HOST.HOST}]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','1',NULL,'Discovery of all network devices.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31602','3','','10174','Disk device discovery','vmware.vm.vfs.dev.discovery[{$VMWARE.URL},{HOST.HOST}]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','1',NULL,'Discovery of all disk devices.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31603','3','','10174','Mounted filesystem discovery','vmware.vm.vfs.fs.discovery[{$VMWARE.URL},{HOST.HOST}]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','1',NULL,'Discovery of all guest file systems.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31604','3','','10175','Datastore discovery','vmware.hv.datastore.discovery[{$VMWARE.URL},{HOST.HOST}]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31605','3','','10173','VMware: Status of "{#CLUSTER.NAME}" cluster','vmware.cluster.status[{$VMWARE.URL},{#CLUSTER.NAME}]','1m','7d','365d','0','3','','','','',NULL,'13','','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware cluster status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31606','3','','10173','VMware: Average read latency of the datastore {#DATASTORE}','vmware.datastore.read[{$VMWARE.URL},{#DATASTORE},latency]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'Amount of time for a read operation from the datastore (milliseconds).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31607','3','','10173','VMware: Free space on datastore {#DATASTORE} (percentage)','vmware.datastore.size[{$VMWARE.URL},{#DATASTORE},pfree]','5m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware datastore space in percentage from total.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31608','3','','10173','VMware: Total size of datastore {#DATASTORE}','vmware.datastore.size[{$VMWARE.URL},{#DATASTORE}]','5m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware datastore space in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31609','3','','10173','VMware: Average write latency of the datastore {#DATASTORE}','vmware.datastore.write[{$VMWARE.URL},{#DATASTORE},latency]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'Amount of time for a write operation to the datastore (milliseconds).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31610','3','','10174','VMware: Number of bytes received on interface {#IFDESC}','vmware.vm.net.if.in[{$VMWARE.URL},{HOST.HOST},{#IFNAME},bps]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware virtual machine network interface input statistics (bytes per second).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31611','3','','10174','VMware: Number of packets received on interface {#IFDESC}','vmware.vm.net.if.in[{$VMWARE.URL},{HOST.HOST},{#IFNAME},pps]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware virtual machine network interface input statistics (packets per second).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31612','3','','10174','VMware: Number of bytes transmitted on interface {#IFDESC}','vmware.vm.net.if.out[{$VMWARE.URL},{HOST.HOST},{#IFNAME},bps]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware virtual machine network interface output statistics (bytes per second).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31613','3','','10174','VMware: Number of packets transmitted on interface {#IFDESC}','vmware.vm.net.if.out[{$VMWARE.URL},{HOST.HOST},{#IFNAME},pps]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware virtual machine network interface output statistics (packets per second).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31614','3','','10174','VMware: Average number of bytes read from the disk {#DISKDESC}','vmware.vm.vfs.dev.read[{$VMWARE.URL},{HOST.HOST},{#DISKNAME},bps]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware virtual machine disk device read statistics (bytes per second).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31615','3','','10174','VMware: Average number of reads from the disk {#DISKDESC}','vmware.vm.vfs.dev.read[{$VMWARE.URL},{HOST.HOST},{#DISKNAME},ops]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware virtual machine disk device read statistics (operations per second).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31616','3','','10174','VMware: Average number of bytes written to the disk {#DISKDESC}','vmware.vm.vfs.dev.write[{$VMWARE.URL},{HOST.HOST},{#DISKNAME},bps]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware virtual machine disk device write statistics (bytes per second).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31617','3','','10174','VMware: Average number of writes to the disk {#DISKDESC}','vmware.vm.vfs.dev.write[{$VMWARE.URL},{HOST.HOST},{#DISKNAME},ops]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware virtual machine disk device write statistics (operations per second).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31618','3','','10174','VMware: Free disk space on {#FSNAME}','vmware.vm.vfs.fs.size[{$VMWARE.URL},{HOST.HOST},{#FSNAME},free]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware virtual machine file system statistics (bytes).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31619','3','','10174','VMware: Free disk space on {#FSNAME} (percentage)','vmware.vm.vfs.fs.size[{$VMWARE.URL},{HOST.HOST},{#FSNAME},pfree]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware virtual machine file system statistics (percentages).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31620','3','','10174','VMware: Total disk space on {#FSNAME}','vmware.vm.vfs.fs.size[{$VMWARE.URL},{HOST.HOST},{#FSNAME},total]','1h','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware virtual machine total disk space (bytes).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31621','3','','10174','VMware: Used disk space on {#FSNAME}','vmware.vm.vfs.fs.size[{$VMWARE.URL},{HOST.HOST},{#FSNAME},used]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware virtual machine used disk space (bytes).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31622','3','','10175','VMware: Average read latency of the datastore {#DATASTORE}','vmware.hv.datastore.read[{$VMWARE.URL},{HOST.HOST},{#DATASTORE},latency]','{$VMWARE_PERF_INTERVAL}','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'Average amount of time for a read operation from the datastore (milliseconds).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31623','3','','10175','VMware: Free space on datastore {#DATASTORE} (percentage)','vmware.hv.datastore.size[{$VMWARE.URL},{HOST.HOST},{#DATASTORE},pfree]','5m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware datastore space in percentage from total.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31624','3','','10175','VMware: Total size of datastore {#DATASTORE}','vmware.hv.datastore.size[{$VMWARE.URL},{HOST.HOST},{#DATASTORE}]','5m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'VMware datastore space in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31625','3','','10175','VMware: Average write latency of the datastore {#DATASTORE}','vmware.hv.datastore.write[{$VMWARE.URL},{HOST.HOST},{#DATASTORE},latency]','{$VMWARE_PERF_INTERVAL}','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$VMWARE.USERNAME}','{$VMWARE.PASSWORD}','','','2',NULL,'Average amount of time for a write operation to the datastore (milliseconds).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31626','15','','10327','MSSQL: Percent of Adhoc queries running','mssql.percent_of_adhoc_queries','0;m0-59s3','7d','365d','0','0','','%','','',NULL,NULL,'last(mssql.sql_compilations_sec.rate) * 100 /
(last(mssql.batch_requests_sec.rate) + (last(mssql.batch_requests_sec.rate)=0))','','0','','','','','0',NULL,'The ratio of SQL compilations per second to Batch requests per second in percentage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31627','15','','10327','MSSQL: Full scans to Index searches ratio','mssql.scan_to_search','0;m0-59s3','7d','365d','0','0','','','','',NULL,NULL,'last(mssql.full_scans_sec.rate) / (last(mssql.index_searches_sec.rate) + (last(mssql.index_searches_sec.rate)=0))','','0','','','','','0',NULL,'The ratio of Full scans per second to Index searches per second. The threshold recommendation is strictly for OLTP workloads.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31628','15','','10327','MSSQL: Percent of Recompiled Transact-SQL Objects','mssql.percent_recompilations_to_compilations','0;m0-59s3','7d','365d','0','0','','%','','',NULL,NULL,'last(mssql.sql_recompilations_sec.rate) * 100 /
(last(mssql.sql_compilations_sec.rate) + (last(mssql.sql_compilations_sec.rate)=0))','','0','','','','','0',NULL,'The ratio of SQL re-compilations per second to SQL compilations per second in percentage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31629','0','','10333','Oracle: Ping','oracle.ping["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','30s','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'Test the connection to Oracle Database state','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31630','0','','10333','Oracle: Datafiles count','oracle.datafiles.stats["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Current number of datafile.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31631','0','','10333','Oracle: Get FRA stats','oracle.fra.stats["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get FRA statistics.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31632','0','','10333','Oracle: Number of processes','oracle.proc.stats["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31633','0','','10333','Oracle: Get SGA stats','oracle.sga.stats["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get SGA statistics.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31634','0','','10333','Oracle: Get PDB info','oracle.pdb.info["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get info about PDB databases on instansce.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31635','0','','10333','Oracle: Get ASM stats','oracle.diskgroups.stats["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get ASM disk groups stats.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31636','0','','10333','Oracle: Get system metrics','oracle.sys.metrics["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','0;m0-59','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The item gets system metric values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31637','0','','10333','Oracle: Get instance state','oracle.instance.info["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The item gets state of the current instance.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31638','0','','10333','Oracle: Get system parameters','oracle.sys.params["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get a set of system parameter values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31639','0','','10333','Oracle: Get PGA stats','oracle.pga.stats["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get PGA statistics.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31640','0','','10333','Oracle: Redo logs available to switch','oracle.redolog.info["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of available for log switching inactive/unused REDO logs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31641','0','','10333','Oracle: User''s expire password','oracle.user.info["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','7d','365d','0','0','','days','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of days before zabbix account password expired.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31642','0','','10333','Oracle: Get archive log info','oracle.archive.info["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','5m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31643','0','','10333','Oracle: Get sessions stats','oracle.sessions.stats["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}","{$ORACLE.SESSION.LOCK.MAX.TIME}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get sessions statistics. {$ORACLE.SESSION.LOCK.MAX.TIME} -- maximum seconds in the current wait condition for counting long time locked sessions. Default: 600 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31644','0','','10333','Oracle: Get CDB and No-CDB info','oracle.cdb.info["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get info about CDB and  No-CDB databases on instansce.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31645','0','','10333','Oracle: Get tablespaces stats','oracle.ts.stats["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get tablespaces stats.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31706','0','','10333','Archive log discovery','oracle.archive.discovery["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Log archive destinations.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31707','0','','10333','Database discovery','oracle.db.discovery["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning databases in DBMS.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31708','0','','10333','ASM disk groups discovery','oracle.diskgroups.discovery["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'ASM disk groups','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31709','0','','10333','PDB discovery','oracle.pdb.discovery["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning PDB in DBMS.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31710','0','','10333','Tablespace discovery','oracle.ts.discovery["{$ORACLE.CONNSTRING}","{$ORACLE.USER}","{$ORACLE.PASSWORD}","{$ORACLE.SERVICE}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning tablespaces in DBMS.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31787','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.14988.1.1.3.10]','10233','Temperature sensor discovery','mtxrHlTemperature.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'MIKROTIK-MIB::mtxrHlTemperature
Since temperature sensor is not available on all Mikrotik hardware,
this is done to avoid unsupported items.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31788','20','discovery[{#IFNAME},1.3.6.1.4.1.14988.1.1.14.1.1.2,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFTYPE},1.3.6.1.2.1.2.2.1.3,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7]','10233','AP channel discovery','mtxrWlAp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'MIKROTIK-MIB::mtxrWlAp','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31789','20','discovery[{#IFNAME},1.3.6.1.4.1.14988.1.1.14.1.1.2,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10233','CAPsMAN AP channel discovery','mtxrWlCMChannel.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'MIKROTIK-MIB::mtxrWlCMChannel','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31790','20','1.3.6.1.4.1.14988.1.1.3.10.{#SNMPINDEX}','10233','Device: Temperature','sensor.temp.value[mtxrHlTemperature.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrHlTemperature Device temperature in Celsius (degrees C).
Might be missing in entry models (RB750, RB450G..).

Reference: http://wiki.mikrotik.com/wiki/Manual:SNMP','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31791','20','1.3.6.1.4.1.14988.1.1.1.3.1.11.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): AP authenticated clients','ssid.authclient[mtxrWlApAuthClientCount.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrWlApAuthClientCount Number of authentication clients.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31792','20','1.3.6.1.4.1.14988.1.1.1.3.1.8.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): AP band','ssid.band[mtxrWlApBand.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrWlApBand','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31793','20','1.3.6.1.4.1.14988.1.1.1.3.1.4.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): SSID','ssid.name[mtxrWlApSsid.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrWlApSsid Service Set Identifier.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31794','20','1.3.6.1.4.1.14988.1.1.1.3.1.9.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): AP noise floor','ssid.noise[mtxrWlApNoiseFloor.{#SNMPINDEX}]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrWlApNoiseFloor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31795','20','1.3.6.1.4.1.14988.1.1.1.3.1.6.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): AP registered clients','ssid.regclient[mtxrWlApClientCount.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrWlApClientCount Client established connection to AP, but didn''t finish all authetncation procedures for full connection.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31796','20','1.3.6.1.4.1.14988.1.1.1.7.1.3.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): AP authenticated clients','ssid.authclient[mtxrWlCMAuthClientCount.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrWlCMAuthClientCount Number of authentication clients.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31797','20','1.3.6.1.4.1.14988.1.1.1.7.1.5.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): AP channel','ssid.channel[mtxrWlCMChannel.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrWlCMChannel','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31798','20','1.3.6.1.4.1.14988.1.1.1.7.1.2.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): AP registered clients','ssid.regclient[mtxrWlCMRegClientCount.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrWlCMRegClientCount Client established connection to AP, but didn''t finish all authetncation procedures for full connection.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31799','20','1.3.6.1.4.1.14988.1.1.1.7.1.4.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): AP state','ssid.state[mtxrWlCMState.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrWlCMState Wireless interface state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31800','0','','10334','Ceph: Get df','ceph.df.details["{$CEPH.CONNSTRING}","{$CEPH.USER}","{$CEPH.API.KEY}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31801','0','','10334','Ceph: Get OSD dump','ceph.osd.dump["{$CEPH.CONNSTRING}","{$CEPH.USER}","{$CEPH.API.KEY}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31802','0','','10334','Ceph: Get overall cluster status','ceph.status["{$CEPH.CONNSTRING}","{$CEPH.USER}","{$CEPH.API.KEY}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31803','0','','10334','Ceph: Ping','ceph.ping["{$CEPH.CONNSTRING}","{$CEPH.USER}","{$CEPH.API.KEY}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31804','0','','10334','Ceph: Get OSD stats','ceph.osd.stats["{$CEPH.CONNSTRING}","{$CEPH.USER}","{$CEPH.API.KEY}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31851','0','','10334','OSD','ceph.osd.discovery["{$CEPH.CONNSTRING}","{$CEPH.USER}","{$CEPH.API.KEY}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31852','0','','10334','Pool','ceph.pool.discovery["{$CEPH.CONNSTRING}","{$CEPH.USER}","{$CEPH.API.KEY}"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31868','0','','10335','PHP-FPM: Get status page','web.page.get["{$PHP_FPM.HOST}","{$PHP_FPM.STATUS.PAGE}?json","{$PHP_FPM.PORT}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31869','0','','10335','PHP-FPM: php-fpm_ping','web.page.get["{$PHP_FPM.HOST}","{$PHP_FPM.PING.PAGE}","{$PHP_FPM.PORT}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31870','0','','10335','PHP-FPM: Number of processes running','proc.num["{$PHP_FPM.PROCESS_NAME}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31871','15','','10335','PHP-FPM: Queue usage','php-fpm.listen_queue_usage','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(php-fpm.listen_queue)/(last(php-fpm.listen_queue_len)+(last(php-fpm.listen_queue_len)=0))*100','','0','','','','','0',NULL,'Queue utilization','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31872','0','','10335','PHP-FPM: Memory usage (rss)','proc.mem["{$PHP_FPM.PROCESS_NAME}",,,,rss]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Resident set size memory used by process in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31873','0','','10335','PHP-FPM: Memory usage, %','proc.mem["{$PHP_FPM.PROCESS_NAME}",,,,pmem]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory used percentage relative to total memory available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31874','0','','10335','PHP-FPM: CPU utilization','proc.cpu.util["{$PHP_FPM.PROCESS_NAME}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Process CPU utilization percentage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31891','15','','10336','PHP-FPM: Queue usage','php-fpm.listen_queue_usage','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(php-fpm.listen_queue)/(last(php-fpm.listen_queue_len)+(last(php-fpm.listen_queue_len)=0))*100','','0','','','','','0',NULL,'Queue utilization','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31892','19','','10336','PHP-FPM: Get status page','php-fpm.get_status','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','{$PHP_FPM.SCHEME}://{$PHP_FPM.HOST}:{$PHP_FPM.PORT}/{$PHP_FPM.STATUS.PAGE}?json','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31893','19','','10336','PHP-FPM: Get ping page','php-fpm.get_ping','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','{$PHP_FPM.SCHEME}://{$PHP_FPM.HOST}:{$PHP_FPM.PORT}/{$PHP_FPM.PING.PAGE}','','','200','1','0','','2','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31910','3','','10337','Squid: Service ping','net.tcp.service[tcp,,{$SQUID.HTTP.PORT}]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31911','20','1.3.6.1.4.1.3495.1.3.1.7.0','10337','Squid: Objects count','squid[cacheNumObjCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of objects stored by the cache','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31912','20','1.3.6.1.4.1.3495.1.3.2.2.1.6.5','10337','Squid: ICP query service time per 5 minutes','squid[cacheIcpQuerySvcTime.5]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'ICP query service time per 5 minutes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31913','20','1.3.6.1.4.1.3495.1.3.2.2.1.6.60','10337','Squid: ICP query service time per hour','squid[cacheIcpQuerySvcTime.60]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'ICP query service time per hour','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31914','20','1.3.6.1.4.1.3495.1.3.2.2.1.7.5','10337','Squid: ICP reply service time per 5 minutes','squid[cacheIcpReplySvcTime.5]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'ICP reply service time per 5 minutes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31915','20','1.3.6.1.4.1.3495.1.3.2.2.1.7.60','10337','Squid: ICP reply service time per hour','squid[cacheIcpReplySvcTime.60]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'ICP reply service time per hour','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31916','20','1.3.6.1.4.1.3495.1.4.1.3.0','10337','Squid: IP cache hits per second','squid[cacheIpHits]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of IP Cache hits','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31917','20','1.3.6.1.4.1.3495.1.4.1.6.0','10337','Squid: IP cache misses per second','squid[cacheIpMisses]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of IP Cache misses','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31918','20','1.3.6.1.4.1.3495.1.4.1.2.0','10337','Squid: IP cache requests per second','squid[cacheIpRequests]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of IP Cache requests','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31919','20','1.3.6.1.4.1.3495.1.3.1.6.0','10337','Squid: Memory maximum resident size','squid[cacheMaxResSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum Resident Size','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31920','20','1.3.6.1.4.1.3495.1.2.5.1.0','10337','Squid: Memory maximum cache size','squid[cacheMemMaxSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The value of the cache_mem parameter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31921','20','1.3.6.1.4.1.3495.1.3.1.3.0','10337','Squid: Memory cache usage','squid[cacheMemUsage]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total accounted memory','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31922','20','1.3.6.1.4.1.3495.1.3.2.1.1.0','10337','Squid: HTTP requests received per second','squid[cacheProtoClientHttpRequests]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of HTTP requests received','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31923','20','1.3.6.1.4.1.3495.1.3.2.1.7.0','10337','Squid: ICP messages received per second','squid[cacheIcpPktsRecv]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of ICP messages received','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31924','20','1.3.6.1.4.1.3495.1.3.2.2.1.10.1','10337','Squid: Byte hit ratio per 1 minute','squid[cacheRequestByteRatio.1]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Byte Hit Ratios','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31925','20','1.3.6.1.4.1.3495.1.3.2.2.1.10.5','10337','Squid: Byte hit ratio per 5 minutes','squid[cacheRequestByteRatio.5]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Byte Hit Ratios','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31926','20','1.3.6.1.4.1.3495.1.3.2.2.1.10.60','10337','Squid: Byte hit ratio per 1 hour','squid[cacheRequestByteRatio.60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Byte Hit Ratios','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31927','20','1.3.6.1.4.1.3495.1.3.2.2.1.9.1','10337','Squid: Request hit ratio per 1 minute','squid[cacheRequestHitRatio.1]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Byte Hit Ratios','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31928','20','1.3.6.1.4.1.3495.1.3.2.2.1.9.5','10337','Squid: Request hit ratio per 5 minutes','squid[cacheRequestHitRatio.5]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Byte Hit Ratios','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31929','20','1.3.6.1.4.1.3495.1.3.2.2.1.9.60','10337','Squid: Request hit ratio per 1 hour','squid[cacheRequestHitRatio.60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Byte Hit Ratios','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31930','20','1.3.6.1.4.1.3495.1.2.5.3.0','10337','Squid: Cache swap high water mark','squid[cacheSwapHighWM]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Cache Swap High Water Mark','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31931','20','1.3.6.1.4.1.3495.1.2.5.4.0','10337','Squid: Cache swap low water mark','squid[cacheSwapLowWM]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Cache Swap Low Water Mark','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31932','20','1.3.6.1.4.1.3495.1.2.5.2.0','10337','Squid: Cache swap directory size','squid[cacheSwapMaxSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The total of the cache_dir space allocated','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31933','20','1.3.6.1.4.1.3495.1.3.1.1.0','10337','Squid: Sys page faults per second','squid[cacheSysPageFaults]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Page faults with physical I/O','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31934','20','1.3.6.1.4.1.3495.1.1.3.0','10337','Squid: Uptime','squid[cacheUptime]','5m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'The Uptime of the cache in timeticks (in hundredths of a second) with preprocessing','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31935','20','1.3.6.1.4.1.3495.1.3.2.1.6.0','10337','Squid: ICP messages sent per second','squid[cacheIcpPktsSent]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of ICP messages sent','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31936','20','1.3.6.1.4.1.3495.1.3.2.1.8.0','10337','Squid: ICP traffic transmitted per second','squid[cacheIcpKbSent]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of ICP traffic transmitted','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31937','20','1.3.6.1.4.1.3495.1.3.1.5.0','10337','Squid: CPU usage','squid[cacheCpuUsage]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The percentage use of the CPU','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31938','20','1.3.6.1.4.1.3495.1.4.2.3.0','10337','Squid: FQDN cache hits per second','squid[cacheFqdnHits]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of FQDN Cache hits','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31939','20','1.3.6.1.4.1.3495.1.3.1.12.0','10337','Squid: File descriptor count - current used','squid[cacheCurrentFileDescrCnt]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of file descriptors in use','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31940','20','1.3.6.1.4.1.3495.1.3.1.13.0','10337','Squid: File descriptor count - current maximum','squid[cacheCurrentFileDescrMax]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Highest number of file descriptors in use','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31941','20','1.3.6.1.4.1.3495.1.3.1.8.0','10337','Squid: Objects LRU expiration age','squid[cacheCurrentLRUExpiration]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Storage LRU Expiration Age','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31942','20','1.3.6.1.4.1.3495.1.3.1.11.0','10337','Squid: File descriptor count - current reserved','squid[cacheCurrentResFileDescrCnt]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Reserved number of file descriptors','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31943','20','1.3.6.1.4.1.3495.1.3.2.1.14.0','10337','Squid: Cache swap current size','squid[cacheCurrentSwapSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Storage Swap Size','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31944','20','1.3.6.1.4.1.3495.1.3.1.9.0','10337','Squid: Objects unlinkd requests','squid[cacheCurrentUnlinkRequests]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Requests given to unlinkd','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31945','20','1.3.6.1.4.1.3495.1.3.1.10.0','10337','Squid: File descriptor count - current available','squid[cacheCurrentUnusedFDescrCnt]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Available number of file descriptors','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31946','20','1.3.6.1.4.1.3495.1.4.3.2.0','10337','Squid: DNS server replies per second','squid[cacheDnsReplies]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of external dns server replies','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31947','20','1.3.6.1.4.1.3495.1.4.3.1.0','10337','Squid: DNS server requests per second','squid[cacheDnsRequests]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of external dns server requests','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31948','20','1.3.6.1.4.1.3495.1.3.2.2.1.8.5','10337','Squid: DNS service time per 5 minutes','squid[cacheDnsSvcTime.5]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'DNS service time per 5 minutes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31949','20','1.3.6.1.4.1.3495.1.3.2.2.1.8.60','10337','Squid: DNS service time per hour','squid[cacheDnsSvcTime.60]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'DNS service time per hour','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31950','20','1.3.6.1.4.1.3495.1.4.2.6.0','10337','Squid: FQDN cache misses per second','squid[cacheFqdnMisses]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of FQDN Cache misses','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31951','20','1.3.6.1.4.1.3495.1.3.2.1.9.0','10337','Squid: ICP traffic received per second','squid[cacheIcpKbRecv]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of ICP traffic received','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31952','20','1.3.6.1.4.1.3495.1.4.2.2.0','10337','Squid: FQDN cache requests per second','squid[cacheFqdnRequests]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of FQDN Cache requests','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31953','20','1.3.6.1.4.1.3495.1.3.2.2.1.2.5','10337','Squid: HTTP all service time per 5 minutes','squid[cacheHttpAllSvcTime.5]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'HTTP all service time per 5 minutes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31954','20','1.3.6.1.4.1.3495.1.3.2.2.1.2.60','10337','Squid: HTTP all service time per hour','squid[cacheHttpAllSvcTime.60]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'HTTP all service time per hour','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31955','20','1.3.6.1.4.1.3495.1.3.2.1.3.0','10337','Squid: HTTP Errors sent per second','squid[cacheHttpErrors]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of HTTP Errors sent to clients','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31956','20','1.3.6.1.4.1.3495.1.3.2.1.2.0','10337','Squid: HTTP Hits sent from cache per second','squid[cacheHttpHits]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of HTTP Hits sent to clients from cache','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31957','20','1.3.6.1.4.1.3495.1.3.2.2.1.5.5','10337','Squid: HTTP miss service time per 5 minutes','squid[cacheHttpHitSvcTime.5]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'HTTP hit service time per 5 minutes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31958','20','1.3.6.1.4.1.3495.1.3.2.2.1.5.60','10337','Squid: HTTP hit service time per hour','squid[cacheHttpHitSvcTime.60]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'HTTP hit service time per hour','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31959','20','1.3.6.1.4.1.3495.1.3.2.1.4.0','10337','Squid: HTTP traffic received per second','squid[cacheHttpInKb]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of HTTP traffic received from clients','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31960','20','1.3.6.1.4.1.3495.1.3.2.2.1.3.5','10337','Squid: HTTP miss service time per 5 minutes','squid[cacheHttpMissSvcTime.5]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'HTTP miss service time per 5 minutes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31961','20','1.3.6.1.4.1.3495.1.3.2.2.1.3.60','10337','Squid: HTTP miss service time per hour','squid[cacheHttpMissSvcTime.60]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'HTTP miss service time per hour','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31962','20','1.3.6.1.4.1.3495.1.3.2.1.5.0','10337','Squid: HTTP traffic sent per second','squid[cacheHttpOutKb]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of HTTP traffic sent to clients','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31963','20','1.3.6.1.4.1.3495.1.2.3.0','10337','Squid: Version','squid[cacheVersionId]','1m','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Cache Software Version','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31964','20','discovery[{#IFNAME},1.3.6.1.4.1.14988.1.1.14.1.1.2,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10233','LTE modem discovery','mtxrLTEModem.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'MIKROTIK-MIB::mtxrLTEModemInterfaceIndex','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31965','20','1.3.6.1.4.1.14988.1.1.16.1.1.4.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): LTE modem RSRP','lte.modem.rsrp[mtxrLTEModemSignalRSRP.{#SNMPINDEX}]','1m','7d','365d','0','0','','dbm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrLTEModemSignalRSRP Reference Signal Received Power.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31966','20','1.3.6.1.4.1.14988.1.1.16.1.1.3.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): LTE modem RSRQ','lte.modem.rsrq[mtxrLTEModemSignalRSRQ.{#SNMPINDEX}]','1m','7d','365d','0','0','','db','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrLTEModemSignalRSRQ Reference Signal Received Quality.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31967','20','1.3.6.1.4.1.14988.1.1.16.1.1.2.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): LTE modem RSSI','lte.modem.rssi[mtxrLTEModemSignalRSSI.{#SNMPINDEX}]','1m','7d','365d','0','0','','dbm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrLTEModemSignalRSSI Received Signal Strength Indicator.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31968','20','1.3.6.1.4.1.14988.1.1.16.1.1.7.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): LTE modem SINR','lte.modem.sinr[mtxrLTEModemSignalSINR.{#SNMPINDEX}]','1m','7d','365d','0','0','','db','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: MIKROTIK-MIB
mtxrLTEModemSignalSINR Signal to Interference & Noise Ratio.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32012','19','','10339','Get DataNodes states','hadoop.datanodes.get','1m','0h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','{$HADOOP.NAMENODE.HOST}:{$HADOOP.NAMENODE.PORT}/jmx?qry=Hadoop:service=NameNode,name=NameNodeInfo','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32013','19','','10339','Get NodeManagers states','hadoop.nodemanagers.get','1m','0h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','{$HADOOP.RESOURCEMANAGER.HOST}:{$HADOOP.RESOURCEMANAGER.PORT}/jmx?qry=Hadoop:service=ResourceManager,name=RMNMInfo','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32014','3','','10339','NameNode: Service status','net.tcp.service["tcp","{$HADOOP.NAMENODE.HOST}","{$HADOOP.NAMENODE.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'Hadoop NameNode API port availability.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32015','3','','10339','ResourceManager: Service response time','net.tcp.service.perf["tcp","{$HADOOP.RESOURCEMANAGER.HOST}","{$HADOOP.RESOURCEMANAGER.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Hadoop ResourceManager API performance.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32016','3','','10339','NameNode: Service response time','net.tcp.service.perf["tcp","{$HADOOP.NAMENODE.HOST}","{$HADOOP.NAMENODE.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Hadoop NameNode API performance.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32017','19','','10339','Get ResourceManager stats','hadoop.resourcemanager.get','1m','0h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','{$HADOOP.RESOURCEMANAGER.HOST}:{$HADOOP.RESOURCEMANAGER.PORT}/jmx','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32018','3','','10339','ResourceManager: Service status','net.tcp.service["tcp","{$HADOOP.RESOURCEMANAGER.HOST}","{$HADOOP.RESOURCEMANAGER.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'Hadoop ResourceManager API port availability.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32019','19','','10339','Get NameNode stats','hadoop.namenode.get','1m','0h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','{$HADOOP.NAMENODE.HOST}:{$HADOOP.NAMENODE.PORT}/jmx','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32046','19','','10339','Data node discovery','hadoop.datanode.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','{$HADOOP.NAMENODE.HOST}:{$HADOOP.NAMENODE.PORT}/jmx?qry=Hadoop:service=NameNode,name=NameNodeInfo','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32047','19','','10339','Node manager discovery','hadoop.nodemanager.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','{$HADOOP.RESOURCEMANAGER.HOST}:{$HADOOP.RESOURCEMANAGER.PORT}/jmx?qry=Hadoop:service=ResourceManager,name=RMNMInfo','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32048','19','','10339','Hadoop DataNode {#HOSTNAME}: Get stats','hadoop.datanode.get[{#HOSTNAME}]','1m','0h','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','{#INFOADDR}/jmx','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32049','19','','10339','Hadoop NodeManager {#HOSTNAME}: Get stats','hadoop.nodemanager.get[{#HOSTNAME}]','1m','0h','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','{#NODEHTTPADDRESS}/jmx','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32071','16','','10340','Kafka: Leader election per second','jmx["kafka.controller:type=ControllerStats,name=LeaderElectionRateAndTimeMs","Count"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Number of leader elections per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32072','16','','10340','Kafka: Request handler average idle percent','jmx["kafka.server:type=KafkaRequestHandlerPool,name=RequestHandlerAvgIdlePercent","OneMinuteRate"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Indicates the percentage of time that the request handler (IO) threads are not in use.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32073','16','','10340','Kafka: Fetch-Consumer request total time, mean','jmx["kafka.network:type=RequestMetrics,name=TotalTimeMs,request=UpdateMetadata","Mean"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Average time for a request to update metadata.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32074','16','','10340','Kafka: Network processor average idle percent','jmx["kafka.network:type=SocketServer,name=NetworkProcessorAvgIdlePercent","Value"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The average percentage of time that the network processors are idle.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32075','16','','10340','Kafka: Uptime','jmx["kafka.server:type=app-info","start-time-ms"]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Service uptime in seconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32076','16','','10340','Kafka: Version','jmx["kafka.server:type=app-info","version"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Current version of brocker.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32077','16','','10340','Kafka: Bytes in per second','jmx["kafka.server:type=BrokerTopicMetrics,name=BytesInPerSec","Count"]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The rate at which data sent from producers is consumed by the broker.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32078','16','','10340','Kafka: Bytes out per second','jmx["kafka.server:type=BrokerTopicMetrics,name=BytesOutPerSec","Count"]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The rate at which data is fetched and read from the broker by consumers.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32079','16','','10340','Kafka: Bytes rejected per second','jmx["kafka.server:type=BrokerTopicMetrics,name=BytesRejectedPerSec","Count"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The rate at which bytes rejected per second by the broker.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32080','16','','10340','Kafka: Client fetch request failed per second','jmx["kafka.server:type=BrokerTopicMetrics,name=FailedFetchRequestsPerSec","Count"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Number of client fetch request failures per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32081','16','','10340','Kafka: Produce requests failed per second','jmx["kafka.server:type=BrokerTopicMetrics,name=FailedProduceRequestsPerSec","Count"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Number of failed produce requests per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32082','16','','10340','Kafka: Messages in per second','jmx["kafka.server:type=BrokerTopicMetrics,name=MessagesInPerSec","Count"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The rate at which individual messages are consumed by the broker.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32083','16','','10340','Kafka: Requests in producer purgatory','jmx["kafka.server:type=DelayedOperationPurgatory,name=PurgatorySize,delayedOperation=Fetch","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Number of requests waiting in producer purgatory.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32084','16','','10340','Kafka: Requests in fetch purgatory','jmx["kafka.server:type=DelayedOperationPurgatory,name=PurgatorySize,delayedOperation=Produce","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Number of requests waiting in fetch purgatory.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32085','16','','10340','Kafka: Replication maximum lag','jmx["kafka.server:type=ReplicaFetcherManager,name=MaxLag,clientId=Replica","Value"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The maximum lag between the time that messages are received by the leader replica and by the follower replicas.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32086','16','','10340','Kafka: UpdateMetadata request total time, p95','jmx["kafka.network:type=RequestMetrics,name=TotalTimeMs,request=UpdateMetadata","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Time for update metadata requests for 95th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32087','16','','10340','Kafka: ISR expands per second','jmx["kafka.server:type=ReplicaManager,name=IsrExpandsPerSec","Count"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The rate at which the number of ISRs in the broker increases.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32088','16','','10340','Kafka: ISR shrink per second','jmx["kafka.server:type=ReplicaManager,name=IsrShrinksPerSec","Count"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Rate of replicas leaving the ISR pool.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32089','16','','10340','Kafka: Leader count','jmx["kafka.server:type=ReplicaManager,name=LeaderCount","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The number of replicas for which this broker is the leader.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32090','16','','10340','Kafka: Partition count','jmx["kafka.server:type=ReplicaManager,name=PartitionCount","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The number of partitions in the broker.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32091','16','','10340','Kafka: Number of reassigning partitions','jmx["kafka.server:type=ReplicaManager,name=ReassigningPartitions","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The number of reassigning leader partitions on a broker.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32092','16','','10340','Kafka: Under minimum ISR partition count','jmx["kafka.server:type=ReplicaManager,name=UnderMinIsrPartitionCount","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The number of partitions under the minimum In-Sync Replica (ISR) count.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32093','16','','10340','Kafka: Under replicated partitions','jmx["kafka.server:type=ReplicaManager,name=UnderReplicatedPartitions","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The number of partitions that have not been fully replicated in the follower replicas (the number of non-reassigning replicas - the number of ISR > 0).','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32094','16','','10340','Kafka: Request queue size','jmx["kafka.server:type=Request","queue-size"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The size of the delay queue.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32095','16','','10340','Kafka: ZooKeeper connection status','jmx["kafka.server:type=SessionExpireListener,name=SessionState","Value"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Connection status of broker''s ZooKeeper session.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32096','16','','10340','Kafka: ZooKeeper disconnect rate','jmx["kafka.server:type=SessionExpireListener,name=ZooKeeperDisconnectsPerSec","Count"]','1m','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'ZooKeeper client disconnect per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32097','16','','10340','Kafka: ZooKeeper session expiration rate','jmx["kafka.server:type=SessionExpireListener,name=ZooKeeperExpiresPerSec","Count"]','1m','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'ZooKeeper client session expiration  per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32098','16','','10340','Kafka: ZooKeeper readonly rate','jmx["kafka.server:type=SessionExpireListener,name=ZooKeeperReadOnlyConnectsPerSec","Count"]','1m','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'ZooKeeper client readonly  per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32099','16','','10340','Kafka: ZooKeeper sync rate','jmx["kafka.server:type=SessionExpireListener,name=ZooKeeperSyncConnectsPerSec","Count"]','1m','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'ZooKeeper client sync  per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32100','16','','10340','Kafka: UpdateMetadata request total time, p99','jmx["kafka.network:type=RequestMetrics,name=TotalTimeMs,request=UpdateMetadata","99thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Time for update metadata requests for 99th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32101','16','','10340','Kafka: Produce request total time, mean','jmx["kafka.network:type=RequestMetrics,name=TotalTimeMs,request=Produce","Mean"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Average time in ms to serve the Produce request.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32102','16','','10340','Kafka: Unclean leader election per second','jmx["kafka.controller:type=ControllerStats,name=UncleanLeaderElectionsPerSec","Count"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Number of “unclean” elections per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32103','16','','10340','Kafka: Produce response send time, p95','jmx["kafka.network:type=RequestMetrics,name=ResponseSendTimeMs,request=Produce","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The time taken, in milliseconds, to send the response for 95th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32104','16','','10340','Kafka: Controller state on broker','jmx["kafka.controller:type=KafkaController,name=ActiveControllerCount","Value"]','1m','7d','365d','0','3','','','','',NULL,'122','','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'One indicates that the broker is the controller for the cluster.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32105','16','','10340','Kafka: Offline partitions count','jmx["kafka.controller:type=KafkaController,name=OfflinePartitionsCount","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Number of partitions that don''t have an active leader.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32106','16','','10340','Kafka: Ineligible pending replica deletes','jmx["kafka.controller:type=KafkaController,name=ReplicasIneligibleToDeleteCount","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The number of ineligible pending replica deletes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32107','16','','10340','Kafka: Pending replica deletes','jmx["kafka.controller:type=KafkaController,name=ReplicasToDeleteCount","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The number of pending replica deletes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32108','16','','10340','Kafka: Ineligible pending topic deletes','jmx["kafka.controller:type=KafkaController,name=TopicsIneligibleToDeleteCount","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The number of ineligible pending topic deletes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32109','16','','10340','Kafka: Pending topic deletes','jmx["kafka.controller:type=KafkaController,name=TopicsToDeleteCount","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The number of pending topic deletes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32110','16','','10340','Kafka: Offline log directory count','jmx["kafka.log:type=LogManager,name=OfflineLogDirectoryCount","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The number of offline log directories (for example, after a hardware failure).','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32111','16','','10340','Kafka: Fetch-Consumer response send time, p95','jmx["kafka.network:type=RequestMetrics,name=ResponseSendTimeMs,request=FetchConsumer","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The time taken, in milliseconds, to send the response for 95th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32112','16','','10340','Kafka: Fetch-Consumer response send time, p99','jmx["kafka.network:type=RequestMetrics,name=ResponseSendTimeMs,request=FetchConsumer","99thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The time taken, in milliseconds, to send the response for 99th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32113','16','','10340','Kafka: Fetch-Consumer response send time, mean','jmx["kafka.network:type=RequestMetrics,name=ResponseSendTimeMs,request=FetchConsumer","Mean"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Average time taken, in milliseconds, to send the response.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32114','16','','10340','Kafka: Fetch-Follower response send time, p95','jmx["kafka.network:type=RequestMetrics,name=ResponseSendTimeMs,request=FetchFollower","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The time taken, in milliseconds, to send the response for 95th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32115','16','','10340','Kafka: Fetch-Follower response send time, p99','jmx["kafka.network:type=RequestMetrics,name=ResponseSendTimeMs,request=FetchFollower","99thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The time taken, in milliseconds, to send the response for 99th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32116','16','','10340','Kafka: Fetch-Follower response send time, mean','jmx["kafka.network:type=RequestMetrics,name=ResponseSendTimeMs,request=FetchFollower","Mean"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Average time taken, in milliseconds, to send the response.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32117','16','','10340','Kafka: Produce response send time, p99','jmx["kafka.network:type=RequestMetrics,name=ResponseSendTimeMs,request=Produce","99thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The time taken, in milliseconds, to send the response for 99th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32118','16','','10340','Kafka: Produce request total time, p99','jmx["kafka.network:type=RequestMetrics,name=TotalTimeMs,request=Produce","99thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Time in ms  to serve the Produce requests for 99th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32119','16','','10340','Kafka: Produce response send time, mean','jmx["kafka.network:type=RequestMetrics,name=ResponseSendTimeMs,request=Produce","Mean"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Average time taken, in milliseconds, to send the response.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32120','16','','10340','Kafka: Temporary memory size in bytes (Fetch), max','jmx["kafka.network:type=RequestMetrics,name=TemporaryMemoryBytes,request=Fetch","Max"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The maximum of temporary memory used for converting message formats and decompressing messages.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32121','16','','10340','Kafka: Temporary memory size in bytes (Fetch), min','jmx["kafka.network:type=RequestMetrics,name=TemporaryMemoryBytes,request=Fetch","Mean"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The minimum of temporary memory used for converting message formats and decompressing messages.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32122','16','','10340','Kafka: Temporary memory size in bytes (Produce), max','jmx["kafka.network:type=RequestMetrics,name=TemporaryMemoryBytes,request=Produce","Max"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The maximum of temporary memory used for converting message formats and decompressing messages.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32123','16','','10340','Kafka: Temporary memory size in bytes (Produce), avg','jmx["kafka.network:type=RequestMetrics,name=TemporaryMemoryBytes,request=Produce","Mean"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The amount of temporary memory used for converting message formats and decompressing messages.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32124','16','','10340','Kafka: Temporary memory size in bytes (Produce), min','jmx["kafka.network:type=RequestMetrics,name=TemporaryMemoryBytes,request=Produce","Min"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'The minimum of temporary memory used for converting message formats and decompressing messages.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32125','16','','10340','Kafka: Fetch-Consumer request total time, p95','jmx["kafka.network:type=RequestMetrics,name=TotalTimeMs,request=FetchConsumer","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Time in ms to serve the Fetch-Consumer request for 95th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32126','16','','10340','Kafka: Fetch-Consumer request total time, p99','jmx["kafka.network:type=RequestMetrics,name=TotalTimeMs,request=FetchConsumer","99thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Time in ms to serve the specified Fetch-Consumer for 99th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32127','16','','10340','Kafka: Fetch-Consumer request total time, mean','jmx["kafka.network:type=RequestMetrics,name=TotalTimeMs,request=FetchConsumer","Mean"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Average time in ms to serve the Fetch-Consumer request.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32128','16','','10340','Kafka: Fetch-Follower request total time, p95','jmx["kafka.network:type=RequestMetrics,name=TotalTimeMs,request=FetchFollower","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Time in ms to serve the Fetch-Follower request for 95th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32129','16','','10340','Kafka: Fetch-Follower request total time, p99','jmx["kafka.network:type=RequestMetrics,name=TotalTimeMs,request=FetchFollower","99thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Time in ms to serve the Fetch-Follower request for 99th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32130','16','','10340','Kafka: Fetch-Follower request total time, mean','jmx["kafka.network:type=RequestMetrics,name=TotalTimeMs,request=FetchFollower","Mean"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Average time in ms to serve the Fetch-Follower request.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32131','16','','10340','Kafka: Produce request total time, p95','jmx["kafka.network:type=RequestMetrics,name=TotalTimeMs,request=Produce","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Time in ms  to serve the Produce requests for 95th percentile.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32132','16','','10340','Kafka: ZooKeeper client request latency','jmx["kafka.server:type=ZooKeeperClientMetrics,name=ZooKeeperRequestLatencyMs","Count"]','1m','7d','365d','0','3','','ms','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','0',NULL,'Latency in milliseconds for ZooKeeper requests from broker.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32133','16','','10340','Topic Metrics  (read)','jmx.discovery[beans,"kafka.server:type=BrokerTopicMetrics,name=BytesOutPerSec,topic=*"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','1',NULL,'','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32134','16','','10340','Topic Metrics (errors)','jmx.discovery[beans,"kafka.server:type=BrokerTopicMetrics,name=BytesRejectedPerSec,topic=*"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','1',NULL,'','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32135','16','','10340','Topic Metrics (write)','jmx.discovery[beans,"kafka.server:type=BrokerTopicMetrics,name=MessagesInPerSec,topic=*"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','1',NULL,'','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32136','16','','10340','Kafka {#JMXTOPIC}: Bytes out per second','jmx["kafka.server:type=BrokerTopicMetrics,name=BytesOutPerSec,topic={#JMXTOPIC}","Count"]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','2',NULL,'The rate at which data is fetched and read from the broker by consumers (by topic).','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32137','16','','10340','Kafka {#JMXTOPIC}: Bytes rejected per second','jmx["kafka.server:type=BrokerTopicMetrics,name=BytesRejectedPerSec,topic={#JMXTOPIC}","Count"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','2',NULL,'Rejected bytes rate by topic.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32138','16','','10340','Kafka {#JMXTOPIC}: Bytes in per second','jmx["kafka.server:type=BrokerTopicMetrics,name=BytesInPerSec,topic={#JMXTOPIC}","Count"]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','2',NULL,'The rate at which data sent from producers is consumed by topic.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32139','16','','10340','Kafka {#JMXTOPIC}: Messages in per second','jmx["kafka.server:type=BrokerTopicMetrics,name=MessagesInPerSec,topic={#JMXTOPIC}","Count"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$KAFKA.USER}','{$KAFKA.PASSWORD}','','','2',NULL,'The rate at which individual messages are consumed by topic.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32140','16','','10260','Protocol handlers discovery','jmx.discovery[attributes,"Catalina:type=ProtocolHandler,port=*"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','1',NULL,'Discovery for ProtocolHandler','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32141','16','','10260','Global request processors discovery','jmx.discovery[beans,"Catalina:type=GlobalRequestProcessor,name=*"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','1',NULL,'Discovery for GlobalRequesProcessor','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32142','16','','10260','Contexts discovery','jmx.discovery[beans,"Catalina:type=Manager,host=*,context=*"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','1',NULL,'Discovery for contexts','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32143','16','','10260','Thread pools discovery','jmx.discovery[beans,"Catalina:type=ThreadPool,name=*"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','1',NULL,'Discovery for ThreadPool','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32144','16','','10260','{#JMXVALUE}: Gzip compression status','jmx[{#JMXOBJ},compression]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'Gzip compression status on {#JMXNAME}. Enabling gzip compression may save server bandwidth.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32145','16','','10260','{#JMXNAME}: Bytes received per second','jmx[{#JMXOBJ},bytesReceived]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'Bytes received rate by processor {#JMXNAME}','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32146','16','','10260','{#JMXNAME}: Bytes sent per second','jmx[{#JMXOBJ},bytesSent]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'Bytes sent rate by processor {#JMXNAME}','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32147','16','','10260','{#JMXNAME}: Errors per second','jmx[{#JMXOBJ},errorCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'Error rate of request processor {#JMXNAME}','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32148','16','','10260','{#JMXNAME}: Requests processing time','jmx[{#JMXOBJ},processingTime]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'The total time to process all incoming requests of request processor {#JMXNAME}','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32149','16','','10260','{#JMXNAME}: Requests per second','jmx[{#JMXOBJ},requestCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'Rate of requests served by request processor {#JMXNAME}','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32150','16','','10260','{#JMXHOST}{#JMXCONTEXT}: Sessions active','jmx[{#JMXOBJ},activeSessions]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'Active sessions of the application.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32151','16','','10260','{#JMXHOST}{#JMXCONTEXT}: Sessions active maximum so far','jmx[{#JMXOBJ},maxActive]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'Maximum number of active sessions so far.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32152','16','','10260','{#JMXHOST}{#JMXCONTEXT}: Sessions allowed maximum','jmx[{#JMXOBJ},maxActiveSessions]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'The maximum number of active Sessions allowed, or -1 for no limit.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32153','16','','10260','{#JMXHOST}{#JMXCONTEXT}: Sessions rejected per second','jmx[{#JMXOBJ},rejectedSessions]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'Rate of sessions we rejected due to maxActive being reached.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32154','16','','10260','{#JMXHOST}{#JMXCONTEXT}: Sessions created per second','jmx[{#JMXOBJ},sessionCounter]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'Rate of sessions created by this application per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32155','16','','10260','{#JMXNAME}: Threads count','jmx[{#JMXOBJ},currentThreadCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'Amount of threads the thread pool has right now, both busy and free.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32156','16','','10260','{#JMXNAME}: Threads busy','jmx[{#JMXOBJ},currentThreadsBusy]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'Number of the requests that are being currently handled.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32157','16','','10260','{#JMXNAME}: Threads limit','jmx[{#JMXOBJ},maxThreads]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$TOMCAT.USER}','{$TOMCAT.PASSWORD}','','','2',NULL,'Limit of the threads count. When currentThreadsBusy counter reaches the maxThreads limit, no more requests could be handled, and the application chokes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32158','19','','10341','Zookeeper: Get server metrics','zookeeper.get_metrics','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','{$ZOOKEEPER.SCHEME}://{HOST.CONN}:{$ZOOKEEPER.PORT}/{$ZOOKEEPER.COMMAND_URL}/monitor','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32159','19','','10341','Zookeeper: Get connections stats','zookeeper.get_connections_stats','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Get information on client connections to server. Note, depending on the number of client connections this operation may be expensive (i.e. impact server performance).','0','30d','0','',NULL,'3s','{$ZOOKEEPER.SCHEME}://{HOST.CONN}:{$ZOOKEEPER.PORT}/{$ZOOKEEPER.COMMAND_URL}/connections','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32193','19','','10341','Clients discovery','zookeeper.clients','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Get list of client connections.
Note, depending on the number of client connections this operation may be expensive (i.e. impact server performance).','0','30d','0','',NULL,'3s','{$ZOOKEEPER.SCHEME}://{HOST.CONN}:{$ZOOKEEPER.PORT}/{$ZOOKEEPER.COMMAND_URL}/connections','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32207','16','','10342','Cluster: Name','jmx["org.apache.cassandra.db:type=StorageService","ClusterName"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32208','16','','10342','Thread pool SecondaryIndexManagement: Currently blocked task','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=SecondaryIndexManagement,name=CurrentlyBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that are currently blocked due to queue saturation but on retry will become unblocked.
SecondaryIndexManagement:Performs updates to secondary indexes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32209','16','','10342','Thread pool HintsDispatcher: Pending tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=HintsDispatcher,name=PendingTasks","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of queued tasks queued up on this pool.
HintsDispatcher:Performs hinted handoff.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32210','16','','10342','Thread pool HintsDispatcher: Total blocked tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=HintsDispatcher,name=TotalBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that were blocked due to queue saturation.
HintsDispatcher:Performs hinted handoff.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32211','16','','10342','Thread pool MemtableFlushWriter: Currently blocked task','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=MemtableFlushWriter,name=CurrentlyBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that are currently blocked due to queue saturation but on retry will become unblocked.
MemtableFlushWriter:Writes memtables to disk.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32212','16','','10342','Thread pool MemtableFlushWriter: Pending tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=MemtableFlushWriter,name=PendingTasks","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of queued tasks queued up on this pool.
MemtableFlushWriter:Writes memtables to disk.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32213','16','','10342','Thread pool MemtableFlushWriter: Total blocked tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=MemtableFlushWriter,name=TotalBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that were blocked due to queue saturation.
MemtableFlushWriter:Writes memtables to disk.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32214','16','','10342','Thread pool MemtablePostFlush: Currently blocked task','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=MemtablePostFlush,name=CurrentlyBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that are currently blocked due to queue saturation but on retry will become unblocked.
MemtablePostFlush:Cleans up commit log after memtable is written to disk.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32215','16','','10342','Thread pool MemtablePostFlush: Pending tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=MemtablePostFlush,name=PendingTasks","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of queued tasks queued up on this pool.
MemtablePostFlush:Cleans up commit log after memtable is written to disk.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32216','16','','10342','Thread pool MemtablePostFlush: Total blocked tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=MemtablePostFlush,name=TotalBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that were blocked due to queue saturation.
MemtablePostFlush:Cleans up commit log after memtable is written to disk.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32217','16','','10342','Thread pool MigrationStage: Currently blocked task','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=MigrationStage,name=CurrentlyBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that are currently blocked due to queue saturation but on retry will become unblocked.
MigrationStage:Runs schema migrations.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32218','16','','10342','Thread pool MigrationStage: Pending tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=MigrationStage,name=PendingTasks","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of queued tasks queued up on this pool.
MigrationStage:Runs schema migrations.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32219','16','','10342','Thread pool MigrationStage: Total blocked tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=MigrationStage,name=TotalBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that were blocked due to queue saturation.
MigrationStage:Runs schema migrations.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32220','16','','10342','Thread pool MiscStage: Currently blocked task','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=MiscStage,name=CurrentlyBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that are currently blocked due to queue saturation but on retry will become unblocked.
MiscStage:Misceleneous tasks run here.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32221','16','','10342','Thread pool MiscStage: Pending tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=MiscStage,name=PendingTasks","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of queued tasks queued up on this pool.
MiscStage:Misceleneous tasks run here.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32222','16','','10342','Thread pool MiscStage: Total blocked tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=MiscStage,name=TotalBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that were blocked due to queue saturation.
MiscStage:Misceleneous tasks run here.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32223','16','','10342','Thread pool SecondaryIndexManagement: Pending tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=SecondaryIndexManagement,name=PendingTasks","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of queued tasks queued up on this pool.
SecondaryIndexManagement:Performs updates to secondary indexes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32224','16','','10342','Storage: Hints','jmx["org.apache.cassandra.metrics:type=Storage,name=TotalHints","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of hint messages written to this node since [re]start. Includes one entry for each host to be hinted per hint.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32225','16','','10342','Thread pool SecondaryIndexManagement: Total blocked tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=SecondaryIndexManagement,name=TotalBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that were blocked due to queue saturation.
SecondaryIndexManagement:Performs updates to secondary indexes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32226','16','','10342','Thread pool CounterMutationStage: Currently blocked task','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=request,scope=CounterMutationStage,name=CurrentlyBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that are currently blocked due to queue saturation but on retry will become unblocked.
CounterMutationStage:Responsible for counter writes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32227','16','','10342','Thread pool CounterMutationStage: Pending tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=request,scope=CounterMutationStage,name=PendingTasks","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of queued tasks queued up on this pool.
CounterMutationStage:Responsible for counter writes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32228','16','','10342','Thread pool CounterMutationStage: Total blocked tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=request,scope=CounterMutationStage,name=TotalBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that were blocked due to queue saturation.
CounterMutationStage:Responsible for counter writes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32229','16','','10342','Thread pool MutationStage: Currently blocked task','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=request,scope=MutationStage,name=CurrentlyBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that are currently blocked due to queue saturation but on retry will become unblocked.
MutationStage:Responsible for writes (exclude materialized and counter writes).','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32230','16','','10342','Thread pool.MutationStage: Pending tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=request,scope=MutationStage,name=PendingTasks","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of queued tasks queued up on this pool.
MutationStage:Responsible for writes (exclude materialized and counter writes).','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32231','16','','10342','Thread pool MutationStage: Total blocked tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=request,scope=MutationStage,name=TotalBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that were blocked due to queue saturation.
MutationStage:Responsible for writes (exclude materialized and counter writes).','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32232','16','','10342','Thread pool ReadStage: Currently blocked task','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=request,scope=ReadStage,name=CurrentlyBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that are currently blocked due to queue saturation but on retry will become unblocked.
ReadStage:Local reads run on this thread pool.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32233','16','','10342','Thread pool ReadStage: Pending tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=request,scope=ReadStage,name=PendingTasks","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of queued tasks queued up on this pool.
ReadStage:Local reads run on this thread pool.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32234','16','','10342','Thread pool ReadStage: Total blocked tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=request,scope=ReadStage,name=TotalBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that were blocked due to queue saturation.
ReadStage:Local reads run on this thread pool.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32235','16','','10342','Thread pool ViewMutationStage: Currently blocked task','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=request,scope=ViewMutationStage,name=CurrentlyBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that are currently blocked due to queue saturation but on retry will become unblocked.
ViewMutationStage:Responsible for materialized view writes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32236','16','','10342','Thread pool ViewMutationStage: Pending tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=request,scope=ViewMutationStage,name=PendingTasks","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of queued tasks queued up on this pool.
ViewMutationStage:Responsible for materialized view writes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32237','16','','10342','Thread pool ViewMutationStage: Total blocked tasks','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=request,scope=ViewMutationStage,name=TotalBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that were blocked due to queue saturation.
ViewMutationStage:Responsible for materialized view writes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32238','16','','10342','Cluster: Nodes down','jmx["org.apache.cassandra.net:type=FailureDetector","DownEndpointCount"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32239','16','','10342','Thread pool HintsDispatcher: Currently blocked task','jmx["org.apache.cassandra.metrics:type=ThreadPools,path=internal,scope=HintsDispatcher,name=CurrentlyBlockedTasks","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of tasks that are currently blocked due to queue saturation but on retry will become unblocked.
HintsDispatcher:Performs hinted handoff.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32240','16','','10342','Storage: Used (bytes)','jmx["org.apache.cassandra.metrics:type=Storage,name=Load","Count"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Size, in bytes, of the on disk data size this node manages.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32241','16','','10342','Version','jmx["org.apache.cassandra.db:type=StorageService","ReleaseVersion"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32242','16','','10342','KeyCache: requests per second','jmx["org.apache.cassandra.metrics:type=Cache,scope=KeyCache,name=Requests","Count"]','1m','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Rate of cache requests.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32243','16','','10342','Compaction: Number of completed tasks','jmx["org.apache.cassandra.metrics:name=CompletedTasks,type=Compaction","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of completed compactions since server [re]start.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32244','16','','10342','Commitlog: Pending tasks','jmx["org.apache.cassandra.metrics:name=PendingTasks,type=CommitLog","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of commit log messages written but yet to be fsync’d.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32245','16','','10342','Latency: Read median','jmx["org.apache.cassandra.metrics:name=ReadLatency,type=Table","50thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Latency read from disk in milliseconds - median.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32246','16','','10342','Latency: Read 75 percentile','jmx["org.apache.cassandra.metrics:name=ReadLatency,type=Table","75thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Latency read from disk in milliseconds - p75.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32247','16','','10342','Latency: Read 95 percentile','jmx["org.apache.cassandra.metrics:name=ReadLatency,type=Table","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Latency read from disk in milliseconds - p95.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32248','16','','10342','Commitlog: Total size','jmx["org.apache.cassandra.metrics:name=TotalCommitLogSize,type=CommitLog","Value"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Current size, in bytes, used by all the commit log segments.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32249','16','','10342','Compaction: Total compactions completed','jmx["org.apache.cassandra.metrics:name=TotalCompactionsCompleted,type=Compaction","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Throughput of completed compactions since server [re]start.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32250','16','','10342','Latency: Write median','jmx["org.apache.cassandra.metrics:name=WriteLatency,type=Table","50thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Latency write to disk in milliseconds - median.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32251','16','','10342','Latency: Write 75 percentile','jmx["org.apache.cassandra.metrics:name=WriteLatency,type=Table","75thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Latency write to disk in milliseconds - p75.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32252','16','','10342','Latency: Write 95 percentile','jmx["org.apache.cassandra.metrics:name=WriteLatency,type=Table","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Latency write to disk in milliseconds - p95.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32253','16','','10342','KeyCache: Capacity','jmx["org.apache.cassandra.metrics:type=Cache,scope=KeyCache,name=Capacity","Value"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Cache capacity in bytes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32254','16','','10342','KeyCache: Entries','jmx["org.apache.cassandra.metrics:type=Cache,scope=KeyCache,name=Entries","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Total number of cache entries.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32255','16','','10342','KeyCache: HitRate','jmx["org.apache.cassandra.metrics:type=Cache,scope=KeyCache,name=HitRate","Value"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'All time cache hit rate.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32256','16','','10342','KeyCache: Hits per second','jmx["org.apache.cassandra.metrics:type=Cache,scope=KeyCache,name=Hits","Count"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Rate of cache hits.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32257','16','','10342','KeyCache: Size','jmx["org.apache.cassandra.metrics:type=Cache,scope=KeyCache,name=Size","Value"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Total size of occupied cache, in bytes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32258','16','','10342','Storage: Errors','jmx["org.apache.cassandra.metrics:type=Storage,name=Exceptions","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of internal exceptions caught. Under normal exceptions this should be zero.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32259','16','','10342','Client connections: Native','jmx["org.apache.cassandra.metrics:type=Client,name=connectedNativeClients","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of clients connected to this nodes native protocol server.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32260','16','','10342','Client connections: Trifts','jmx["org.apache.cassandra.metrics:type=Client,name=connectedThriftClients","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of connected to this nodes thrift clients.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32261','16','','10342','Latency: Client request read median','jmx["org.apache.cassandra.metrics:type=ClientRequest,scope=Read,name=Latency","50thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Total latency serving data to clients in milliseconds - median.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32262','16','','10342','Latency: Client request read 75 percentile','jmx["org.apache.cassandra.metrics:type=ClientRequest,scope=Read,name=Latency","75thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Total latency serving data to clients in milliseconds - p75.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32263','16','','10342','Latency: Client request read 95 percentile','jmx["org.apache.cassandra.metrics:type=ClientRequest,scope=Read,name=Latency","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Total latency serving data to clients in milliseconds - p95.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32264','16','','10342','Client request: Read per second','jmx["org.apache.cassandra.metrics:type=ClientRequest,scope=Read,name=Latency","Count"]','1m','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'The number of client requests per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32265','16','','10342','Latency: Client request write median','jmx["org.apache.cassandra.metrics:type=ClientRequest,scope=Write,name=Latency","50thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Total latency serving write requests from clients in milliseconds - median.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32266','16','','10342','Latency: Client request write 75 percentile','jmx["org.apache.cassandra.metrics:type=ClientRequest,scope=Write,name=Latency","75thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Total latency serving write requests from clients in milliseconds - p75.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32267','16','','10342','Latency: Client request write 95 percentile','jmx["org.apache.cassandra.metrics:type=ClientRequest,scope=Write,name=Latency","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Total latency serving write requests from clients in milliseconds - p95.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32268','16','','10342','Client request: Write per second','jmx["org.apache.cassandra.metrics:type=ClientRequest,scope=Write,name=Latency","Count"]','1m','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'The number of local write requests per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32269','16','','10342','Client request: Write Timeouts','jmx["org.apache.cassandra.metrics:type=ClientRequest,scope=Write,name=Timeouts","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of write requests timeouts encountered.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32270','16','','10342','Compaction: Pending tasks','jmx["org.apache.cassandra.metrics:type=Compaction,name=PendingTasks","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Estimated number of compactions remaining to perform.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32271','16','','10342','Dropped messages: Write (Mutation)','jmx["org.apache.cassandra.metrics:type=DroppedMessage,scope=MUTATION,name=Dropped","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of dropped regular writes messages.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32272','16','','10342','Dropped messages: Read','jmx["org.apache.cassandra.metrics:type=DroppedMessage,scope=READ,name=Dropped","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'Number of dropped regular reads messages.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32273','16','','10342','Cluster: Nodes up','jmx["org.apache.cassandra.net:type=FailureDetector","UpEndpointCount"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','0',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32274','16','','10342','Tables','jmx.discovery[beans,"org.apache.cassandra.metrics:type=Table,keyspace=*,scope=*,name=ReadLatency"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','1',NULL,'Info about keyspaces and tables','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32275','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Bloom filter false ratio','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=BloomFilterFalseRatio","Value"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The ratio of Bloom filter false positives to total checks.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32276','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Row cache hits','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=RowCacheHit","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The number of row cache hits.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32277','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Write latency 95 percentile','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=WriteLatency","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'Latency write to disk in milliseconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32278','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Write latency 75 percentile','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=WriteLatency","75thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'Latency write to disk in milliseconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32279','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Waiting on free memtable space95 percentile','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=WaitingOnFreeMemtableSpace","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The time spent waiting for free memtable space either on- or off-heap - p95.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32280','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Waiting on free memtable space 75 percentile','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=WaitingOnFreeMemtableSpace","75thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The time spent waiting for free memtable space either on- or off-heap - p75.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32281','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Disk space used','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=TotalDiskSpaceUsed","Count"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'Disk space used.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32282','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Tombstone scanned 95 percentile','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=TombstoneScannedHistogram","95thPercentile"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'Number of tombstones scanned per read - p95.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32283','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Tombstone scanned 75 percentile','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=TombstoneScannedHistogram","75thPercentile"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'Number of tombstones scanned per read - p75.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32284','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: SS Tables per read 95 percentile','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=SSTablesPerReadHistogram","95thPercentile"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The number of SSTable data files accessed per read - p95.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32285','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: SS Tables per read 75 percentile','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=SSTablesPerReadHistogram","75thPercentile"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The number of SSTable data files accessed per read - p75.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32286','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Snapshots size','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=SnapshotsSize","Value"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The disk space truly used by snapshots.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32287','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Row cache misses','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=RowCacheMiss","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The number of table row cache misses.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32288','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Out of row cache hits','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=RowCacheHitOutOfRange","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The number of row cache hits that do not satisfy the query filter and went to disk.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32289','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Read per second','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=ReadLatency","Count"]','1m','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The number of client requests per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32290','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Bytes flushed','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=BytesFlushed","Count"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The amount of data that was flushed since (re)start.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32291','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Read latency 95 percentile','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=ReadLatency","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'Latency read from disk in milliseconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32292','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Read latency 75 percentile','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=ReadLatency","75thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'Latency read from disk in milliseconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32293','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Pending flushes','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=PendingFlushes","Count"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The number of pending flushes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32294','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Pending compactions','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=PendingCompactions","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The number of pending compactions.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32295','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Mean partition size','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=MeanPartitionSize","Value"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The average size of compacted partition.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32296','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Max sartition size','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=MaxPartitionSize","Value"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The size of the largest compacted partition.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32297','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Live SS Table','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=LiveSSTableCount","Value"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'Number of "live" (in use) SSTables.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32298','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Live disk space used','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=LiveDiskSpaceUsed","Count"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The disk space used by "live" SSTables (only counts in use files).','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32299','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: KeyCache hit rate','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=KeyCacheHitRate","Value"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The key cache hit rate.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32300','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Compression ratio','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=CompressionRatio","Value"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The compression ratio for all SSTables.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32301','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Compaction bytes written','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=CompactionBytesWritten","Count"]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The amount of data that was compacted since (re)start.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32302','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Col update time delta 95 percentile','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=ColUpdateTimeDeltaHistogram","95thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The column update time delta - p95.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32303','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Col update time delta75 percentile','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=ColUpdateTimeDeltaHistogram","75thPercentile"]','1m','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The column update time delta - p75.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32304','16','','10342','{#JMXKEYSPACE}.{#JMXSCOPE}: Write per second','jmx["org.apache.cassandra.metrics:type=Table,keyspace={#JMXKEYSPACE},scope={#JMXSCOPE},name=WriteLatency","Count"]','1m','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','{$CASSANDRA.USER}','{$CASSANDRA.PASSWORD}','','','2',NULL,'The number of local write requests per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32307','20','1.3.6.1.2.1.99.1.1.1.4.{#SNMPINDEX}','10254','{#SENSOR_INFO}: Voltage','sensor.voltage.value[entPhySensorValue.{#SNMPINDEX}]','1m','90d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-SENSORS-MIB
The most recent measurement obtained by the agent for this sensor.
To correctly interpret the value of this object, the associated entPhySensorType,
entPhySensorScale, and entPhySensorPrecision objects must also be examined.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32308','20','1.3.6.1.4.1.33333.5.64.0','10343','Array: Sweep Pmax','array.sweep_pmax[arrayMaxPowerSweep.0]','1m','7d','365d','0','0','','W','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Array Max. Power (sweep)
 Description:Array Max. Power (last sweep)
 Scaling Factor:1.0
 Units:W
 Range:[0.0, 500]
 Modbus address:0x003E','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32309','20','1.3.6.1.4.1.33333.5.53.0','10343','Load: State','load.state[loadState.0]','1m','7d','365d','0','0','','','','',NULL,'124','','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Load State
 Description:Load State
 Modbus address:0x002E

 0: Start
1: Normal
2: LvdWarning
3: Lvd
4: Fault
5: Disconnect
6: NormalOff
7: Override
8: NotUsed','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32310','20','1.3.6.1.4.1.33333.5.39.0','10343','Temperature: Battery','temp.battery[batteryTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Battery Temperature
  Description:Battery Temperature
  Scaling Factor:1.0
  Units:deg C
  Range:[-128, 127]
  Modbus address:0x001B','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32311','20','1.3.6.1.4.1.33333.5.40.0','10343','Temperature: Ambient','temp.ambient[ambientTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Ambient Temperature
 Description:Ambient Temperature
 Scaling Factor:1.0
 Units:deg C
 Range:[-128, 127]
 Modbus address:0x001C','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32312','20','1.3.6.1.4.1.33333.5.48.0','10343','Battery: Target Voltage','target.voltage[targetVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Target Voltage
 Description:Target Regulation Voltage
 Scaling Factor:1.0
 Units:V
 Range:[0.0, 80.0]
 Modbus address:0x0024','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32313','20','1.3.6.1.2.1.1.3.0','10343','Status: Uptime','status.uptime','1m','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'Device uptime in seconds','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32314','20','1.3.6.1.4.1.33333.5.54.0','10343','Status: Load Faults','status.load_faults[loadFaults.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Description:Array Faults
Modbus address:0x0022','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32315','20','1.3.6.1.4.1.33333.5.46.0','10343','Status: Array Faults','status.array_faults[arrayFaults.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Description:Array Faults
Modbus address:0x0022','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32316','20','1.3.6.1.4.1.33333.5.59.0','10343','Status: Alarms','status.alarms[alarms.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Description:Alarms
Modbus addresses:H=0x0038 L=0x0039','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32317','20','1.3.6.1.4.1.33333.5.32.0','10343','Load: Voltage','load.voltage[loadVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Load Voltage
 Description:Load Voltage
 Scaling Factor:1.0
 Units:V
 Range:[0, 80]
 Modbus address:0x0014','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32318','20','1.3.6.1.4.1.33333.5.34.0','10343','Load: Current','load.current[loadCurrent.0]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Load Current
 Description:Load Current
 Scaling Factor:1.0
 Units:A
 Range:[0, 60]
 Modbus address:0x0016','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32319','20','1.3.6.1.4.1.33333.5.63.0','10343','Array: Sweep Vmp','array.sweep_vmp[arrayVmp.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Array Vmp
  Description:Array Max. Power Point Voltage
  Scaling Factor:1.0
  Units:V
  Range:[0.0, 5000.0]
  Modbus address:0x003D','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32320','20','1.3.6.1.4.1.33333.5.56.0','10343','Counter: Load Amp-hours','counter.load_amp_hours[ahLoadResettable.0]','1m','7d','365d','0','0','','Ah','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Description:Ah Load (Resettable)
Scaling Factor:0.1
Units:Ah
Range:[0.0, 4294967294]
Modbus addresses:H=0x0032 L=0x0033','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32321','20','1.3.6.1.4.1.33333.5.51.0','10343','Counter: Charge KW-hours','counter.charge_kw_hours[kwhChargeResettable.0]','1m','7d','365d','0','0','','!kWh','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
kWh Charge (Resettable)
Description:Kilowatt Hours Charge (Resettable)
Scaling Factor:1.0
Units:kWh
Range:[0.0, 65535]
Modbus address:0x002A','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32322','20','1.3.6.1.4.1.33333.5.49.0','10343','Counter: Charge Amp-hours','counter.charge_amp_hours[ahChargeResettable.0]','1m','7d','365d','0','0','','Ah','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Ah Charge (Resettable)
 Description:Ah Charge (Resettable)
 Scaling Factor:0.1
 Units:Ah
 Range:[0.0, 4294967294]
 Modbus addresses:H=0x0026 L=0x0027','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32323','20','1.3.6.1.4.1.33333.5.45.0','10343','Battery: Charge State','charge.state[chargeState.0]','1m','7d','365d','0','0','','','','',NULL,'123','','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Charge State
  Description:Control State
  Modbus address:0x0021

  0: Start
  1: NightCheck
  2: Disconnect
  3: Night
  4: Fault
  5: BulkMppt
  6: Absorption
  7: Float
  8: Equalize
  9: Slave
  10: Fixed','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32324','20','1.3.6.1.4.1.33333.5.33.0','10343','Battery: Charge Current','charge.current[chargeCurrent.0]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Charge Current
  Description:Charge Current
  Scaling Factor:1.0
  Units:A
  Range:[0, 40]
  Modbus address:0x0010','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32325','20','1.3.6.1.4.1.33333.5.30.0','10343','Battery: Battery Voltage discovery','battery.voltage.discovery[batteryTerminalVoltage.0]','15m','0','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32326','20','1.3.6.1.4.1.33333.5.31.0','10343','Array: Voltage','array.voltage[arrayVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Array Voltage
  Description:Array Voltage
  Scaling Factor:1.0
  Units:V
  Range:[0, 80]
  Modbus address:0x0013','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32327','20','1.3.6.1.4.1.33333.5.65.0','10343','Array: Sweep Voc','array.sweep_voc[arrayVoc.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Array Voc
 Description:Array Open Circuit Voltage
 Scaling Factor:1.0
 Units:V
 Range:[0.0, 80.0]
 Modbus address:0x003F','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32328','20','1.3.6.1.4.1.33333.5.38.0','10343','Temperature: Heatsink','temp.heatsink[heatsinkTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-MPPT
Heatsink Temperature
 Description:Heatsink Temperature
 Scaling Factor:1.0
 Units:deg C
 Range:[-128, 127]
 Modbus address:0x001A','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32330','20','1.3.6.1.4.1.33333.5.30.0','10343','Battery: Voltage{#SINGLETON}','battery.voltage[batteryTerminalVoltage.0{#SINGLETON}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PROSTAR-MPPT
Battery Terminal Voltage
Description:Battery  Terminal Voltage
Scaling Factor:1.0
Units:V
Range:[0.0, 80.0]
Modbus address:0x0012','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32331','20','1.3.6.1.4.1.33333.6.31.0','10344','Array: Voltage','array.voltage[arrayVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Array Voltage
Scaling Factor:1.0
Units:V
Range:[0, 80]
Modbus address:0x0013','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32332','20','1.3.6.1.4.1.33333.6.59.0','10344','Status: Alarms','status.alarms[alarms.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Alarms
Modbus addresses:H=0x0038 L=0x0039','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32333','20','1.3.6.1.4.1.33333.6.39.0','10344','Temperature: Battery','temp.battery[batteryTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Battery Temperature
Scaling Factor:1.0
Units:deg C
Range:[-128, 127]
Modbus address:0x001B','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32334','20','1.3.6.1.4.1.33333.6.40.0','10344','Temperature: Ambient','temp.ambient[ambientTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Ambient Temperature
Scaling Factor:1.0
Units:deg C
Range:[-128, 127]
Modbus address:0x001C','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32335','20','1.3.6.1.4.1.33333.6.48.0','10344','Battery: Target Voltage','target.voltage[targetVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Target Regulation Voltage
Scaling Factor:1.0
Units:V
Range:[0.0, 80.0]
Modbus address:0x0024','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32336','20','1.3.6.1.2.1.1.3.0','10344','Status: Uptime','status.uptime','1m','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'Device uptime in seconds','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32337','20','1.3.6.1.4.1.33333.6.54.0','10344','Status: Load Faults','status.load_faults[loadFaults.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Load Faults
Modbus address:0x002F','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32338','20','1.3.6.1.4.1.33333.6.46.0','10344','Status: Array Faults','status.array_faults[arrayFaults.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Array Faults
Modbus address:0x0022','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32339','20','1.3.6.1.4.1.33333.6.32.0','10344','Load: Voltage','load.voltage[loadVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Load Voltage
Scaling Factor:1.0
Units:V
Range:[0, 80]
Modbus address:0x0014','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32340','20','1.3.6.1.4.1.33333.6.30.0','10344','Battery: Battery Voltage discovery','battery.voltage.discovery[batteryTerminalVoltage.0]','15m','0','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32341','20','1.3.6.1.4.1.33333.6.53.0','10344','Load: State','load.state[loadState.0]','1m','7d','365d','0','0','','','','',NULL,'126','','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Load State
Modbus address:0x002E

0: Start
1: Normal
2: LvdWarning
3: Lvd
4: Fault
5: Disconnect
6: NormalOff
7: Override
8: NotUsed','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32342','20','1.3.6.1.4.1.33333.6.34.0','10344','Load: Current','load.current[loadCurrent.0]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Load Current
Scaling Factor:1.0
Units:A
Range:[0, 60]
Modbus address:0x0016','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32343','20','1.3.6.1.4.1.33333.6.56.0','10344','Counter: Load Amp-hours','counter.load_amp_hours[ahLoadResettable.0]','1m','7d','365d','0','0','','Ah','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Ah Load (Resettable)
Scaling Factor:0.1
Units:Ah
Range:[0.0, 4294967294]
Modbus addresses:H=0x0032 L=0x0033','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32344','20','1.3.6.1.4.1.33333.6.51.0','10344','Counter: Charge KW-hours','counter.charge_kw_hours[kwhChargeResettable.0]','1m','7d','365d','0','0','','!kWh','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Kilowatt Hours Charge (Resettable)
Scaling Factor:1.0
Units:kWh
Range:[0.0, 65535]
Modbus address:0x002A','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32345','20','1.3.6.1.4.1.33333.6.49.0','10344','Counter: Charge Amp-hours','counter.charge_amp_hours[ahChargeResettable.0]','1m','7d','365d','0','0','','Ah','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Ah Charge (Resettable)
Scaling Factor:0.1
Units:Ah
Range:[0.0, 4294967294]
Modbus addresses:H=0x0026 L=0x0027','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32346','20','1.3.6.1.4.1.33333.6.45.0','10344','Battery: Charge State','charge.state[chargeState.0]','1m','7d','365d','0','0','','','','',NULL,'125','','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Control State
Modbus address:0x0021

0: Start
1: NightCheck
2: Disconnect
3: Night
4: Fault
5: Bulk
6: Pwm
7: Float
8: Equalize','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32347','20','1.3.6.1.4.1.33333.6.33.0','10344','Battery: Charge Current','charge.current[chargeCurrent.0]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Charge Current
Scaling Factor:1.0
Units:A
Range:[0, 40]
Modbus address:0x0011','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32348','20','1.3.6.1.4.1.33333.6.38.0','10344','Temperature: Heatsink','temp.heatsink[heatsinkTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PROSTAR-PWM
Description:Heatsink Temperature
Scaling Factor:1.0
Units:deg C
Range:[-128, 127]
Modbus address:0x001A','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32350','20','1.3.6.1.4.1.33333.6.30.0','10344','Battery: Voltage{#SINGLETON}','battery.voltage[batteryTerminalVoltage.0{#SINGLETON}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PROSTAR-PWM
Description:Control State
Modbus address:0x0021','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32351','20','1.3.6.1.4.1.33333.3.57.0','10345','Array: Sweep Pmax','array.sweep_pmax[arrayMaxPowerSweep.0]','1m','7d','365d','0','0','','W','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Array Open Circuit Voltage
Scaling Factor:0.0030517578125
Units:V
Range:[0.0, 80.0]
Modbus address:0x002A','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32352','20','1.3.6.1.4.1.33333.3.46.0','10345','Load: State','load.state[loadState.0]','1m','7d','365d','0','0','','','','',NULL,'129','','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Load State
Modbus address:0x001A

0: Start
1: Normal
2: LvdWarning
3: Lvd
4: Fault
5: Disconnect
6: NormalOff
7: Override
8: NotUsed','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32353','20','1.3.6.1.4.1.33333.3.36.0','10345','Temperature: Battery','temp.battery[batteryTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Heatsink Temperature
Scaling Factor:1.0
Units:deg C
Range:[-128, 127]
Modbus address:0x000D','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32354','20','1.3.6.1.4.1.33333.3.37.0','10345','Temperature: Ambient','temp.ambient[ambientTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Ambient Temperature
Scaling Factor:1.0
Units:deg C
Range:[-128, 127]
Modbus address:0x000F','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32355','20','1.3.6.1.4.1.33333.3.42.0','10345','Battery: Target Voltage','target.voltage[targetVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Target Regulation Voltage
Scaling Factor:0.0030517578125
Units:V
Range:[0.0, 80.0]
Modbus address:0x0014','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32356','20','1.3.6.1.2.1.1.3.0','10345','Status: Uptime','status.uptime','1m','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'Device uptime in seconds','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32357','20','1.3.6.1.4.1.33333.3.47.0','10345','Status: Load Faults','status.load_faults[loadFaults.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Array Faults
Modbus address:0x0012','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32358','20','1.3.6.1.4.1.33333.3.40.0','10345','Status: Array Faults','status.array_faults[arrayFaults.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Array Faults
Modbus address:0x0012','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32359','20','1.3.6.1.4.1.33333.3.52.0','10345','Status: Alarms','status.alarms[alarms.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Alarms
Modbus addresses:H=0x0023 L=0x0024','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32360','20','1.3.6.1.4.1.33333.3.32.0','10345','Load: Voltage','load.voltage[loadVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Load Voltage
Scaling Factor:0.0030517578125
Units:V
Range:[0, 80]
Modbus address:0x000A','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32361','20','1.3.6.1.4.1.33333.3.34.0','10345','Load: Current','load.current[loadCurrent.0]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Load Current
Scaling Factor:0.002415771484375
Units:A
Range:[0, 60]
Modbus address:0x000C','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32362','20','1.3.6.1.4.1.33333.3.56.0','10345','Array: Sweep Vmp','array.sweep_vmp[arrayVmp.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Array Max. Power Point Voltage
Scaling Factor:0.0030517578125
Units:V
Range:[0.0, 5000.0]
Modbus address:0x0028','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32363','20','1.3.6.1.4.1.33333.3.49.0','10345','Counter: Load Amp-hours','counter.load_amp_hours[ahLoadResettable.0]','1m','7d','365d','0','0','','Ah','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Ah Load(Resettable)
Scaling Factor:0.1
Units:Ah
Range:[0.0, 4294967294]
Modbus addresses:H=0x001D L=0x001E','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32364','20','1.3.6.1.4.1.33333.3.45.0','10345','Counter: Charge KW-hours','counter.charge_kw_hours[kwhCharge.0]','1m','7d','365d','0','3','','!kWh','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32365','20','1.3.6.1.4.1.33333.3.43.0','10345','Counter: Charge Amp-hours','counter.charge_amp_hours[ahChargeResettable.0]','1m','7d','365d','0','0','','Ah','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Ah Charge(Resettable)
Scaling Factor:0.1
Units:Ah
Range:[0.0, 4294967294]
Modbus addresses:H=0x0015 L=0x0016','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32366','20','1.3.6.1.4.1.33333.3.39.0','10345','Battery: Charge State','charge.state[chargeState.0]','1m','7d','365d','0','0','','','','',NULL,'128','','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Control State
Modbus address:0x0011

0: Start
1: NightCheck
2: Disconnect
3: Night
4: Fault
5: BulkMppt
6: Pwm
7: Float
8: Equalize','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32367','20','1.3.6.1.4.1.33333.3.33.0','10345','Battery: Charge Current','charge.current[chargeCurrent.0]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Target Regulation Voltage
Scaling Factor:0.0030517578125
Units:V
Range:[0.0, 80.0]
Modbus address:0x0014','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32368','20','1.3.6.1.4.1.33333.3.30.0','10345','Battery: Battery Voltage discovery','battery.voltage.discovery[batteryVoltage.0]','15m','0','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32369','20','1.3.6.1.4.1.33333.3.31.0','10345','Array: Voltage','array.voltage[arrayVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Array Voltage
Scaling Factor:0.0030517578125
Units:V
Range:[0, 80]
Modbus address:0x0009','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32370','20','1.3.6.1.4.1.33333.3.58.0','10345','Array: Sweep Voc','array.sweep_voc[arrayVoc.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Array Open Circuit Voltage
Scaling Factor:0.0030517578125
Units:V
Range:[0.0, 80.0]
Modbus address:0x002A','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32371','20','1.3.6.1.4.1.33333.3.35.0','10345','Temperature: Heatsink','temp.heatsink[heatsinkTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SUNSAVER-MPPT
Description:Battery Temperature
Scaling Factor:1.0
Units:deg C
Range:[-128, 127]
Modbus address:0x000E','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32373','20','1.3.6.1.4.1.33333.3.30.0','10345','Battery: Voltage{#SINGLETON}','battery.voltage[batteryVoltage.0{#SINGLETON}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: SUNSAVER-MPPT
Description:Control State
Modbus address:0x0011','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32374','20','1.3.6.1.4.1.33333.9.30.0','10346','Battery: Battery Voltage discovery','battery.voltage.discovery[batteryVoltageSlow.0]','15m','0','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SURESINE','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32375','20','1.3.6.1.4.1.33333.9.31.0','10346','Load: A/C Current','load.ac_current[acCurrent.0]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SURESINE
Description:AC Output Current
Scaling Factor:0.0001953125
Units:A
Range:[0.0, 17]
Modbus address:0x0005','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32376','20','1.3.6.1.4.1.33333.9.33.0','10346','Load: State','load.state[loadState.0]','1m','7d','365d','0','0','','','','',NULL,'130','','','0','','','','','0',NULL,'MIB: SURESINE
Description:Load State
Modbus address:0x000B

 0: Start
1: LoadOn
2: LvdWarning
3: LowVoltageDisconnect
4: Fault
5: Disconnect
6: NormalOff
7: UnknownState
8: Standby','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32377','20','1.3.6.1.4.1.33333.9.34.0','10346','Status: Alarms','status.alarms[alarms.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SURESINE
Description:Faults
Modbus address:0x0007','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32378','20','1.3.6.1.4.1.33333.9.35.0','10346','Status: Faults','status.faults[faults.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SURESINE
Description:Faults
Modbus address:0x0007','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32379','20','1.3.6.1.2.1.1.3.0','10346','Status: Uptime','status.uptime','1m','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'Device uptime in seconds','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32380','20','1.3.6.1.4.1.33333.9.32.0','10346','Temperature: Heatsink','temp.heatsink[heatsinkTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SURESINE
Description:Heatsink Temperature
Scaling Factor:1
Units:C
Range:[-128, 127]
Modbus address:0x0006','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32382','20','1.3.6.1.4.1.33333.9.30.0','10346','Battery: Voltage{#SINGLETON}','battery.voltage[batteryVoltageSlow.0{#SINGLETON}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: SURESINE
Description:Battery Voltage(slow)
Scaling Factor:0.0002581787109375
Units:V
Range:[0.0, 17.0]
Modbus address:0x0004','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32383','20','1.3.6.1.4.1.33333.7.31.0','10347','Array: Array Current','array.current[arrayCurrent.0]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Array Current
Scaling Factor:1.0
Units:A
Range:[-10, 80]
Modbus address:0x001d','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32384','20','1.3.6.1.4.1.33333.7.50.0','10347','Counter: Charge Amp-hours','counter.charge_amp_hours[ahChargeResetable.0]','1m','7d','365d','0','0','','Ah','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Ah Charge Resettable
Scaling Factor:1.0
Units:Ah
Range:[0.0, 5000]
Modbus addresses:H=0x0034 L=0x0035','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32385','20','1.3.6.1.4.1.33333.7.48.0','10347','Temperature: Battery','temp.battery[batteryTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Batt. Temp
Scaling Factor:1.0
Units:C
Range:[-40, 80]
Modbus address:0x0025','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32386','20','1.3.6.1.4.1.33333.7.45.0','10347','Battery: Target Voltage','target.voltage[targetRegulationVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Target Voltage
Scaling Factor:1.0
Units:V
Range:[-10, 650.0]
Modbus address:0x0033','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32387','20','1.3.6.1.2.1.1.3.0','10347','Status: Uptime','status.uptime','1m','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'Device uptime in seconds','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32388','20','1.3.6.1.4.1.33333.7.55.0','10347','Status: Faults','status.faults[faults.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Faults
Modbus addresses:H=0x002c L=0x002d','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32389','20','1.3.6.1.4.1.33333.7.57.0','10347','Status: Alarms','status.alarms[alarms.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Alarms
Modbus addresses:H=0x002e L=0x002f','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32390','20','1.3.6.1.4.1.33333.7.52.0','10347','Counter: Charge KW-hours','counter.charge_kw_hours[kwhChargeResetable.0]','1m','7d','365d','0','0','','!kWh','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:kWh Charge Resettable
Scaling Factor:1.0
Units:kWh
Range:[0.0, 65535.0]
Modbus address:0x0038','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32391','20','1.3.6.1.4.1.33333.7.46.0','10347','Battery: Charge State','charge.state[chargeState.0]','1m','7d','365d','0','0','','','','',NULL,'131','','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Charge State
Modbus address:0x0032

0: Start
1: NightCheck
2: Disconnect
3: Night
4: Fault
5: Mppt
6: Absorption
7: Float
8: Equalize
9: Slave
10: Fixed','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32392','20','1.3.6.1.4.1.33333.7.33.0','10347','Array: Sweep Pmax','array.sweep_pmax[arrayPmaxLastSweep.0]','1m','7d','365d','0','0','','W','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Pmax (last sweep)
Scaling Factor:1.0
Units:W
Range:[-10, 5000]
Modbus address:0x003c','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32393','20','1.3.6.1.4.1.33333.7.44.0','10347','Battery: Output Power','charge.output_power[ outputPower.0]','1m','7d','365d','0','0','','W','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Output Power
Scaling Factor:1.0
Units:W
Range:[-10, 4000]
Modbus address:0x003a','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32394','20','1.3.6.1.4.1.33333.7.42.0','10347','Battery: Charge Current','charge.current[batteryCurrent.0]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Battery Current
Scaling Factor:1.0
Units:A
Range:[-10, 80]
Modbus address:0x001c','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32395','20','1.3.6.1.4.1.33333.7.36.0','10347','Battery: Battery Voltage discovery','battery.voltage.discovery[batteryVoltage.0]','15m','0','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Battery voltage
Scaling Factor:1.0
Units:V
Range:[-10, 80]
Modbus address:0x0018','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32396','20','1.3.6.1.4.1.33333.7.30.0','10347','Array: Voltage','array.voltage[arrayVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Array Voltage
Scaling Factor:1.0
Units:V
Range:[-10, 650]
Modbus address:0x001b','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32397','20','1.3.6.1.4.1.33333.7.35.0','10347','Array: Sweep Voc','array.sweep_voc[arrayVocLastSweep.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Voc (last sweep)
Scaling Factor:1.0
Units:V
Range:[-10, 650.0]
Modbus address:0x003e','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32398','20','1.3.6.1.4.1.33333.7.34.0','10347','Array: Sweep Vmp','array.sweep_vmp[arrayVmpLastSweep.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Vmp (last sweep)
Scaling Factor:1.0
Units:V
Range:[-10, 650.0]
Modbus address:0x003d','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32399','20','1.3.6.1.4.1.33333.7.49.0','10347','Temperature: Heatsink','temp.heatsink[heatsinkTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:HS Temp
Scaling Factor:1.0
Units:C
Range:[-40, 80]
Modbus address:0x0023','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32401','20','1.3.6.1.4.1.33333.7.36.0','10347','Battery: Voltage{#SINGLETON}','battery.voltage[batteryVoltage.0{#SINGLETON}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TRISTAR-MPPT
Description:Battery voltage
Scaling Factor:1.0
Units:V
Range:[-10, 80]
Modbus address:0x0018','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32402','20','1.3.6.1.4.1.33333.2.31.0','10348','Array: Array Current','array.current[arrayCurrent.0]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Array Current
Scaling Factor:0.00244140625
Units:A
Range:[-10, 80]
Modbus address:0x001d','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32403','20','1.3.6.1.4.1.33333.2.50.0','10348','Counter: Charge Amp-hours','counter.charge_amp_hours[ahChargeResetable.0]','1m','7d','365d','0','0','','Ah','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Ah Charge Resettable
Scaling Factor:0.1
Units:Ah
Range:[0.0, 5000]
Modbus addresses:H=0x0034 L=0x0035','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32404','20','1.3.6.1.4.1.33333.2.48.0','10348','Temperature: Battery','temp.battery[batteryTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Batt. Temp
Scaling Factor:1.0
Units:C
Range:[-40, 80]
Modbus address:0x0025','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32405','20','1.3.6.1.4.1.33333.2.45.0','10348','Battery: Target Voltage','target.voltage[targetRegulationVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Target Voltage
Scaling Factor:0.0054931640625
Units:V
Range:[-10, 180.0]
Modbus address:0x0033','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32406','20','1.3.6.1.2.1.1.3.0','10348','Status: Uptime','status.uptime','1m','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'Device uptime in seconds','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32407','20','1.3.6.1.4.1.33333.2.55.0','10348','Status: Faults','status.faults[faults.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Faults
Modbus address:0x002c','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32408','20','1.3.6.1.4.1.33333.2.57.0','10348','Status: Alarms','status.alarms[alarms.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Faults
Modbus address:0x002c','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32409','20','1.3.6.1.4.1.33333.2.52.0','10348','Counter: Charge KW-hours','counter.charge_kw_hours[kwhChargeResetable.0]','1m','7d','365d','0','3','','!kWh','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:kWh Charge Resettable
Scaling Factor:0.1
Units:kWh
Range:[0.0, 65535.0]
Modbus address:0x0038','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32410','20','1.3.6.1.4.1.33333.2.46.0','10348','Battery: Charge State','charge.state[chargeState.0]','1m','7d','365d','0','0','','','','',NULL,'132','','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Charge State
Modbus address:0x0032

0: Start
1: NightCheck
2: Disconnect
3: Night
4: Fault
5: Mppt
6: Absorption
7: Float
8: Equalize
9: Slave','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32411','20','1.3.6.1.4.1.33333.2.33.0','10348','Array: Sweep Pmax','array.sweep_pmax[arrayPmaxLastSweep.0]','1m','7d','365d','0','0','','W','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Pmax (last sweep)
Scaling Factor:0.10986328125
Units:W
Range:[-10, 5000]
Modbus address:0x003c','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32412','20','1.3.6.1.4.1.33333.2.44.0','10348','Battery: Output Power','charge.output_power[ outputPower.0]','1m','7d','365d','0','0','','W','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Output Power
Scaling Factor:0.10986328125
Units:W
Range:[-10, 5000]
Modbus address:0x003a','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32413','20','1.3.6.1.4.1.33333.2.42.0','10348','Battery: Charge Current','charge.current[batteryCurrent.0]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Battery Current
Scaling Factor:0.00244140625
Units:A
Range:[-10, 80]
Modbus address:0x001c','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32414','20','1.3.6.1.4.1.33333.2.36.0','10348','Battery: Battery Voltage discovery','battery.voltage.discovery[batteryVoltage.0]','15m','0','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32415','20','1.3.6.1.4.1.33333.2.30.0','10348','Array: Voltage','array.voltage[arrayVoltage.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Array Voltage
Scaling Factor:0.0054931640625
Units:V
Range:[-10, 180]
Modbus address:0x001b','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32416','20','1.3.6.1.4.1.33333.2.35.0','10348','Array: Sweep Voc','array.sweep_voc[arrayVocLastSweep.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Voc (last sweep)
Scaling Factor:0.0054931640625
Units:V
Range:[-10, 180.0]
Modbus address:0x003e','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32417','20','1.3.6.1.4.1.33333.2.34.0','10348','Array: Sweep Vmp','array.sweep_vmp[arrayVmpLastSweep.0]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:Vmp (last sweep)
Scaling Factor:0.0054931640625
Units:V
Range:[-10, 180.0]
Modbus address:0x003d','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32418','20','1.3.6.1.4.1.33333.2.49.0','10348','Temperature: Heatsink','temp.heatsink[heatsinkTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR-MPPT
Description:HS Temp
Scaling Factor:1.0
Units:C
Range:[-40, 80]
Modbus address:0x0023','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32420','20','1.3.6.1.4.1.33333.2.36.0','10348','Battery: Voltage{#SINGLETON}','battery.voltage[batteryVoltage.0{#SINGLETON}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TRISTAR-MPPT
Description:Battery voltage
Scaling Factor:0.0054931640625
Units:V
Range:[-10, 180.0]
Modbus address:0x0018','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32421','20','1.3.6.1.4.1.33333.8.30.0','10349','Battery: Battery Voltage discovery','battery.voltage.discovery[batteryVoltage.0]','15m','0','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR
Description:Battery voltage
Scaling Factor:0.002950042724609375
Units:V
Range:[0.0, 80.0]
Modbus address:0x0008','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32422','20','1.3.6.1.4.1.33333.8.45.0','10349','Status: Control Mode','control.mode[controlMode.0]','1m','7d','365d','0','0','','','','',NULL,'135','','','0','','','','','0',NULL,'MIB: TRISTAR
Description:Control Mode
Modbus address:0x001A

0: charge
1: loadControl
2: diversion
3: lighting','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32423','20','1.3.6.1.4.1.33333.8.39.0','10349','Counter: Amp-hours','counter.charge_amp_hours[ahResettable.0]','1m','7d','365d','0','0','','Ah','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR
Description:Ah (Resettable)
Scaling Factor:0.1
Units:Ah
Range:[0.0, 50000.0]
Modbus addresses:H=0x0011 L=0x0012','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32424','20','1.3.6.1.4.1.33333.8.49.0','10349','Counter: KW-hours','counter.charge_kw_hours[kilowattHours.0]','1m','7d','365d','0','0','','!kWh','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR
Description:Kilowatt Hours
Scaling Factor:1.0
Units:kWh
Range:[0.0, 5000.0]
Modbus address:0x001E','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32425','20','1.3.6.1.4.1.33333.8.42.0','10349','Status: Alarms','status.alarms[alarms.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR
Description:Alarms
Modbus addresses:H=0x001D L=0x0017','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32426','20','1.3.6.1.4.1.33333.8.43.0','10349','Status: Faults','status.faults[faults.0]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR
Description:Battery voltage
Scaling Factor:0.002950042724609375
Units:V
Range:[0.0, 80.0]
Modbus address:0x0008','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32427','20','1.3.6.1.2.1.1.3.0','10349','Status: Uptime','status.uptime','1m','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'Device uptime in seconds','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32428','20','1.3.6.1.4.1.33333.8.37.0','10349','Temperature: Battery','temp.battery[batteryTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR
Description:Battery Temperature
Scaling Factor:1.0
Units:deg C
Range:[-40, 120]
Modbus address:0x000F','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32429','20','1.3.6.1.4.1.33333.8.36.0','10349','Temperature: Heatsink','temp.heatsink[heatsinkTemperature.0]','1m','7d','365d','0','0','','C','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: TRISTAR
Description:Heatsink Temperature
Scaling Factor:1.0
Units:deg C
Range:[-40, 120]
Modbus address:0x000E','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32436','20','1.3.6.1.4.1.33333.8.30.0','10349','Battery: Voltage{#SINGLETON}','battery.voltage[batteryVoltage.0{#SINGLETON}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TRISTAR
Description:Battery voltage
Scaling Factor:0.002950042724609375
Units:V
Range:[0.0, 80.0]
Modbus address:0x0008','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32437','20','1.3.6.1.4.1.33333.8.46.0','10349','Battery: Charge State{#SINGLETON}','charge.state[controlState.0{#SINGLETON}]','1m','7d','365d','0','0','','','','',NULL,'133','','','0','','','','','2',NULL,'MIB: TRISTAR
Description:Control State
Modbus address:0x001B','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32438','20','1.3.6.1.4.1.33333.8.38.0','10349','Battery: Target Voltage{#SINGLETON}','target.voltage[targetVoltage.0{#SINGLETON}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TRISTAR
Description:Target Regulation Voltage
Scaling Factor:0.002950042724609375
Units:V
Range:[0.0, 80.0]
Modbus address:0x0010','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32439','20','1.3.6.1.4.1.33333.8.32.0','10349','Array: Voltage{#SINGLETON}','array.voltage[arrayloadVoltage.0{#SINGLETON}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TRISTAR
Description:Array/Load Voltage
Scaling Factor:0.00424652099609375
Units:V
Range:[0, 80]
Modbus address:0x000A','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32440','20','1.3.6.1.4.1.33333.8.33.0','10349','Battery: Charge Current{#SINGLETON}','charge.current[chargeCurrent.0{#SINGLETON}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TRISTAR
Description:Charge Current
Scaling Factor:0.002034515380859375
Units:A
Range:[0, 60]
Modbus address:0x000B','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32441','20','1.3.6.1.4.1.33333.8.48.0','10349','Load: PWM Duty Cycle{#SINGLETON}','diversion.pwm_duty_cycle[pwmDutyCycle.0{#SINGLETON}]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TRISTAR
Description:PWM Duty Cycle
Scaling Factor:0.392156862745098
Units:%
Range:[0.0, 100.0]
Modbus address:0x001C','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32442','20','1.3.6.1.4.1.33333.8.34.0','10349','Load: Current{#SINGLETON}','load.current[loadCurrent.0{#SINGLETON}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TRISTAR
Description:Load Current
Scaling Factor:0.00966400146484375
Units:A
Range:[0, 60]
Modbus address:0x000C','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32443','20','1.3.6.1.4.1.33333.8.32.0','10349','Load: Voltage{#SINGLETON}','load.voltage[arrayloadVoltage.0{#SINGLETON}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: TRISTAR
Description:Array/Load Voltage
Scaling Factor:0.00424652099609375
Units:V
Range:[0, 80]
Modbus address:0x000A','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32444','20','1.3.6.1.4.1.33333.8.47.0','10349','Load: State{#SINGLETON}','load.state[loadState.0{#SINGLETON}]','1m','7d','365d','0','0','','','','',NULL,'134','','','0','','','','','2',NULL,'MIB: TRISTAR
Description:Load State
Modbus address:0x001B

0: Start
1: Normal
2: LvdWarning
3: Lvd
4: Fault
5: Disconnect
6: LvdWarning1
7: OverrideLvd
8: Equalize','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32445','0','','10289','{#DEVNAME}: Average disk read queue length','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk Read Queue Length",60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Average disk read queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32446','0','','10289','{#DEVNAME}: Disk read request avg waiting time','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk sec/Read",60]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The average time for read requests issued to the device to be served. This includes the time spent by the requests in queue and the time spent servicing them.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32447','0','','10289','{#DEVNAME}: Disk write request avg waiting time','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk sec/Write",60]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The average time for write requests issued to the device to be served. This includes the time spent by the requests in queue and the time spent servicing them.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32448','0','','10289','{#DEVNAME}: Average disk write queue length','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk Write Queue Length",60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Average disk write queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32453','7','','10296','{#DEVNAME}: Average disk read queue length','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk Read Queue Length",60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Average disk read queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32454','7','','10296','{#DEVNAME}: Disk read request avg waiting time','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk sec/Read",60]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The average time for read requests issued to the device to be served. This includes the time spent by the requests in queue and the time spent servicing them.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32455','7','','10296','{#DEVNAME}: Disk write request avg waiting time','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk sec/Write",60]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The average time for write requests issued to the device to be served. This includes the time spent by the requests in queue and the time spent servicing them.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32456','7','','10296','{#DEVNAME}: Average disk write queue length','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk Write Queue Length",60]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Average disk write queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32463','16','','10350','Destinations discovery','jmx.discovery[beans,"org.apache.activemq:type=Broker,brokerName=*,destinationType=*,destinationName=*"]','1h','90d','0','0','4','','','{1112} and {1113}','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','1',NULL,'Discovery of destinations','0','30d','3','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32464','16','','10350','Brokers discovery','jmx.discovery[beans,"org.apache.activemq:type=Broker,brokerName=*"]','1h','90d','0','0','4','','','{1114} and {1115}','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','1',NULL,'Discovery of brokers','0','30d','3','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32465','16','','10350','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Consumers count total on {#JMXBROKERNAME}','jmx["org.apache.activemq:type=Broker,brokerName={#JMXBROKERNAME}",{$ACTIVEMQ.TOTAL.CONSUMERS.COUNT: "{#JMXDESTINATIONNAME}"}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Number of consumers attached to the broker of this destination. Used to suppress destination''s triggers when the count of consumers on the broker is lower than threshold.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32466','16','','10350','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Producers count total on {#JMXBROKERNAME}','jmx["org.apache.activemq:type=Broker,brokerName={#JMXBROKERNAME}",{$ACTIVEMQ.TOTAL.PRODUCERS.COUNT: "{#JMXDESTINATIONNAME}"}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Number of producers attached to the broker of this destination. Used to suppress destination''s triggers when the count of producers on the broker is lower than threshold.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32467','16','','10350','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Consumers count','jmx[{#JMXOBJ},ConsumerCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Number of consumers attached to this destination.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32468','16','','10350','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Messages dequeue rate','jmx[{#JMXOBJ},DequeueCount]','1m','7d','365d','0','3','','messages/sec','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Rate of messages that has been acknowledged (and removed) from the destination.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32469','16','','10350','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Messages enqueue rate','jmx[{#JMXOBJ},EnqueueCount]','1m','7d','365d','0','3','','messages/sec','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Rate of messages that have been sent to the destination.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32470','16','','10350','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Expired messages count','jmx[{#JMXOBJ},ExpiredCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Number of messages that have been expired.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32471','16','','10350','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Memory usage in percents','jmx[{#JMXOBJ},MemoryPercentUsage]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'The percentage of the memory limit used.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32472','16','','10350','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Producers count','jmx[{#JMXOBJ},ProducerCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Number of producers attached to this destination.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32473','16','','10350','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Queue size','jmx[{#JMXOBJ},QueueSize]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Number of messages on this destination, including any that have been dispatched but not acknowledged.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32474','16','','10350','Broker {#JMXBROKERNAME}: Version','jmx[{#JMXOBJ},BrokerVersion]','1m','7d','0','0','4','','','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'The version of the broker.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32475','16','','10350','Broker {#JMXBROKERNAME}: Memory limit','jmx[{#JMXOBJ},MemoryLimit]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Memory limit, in bytes, used for holding undelivered messages before paging to temporary storage.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32476','16','','10350','Broker {#JMXBROKERNAME}: Memory usage in percents','jmx[{#JMXOBJ}, MemoryPercentUsage]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Percent of memory limit used.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32477','16','','10350','Broker {#JMXBROKERNAME}: Storage limit','jmx[{#JMXOBJ},StoreLimit]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Disk limit, in bytes, used for persistent messages before producers are blocked.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32478','16','','10350','Broker {#JMXBROKERNAME}: Storage usage in percents','jmx[{#JMXOBJ},StorePercentUsage]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Percent of store limit used.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32479','16','','10350','Broker {#JMXBROKERNAME}: Temp limit','jmx[{#JMXOBJ},TempLimit]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Disk limit, in bytes, used for non-persistent messages and temporary data before producers are blocked.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32480','16','','10350','Broker {#JMXBROKERNAME}: Temp usage in percents','jmx[{#JMXOBJ},TempPercentUsage]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Percent of temp limit used.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32481','16','','10350','Broker {#JMXBROKERNAME}: Consumers count total','jmx[{#JMXOBJ},TotalConsumerCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Number of consumers attached to this broker.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32482','16','','10350','Broker {#JMXBROKERNAME}: Messages dequeue rate','jmx[{#JMXOBJ},TotalDequeueCount]','1m','7d','365d','0','3','','messages/sec','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Rate of messages that have been delivered by the broker and acknowledged by consumers.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32483','16','','10350','Broker {#JMXBROKERNAME}: Messages enqueue rate','jmx[{#JMXOBJ},TotalEnqueueCount]','1m','7d','365d','0','3','','messages/sec','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Rate of messages that have been sent to the broker.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32484','16','','10350','Broker {#JMXBROKERNAME}: Producers count total','jmx[{#JMXOBJ},TotalProducerCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'Number of producers attached to this broker.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32485','16','','10350','Broker {#JMXBROKERNAME}: Uptime','jmx[{#JMXOBJ},UptimeMillis]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','{$ACTIVEMQ.USER}','{$ACTIVEMQ.PASSWORD}','','','2',NULL,'The uptime of the broker.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32486','0','','10351','MS Exchange: Databases total mounted','perf_counter_en["\MSExchange Active Manager(_total)\Database Mounted"]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of active database copies on the server.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32487','0','','10351','MS Exchange [Client Access Server]: ActiveSync: ping command pending','perf_counter_en["\MSExchange ActiveSync\Ping Commands Pending", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of ping commands currently pending in the queue.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32488','0','','10351','MS Exchange [Client Access Server]: ActiveSync: requests per second','perf_counter_en["\MSExchange ActiveSync\Requests/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of HTTP requests received from the client via ASP.NET per second. Determines the current Exchange ActiveSync request rate. Used only to determine current user load.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32489','0','','10351','MS Exchange [Client Access Server]: ActiveSync: sync commands per second','perf_counter_en["\MSExchange ActiveSync\Sync Commands/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of sync commands processed per second. Clients use this command to synchronize items within a folder.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32490','0','','10351','MS Exchange [Client Access Server]: Autodiscover: requests per second','perf_counter_en["\MSExchangeAutodiscover\Requests/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of Autodiscover service requests processed each second. Determines current user load.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32491','0','','10351','MS Exchange [Client Access Server]: Availability Service: availability requests per second','perf_counter_en["\MSExchange Availability Service\Availability Requests (sec)", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of requests serviced per second. The request can be only for free/ busy information or include suggestions. One request may contain multiple mailboxes. Determines the rate at which Availability service requests are occurring.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32492','0','','10351','MS Exchange [Client Access Server]: Outlook Web App: current unique users','perf_counter_en["\MSExchange OWA\Current Unique Users", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of unique users currently logged on to Outlook Web App. This value monitors the number of unique active user sessions, so that users are only removed from this counter after they log off or their session times out. Determines current user load.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32493','0','','10351','MS Exchange [Client Access Server]: Outlook Web App: requests per second','perf_counter_en["\MSExchange OWA\Requests/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of requests handled by Outlook Web App per second. Determines current user load.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32494','0','','10351','MS Exchange [Client Access Server]: MSExchangeWS: requests per second','perf_counter_en["\MSExchangeWS\Requests/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of requests processed each second. Determines current user load.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32495','0','','10351','LDAP discovery','perf_instance_en.discovery["MSExchange ADAccess Domain Controllers"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of domain controller.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32496','0','','10351','Web services discovery','perf_instance_en.discovery["Web Service"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of Exchange web services.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32497','0','','10351','Databases discovery','perf_instance.discovery["MSExchange Active Manager"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of Exchange databases.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32498','0','','10351','Domain Controller [{#INSTANCE}]: Read time','perf_counter_en["\MSExchange ADAccess Domain Controllers({#INSTANCE})\LDAP Read Time", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Time that it takes to send an LDAP read request to the domain controller in question and get a response. Should ideally be below 50 ms; spikes below 100 ms are acceptable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32499','0','','10351','Domain Controller [{#INSTANCE}]: Search time','perf_counter_en["\MSExchange ADAccess Domain Controllers({#INSTANCE})\LDAP Search Time", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Time that it takes to send an LDAP search request and get a response. Should ideally be below 50 ms; spikes below 100 ms are acceptable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32500','0','','10351','Web Service [{#INSTANCE}]: Current connections','perf_counter_en["\Web Service({#INSTANCE})\Current Connections", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the current number of connections established to the each Web Service.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32501','0','','10351','Active Manager [{#INSTANCE}]: Database copy role','perf_counter_en["\MSExchange Active Manager({#INSTANCE})\Database Copy Role Active"]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,'136','','','0','','','','','2',NULL,'Database copy active or passive role.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32502','0','','10351','Information Store [{#INSTANCE}]: Page faults per second','perf_counter_en["\MSExchange Database({#INF.STORE})\Database Page Fault Stalls/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Indicates the rate of page faults that can''t be serviced because there are no pages available for allocation from the database cache. If this counter is above 0, it''s an indication that the MSExchange Database\I/O Database Writes (Attached) Average Latency is too high.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32503','0','','10351','Information Store [{#INSTANCE}]: Log records stalled','perf_counter_en["\MSExchange Database({#INF.STORE})\Log Record Stalls/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Indicates the number of log records that can''t be added to the log buffers per second because the log buffers are full. The average value should be below 10 per second. Spikes (maximum values) shouldn''t be higher than 100 per second.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32504','0','','10351','Information Store [{#INSTANCE}]: Log threads waiting','perf_counter_en["\MSExchange Database({#INF.STORE})\Log Threads Waiting", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Indicates the number of threads waiting to complete an update of the database by writing their data to the log.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32505','0','','10351','Database Counters [{#INSTANCE}]: Active database read operations per second','perf_counter_en["\MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Reads (Attached)/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the number of database read operations.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32506','0','','10351','Database Counters [{#INSTANCE}]: Active database read operations latency','perf_counter_en["\MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Reads (Attached) Average Latency", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the average length of time per database read operation. Should be less than 20 ms on average.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32507','0','','10351','Database Counters [{#INSTANCE}]: Passive database read operations latency','perf_counter_en["\MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Reads (Recovery) Average Latency", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the average length of time per passive database read operation. Should be less than 200ms on average.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32508','0','','10351','Database Counters [{#INSTANCE}]: Active database write operations per second','perf_counter_en["\MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Writes (Attached)/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the number of database write operations per second for each attached database instance.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32509','0','','10351','Database Counters [{#INSTANCE}]: Active database write operations latency','perf_counter_en["\MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Writes (Attached) Average Latency", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the average length of time per database write operation. Should be less than 50ms on average.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32510','0','','10351','Database Counters [{#INSTANCE}]: Passive database write operations latency','perf_counter_en["\MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Writes (Recovery) Average Latency", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the average length of time, in ms, per passive database write operation. Should be less than the read latency for the same instance, as measured by the MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Reads (Recovery) Average Latency counter.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32511','0','','10351','Information Store [{#INSTANCE}]: Active mailboxes count','perf_counter_en["\MSExchangeIS Store({#INSTANCE})\Active mailboxes"]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of active mailboxes in this database.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32512','0','','10351','Information Store [{#INSTANCE}]: Database state','perf_counter_en["\MSExchangeIS Store({#INSTANCE})\Database State"]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,'137','','','0','','','','','2',NULL,'Database state. Possible values:
0: Database without any copy and dismounted.
1: Database is a primary database and mounted.
2: Database is a passive copy and the state is healthy.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32513','0','','10351','Information Store [{#INSTANCE}]: RPC requests latency','perf_counter_en["\MSExchangeIS Store({#INSTANCE})\RPC Average Latency", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'RPC Latency average is the average latency of RPC requests per database. Average is calculated over all RPCs since exrpc32 was loaded. Should be less than 50ms at all times, with spikes less than 100ms.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32514','0','','10351','Information Store [{#INSTANCE}]: RPC requests per second','perf_counter_en["\MSExchangeIS Store({#INSTANCE})\RPC Operations/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the number of RPC operations per second for each database instance.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32515','0','','10351','Information Store [{#INSTANCE}]: RPC requests total','perf_counter_en["\MSExchangeIS Store({#INSTANCE})\RPC requests", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Indicates the overall RPC requests currently executing within the information store process. Should be below 70 at all times.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32516','7','','10352','MS Exchange: Databases total mounted','perf_counter_en["\MSExchange Active Manager(_total)\Database Mounted"]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of active database copies on the server.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32517','7','','10352','MS Exchange [Client Access Server]: ActiveSync: ping command pending','perf_counter_en["\MSExchange ActiveSync\Ping Commands Pending", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of ping commands currently pending in the queue.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32518','7','','10352','MS Exchange [Client Access Server]: ActiveSync: requests per second','perf_counter_en["\MSExchange ActiveSync\Requests/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of HTTP requests received from the client via ASP.NET per second. Determines the current Exchange ActiveSync request rate. Used only to determine current user load.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32519','7','','10352','MS Exchange [Client Access Server]: ActiveSync: sync commands per second','perf_counter_en["\MSExchange ActiveSync\Sync Commands/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of sync commands processed per second. Clients use this command to synchronize items within a folder.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32520','7','','10352','MS Exchange [Client Access Server]: Autodiscover: requests per second','perf_counter_en["\MSExchangeAutodiscover\Requests/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of Autodiscover service requests processed each second. Determines current user load.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32521','7','','10352','MS Exchange [Client Access Server]: Availability Service: availability requests per second','perf_counter_en["\MSExchange Availability Service\Availability Requests (sec)", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of requests serviced per second. The request can be only for free/ busy information or include suggestions. One request may contain multiple mailboxes. Determines the rate at which Availability service requests are occurring.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32522','7','','10352','MS Exchange [Client Access Server]: Outlook Web App: current unique users','perf_counter_en["\MSExchange OWA\Current Unique Users", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of unique users currently logged on to Outlook Web App. This value monitors the number of unique active user sessions, so that users are only removed from this counter after they log off or their session times out. Determines current user load.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32523','7','','10352','MS Exchange [Client Access Server]: Outlook Web App: requests per second','perf_counter_en["\MSExchange OWA\Requests/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of requests handled by Outlook Web App per second. Determines current user load.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32524','7','','10352','MS Exchange [Client Access Server]: MSExchangeWS: requests per second','perf_counter_en["\MSExchangeWS\Requests/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Shows the number of requests processed each second. Determines current user load.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32525','7','','10352','LDAP discovery','perf_instance_en.discovery["MSExchange ADAccess Domain Controllers"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of domain controller.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32526','7','','10352','Web services discovery','perf_instance_en.discovery["Web Service"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of Exchange web services.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32527','7','','10352','Databases discovery','perf_instance.discovery["MSExchange Active Manager"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of Exchange databases.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32528','7','','10352','Domain Controller [{#INSTANCE}]: Read time','perf_counter_en["\MSExchange ADAccess Domain Controllers({#INSTANCE})\LDAP Read Time", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Time that it takes to send an LDAP read request to the domain controller in question and get a response. Should ideally be below 50 ms; spikes below 100 ms are acceptable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32529','7','','10352','Domain Controller [{#INSTANCE}]: Search time','perf_counter_en["\MSExchange ADAccess Domain Controllers({#INSTANCE})\LDAP Search Time", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Time that it takes to send an LDAP search request and get a response. Should ideally be below 50 ms; spikes below 100 ms are acceptable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32530','7','','10352','Web Service [{#INSTANCE}]: Current connections','perf_counter_en["\Web Service({#INSTANCE})\Current Connections", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the current number of connections established to the each Web Service.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32531','7','','10352','Active Manager [{#INSTANCE}]: Database copy role','perf_counter_en["\MSExchange Active Manager({#INSTANCE})\Database Copy Role Active"]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,'136','','','0','','','','','2',NULL,'Database copy active or passive role.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32532','7','','10352','Information Store [{#INSTANCE}]: Page faults per second','perf_counter_en["\MSExchange Database({#INF.STORE})\Database Page Fault Stalls/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Indicates the rate of page faults that can''t be serviced because there are no pages available for allocation from the database cache. If this counter is above 0, it''s an indication that the MSExchange Database\I/O Database Writes (Attached) Average Latency is too high.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32533','7','','10352','Information Store [{#INSTANCE}]: Log records stalled','perf_counter_en["\MSExchange Database({#INF.STORE})\Log Record Stalls/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Indicates the number of log records that can''t be added to the log buffers per second because the log buffers are full. The average value should be below 10 per second. Spikes (maximum values) shouldn''t be higher than 100 per second.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32534','7','','10352','Information Store [{#INSTANCE}]: Log threads waiting','perf_counter_en["\MSExchange Database({#INF.STORE})\Log Threads Waiting", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Indicates the number of threads waiting to complete an update of the database by writing their data to the log.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32535','7','','10352','Database Counters [{#INSTANCE}]: Active database read operations per second','perf_counter_en["\MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Reads (Attached)/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the number of database read operations.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32536','7','','10352','Database Counters [{#INSTANCE}]: Active database read operations latency','perf_counter_en["\MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Reads (Attached) Average Latency", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the average length of time per database read operation. Should be less than 20 ms on average.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32537','7','','10352','Database Counters [{#INSTANCE}]: Passive database read operations latency','perf_counter_en["\MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Reads (Recovery) Average Latency", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the average length of time per passive database read operation. Should be less than 200ms on average.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32538','7','','10352','Database Counters [{#INSTANCE}]: Active database write operations per second','perf_counter_en["\MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Writes (Attached)/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the number of database write operations per second for each attached database instance.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32539','7','','10352','Database Counters [{#INSTANCE}]: Active database write operations latency','perf_counter_en["\MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Writes (Attached) Average Latency", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the average length of time per database write operation. Should be less than 50ms on average.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32540','7','','10352','Database Counters [{#INSTANCE}]: Passive database write operations latency','perf_counter_en["\MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Writes (Recovery) Average Latency", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the average length of time, in ms, per passive database write operation. Should be less than the read latency for the same instance, as measured by the MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Reads (Recovery) Average Latency counter.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32541','7','','10352','Information Store [{#INSTANCE}]: Active mailboxes count','perf_counter_en["\MSExchangeIS Store({#INSTANCE})\Active mailboxes"]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of active mailboxes in this database.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32542','7','','10352','Information Store [{#INSTANCE}]: Database state','perf_counter_en["\MSExchangeIS Store({#INSTANCE})\Database State"]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,'137','','','0','','','','','2',NULL,'Database state. Possible values:
0: Database without any copy and dismounted.
1: Database is a primary database and mounted.
2: Database is a passive copy and the state is healthy.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32543','7','','10352','Information Store [{#INSTANCE}]: RPC requests latency','perf_counter_en["\MSExchangeIS Store({#INSTANCE})\RPC Average Latency", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'RPC Latency average is the average latency of RPC requests per database. Average is calculated over all RPCs since exrpc32 was loaded. Should be less than 50ms at all times, with spikes less than 100ms.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32544','7','','10352','Information Store [{#INSTANCE}]: RPC requests per second','perf_counter_en["\MSExchangeIS Store({#INSTANCE})\RPC Operations/sec", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Shows the number of RPC operations per second for each database instance.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32545','7','','10352','Information Store [{#INSTANCE}]: RPC requests total','perf_counter_en["\MSExchangeIS Store({#INSTANCE})\RPC requests", {$MS.EXCHANGE.PERF.INTERVAL}]','{$MS.EXCHANGE.PERF.INTERVAL}','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Indicates the overall RPC requests currently executing within the information store process. Should be below 70 at all times.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32546','15','','10316','MySQL: Calculated value of innodb_log_file_size','mysql.innodb_log_file_size','1m','7d','365d','0','0','','','','',NULL,NULL,'(last(mysql.innodb_os_log_written) - last(mysql.innodb_os_log_written,1h)) / {$MYSQL.INNODB_LOG_FILES}','','0','','','','','0',NULL,'Calculated by (innodb_os_log_written-innodb_os_log_written(time shift -1h))/{$MYSQL.INNODB_LOG_FILES} value of the innodb_log_file_size. Innodb_log_file_size is the size in bytes of the each InnoDB redo log file in the log group. The combined size can be no more than 512GB. Larger values mean less disk I/O due to less flushing checkpoint activity, but also slower recovery from a crash.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32560','15','','10320','MySQL: Calculated value of innodb_log_file_size','mysql.innodb_log_file_size','1m','7d','365d','0','0','','','','',NULL,NULL,'(last(mysql.innodb_os_log_written) - last(mysql.innodb_os_log_written,1h)) / {$MYSQL.INNODB_LOG_FILES}','','0','','','','','0',NULL,'Calculated by (innodb_os_log_written-innodb_os_log_written(time shift -1h))/{$MYSQL.INNODB_LOG_FILES} value of the innodb_log_file_size. Innodb_log_file_size is the size in bytes of the each InnoDB redo log file in the log group. The combined size can be no more than 512GB. Larger values mean less disk I/O due to less flushing checkpoint activity, but also slower recovery from a crash.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32574','15','','10317','MySQL: Calculated value of innodb_log_file_size','mysql.innodb_log_file_size','1m','7d','365d','0','0','','','','',NULL,NULL,'(last(mysql.innodb_os_log_written) - last(mysql.innodb_os_log_written,1h)) / {$MYSQL.INNODB_LOG_FILES}','','0','','','','','0',NULL,'Calculated by (innodb_os_log_written-innodb_os_log_written(time shift -1h))/{$MYSQL.INNODB_LOG_FILES} value of the innodb_log_file_size. Innodb_log_file_size is the size in bytes of the each InnoDB redo log file in the log group. The combined size can be no more than 512GB. Larger values mean less disk I/O due to less flushing checkpoint activity, but also slower recovery from a crash.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32592','0','','10328','PostgreSQL: Custom queries','pgsql.custom.query["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}","{$PG.DATABASE}",""]','1m','1h','0','1','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Execute custom queries from file *.sql','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32595','0','','10328','PostgreSQL: Get replication','pgsql.replication.process["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect metrics from the pg_stat_replication, which contains information about the WAL sender process, showing statistics about replication to that sender''s connected standby server.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32597','0','','10328','Replication Discovery','pgsql.replication.process.discovery["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','15m','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32612','20','1.3.6.1.4.1.789.1.6.4.7.0','10353','NetApp FAS3220: Failed disks count','fas3220.disk[diskFailedCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of disks that are currently broken.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32613','20','1.3.6.1.4.1.789.1.6.4.10.0','10353','NetApp FAS3220: Failed disks message','fas3220.disk[diskFailedMessage]','1m','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'If diskFailedCount is non-zero, this is a string describing the failed disk or disks. Each failed disk is described.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32614','20','1.3.6.1.4.1.789.1.1.6.0','10353','NetApp FAS3220: Product firmware version','fas3220.inventory[productFirmwareVersion]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version string for the firmware running on this platform.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32615','20','1.3.6.1.4.1.789.1.1.2.0','10353','NetApp FAS3220: Product version','fas3220.inventory[productVersion]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version string for the software running on this platform.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32616','20','discovery[{#NODE.NAME},1.3.6.1.4.1.789.1.25.2.1.1]','10353','Cluster metrics discovery','fas3220.cluster.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of Cluster metrics per node','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32617','20','discovery[{#NODE.NAME},1.3.6.1.4.1.789.1.2.1.14.1.1]','10353','CPU discovery','fas3220.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of CPU metrics per node','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32618','20','discovery[{#FSNAME},1.3.6.1.4.1.789.1.5.4.1.2,{#FSTYPE},1.3.6.1.4.1.789.1.5.4.1.23,{#VSERVER},1.3.6.1.4.1.789.1.5.4.1.34]','10353','Filesystems discovery','fas3220.fs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Filesystems discovery with filter.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32619','20','discovery[{#NODE.NAME},1.3.6.1.4.1.789.1.21.2.1.1,{#PARTNER.NAME},1.3.6.1.4.1.789.1.21.2.1.8]','10353','HA discovery','fas3220.ha.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of high availability metrics per node','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32620','20','discovery[{#IFNAME},1.3.6.1.4.1.789.1.22.2.1.2,{#NODE},1.3.6.1.4.1.789.1.22.2.1.1,{#TYPE},1.3.6.1.4.1.789.1.22.2.1.15,{#ROLE},1.3.6.1.4.1.789.1.22.2.1.3,{#IFDESCR},1.3.6.1.4.1.789.1.22.1.2.1.2]','10353','Network ports discovery','fas3220.net.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Network interfaces discovery with filter.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32621','20','1.3.6.1.4.1.789.1.25.2.1.19.{#SNMPINDEX}','10353','Node {#NODE.NAME}: Failed FAN count','fas3220.cluster[nodeEnvFailedFanCount, "{#NODE.NAME}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of the number of chassis fans that are not operating within the recommended RPM range.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32622','20','1.3.6.1.4.1.789.1.25.2.1.20.{#SNMPINDEX}','10353','Node {#NODE.NAME}: Failed FAN message','fas3220.cluster[nodeEnvFailedFanMessage, "{#NODE.NAME}"]','1m','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Text message describing current condition of chassis fans. This is useful only if envFailedFanCount is not zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32623','20','1.3.6.1.4.1.789.1.25.2.1.21.{#SNMPINDEX}','10353','Node {#NODE.NAME}: Degraded power supplies count','fas3220.cluster[nodeEnvFailedPowerSupplyCount, "{#NODE.NAME}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of the number of power supplies that are in degraded mode.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32624','20','1.3.6.1.4.1.789.1.25.2.1.22.{#SNMPINDEX}','10353','Node {#NODE.NAME}: Degraded power supplies message','fas3220.cluster[nodeEnvFailedPowerSupplyMessage, "{#NODE.NAME}"]','1m','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Text message describing the state of any power supplies that are currently degraded. This is useful only if envFailedPowerSupplyCount is not zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32625','20','1.3.6.1.4.1.789.1.25.2.1.18.{#SNMPINDEX}','10353','Node {#NODE.NAME}: Over-temperature','fas3220.cluster[nodeEnvOverTemperature, "{#NODE.NAME}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'An indication of whether the hardware is currently operating outside of its recommended temperature range. The hardware will shutdown if the temperature exceeds critical thresholds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32626','20','1.3.6.1.4.1.789.1.25.2.1.11.{#SNMPINDEX}','10353','Node {#NODE.NAME}: Health','fas3220.cluster[nodeHealth, "{#NODE.NAME}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','2',NULL,'Whether or not the node can communicate with the cluster.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32627','20','1.3.6.1.4.1.789.1.25.2.1.3.{#SNMPINDEX}','10353','Node {#NODE.NAME}: Location','fas3220.cluster[nodeLocation, "{#NODE.NAME}"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Node Location. Same as sysLocation for a specific node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32628','20','1.3.6.1.4.1.789.1.25.2.1.4.{#SNMPINDEX}','10353','Node {#NODE.NAME}: Model','fas3220.cluster[nodeModel, "{#NODE.NAME}"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Node Model. Same as productModel for a specific node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32629','20','1.3.6.1.4.1.789.1.25.2.1.17.{#SNMPINDEX}','10353','Node {#NODE.NAME}: NVRAM battery status','fas3220.cluster[nodeNvramBatteryStatus, "{#NODE.NAME}"]','1m','7d','365d','0','3','','','','',NULL,'139','','','0','','','','','2',NULL,'An indication of the current status of the NVRAM battery or batteries.
Batteries which are fully or partially discharged may not fully protect the system during a crash. The end-of-life status values are based on the manufacturer''s recommended life for the batteries.
Possible values:
ok(1),
partiallyDischarged(2),
fullyDischarged(3),
notPresent(4),
nearEndOfLife(5),
atEndOfLife(6),
unknown(7),
overCharged(8),
fullyCharged(9).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32630','20','1.3.6.1.4.1.789.1.25.2.1.5.{#SNMPINDEX}','10353','Node {#NODE.NAME}: Serial number','fas3220.cluster[nodeSerialNumber, "{#NODE.NAME}"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Node Serial Number. Same as productSerialNum for a specific node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32631','20','1.3.6.1.4.1.789.1.25.2.1.7.{#SNMPINDEX}','10353','Node {#NODE.NAME}: Uptime','fas3220.cluster[nodeUptime, "{#NODE.NAME}"]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Node uptime. Same as sysUpTime for a specific node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32632','20','1.3.6.1.4.1.789.1.2.1.14.1.4.{#SNMPINDEX}','10353','Node {#NODE.NAME}: CPU utilization','fas3220.cpu[cDOTCpuBusyTimePerCent, "{#NODE.NAME}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'The average, over the last minute, of the percentage of time that this processor was not idle.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32633','20','1.3.6.1.4.1.789.1.5.4.1.31.{#SNMPINDEX}','10353','{#VSERVER}{#FSNAME}: Total space available','fas3220.fs[df64AvailKBytes, "{#VSERVER}{#FSNAME}"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The total disk space that is free for use on {#FSNAME}.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32634','20','1.3.6.1.4.1.789.1.5.4.1.29.{#SNMPINDEX}','10353','{#VSERVER}{#FSNAME}: Total space','fas3220.fs[df64TotalKBytes, "{#VSERVER}{#FSNAME}"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The total capacity in Bytes for {#FSNAME}.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32635','20','1.3.6.1.4.1.789.1.5.4.1.30.{#SNMPINDEX}','10353','{#VSERVER}{#FSNAME}: Total space used','fas3220.fs[df64UsedKBytes, "{#VSERVER}{#FSNAME}"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The total disk space that is in use on {#FSNAME}.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32636','20','1.3.6.1.4.1.789.1.5.4.1.38.{#SNMPINDEX}','10353','{#VSERVER}{#FSNAME}: Saved by compression percents','fas3220.fs[dfCompressSavedPercent, "{#VSERVER}{#FSNAME}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Provides the percentage of compression savings in a volume, which is ((compr_saved/used)) * 10(compr_saved + 0). This is only returned for volumes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32637','20','1.3.6.1.4.1.789.1.5.4.1.40.{#SNMPINDEX}','10353','{#VSERVER}{#FSNAME}: Saved by deduplication percents','fas3220.fs[dfDedupeSavedPercent, "{#VSERVER}{#FSNAME}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Provides the percentage of deduplication savings in a volume, which is ((dedup_saved/(dedup_saved + used)) * 100). This is only returned for volumes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32638','20','1.3.6.1.4.1.789.1.5.4.1.6.{#SNMPINDEX}','10353','{#VSERVER}{#FSNAME}: Used space percents','fas3220.fs[dfPerCentKBytesCapacity, "{#VSERVER}{#FSNAME}"]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'The percentage of disk space currently in use on {#FSNAME}.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32639','20','1.3.6.1.4.1.789.1.21.2.1.5.{#SNMPINDEX}','10353','Node {#NODE.NAME}: Cannot takeover cause','fas3220.ha[haCannotTakeoverCause, "{#NODE.NAME}"]','1m','7d','365d','0','3','','','','',NULL,'140','','','0','','','','','2',NULL,'The reason node cannot take over it''s HA partner {#PARTNER.NAME}.
Possible states:
  ok(1),
  unknownReason(2),
  disabledByOperator(3),
  interconnectOffline(4),
  disabledByPartner(5),
  takeoverFailed(6),
  mailboxIsInDegradedState(7),
  partnermailboxIsInUninitialisedState(8),
  mailboxVersionMismatch(9),
  nvramSizeMismatch(10),
  kernelVersionMismatch(11),
  partnerIsInBootingStage(12),
  diskshelfIsTooHot(13),
  partnerIsPerformingRevert(14),
  nodeIsPerformingRevert(15),
  sametimePartnerIsAlsoTryingToTakeUsOver(16),
  alreadyInTakenoverMode(17),
  nvramLogUnsynchronized(18),
  stateofBackupMailboxIsDoubtful(19).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32640','20','1.3.6.1.4.1.789.1.21.2.1.3.{#SNMPINDEX}','10353','Node {#NODE.NAME}: HA settings','fas3220.ha[haSettings, "{#NODE.NAME}"]','1m','7d','365d','0','3','','','','',NULL,'141','','','0','','','','','2',NULL,'High Availability configuration settings. The value notConfigured(1) indicates that the HA is not licensed. The thisNodeDead(5) setting indicates that this node has been takenover.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32641','20','1.3.6.1.4.1.789.1.22.1.2.1.28.{#IFSNMPINDEX}','10353','Node {#NODE}: port {#IFNAME} ({#TYPE}): Inbound packets discarded','fas3220.net.if[if64InDiscards, "{#NODE}", "{#IFNAME}"]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets that were chosen to be discarded even though no errors had been detected to prevent their being deliverable to a higher-layer protocol. One possible reason for discarding such a packet could be to free up buffer space.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32642','20','1.3.6.1.4.1.789.1.22.1.2.1.29.{#IFSNMPINDEX}','10353','Node {#NODE}: port {#IFNAME} ({#TYPE}): Inbound packets with errors','fas3220.net.if[if64InErrors, "{#NODE}", "{#IFNAME}"]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32643','20','1.3.6.1.4.1.789.1.22.1.2.1.25.{#IFSNMPINDEX}','10353','Node {#NODE}: port {#IFNAME} ({#TYPE}): Bits received','fas3220.net.if[if64InOctets, "{#NODE}", "{#IFNAME}"]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of octets received on the interface, including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32644','20','1.3.6.1.4.1.789.1.22.1.2.1.34.{#IFSNMPINDEX}','10353','Node {#NODE}: port {#IFNAME} ({#TYPE}): Outbound packets discarded','fas3220.net.if[if64OutDiscards, "{#NODE}", "{#IFNAME}"]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets that were chosen to be discarded even though no errors had been detected to prevent their being transmitted. One possible reason for discarding such a packet could be to free up buffer space.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32645','20','1.3.6.1.4.1.789.1.22.1.2.1.35.{#IFSNMPINDEX}','10353','Node {#NODE}: port {#IFNAME} ({#TYPE}): Outbound packets with errors','fas3220.net.if[if64OutErrors, "{#NODE}", "{#IFNAME}"]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets that could not be transmitted because of errors.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32646','20','1.3.6.1.4.1.789.1.22.1.2.1.31.{#IFSNMPINDEX}','10353','Node {#NODE}: port {#IFNAME} ({#TYPE}): Bits sent','fas3220.net.if[if64OutOctets, "{#NODE}", "{#IFNAME}"]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of octets transmitted out of the interface, including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32647','20','1.3.6.1.4.1.789.1.22.2.1.32.{#SNMPINDEX}','10353','Node {#NODE}: port {#IFNAME} ({#TYPE}): Health degraded reason','fas3220.net.port[netportDegradedReason, "{#NODE}", "{#IFNAME}"]','1m','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The list of reasons why the port is marked as degraded.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32648','20','1.3.6.1.4.1.789.1.22.2.1.30.{#SNMPINDEX}','10353','Node {#NODE}: port {#IFNAME} ({#TYPE}): Health','fas3220.net.port[netportHealthStatus, "{#NODE}", "{#IFNAME}"]','1m','7d','365d','0','0','','','','',NULL,'143','','','0','','','','','2',NULL,'The health status of the port.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32649','20','1.3.6.1.4.1.789.1.22.2.1.4.{#SNMPINDEX}','10353','Node {#NODE}: port {#IFNAME} ({#TYPE}): State','fas3220.net.port[netportLinkState, "{#NODE}", "{#IFNAME}"]','1m','7d','365d','0','3','','','','',NULL,'142','','','0','','','','','2',NULL,'The link-state of the port. Normally it is either UP(2) or DOWN(3).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32650','20','1.3.6.1.4.1.789.1.22.2.1.3.{#SNMPINDEX}','10353','Node {#NODE}: port {#IFNAME} ({#TYPE}): Role','fas3220.net.port[netportRole, "{#NODE}", "{#IFNAME}"]','1m','7d','365d','0','3','','','','',NULL,'145','','','0','','','','','2',NULL,'Role of the port. A port must have one of the following roles: cluster(1), data(2), mgmt(3), intercluster(4), cluster-mgmt(5) or undef(0). The cluster port is used to communicate to other node(s) in the cluster. The data port services clients'' requests. It is where all the file requests come in. The management port is used by administrator to manage resources within a node. The intercluster port is used to communicate to other cluster. The cluster-mgmt port is used to manage resources within the cluster. The undef role is for the port that has not yet been assigned a role.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32651','20','1.3.6.1.4.1.789.1.22.2.1.11.{#SNMPINDEX}','10353','Node {#NODE}: port {#IFNAME} ({#TYPE}): Speed','fas3220.net.port[netportSpeedOper, "{#NODE}", "{#IFNAME}"]','1m','7d','365d','0','3','','','','',NULL,'147','','','0','','','','','2',NULL,'The speed appears on the port. It can be either undef(0), auto(1), ten Mb/s(2), hundred Mb/s(3), one Gb/s(4), or ten Gb/s(5).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32652','20','1.3.6.1.4.1.789.1.22.2.1.14.{#SNMPINDEX}','10353','Node {#NODE}: port {#IFNAME} ({#TYPE}): Up by an administrator','fas3220.net.port[netportUpAdmin, "{#NODE}", "{#IFNAME}"]','1m','7d','365d','0','3','','','','',NULL,'144','','','0','','','','','2',NULL,'Indicates whether the port status is set ''UP'' by an administrator.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32653','16','','10354','Cache groups','jmx.discovery[beans,"org.apache:group=\"Cache groups\",*"]','10m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','1',NULL,'','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32654','16','','10354','Thread pool metrics','jmx.discovery[beans,"org.apache:group=\"Thread Pools\",*"]','10m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','1',NULL,'','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32655','16','','10354','Data region metrics','jmx.discovery[beans,"org.apache:group=DataRegionMetrics,*"]','10m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','1',NULL,'','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32656','16','','10354','Local node metrics','jmx.discovery[beans,"org.apache:group=Kernal,name=ClusterLocalNodeMetricsMXBeanImpl,*"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32657','16','','10354','Cluster metrics','jmx.discovery[beans,"org.apache:group=Kernal,name=ClusterMetricsMXBeanImpl,*"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32658','16','','10354','Ignite kernal metrics','jmx.discovery[beans,"org.apache:group=Kernal,name=IgniteKernal,*"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32659','16','','10354','TCP Ccmmunication SPI metrics','jmx.discovery[beans,"org.apache:group=SPIs,name=TcpCommunicationSpi,*"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32660','16','','10354','TCP discovery SPI','jmx.discovery[beans,"org.apache:group=SPIs,name=TcpDiscoverySpi,*"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32661','16','','10354','Transaction metrics','jmx.discovery[beans,"org.apache:group=TransactionMetrics,name=TransactionMetricsMxBeanImpl,*"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32662','16','','10354','Cache metrics','jmx.discovery[beans,"org.apache:name=\"org.apache.ignite.internal.processors.cache.CacheLocalMetricsMXBeanImpl\",*"]','10m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','1',NULL,'','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32663','16','','10354','Cache group [{#JMXNAME}]: Backups','jmx["{#JMXOBJ}",Backups]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Count of backups configured for cache group.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32664','16','','10354','Cache group [{#JMXNAME}]: Caches','jmx["{#JMXOBJ}",Caches]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'List of caches.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32665','16','','10354','Cache group [{#JMXNAME}]: Local node partitions, moving','jmx["{#JMXOBJ}",LocalNodeMovingPartitionsCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Count of partitions with state MOVING for this cache group located on this node.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32666','16','','10354','Cache group [{#JMXNAME}]: Local node partitions, owning','jmx["{#JMXOBJ}",LocalNodeOwningPartitionsCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Count of partitions with state OWNING for this cache group located on this node.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32667','16','','10354','Cache group [{#JMXNAME}]: Local node entries, renting','jmx["{#JMXOBJ}",LocalNodeRentingEntriesCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Count of entries remains to evict in RENTING partitions located on this node for this cache group.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32668','16','','10354','Cache group [{#JMXNAME}]: Local node partitions, renting','jmx["{#JMXOBJ}",LocalNodeRentingPartitionsCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Count of partitions with state RENTING for this cache group located on this node.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32669','16','','10354','Cache group [{#JMXNAME}]: Partition copies, max','jmx["{#JMXOBJ}",MaximumNumberOfPartitionCopies]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Maximum number of partition copies for all partitions of this cache group.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32670','16','','10354','Cache group [{#JMXNAME}]: Partition copies, min','jmx["{#JMXOBJ}",MinimumNumberOfPartitionCopies]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Minimum number of partition copies for all partitions of this cache group.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32671','16','','10354','Cache group [{#JMXNAME}]: Partitions','jmx["{#JMXOBJ}",Partitions]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Count of partitions for cache group.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32672','16','','10354','Thread pool [{#JMXNAME}]: Pool size, core','jmx["{#JMXOBJ}",CorePoolSize]','1m','7d','365d','0','3','','!msg','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The core number of threads.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32673','16','','10354','Thread pool [{#JMXNAME}]: Pool size, max','jmx["{#JMXOBJ}",MaximumPoolSize]','1m','7d','365d','0','3','','!msg','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The maximum allowed number of threads.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32674','16','','10354','Thread pool [{#JMXNAME}]: Pool size','jmx["{#JMXOBJ}",PoolSize]','1m','7d','365d','0','3','','!msg','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Current number of threads in the pool.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32675','16','','10354','Thread pool [{#JMXNAME}]: Queue size','jmx["{#JMXOBJ}",QueueSize]','1m','7d','365d','0','3','','!msg','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Current size of the execution queue.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32676','16','','10354','Data region {#JMXNAME}: Allocation, rate','jmx["{#JMXOBJ}",AllocationRate]','1m','7d','365d','0','0','','!pps','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Allocation rate (pages per second) averaged across rateTimeInternal.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32677','16','','10354','Data region {#JMXNAME}: Checkpoint buffer size','jmx["{#JMXOBJ}",CheckpointBufferSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Total size in bytes for checkpoint buffer.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32678','16','','10354','Data region {#JMXNAME}: Dirty pages','jmx["{#JMXOBJ}",DirtyPages]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Number of pages in memory not yet synchronized with persistent storage.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32679','16','','10354','Data region {#JMXNAME}: Eviction, rate','jmx["{#JMXOBJ}",EvictionRate]','1m','7d','365d','0','0','','!pps','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Eviction rate (pages per second).','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32680','16','','10354','Data region {#JMXNAME}: Size, max','jmx["{#JMXOBJ}",MaxSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Maximum memory region size defined by its data region.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32681','16','','10354','Data region {#JMXNAME}: Offheap size','jmx["{#JMXOBJ}",OffHeapSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Offheap size in bytes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32682','16','','10354','Data region {#JMXNAME}: Offheap used size','jmx["{#JMXOBJ}",OffheapUsedSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Total used offheap size in bytes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32683','16','','10354','Data region {#JMXNAME}: Pages fill factor','jmx["{#JMXOBJ}",PagesFillFactor]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The percentage of the used space.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32684','16','','10354','Data region {#JMXNAME}: Pages replace, rate','jmx["{#JMXOBJ}",PagesReplaceRate]','1m','7d','365d','0','0','','!pps','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Rate at which pages in memory are replaced with pages from persistent storage (pages per second).','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32685','16','','10354','Data region {#JMXNAME}: Allocated, bytes','jmx["{#JMXOBJ}",TotalAllocatedSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Total size of memory allocated in bytes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32686','16','','10354','Data region {#JMXNAME}: Used checkpoint buffer size','jmx["{#JMXOBJ}",UsedCheckpointBufferSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Used checkpoint buffer size in bytes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32687','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Jobs active, current','jmx["{#JMXOBJ}",CurrentActiveJobs]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Number of currently active jobs concurrently executing on the node.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32688','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Jobs cancelled, current','jmx["{#JMXOBJ}",CurrentCancelledJobs]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Number of cancelled jobs that are still running.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32689','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: PME duration, current','jmx["{#JMXOBJ}",CurrentPmeDuration]','1m','7d','365d','0','3','','ms','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Current PME duration in milliseconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32690','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Jobs rejected, current','jmx["{#JMXOBJ}",CurrentRejectedJobs]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Number of jobs rejected after more recent collision resolution operation.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32691','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Threads count, current','jmx["{#JMXOBJ}",CurrentThreadCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Current number of live threads.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32692','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Jobs waiting, current','jmx["{#JMXOBJ}",CurrentWaitingJobs]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Number of queued jobs currently waiting to be executed.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32693','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Heap memory used','jmx["{#JMXOBJ}",HeapMemoryUsed]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Current heap size that is used for object allocation.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32694','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Jobs cancelled, rate','jmx["{#JMXOBJ}",TotalCancelledJobs]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Total number of jobs cancelled by the node per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32695','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Jobs executed, rate','jmx["{#JMXOBJ}",TotalExecutedJobs]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Total number of jobs handled by the node per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32696','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Jobs rejects, rate','jmx["{#JMXOBJ}",TotalRejectedJobs]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Total number of jobs this node rejects during collision resolution operations since node startup per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32697','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Nodes, Active baseline','jmx["{#JMXOBJ}",ActiveBaselineNodes]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of nodes that are currently active in the baseline topology.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32698','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Nodes, Baseline','jmx["{#JMXOBJ}",TotalBaselineNodes]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Total baseline nodes that are registered in the baseline topology.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32699','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Nodes, Client','jmx["{#JMXOBJ}",TotalClientNodes]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of client nodes in the cluster.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32700','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Nodes, total','jmx["{#JMXOBJ}",TotalNodes]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Total number of nodes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32701','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Nodes, Server','jmx["{#JMXOBJ}",TotalServerNodes]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of server nodes in the cluster.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32702','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Version','jmx["{#JMXOBJ}",FullVersion]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Version of Ignite instance.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32703','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Local node ID','jmx["{#JMXOBJ}",LocalNodeId]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Unique identifier for this node within grid.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32704','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Uptime','jmx["{#JMXOBJ}",UpTime]','1m','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Uptime of Ignite instance.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32705','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Communication outbound messages queue','jmx["{#JMXOBJ}",OutboundMessagesQueueSize]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Outbound messages queue size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32706','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Communication messages received, rate','jmx["{#JMXOBJ}",ReceivedMessagesCount]','1m','7d','365d','0','0','','!msg/s','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of  messages received per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32708','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Communication messages sent, rate','jmx["{#JMXOBJ}",SentMessagesCount]','1m','7d','365d','0','0','','!msg/s','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of  messages sent per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32709','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Coordinator','jmx["{#JMXOBJ}",Coordinator]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Current coordinator UUID.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32710','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Discovery message worker queue','jmx["{#JMXOBJ}",MessageWorkerQueueSize]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Message worker queue current size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32711','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Nodes failed','jmx["{#JMXOBJ}",NodesFailed]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Nodes failed count.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32712','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Nodes joined','jmx["{#JMXOBJ}",NodesJoined]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Nodes join count.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32713','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Nodes left','jmx["{#JMXOBJ}",NodesLeft]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Nodes left count.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32714','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Discovery reconnect, rate','jmx["{#JMXOBJ}",ReconnectCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Number of times node tries to (re)establish connection to another node per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32715','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: TotalProcessedMessages','jmx["{#JMXOBJ}",TotalProcessedMessages]','1m','7d','365d','0','0','','!msg/s','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of messages received per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32716','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Discovery messages received, rate','jmx["{#JMXOBJ}",TotalReceivedMessages]','1m','7d','365d','0','0','','!msg/s','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of messages processed per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32717','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Locked keys','jmx["{#JMXOBJ}",LockedKeysNumber]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of keys locked on the node.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32718','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Transactions owner, current','jmx["{#JMXOBJ}",OwnerTransactionsNumber]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of active transactions for which this node is the initiator.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32719','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Transactions committed, rate','jmx["{#JMXOBJ}",TransactionsCommittedNumber]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of transactions which were committed per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32720','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Transactions holding lock, current','jmx["{#JMXOBJ}",TransactionsHoldingLockNumber]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of active transactions holding at least one key lock.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32721','16','','10354','Ignite [{#JMXIGNITEINSTANCENAME}]: Transactions rolledback, rate','jmx["{#JMXOBJ}",TransactionsRolledBackNumber]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of transactions which were rollback per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32722','16','','10354','Cache group [{#JMXGROUP}]: Cache gets, rate','jmx["{#JMXOBJ}",CacheGets]','1m','7d','365d','0','0','','ops','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of gets to the cache per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32723','16','','10354','Cache group [{#JMXGROUP}]: Cache hits, pct','jmx["{#JMXOBJ}",CacheHitPercentage]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Percentage of successful hits.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32724','16','','10354','Cache group [{#JMXGROUP}]: Cache misses, pct','jmx["{#JMXOBJ}",CacheMissPercentage]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'Percentage of accesses that failed to find anything.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32725','16','','10354','Cache group [{#JMXGROUP}]: Cache puts, rate','jmx["{#JMXOBJ}",CachePuts]','1m','7d','365d','0','0','','ops','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of puts to the cache per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32726','16','','10354','Cache group [{#JMXGROUP}]: Cache removals, rate','jmx["{#JMXOBJ}",CacheRemovals]','1m','7d','365d','0','0','','ops','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of removals from the cache per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32727','16','','10354','Cache group [{#JMXGROUP}]: Cache size','jmx["{#JMXOBJ}",CacheSize]','1m','7d','365d','0','3','','!keys','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of non-null values in the cache as a long value.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32728','16','','10354','Cache group [{#JMXGROUP}]: Cache transaction commits, rate','jmx["{#JMXOBJ}",CacheTxCommits]','1m','7d','365d','0','0','','!tps','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of transaction commits per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32729','16','','10354','Cache group [{#JMXGROUP}]: Cache transaction rollbacks, rate','jmx["{#JMXOBJ}",CacheTxRollbacks]','1m','7d','365d','0','0','','!tps','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of transaction rollback per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32730','16','','10354','Cache group [{#JMXGROUP}]: Cache heap entries','jmx["{#JMXOBJ}",HeapEntriesCount]','1m','7d','365d','0','3','','!keys','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$IGNITE.PASSWORD}','','','2',NULL,'The number of entries in heap memory.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32731','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10256','Temperature Discovery System','tempDescr.discovery.system','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries: CPQHLTH-MIB::cpqHeTemperatureTable with system(3) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32732','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10256','{#SNMPINDEX}: Temperature sensor condition','sensor.temp.condition[cpqHeTemperatureCondition.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32733','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10256','Ambient: Temperature sensor condition','sensor.temp.condition[cpqHeTemperatureCondition.Ambient.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32734','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10256','CPU-{#SNMPINDEX}: Temperature sensor condition','sensor.temp.condition[cpqHeTemperatureCondition.CPU.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32735','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10256','I/O-{#SNMPINDEX}: Temperature sensor condition','sensor.temp.condition[cpqHeTemperatureCondition."I/O.{#SNMPINDEX}"]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32736','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10256','I/O-{#SNMPINDEX}: Temperature','sensor.temp.value[cpqHeTemperatureCelsius."I/O.{#SNMPINDEX}"]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: I/O-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32737','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10256','Memory-{#SNMPINDEX}: Temperature sensor condition','sensor.temp.condition[cpqHeTemperatureCondition.Memory.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32738','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10256','PSU-{#SNMPINDEX}: Temperature sensor condition','sensor.temp.condition[cpqHeTemperatureCondition.PSU.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32739','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10256','System-{#SNMPINDEX}: Temperature sensor condition','sensor.temp.condition[cpqHeTemperatureCondition.System.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32740','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10256','System-{#SNMPINDEX}: Temperature','sensor.temp.value[cpqHeTemperatureCelsius.System.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: System-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32741','0','','10355','SMART: Get attributes','smart.disk.get','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32742','0','','10355','Attribute discovery','smart.attribute.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery SMART Vendor Specific Attributes of disks.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32743','0','','10355','Disk discovery','smart.disk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery SMART disks.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32753','7','','10356','SMART: Get attributes','smart.disk.get','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32754','7','','10356','Attribute discovery','smart.attribute.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery SMART Vendor Specific Attributes of disks.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32755','7','','10356','Disk discovery','smart.disk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery SMART disks.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32776','20','1.3.6.1.4.1.34774.4.1.1.3.0','10357','OceanStor 5300 V5: Status','huawei.5300.v5[status]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System running status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32777','20','1.3.6.1.4.1.34774.4.1.1.5.0','10357','OceanStor 5300 V5: Capacity total','huawei.5300.v5[totalCapacity]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total capacity of a device.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32778','20','1.3.6.1.4.1.34774.4.1.1.4.0','10357','OceanStor 5300 V5: Capacity used','huawei.5300.v5[usedCapacity]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Used capacity of a device.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32779','20','1.3.6.1.4.1.34774.4.1.1.6.0','10357','OceanStor 5300 V5: Version','huawei.5300.v5[version]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The device version.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32780','20','discovery[{#ID},1.3.6.1.4.1.34774.4.1.23.5.5.1.1,{#LOCATION},1.3.6.1.4.1.34774.4.1.23.5.5.1.2]','10357','BBU discovery','huawei.5300.bbu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of BBU','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32781','20','discovery[{#ID},1.3.6.1.4.1.34774.4.1.23.5.2.1.1]','10357','Controllers discovery','huawei.5300.controllers.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of controllers','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32782','20','discovery[{#ID},1.3.6.1.4.1.34774.4.1.23.5.1.1.1,{#MODEL},1.3.6.1.4.1.34774.4.1.23.5.1.1.12,{#LOCATION},1.3.6.1.4.1.34774.4.1.23.5.1.1.4]','10357','Disks discovery','huawei.5300.disks.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of disks','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32783','20','discovery[{#NAME},1.3.6.1.4.1.34774.4.1.23.5.6.1.2]','10357','Enclosure discovery','huawei.5300.enclosure.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of enclosures','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32784','20','discovery[{#ID},1.3.6.1.4.1.34774.4.1.23.5.4.1.1,{#LOCATION},1.3.6.1.4.1.34774.4.1.23.5.4.1.2]','10357','FANs discovery','huawei.5300.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of FANs','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32785','20','discovery[{#NAME},1.3.6.1.4.1.34774.4.1.19.9.4.1.2]','10357','LUNs discovery','huawei.5300.lun.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of LUNs','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32786','20','discovery[{#NODE},1.3.6.1.4.1.34774.4.1.21.3.1.1]','10357','Nodes performance discovery','huawei.5300.nodes.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of nodes performance counters','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32787','20','discovery[{#NAME},1.3.6.1.4.1.34774.4.1.23.4.2.1.2,{#THRESHOLD},1.3.6.1.4.1.34774.4.1.23.4.2.1.14]','10357','Storage pools discovery','huawei.5300.pool.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of storage pools','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32788','20','1.3.6.1.4.1.34774.4.1.23.5.5.1.3.{#SNMPINDEX}','10357','BBU {#ID} on {#LOCATION}: Health status','huawei.5300.v5[hwInfoBBUHealthStatus, "{#ID}:{#LOCATION}"]','1m','7d','365d','0','3','','','','',NULL,'150','','','0','','','','','2',NULL,'Health status of a BBU. For details, see definition of Enum Values (HEALTH_STATUS_E).
https://support.huawei.com/enterprise/en/centralized-storage/oceanstor-5300-v5-pid-22462029?category=reference-guides&subcategory=mib-reference','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32789','20','1.3.6.1.4.1.34774.4.1.23.5.5.1.4.{#SNMPINDEX}','10357','BBU {#ID} on {#LOCATION}: Running status','huawei.5300.v5[hwInfoBBURunningStatus, "{#ID}:{#LOCATION}"]','1m','7d','365d','0','3','','','','',NULL,'152','','','0','','','','','2',NULL,'Running status of a BBU. For details, see definition of Enum Values (RUNNING_STATUS_E).
https://support.huawei.com/enterprise/en/centralized-storage/oceanstor-5300-v5-pid-22462029?category=reference-guides&subcategory=mib-reference','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32790','20','1.3.6.1.4.1.34774.4.1.23.5.2.1.8.{#SNMPINDEX}','10357','Controller {#ID}: CPU utilization','huawei.5300.v5[hwInfoControllerCPUUsage, "{#ID}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'CPU usage of a controller {#ID}.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32791','20','1.3.6.1.4.1.34774.4.1.23.5.2.1.2.{#SNMPINDEX}','10357','Controller {#ID}: Health status','huawei.5300.v5[hwInfoControllerHealthStatus, "{#ID}"]','1m','7d','365d','0','3','','','','',NULL,'150','','','0','','','','','2',NULL,'Controller health status. For details, see definition of Enum Values (HEALTH_STATUS_E).
https://support.huawei.com/enterprise/en/centralized-storage/oceanstor-5300-v5-pid-22462029?category=reference-guides&subcategory=mib-reference','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32792','20','1.3.6.1.4.1.34774.4.1.23.5.2.1.9.{#SNMPINDEX}','10357','Controller {#ID}: Memory utilization','huawei.5300.v5[hwInfoControllerMemoryUsage, "{#ID}"]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Memory usage of a controller {#ID}.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32793','20','1.3.6.1.4.1.34774.4.1.23.5.2.1.6.{#SNMPINDEX}','10357','Controller {#ID}: Role','huawei.5300.v5[hwInfoControllerRole, "{#ID}"]','1m','7d','365d','0','3','','','','',NULL,'149','','','0','','','','','2',NULL,'Controller role..','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32794','20','1.3.6.1.4.1.34774.4.1.23.5.2.1.3.{#SNMPINDEX}','10357','Controller {#ID}: Running status','huawei.5300.v5[hwInfoControllerRunningStatus, "{#ID}"]','1m','7d','365d','0','3','','','','',NULL,'152','','','0','','','','','2',NULL,'Controller running status. For details, see definition of Enum Values (RUNNING_STATUS_E).
https://support.huawei.com/enterprise/en/centralized-storage/oceanstor-5300-v5-pid-22462029?category=reference-guides&subcategory=mib-reference','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32795','20','1.3.6.1.4.1.34774.4.1.23.5.1.1.25.{#SNMPINDEX}','10357','Disk {#MODEL} on {#LOCATION}: Health score','huawei.5300.v5[hwInfoDiskHealthMark, "{#ID}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Health score of a disk. If the value is 255, indicating invalid.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32796','20','1.3.6.1.4.1.34774.4.1.23.5.1.1.2.{#SNMPINDEX}','10357','Disk {#MODEL} on {#LOCATION}: Health status','huawei.5300.v5[hwInfoDiskHealthStatus, "{#ID}"]','1m','7d','365d','0','3','','','','',NULL,'150','','','0','','','','','2',NULL,'Disk health status. For details, see definition of Enum Values (HEALTH_STATUS_E).
https://support.huawei.com/enterprise/en/centralized-storage/oceanstor-5300-v5-pid-22462029?category=reference-guides&subcategory=mib-reference','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32797','20','1.3.6.1.4.1.34774.4.1.23.5.1.1.3.{#SNMPINDEX}','10357','Disk {#MODEL} on {#LOCATION}: Running status','huawei.5300.v5[hwInfoDiskRunningStatus, "{#ID}"]','1m','7d','365d','0','3','','','','',NULL,'152','','','0','','','','','2',NULL,'Disk running status. For details, see definition of Enum Values (RUNNING_STATUS_E).
https://support.huawei.com/enterprise/en/centralized-storage/oceanstor-5300-v5-pid-22462029?category=reference-guides&subcategory=mib-reference','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32798','20','1.3.6.1.4.1.34774.4.1.23.5.1.1.11.{#SNMPINDEX}','10357','Disk {#MODEL} on {#LOCATION}: Temperature','huawei.5300.v5[hwInfoDiskTemperature, "{#ID}"]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'Disk temperature.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32799','20','1.3.6.1.4.1.34774.4.1.23.5.6.1.4.{#SNMPINDEX}','10357','Enclosure {#NAME}: Health status','huawei.5300.v5[hwInfoEnclosureHealthStatus, "{#NAME}"]','1m','7d','365d','0','3','','','','',NULL,'150','','','0','','','','','2',NULL,'Enclosure health status. For details, see definition of Enum Values (HEALTH_STATUS_E).
https://support.huawei.com/enterprise/en/centralized-storage/oceanstor-5300-v5-pid-22462029?category=reference-guides&subcategory=mib-reference','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32800','20','1.3.6.1.4.1.34774.4.1.23.5.6.1.5.{#SNMPINDEX}','10357','Enclosure {#NAME}: Running status','huawei.5300.v5[hwInfoEnclosureRunningStatus, "{#NAME}"]','1m','7d','365d','0','3','','','','',NULL,'152','','','0','','','','','2',NULL,'Enclosure running status. For details, see definition of Enum Values (RUNNING_STATUS_E).
https://support.huawei.com/enterprise/en/centralized-storage/oceanstor-5300-v5-pid-22462029?category=reference-guides&subcategory=mib-reference','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32801','20','1.3.6.1.4.1.34774.4.1.23.5.6.1.8.{#SNMPINDEX}','10357','Enclosure {#NAME}: Temperature','huawei.5300.v5[hwInfoEnclosureTemperature, "{#NAME}"]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'Enclosure temperature.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32802','20','1.3.6.1.4.1.34774.4.1.23.5.4.1.3.{#SNMPINDEX}','10357','FAN {#ID} on {#LOCATION}: Health status','huawei.5300.v5[hwInfoFanHealthStatus, "{#ID}:{#LOCATION}"]','1m','7d','365d','0','3','','','','',NULL,'150','','','0','','','','','2',NULL,'Health status of a fan. For details, see definition of Enum Values (HEALTH_STATUS_E).
https://support.huawei.com/enterprise/en/centralized-storage/oceanstor-5300-v5-pid-22462029?category=reference-guides&subcategory=mib-reference','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32803','20','1.3.6.1.4.1.34774.4.1.23.5.4.1.4.{#SNMPINDEX}','10357','FAN {#ID} on {#LOCATION}: Running status','huawei.5300.v5[hwInfoFanRunningStatus, "{#ID}:{#LOCATION}"]','1m','7d','365d','0','3','','','','',NULL,'152','','','0','','','','','2',NULL,'Operating status of a fan. For details, see definition of Enum Values (RUNNING_STATUS_E).
https://support.huawei.com/enterprise/en/centralized-storage/oceanstor-5300-v5-pid-22462029?category=reference-guides&subcategory=mib-reference','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32804','20','1.3.6.1.4.1.34774.4.1.21.4.1.13.{#SNMPINDEX}','10357','LUN {#NAME}: Average total I/O latency','huawei.5300.v5[hwPerfLunAverageIOResponseTime, "{#NAME}"]','1m','7d','365d','0','3','','!ms','','',NULL,NULL,'','','0','','','','','2',NULL,'Average I/O latency of the node in milliseconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32805','20','1.3.6.1.4.1.34774.4.1.21.4.1.15.{#SNMPINDEX}','10357','LUN {#NAME}: Average read I/O latency','huawei.5300.v5[hwPerfLunAverageReadIOLatency, "{#NAME}"]','1m','7d','365d','0','3','','!ms','','',NULL,NULL,'','','0','','','','','2',NULL,'Average read I/O response time in milliseconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32806','20','1.3.6.1.4.1.34774.4.1.21.4.1.16.{#SNMPINDEX}','10357','LUN {#NAME}: Average write I/O latency','huawei.5300.v5[hwPerfLunAverageWriteIOLatency, "{#NAME}"]','1m','7d','365d','0','3','','!ms','','',NULL,NULL,'','','0','','','','','2',NULL,'Average write I/O response time in milliseconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32807','20','1.3.6.1.4.1.34774.4.1.21.4.1.4.{#SNMPINDEX}','10357','LUN {#NAME}: Read operations per second','huawei.5300.v5[hwPerfLunReadIOPS, "{#NAME}"]','1m','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'Read IOPS of the node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32808','20','1.3.6.1.4.1.34774.4.1.21.4.1.7.{#SNMPINDEX}','10357','LUN {#NAME}: Read traffic per second','huawei.5300.v5[hwPerfLunReadTraffic, "{#NAME}"]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Current read bandwidth for the LUN.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32809','20','1.3.6.1.4.1.34774.4.1.21.4.1.3.{#SNMPINDEX}','10357','LUN {#NAME}: Total I/O per second','huawei.5300.v5[hwPerfLunTotalIOPS, "{#NAME}"]','1m','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'Current IOPS of the LUN.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32810','20','1.3.6.1.4.1.34774.4.1.21.4.1.6.{#SNMPINDEX}','10357','LUN {#NAME}: Total traffic per second','huawei.5300.v5[hwPerfLunTotalTraffic, "{#NAME}"]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Current total bandwidth for the LUN.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32811','20','1.3.6.1.4.1.34774.4.1.21.4.1.5.{#SNMPINDEX}','10357','LUN {#NAME}: Write operations per second','huawei.5300.v5[hwPerfLunWriteIOPS, "{#NAME}"]','1m','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'Write IOPS of the node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32812','20','1.3.6.1.4.1.34774.4.1.21.4.1.8.{#SNMPINDEX}','10357','LUN {#NAME}: Write traffic per second','huawei.5300.v5[hwPerfLunWriteTraffic, "{#NAME}"]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Current write bandwidth for the LUN.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32813','20','1.3.6.1.4.1.34774.4.1.19.9.4.1.5.{#SNMPINDEX}','10357','LUN {#NAME}: Capacity','huawei.5300.v5[hwStorageLunCapacity, "{#NAME}"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Capacity of the LUN.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32814','20','1.3.6.1.4.1.34774.4.1.19.9.4.1.11.{#SNMPINDEX}','10357','LUN {#NAME}: Status','huawei.5300.v5[hwStorageLunStatus, "{#NAME}"]','1m','7d','365d','0','3','','','','',NULL,'151','','','0','','','','','2',NULL,'Status of the LUN.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32815','20','1.3.6.1.4.1.34774.4.1.21.3.1.2.{#SNMPINDEX}','10357','Node {#NODE}: CPU utilization','huawei.5300.v5[hwPerfNodeCPUUsage, "{#NODE}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'CPU usage of the node {#NODE}.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32816','20','1.3.6.1.4.1.34774.4.1.21.3.1.4.{#SNMPINDEX}','10357','Node {#NODE}: Average I/O latency','huawei.5300.v5[hwPerfNodeDelay, "{#NODE}"]','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'','','0','','','','','2',NULL,'Average I/O latency of the node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32817','20','1.3.6.1.4.1.34774.4.1.21.3.1.6.{#SNMPINDEX}','10357','Node {#NODE}: Read operations per second','huawei.5300.v5[hwPerfNodeReadIOPS, "{#NODE}"]','1m','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'Read IOPS of the node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32818','20','1.3.6.1.4.1.34774.4.1.21.3.1.9.{#SNMPINDEX}','10357','Node {#NODE}: Read traffic per second','huawei.5300.v5[hwPerfNodeReadTraffic, "{#NODE}"]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Read bandwidth for the node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32819','20','1.3.6.1.4.1.34774.4.1.21.3.1.5.{#SNMPINDEX}','10357','Node {#NODE}: Total I/O per second','huawei.5300.v5[hwPerfNodeTotalIOPS, "{#NODE}"]','1m','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'Total IOPS of the node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32820','20','1.3.6.1.4.1.34774.4.1.21.3.1.8.{#SNMPINDEX}','10357','Node {#NODE}: Total traffic per second','huawei.5300.v5[hwPerfNodeTotalTraffic, "{#NODE}"]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Total bandwidth for the node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32821','20','1.3.6.1.4.1.34774.4.1.21.3.1.7.{#SNMPINDEX}','10357','Node {#NODE}: Write operations per second','huawei.5300.v5[hwPerfNodeWriteIOPS, "{#NODE}"]','1m','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'Write IOPS of the node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32822','20','1.3.6.1.4.1.34774.4.1.21.3.1.7.{#SNMPINDEX}','10357','Node {#NODE}: Write traffic per second','huawei.5300.v5[hwPerfNodeWriteTraffic, "{#NODE}"]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Write bandwidth for the node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32823','20','1.3.6.1.4.1.34774.4.1.23.4.2.1.9.{#SNMPINDEX}','10357','Pool {#NAME}: Capacity free','huawei.5300.v5[hwInfoStoragePoolFreeCapacity, "{#NAME}"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Available capacity of a storage pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32824','15','','10357','Pool {#NAME}: Capacity used percentage','huawei.5300.v5[hwInfoStoragePoolFreeCapacityPct, "{#NAME}"]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last("huawei.5300.v5[hwInfoStoragePoolSubscribedCapacity, \"{#NAME}\"]")/last("huawei.5300.v5[hwInfoStoragePoolTotalCapacity, \"{#NAME}\"]")*100','','0','','','','','2',NULL,'Used capacity of a storage pool in percents.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32825','20','1.3.6.1.4.1.34774.4.1.23.4.2.1.5.{#SNMPINDEX}','10357','Pool {#NAME}: Health status','huawei.5300.v5[hwInfoStoragePoolHealthStatus, "{#NAME}"]','1m','7d','365d','0','3','','','','',NULL,'150','','','0','','','','','2',NULL,'Health status of a storage pool. For details, see definition of Enum Values (HEALTH_STATUS_E).
https://support.huawei.com/enterprise/en/centralized-storage/oceanstor-5300-v5-pid-22462029?category=reference-guides&subcategory=mib-reference','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32826','20','1.3.6.1.4.1.34774.4.1.23.4.2.1.6.{#SNMPINDEX}','10357','Pool {#NAME}: Running status','huawei.5300.v5[hwInfoStoragePoolRunningStatus, "{#NAME}"]','1m','7d','365d','0','3','','','','',NULL,'152','','','0','','','','','2',NULL,'Operating status of a storage pool. For details, see definition of Enum Values (RUNNING_STATUS_E).
https://support.huawei.com/enterprise/en/centralized-storage/oceanstor-5300-v5-pid-22462029?category=reference-guides&subcategory=mib-reference','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32827','20','1.3.6.1.4.1.34774.4.1.23.4.2.1.8.{#SNMPINDEX}','10357','Pool {#NAME}: Capacity used','huawei.5300.v5[hwInfoStoragePoolSubscribedCapacity, "{#NAME}"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Used capacity of a storage pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32828','20','1.3.6.1.4.1.34774.4.1.23.4.2.1.7.{#SNMPINDEX}','10357','Pool {#NAME}: Capacity total','huawei.5300.v5[hwInfoStoragePoolTotalCapacity, "{#NAME}"]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total capacity of a storage pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32829','0','','10358','RabbitMQ: Get overview','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.CLUSTER_HOST}:{$RABBITMQ.API.PORT}/api/overview"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The HTTP API endpoint that returns cluster-wide metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32830','0','','10358','RabbitMQ: Get exchanges','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.CLUSTER_HOST}:{$RABBITMQ.API.PORT}/api/exchanges"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The HTTP API endpoint that returns exchanges metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32831','0','','10359','RabbitMQ: Service response time','net.tcp.service.perf[http,"{$RABBITMQ.API.HOST}","{$RABBITMQ.API.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32832','0','','10359','RabbitMQ: Service ping','net.tcp.service[http,"{$RABBITMQ.API.HOST}","{$RABBITMQ.API.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32833','0','','10359','RabbitMQ: Get node overview','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/overview"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The HTTP API endpoint that returns cluster-wide metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32834','0','','10359','RabbitMQ: Get nodes','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/nodes/{$RABBITMQ.CLUSTER.NAME}@{HOST.NAME}?memory=true"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The HTTP API endpoint that returns nodes metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32835','0','','10359','RabbitMQ: Get queues','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/queues"]','1m','1h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The HTTP API endpoint that returns queues metrics','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32836','0','','10359','RabbitMQ: Number of processes running','proc.num["{$RABBITMQ.PROCESS_NAME}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32837','0','','10359','RabbitMQ: CPU utilization','proc.cpu.util["{$RABBITMQ.PROCESS_NAME}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Process CPU utilization percentage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32838','0','','10359','RabbitMQ: Memory usage (rss)','proc.mem["{$RABBITMQ.PROCESS_NAME}",,,,rss]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Resident set size memory used by process in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32839','0','','10359','RabbitMQ: Memory usage (vsize)','proc.mem["{$RABBITMQ.PROCESS_NAME}",,,,vsize]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Virtual memory size used by process in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32884','0','','10358','RabbitMQ: Healthcheck: alarms in effect in the cluster{#SINGLETON}','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.CLUSTER_HOST}:{$RABBITMQ.API.PORT}/api/health/checks/alarms{#SINGLETON}"]','1m','7d','365d','0','3','','','','',NULL,'82','','','0','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Responds a 200 OK if there are no alarms in effect in the cluster, otherwise responds with a 503 Service Unavailable.','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/health/checks/alarms','','','200,503,404','1','0','','1','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32885','0','','10359','RabbitMQ: Healthcheck{#SINGLETON}','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/healthchecks/node{#SINGLETON}"]','1m','7h','365d','0','3','','','','',NULL,'82','','','0','','','','','2',NULL,'Runs basic healthchecks in the current node. Checks that the rabbit application is running, channels and queues can be listed successfully, and that no alarms are in effect.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32886','0','','10359','RabbitMQ: Healthcheck: expiration date on the certificates{#SINGLETON}','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/health/checks/certificate-expiration/1/months{#SINGLETON}"]','1m','7d','365d','0','3','','','','',NULL,'82','','','0','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Checks the expiration date on the certificates for every listener configured to use TLS. Responds a 200 OK if all certificates are valid (have not expired), otherwise responds with a 503 Service Unavailable.','0','30d','0','',NULL,'3s','','','','200,503,404','1','0','','1','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32887','0','','10359','RabbitMQ: Healthcheck: local alarms in effect on the this node{#SINGLETON}','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/health/checks/local-alarms{#SINGLETON}"]','1m','7d','365d','0','3','','','','',NULL,'82','','','0','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Responds a 200 OK if there are no local alarms in effect on the target node, otherwise responds with a 503 Service Unavailable.','0','30d','0','',NULL,'3s','','','','200,503,404','1','0','','1','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32888','0','','10359','RabbitMQ: Healthcheck: classic mirrored queues without synchronised mirrors online{#SINGLETON}','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/health/checks/node-is-mirror-sync-critical{#SINGLETON}"]','1m','7d','365d','0','3','','','','',NULL,'82','','','0','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Checks if there are classic mirrored queues without synchronised mirrors online (queues that would potentially lose data if the target node is shut down). Responds a 200 OK if there are no such classic mirrored queues, otherwise responds with a 503 Service Unavailable.','0','30d','0','',NULL,'3s','','','','200,503,404','1','0','','1','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32889','0','','10359','RabbitMQ: Healthcheck: queues with minimum online quorum{#SINGLETON}','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/health/checks/node-is-quorum-critical{#SINGLETON}"]','1m','7d','365d','0','3','','','','',NULL,'82','','','0','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Checks if there are quorum queues with minimum online quorum (queues that would lose their quorum and availability if the target node is shut down). Responds a 200 OK if there are no such quorum queues, otherwise responds with a 503 Service Unavailable.','0','30d','0','',NULL,'3s','','','','200,503,404','1','0','','1','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32890','0','','10359','RabbitMQ: Healthcheck: virtual hosts on the this node{#SINGLETON}','web.page.get["http://{$RABBITMQ.API.USER}:{$RABBITMQ.API.PASSWORD}@{$RABBITMQ.API.HOST}:{$RABBITMQ.API.PORT}/api/health/checks/virtual-hosts{#SINGLETON}"]','1m','7d','365d','0','3','','','','',NULL,'82','','','0','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Responds a 200 OK if all virtual hosts and running on the target node, otherwise responds with a 503 Service Unavailable.','0','30d','0','',NULL,'3s','','','','200,503,404','1','0','','1','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32925','19','','10360','RabbitMQ: Get exchanges','rabbitmq.get_exchanges','1m','1h','0','0','4','','','','',NULL,NULL,'','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','0',NULL,'The HTTP API endpoint that returns exchanges metrics','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/exchanges','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32926','19','','10360','RabbitMQ: Get overview','rabbitmq.get_overview','1m','1h','0','0','4','','','','',NULL,NULL,'','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','0',NULL,'The HTTP API endpoint that returns cluster-wide metrics','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/overview','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32927','3','','10361','RabbitMQ: Service response time','net.tcp.service.perf[http,"{HOST.CONN}","{$RABBITMQ.API.PORT}"]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32928','19','','10361','RabbitMQ: Get nodes','rabbitmq.get_nodes','1m','1h','0','0','4','','','','',NULL,NULL,'','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','0',NULL,'The HTTP API endpoint that returns nodes metrics','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/nodes/{$RABBITMQ.CLUSTER.NAME}@{HOST.NAME}?memory=true','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32929','19','','10361','RabbitMQ: Get node overview','rabbitmq.get_node_overview','1m','1h','0','0','4','','','','',NULL,NULL,'','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','0',NULL,'The HTTP API endpoint that returns cluster-wide metrics','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/overview','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32930','19','','10361','RabbitMQ: Get queues','rabbitmq.get_queues','1m','1h','0','0','4','','','','',NULL,NULL,'','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','0',NULL,'The HTTP API endpoint that returns queues metrics','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/queues','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32931','3','','10361','RabbitMQ: Service ping','net.tcp.service[http,"{HOST.CONN}","{$RABBITMQ.API.PORT}"]','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32976','19','','10360','RabbitMQ: Healthcheck: alarms in effect in the cluster{#SINGLETON}','rabbitmq.healthcheck.alarms[{#SINGLETON}]','1m','7d','365d','0','3','','','','',NULL,'82','','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Responds a 200 OK if there are no alarms in effect in the cluster, otherwise responds with a 503 Service Unavailable.','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/health/checks/alarms','','','200,503,404','1','0','','1','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32977','19','','10361','RabbitMQ: Healthcheck{#SINGLETON}','rabbitmq.healthcheck[{#SINGLETON}]','1m','7h','365d','0','3','','','','',NULL,'82','','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Runs basic healthchecks in the current node. Checks that the rabbit application is running, channels and queues can be listed successfully, and that no alarms are in effect.','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/healthchecks/node','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32978','19','','10361','RabbitMQ: Healthcheck: expiration date on the certificates{#SINGLETON}','rabbitmq.healthcheck.certificate_expiration[{#SINGLETON}]','1m','7d','365d','0','3','','','','',NULL,'82','','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Checks the expiration date on the certificates for every listener configured to use TLS. Responds a 200 OK if all certificates are valid (have not expired), otherwise responds with a 503 Service Unavailable.','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/health/checks/certificate-expiration/1/months','','','200,503,404','1','0','','1','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32979','19','','10361','RabbitMQ: Healthcheck: local alarms in effect on the this node{#SINGLETON}','rabbitmq.healthcheck.local_alarms[{#SINGLETON}]','1m','7d','365d','0','3','','','','',NULL,'82','','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Responds a 200 OK if there are no local alarms in effect on the target node, otherwise responds with a 503 Service Unavailable.','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/health/checks/local-alarms','','','200,503,404','1','0','','1','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32980','19','','10361','RabbitMQ: Healthcheck: classic mirrored queues without synchronised mirrors online{#SINGLETON}','rabbitmq.healthcheck.mirror_sync[{#SINGLETON}]','1m','7d','365d','0','3','','','','',NULL,'82','','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Checks if there are classic mirrored queues without synchronised mirrors online (queues that would potentially lose data if the target node is shut down). Responds a 200 OK if there are no such classic mirrored queues, otherwise responds with a 503 Service Unavailable.','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/health/checks/node-is-mirror-sync-critical','','','200,503,404','1','0','','1','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32981','19','','10361','RabbitMQ: Healthcheck: queues with minimum online quorum{#SINGLETON}','rabbitmq.healthcheck.quorum[{#SINGLETON}]','1m','7d','365d','0','3','','','','',NULL,'82','','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Checks if there are quorum queues with minimum online quorum (queues that would lose their quorum and availability if the target node is shut down). Responds a 200 OK if there are no such quorum queues, otherwise responds with a 503 Service Unavailable.','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/health/checks/node-is-quorum-critical','','','200,503,404','1','0','','1','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32982','19','','10361','RabbitMQ: Healthcheck: virtual hosts on the this node{#SINGLETON}','rabbitmq.healthcheck.virtual_hosts[{#SINGLETON}]','1m','7d','365d','0','3','','','','',NULL,'82','','','1','{$RABBITMQ.API.USER}','{$RABBITMQ.API.PASSWORD}','','','2',NULL,'Responds a 200 OK if all virtual hosts and running on the target node, otherwise responds with a 503 Service Unavailable.','0','30d','0','',NULL,'3s','{$RABBITMQ.API.SCHEME}://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/health/checks/virtual-hosts','','','200,503,404','1','0','','1','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33017','0','','10362','MongoDB: Get server status','mongodb.server.status["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns a database’s state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33018','0','','10362','MongoDB: Get Replica Set status','mongodb.rs.status["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns the replica set status from the point of view of the member where the method is run.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33019','0','','10362','MongoDB: Ping','mongodb.ping["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','30s','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'Test if a connection is alive or not.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33020','0','','10362','MongoDB: Get oplog stats','mongodb.oplog.stats["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns status of the replica set, using data polled from the oplog.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33021','0','','10362','MongoDB: Get collections usage stats','mongodb.collections.usage["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns usage statistics for each collection.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33061','0','','10362','Collection discovery','mongodb.collections.discovery["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Collect collections metrics.
Note, depending on the number of DBs and collections this discovery operation may be expensive. Use filters with macros {$MONGODB.LLD.FILTER.DB.MATCHES}, {$MONGODB.LLD.FILTER.DB.NOT_MATCHES}, {$MONGODB.LLD.FILTER.COLLECTION.MATCHES}, {$MONGODB.LLD.FILTER.COLLECTION.NOT_MATCHES}.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33062','0','','10362','Database discovery','mongodb.db.discovery["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Collect database metrics.
Note, depending on the number of DBs this discovery operation may be expensive. Use filters with macros {$MONGODB.LLD.FILTER.DB.MATCHES}, {$MONGODB.LLD.FILTER.DB.NOT_MATCHES}.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33065','0','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Get collection stats {#DBNAME}.{#COLLECTION}','mongodb.collection.stats["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}","{#DBNAME}","{#COLLECTION}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Returns a variety of storage statistics for a given collection.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33066','0','','10362','MongoDB {#DBNAME}: Get db stats {#DBNAME}','mongodb.db.stats["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}","{#DBNAME}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Returns statistics reflecting the database system’s state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33139','0','','10363','MongoDB cluster: Jumbo chunks','mongodb.jumbo_chunks.count["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of ''jumbo'' chunks in the mongo cluster.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33140','0','','10363','MongoDB cluster: Get server status','mongodb.server.status["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The mongos statistic','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33141','0','','10363','MongoDB cluster: Ping','mongodb.ping["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','30s','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'Test if a connection is alive or not.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33142','0','','10363','MongoDB cluster: Get mongodb.connpool.stats','mongodb.connpool.stats["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns current info about connpool.stats.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33173','0','','10363','Config servers discovery','mongodb.cfg.discovery["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery shared cluster config servers.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33174','0','','10363','Collection discovery','mongodb.collections.discovery["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Collect collections metrics.
Note, depending on the number of DBs and collections this discovery operation may be expensive. Use filters with macros {$MONGODB.LLD.FILTER.DB.MATCHES}, {$MONGODB.LLD.FILTER.DB.NOT_MATCHES}, {$MONGODB.LLD.FILTER.COLLECTION.MATCHES}, {$MONGODB.LLD.FILTER.COLLECTION.NOT_MATCHES}.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33175','0','','10363','Database discovery','mongodb.db.discovery["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Collect database metrics.
Note, depending on the number of DBs this discovery operation may be expensive. Use filters with macros {$MONGODB.LLD.FILTER.DB.MATCHES}, {$MONGODB.LLD.FILTER.DB.NOT_MATCHES}.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33176','0','','10363','Shards discovery','mongodb.sh.discovery["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery shared cluster hosts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33177','0','','10363','MongoDB {#DBNAME}.{#COLLECTION}: Get collection stats {#DBNAME}.{#COLLECTION}','mongodb.collection.stats["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}","{#DBNAME}","{#COLLECTION}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Returns a variety of storage statistics for a given collection.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33178','0','','10363','MongoDB {#DBNAME}: Get db stats {#DBNAME}','mongodb.db.stats["{$MONGODB.CONNSTRING}","{$MONGODB.USER}","{$MONGODB.PASSWORD}","{#DBNAME}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Returns statistics reflecting the database system’s state.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33194','11','','10327','MSSQL AG ''{#GROUP_NAME}'' Non-Local DB ''*{#REPLICA_NAME}*{#DBNAME}'': Get non-local DB states','db.odbc.get["{#GROUP_NAME}*{#REPLICA_NAME}*{#DBNAME}_non-local_db.states","{$MSSQL.DSN}"]','1m','0h','0','0','4','','','','',NULL,NULL,'SELECT drs.log_send_queue_size as log_send_queue_size,
drs.redo_queue_size as redo_queue_size,
ag.name as group_name,
arcs.replica_server_name as replica_name,
db_name(drs.database_id) as dbname
FROM sys.dm_hadr_database_replica_states drs 
JOIN sys.dm_hadr_availability_replica_cluster_states arcs ON arcs.replica_id = drs.replica_id 
JOIN sys.availability_groups ag ON ag.group_id = arcs.group_id 
JOIN sys.dm_hadr_availability_replica_states ars ON ars.replica_id = arcs.replica_id','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','2',NULL,'Getting the states of the non-local availability database.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33197','3','','10366','ICMP ping','icmpping','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33198','3','','10366','ICMP loss','icmppingloss','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33199','3','','10366','ICMP response time','icmppingsec','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33200','17','','10366','SNMP traps (fallback)','snmptrap.fallback','1m','7d','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33201','20','1.3.6.1.2.1.1.4.0','10366','System contact details','system.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33202','20','1.3.6.1.2.1.1.1.0','10366','System description','system.descr','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33203','20','1.3.6.1.2.1.47.1.1.1.1.13.1','10366','Hardware model name','system.hw.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33204','20','1.3.6.1.2.1.47.1.1.1.1.11.1','10366','Hardware serial number','system.hw.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33205','20','1.3.6.1.2.1.1.6.0','10366','System location','system.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33206','20','1.3.6.1.2.1.1.5.0','10366','System name','system.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33207','20','1.3.6.1.2.1.1.2.0','10366','System object ID','system.objectid','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33208','20','1.3.6.1.2.1.1.1.0','10366','Operating system','system.sw.os','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33209','20','1.3.6.1.2.1.1.3.0','10366','Uptime','system.uptime','1m','7d','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33210','5','','10366','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33211','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.109.1.1.1.1.5]','10366','CPU discovery','cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If your IOS device has several CPUs, you must use CISCO-PROCESS-MIB and its object cpmCPUTotal5minRev from the table called cpmCPUTotalTable ,
indexed with cpmCPUTotalIndex .
This table allows CISCO-PROCESS-MIB to keep CPU statistics for different physical entities in the router,
like different CPU chips, group of CPUs, or CPUs in different modules/cards.
In case of a single CPU, cpmCPUTotalTable has only one entry.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33212','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7,{#ENT_SN},1.3.6.1.2.1.47.1.1.1.1.11]','10366','Entity Serial Numbers discovery','entity_sn.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33213','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.4.1.2]','10366','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table of fan status maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33214','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.48.1.1.1.2]','10366','Memory discovery','memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoMemoryPoolTable, a table of memory pool monitoring entries.
http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33215','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10366','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33216','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10366','EtherLike discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33217','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.5.1.2]','10366','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table of power supply status maintained by the environmental monitor card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33218','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.3.1.2]','10366','Temperature discovery','temperature.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoEnvMonTemperatureTable (ciscoEnvMonTemperatureDescr), a table of ambient temperature status
maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33219','20','1.3.6.1.4.1.9.9.109.1.1.1.1.8.{#SNMPINDEX}','10366','#{#SNMPINDEX}: CPU utilization','system.cpu.util[{#SNMPINDEX}]','5m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-PROCESS-MIB
Object name: cpmCPUTotal5minRev
The cpmCPUTotal5minRev MIB object provides a more accurate view of the performance of the router over time than the MIB objects cpmCPUTotal1minRev and cpmCPUTotal5secRev . These MIB objects are not accurate because they look at CPU at one minute and five second intervals, respectively. These MIBs enable you to monitor the trends and plan the capacity of your network. The recommended baseline rising threshold for cpmCPUTotal5minRev is 90 percent. Depending on the platform, some routers that run at 90 percent, for example, 2500s, can exhibit performance degradation versus a high-end router, for example, the 7500 series, which can operate fine.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15215-collect-cpu-util-snmp.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33220','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10366','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB
Object name: entPhysicalSerialNum','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33221','20','1.3.6.1.4.1.9.9.13.1.4.1.3.{#SNMPINDEX}','10366','{#SNMPVALUE}: Fan status','sensor.fan.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonFanState','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33222','20','1.3.6.1.4.1.9.9.48.1.1.1.6.{#SNMPINDEX}','10366','{#SNMPVALUE}: Free memory','vm.memory.free[{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Object name: ciscoMemoryPoolFree
Indicates the number of bytes from the memory pool that are currently unused on the managed device. Note that the sum of ciscoMemoryPoolUsed and ciscoMemoryPoolFree is the total amount of memory in the pool
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33223','20','1.3.6.1.4.1.9.9.48.1.1.1.5.{#SNMPINDEX}','10366','{#SNMPVALUE}: Used memory','vm.memory.used[{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Object name: ciscoMemoryPoolUsed
Indicates the number of bytes from the memory pool that are currently in use by applications on the managed device.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33224','15','','10366','{#SNMPVALUE}: Memory utilization','vm.memory.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.used[{#SNMPINDEX}]")/(last("vm.memory.free[{#SNMPINDEX}]")+last("vm.memory.used[{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33225','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10366','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33226','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10366','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33227','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10366','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33228','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10366','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33229','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10366','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33230','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10366','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33231','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10366','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33232','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10366','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33233','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10366','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33234','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10366','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
Object name: dot3StatsDuplexStatus
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33235','20','1.3.6.1.4.1.9.9.13.1.5.1.3.{#SNMPINDEX}','10366','{#SNMPVALUE}: Power supply status','sensor.psu.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonSupplyState','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33236','20','1.3.6.1.4.1.9.9.13.1.3.1.6.{#SNMPINDEX}','10366','{#SNMPVALUE}: Temperature status','sensor.temp.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonTemperatureState
The current state of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33237','20','1.3.6.1.4.1.9.9.13.1.3.1.3.{#SNMPINDEX}','10366','{#SNMPVALUE}: Temperature','sensor.temp.value[{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonTemperatureValue
The current measurement of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33238','3','','10367','ICMP ping','icmpping','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33239','3','','10367','ICMP loss','icmppingloss','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33240','3','','10367','ICMP response time','icmppingsec','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33241','17','','10367','SNMP traps (fallback)','snmptrap.fallback','1m','7d','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33242','20','1.3.6.1.2.1.1.4.0','10367','System contact details','system.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33243','20','1.3.6.1.2.1.1.1.0','10367','System description','system.descr','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33244','20','1.3.6.1.2.1.47.1.1.1.1.13.1','10367','Hardware model name','system.hw.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33245','20','1.3.6.1.2.1.47.1.1.1.1.11.1','10367','Hardware serial number','system.hw.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33246','20','1.3.6.1.2.1.1.6.0','10367','System location','system.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33247','20','1.3.6.1.2.1.1.5.0','10367','System name','system.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33248','20','1.3.6.1.2.1.1.2.0','10367','System object ID','system.objectid','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33249','20','1.3.6.1.2.1.1.1.0','10367','Operating system','system.sw.os','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33250','20','1.3.6.1.2.1.1.3.0','10367','Uptime','system.uptime','1m','7d','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33251','5','','10367','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33252','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.109.1.1.1.1.5]','10367','CPU discovery','cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If your IOS device has several CPUs, you must use CISCO-PROCESS-MIB and its object cpmCPUTotal5minRev from the table called cpmCPUTotalTable ,
indexed with cpmCPUTotalIndex .
This table allows CISCO-PROCESS-MIB to keep CPU statistics for different physical entities in the router,
like different CPU chips, group of CPUs, or CPUs in different modules/cards.
In case of a single CPU, cpmCPUTotalTable has only one entry.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33253','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7,{#ENT_SN},1.3.6.1.2.1.47.1.1.1.1.11]','10367','Entity Serial Numbers discovery','entity_sn.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33254','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.4.1.2]','10367','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table of fan status maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33255','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.48.1.1.1.2]','10367','Memory discovery','memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoMemoryPoolTable, a table of memory pool monitoring entries.
http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33256','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10367','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33257','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10367','EtherLike discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33258','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.5.1.2]','10367','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table of power supply status maintained by the environmental monitor card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33259','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.3.1.2]','10367','Temperature discovery','temperature.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoEnvMonTemperatureTable (ciscoEnvMonTemperatureDescr), a table of ambient temperature status
maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33260','20','1.3.6.1.4.1.9.9.109.1.1.1.1.8.{#SNMPINDEX}','10367','#{#SNMPINDEX}: CPU utilization','system.cpu.util[{#SNMPINDEX}]','5m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-PROCESS-MIB
Object name: cpmCPUTotal5minRev
The cpmCPUTotal5minRev MIB object provides a more accurate view of the performance of the router over time than the MIB objects cpmCPUTotal1minRev and cpmCPUTotal5secRev . These MIB objects are not accurate because they look at CPU at one minute and five second intervals, respectively. These MIBs enable you to monitor the trends and plan the capacity of your network. The recommended baseline rising threshold for cpmCPUTotal5minRev is 90 percent. Depending on the platform, some routers that run at 90 percent, for example, 2500s, can exhibit performance degradation versus a high-end router, for example, the 7500 series, which can operate fine.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15215-collect-cpu-util-snmp.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33261','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10367','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB
Object name: entPhysicalSerialNum','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33262','20','1.3.6.1.4.1.9.9.13.1.4.1.3.{#SNMPINDEX}','10367','{#SNMPVALUE}: Fan status','sensor.fan.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonFanState','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33263','20','1.3.6.1.4.1.9.9.48.1.1.1.6.{#SNMPINDEX}','10367','{#SNMPVALUE}: Free memory','vm.memory.free[{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Object name: ciscoMemoryPoolFree
Indicates the number of bytes from the memory pool that are currently unused on the managed device. Note that the sum of ciscoMemoryPoolUsed and ciscoMemoryPoolFree is the total amount of memory in the pool
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33264','20','1.3.6.1.4.1.9.9.48.1.1.1.5.{#SNMPINDEX}','10367','{#SNMPVALUE}: Used memory','vm.memory.used[{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Object name: ciscoMemoryPoolUsed
Indicates the number of bytes from the memory pool that are currently in use by applications on the managed device.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33265','15','','10367','{#SNMPVALUE}: Memory utilization','vm.memory.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.used[{#SNMPINDEX}]")/(last("vm.memory.free[{#SNMPINDEX}]")+last("vm.memory.used[{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33266','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10367','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33267','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10367','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33268','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10367','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33269','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10367','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33270','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10367','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33271','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10367','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33272','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10367','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33273','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10367','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33274','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10367','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33275','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10367','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
Object name: dot3StatsDuplexStatus
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33276','20','1.3.6.1.4.1.9.9.13.1.5.1.3.{#SNMPINDEX}','10367','{#SNMPVALUE}: Power supply status','sensor.psu.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonSupplyState','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33277','20','1.3.6.1.4.1.9.9.13.1.3.1.6.{#SNMPINDEX}','10367','{#SNMPVALUE}: Temperature status','sensor.temp.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonTemperatureState
The current state of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33278','20','1.3.6.1.4.1.9.9.13.1.3.1.3.{#SNMPINDEX}','10367','{#SNMPVALUE}: Temperature','sensor.temp.value[{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonTemperatureValue
The current measurement of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33279','3','','10368','ICMP ping','icmpping','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33280','3','','10368','ICMP loss','icmppingloss','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33281','3','','10368','ICMP response time','icmppingsec','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33282','17','','10368','SNMP traps (fallback)','snmptrap.fallback','1m','7d','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33283','20','1.3.6.1.2.1.1.4.0','10368','System contact details','system.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33284','20','1.3.6.1.2.1.1.1.0','10368','System description','system.descr','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33285','20','1.3.6.1.2.1.47.1.1.1.1.13.1','10368','Hardware model name','system.hw.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33286','20','1.3.6.1.2.1.47.1.1.1.1.11.1','10368','Hardware serial number','system.hw.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33287','20','1.3.6.1.2.1.1.6.0','10368','System location','system.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33288','20','1.3.6.1.2.1.1.5.0','10368','System name','system.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33289','20','1.3.6.1.2.1.1.2.0','10368','System object ID','system.objectid','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33290','20','1.3.6.1.2.1.1.1.0','10368','Operating system','system.sw.os','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33291','20','1.3.6.1.2.1.1.3.0','10368','Uptime','system.uptime','1m','7d','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33292','5','','10368','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33293','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.109.1.1.1.1.5]','10368','CPU discovery','cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If your IOS device has several CPUs, you must use CISCO-PROCESS-MIB and its object cpmCPUTotal5minRev from the table called cpmCPUTotalTable ,
indexed with cpmCPUTotalIndex .
This table allows CISCO-PROCESS-MIB to keep CPU statistics for different physical entities in the router,
like different CPU chips, group of CPUs, or CPUs in different modules/cards.
In case of a single CPU, cpmCPUTotalTable has only one entry.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33294','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7,{#ENT_SN},1.3.6.1.2.1.47.1.1.1.1.11]','10368','Entity Serial Numbers discovery','entity_sn.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33295','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.4.1.2]','10368','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table of fan status maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33296','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.48.1.1.1.2]','10368','Memory discovery','memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoMemoryPoolTable, a table of memory pool monitoring entries.
http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33297','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10368','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33298','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10368','EtherLike discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33299','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.5.1.2]','10368','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table of power supply status maintained by the environmental monitor card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33300','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.3.1.2]','10368','Temperature discovery','temperature.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoEnvMonTemperatureTable (ciscoEnvMonTemperatureDescr), a table of ambient temperature status
maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33301','20','1.3.6.1.4.1.9.9.109.1.1.1.1.8.{#SNMPINDEX}','10368','#{#SNMPINDEX}: CPU utilization','system.cpu.util[{#SNMPINDEX}]','5m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-PROCESS-MIB
Object name: cpmCPUTotal5minRev
The cpmCPUTotal5minRev MIB object provides a more accurate view of the performance of the router over time than the MIB objects cpmCPUTotal1minRev and cpmCPUTotal5secRev . These MIB objects are not accurate because they look at CPU at one minute and five second intervals, respectively. These MIBs enable you to monitor the trends and plan the capacity of your network. The recommended baseline rising threshold for cpmCPUTotal5minRev is 90 percent. Depending on the platform, some routers that run at 90 percent, for example, 2500s, can exhibit performance degradation versus a high-end router, for example, the 7500 series, which can operate fine.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15215-collect-cpu-util-snmp.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33302','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10368','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB
Object name: entPhysicalSerialNum','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33303','20','1.3.6.1.4.1.9.9.13.1.4.1.3.{#SNMPINDEX}','10368','{#SNMPVALUE}: Fan status','sensor.fan.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonFanState','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33304','20','1.3.6.1.4.1.9.9.48.1.1.1.6.{#SNMPINDEX}','10368','{#SNMPVALUE}: Free memory','vm.memory.free[{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Object name: ciscoMemoryPoolFree
Indicates the number of bytes from the memory pool that are currently unused on the managed device. Note that the sum of ciscoMemoryPoolUsed and ciscoMemoryPoolFree is the total amount of memory in the pool
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33305','20','1.3.6.1.4.1.9.9.48.1.1.1.5.{#SNMPINDEX}','10368','{#SNMPVALUE}: Used memory','vm.memory.used[{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Object name: ciscoMemoryPoolUsed
Indicates the number of bytes from the memory pool that are currently in use by applications on the managed device.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33306','15','','10368','{#SNMPVALUE}: Memory utilization','vm.memory.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.used[{#SNMPINDEX}]")/(last("vm.memory.free[{#SNMPINDEX}]")+last("vm.memory.used[{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33307','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10368','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33308','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10368','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33309','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10368','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33310','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10368','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33311','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10368','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33312','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10368','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33313','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10368','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33314','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10368','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33315','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10368','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33316','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10368','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
Object name: dot3StatsDuplexStatus
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33317','20','1.3.6.1.4.1.9.9.13.1.5.1.3.{#SNMPINDEX}','10368','{#SNMPVALUE}: Power supply status','sensor.psu.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonSupplyState','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33318','20','1.3.6.1.4.1.9.9.13.1.3.1.6.{#SNMPINDEX}','10368','{#SNMPVALUE}: Temperature status','sensor.temp.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonTemperatureState
The current state of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33319','20','1.3.6.1.4.1.9.9.13.1.3.1.3.{#SNMPINDEX}','10368','{#SNMPVALUE}: Temperature','sensor.temp.value[{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonTemperatureValue
The current measurement of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33320','3','','10369','ICMP ping','icmpping','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33321','3','','10369','ICMP loss','icmppingloss','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33322','3','','10369','ICMP response time','icmppingsec','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33323','17','','10369','SNMP traps (fallback)','snmptrap.fallback','1m','7d','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33324','20','1.3.6.1.2.1.1.4.0','10369','System contact details','system.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33325','20','1.3.6.1.2.1.1.1.0','10369','System description','system.descr','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33326','20','1.3.6.1.2.1.47.1.1.1.1.13.1','10369','Hardware model name','system.hw.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33327','20','1.3.6.1.2.1.47.1.1.1.1.11.1','10369','Hardware serial number','system.hw.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33328','20','1.3.6.1.2.1.1.6.0','10369','System location','system.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33329','20','1.3.6.1.2.1.1.5.0','10369','System name','system.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33330','20','1.3.6.1.2.1.1.2.0','10369','System object ID','system.objectid','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33331','20','1.3.6.1.2.1.1.1.0','10369','Operating system','system.sw.os','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33332','20','1.3.6.1.2.1.1.3.0','10369','Uptime','system.uptime','1m','7d','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33333','5','','10369','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33334','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.109.1.1.1.1.5]','10369','CPU discovery','cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If your IOS device has several CPUs, you must use CISCO-PROCESS-MIB and its object cpmCPUTotal5minRev from the table called cpmCPUTotalTable ,
indexed with cpmCPUTotalIndex .
This table allows CISCO-PROCESS-MIB to keep CPU statistics for different physical entities in the router,
like different CPU chips, group of CPUs, or CPUs in different modules/cards.
In case of a single CPU, cpmCPUTotalTable has only one entry.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33335','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7,{#ENT_SN},1.3.6.1.2.1.47.1.1.1.1.11]','10369','Entity Serial Numbers discovery','entity_sn.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33336','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.4.1.2]','10369','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table of fan status maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33337','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.48.1.1.1.2]','10369','Memory discovery','memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoMemoryPoolTable, a table of memory pool monitoring entries.
http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33338','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10369','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33339','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10369','EtherLike discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33340','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.5.1.2]','10369','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table of power supply status maintained by the environmental monitor card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33341','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.3.1.2]','10369','Temperature discovery','temperature.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoEnvMonTemperatureTable (ciscoEnvMonTemperatureDescr), a table of ambient temperature status
maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33342','20','1.3.6.1.4.1.9.9.109.1.1.1.1.8.{#SNMPINDEX}','10369','#{#SNMPINDEX}: CPU utilization','system.cpu.util[{#SNMPINDEX}]','5m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-PROCESS-MIB
Object name: cpmCPUTotal5minRev
The cpmCPUTotal5minRev MIB object provides a more accurate view of the performance of the router over time than the MIB objects cpmCPUTotal1minRev and cpmCPUTotal5secRev . These MIB objects are not accurate because they look at CPU at one minute and five second intervals, respectively. These MIBs enable you to monitor the trends and plan the capacity of your network. The recommended baseline rising threshold for cpmCPUTotal5minRev is 90 percent. Depending on the platform, some routers that run at 90 percent, for example, 2500s, can exhibit performance degradation versus a high-end router, for example, the 7500 series, which can operate fine.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15215-collect-cpu-util-snmp.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33343','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10369','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB
Object name: entPhysicalSerialNum','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33344','20','1.3.6.1.4.1.9.9.13.1.4.1.3.{#SNMPINDEX}','10369','{#SNMPVALUE}: Fan status','sensor.fan.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonFanState','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33345','20','1.3.6.1.4.1.9.9.48.1.1.1.6.{#SNMPINDEX}','10369','{#SNMPVALUE}: Free memory','vm.memory.free[{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Object name: ciscoMemoryPoolFree
Indicates the number of bytes from the memory pool that are currently unused on the managed device. Note that the sum of ciscoMemoryPoolUsed and ciscoMemoryPoolFree is the total amount of memory in the pool
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33346','20','1.3.6.1.4.1.9.9.48.1.1.1.5.{#SNMPINDEX}','10369','{#SNMPVALUE}: Used memory','vm.memory.used[{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Object name: ciscoMemoryPoolUsed
Indicates the number of bytes from the memory pool that are currently in use by applications on the managed device.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33347','15','','10369','{#SNMPVALUE}: Memory utilization','vm.memory.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.used[{#SNMPINDEX}]")/(last("vm.memory.free[{#SNMPINDEX}]")+last("vm.memory.used[{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33348','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10369','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33349','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10369','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33350','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10369','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33351','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10369','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33352','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10369','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33353','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10369','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33354','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10369','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33355','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10369','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33356','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10369','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33357','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10369','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
Object name: dot3StatsDuplexStatus
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33358','20','1.3.6.1.4.1.9.9.13.1.5.1.3.{#SNMPINDEX}','10369','{#SNMPVALUE}: Power supply status','sensor.psu.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonSupplyState','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33359','20','1.3.6.1.4.1.9.9.13.1.3.1.6.{#SNMPINDEX}','10369','{#SNMPVALUE}: Temperature status','sensor.temp.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonTemperatureState
The current state of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33360','20','1.3.6.1.4.1.9.9.13.1.3.1.3.{#SNMPINDEX}','10369','{#SNMPVALUE}: Temperature','sensor.temp.value[{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonTemperatureValue
The current measurement of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33361','3','','10370','ICMP ping','icmpping','1m','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33362','3','','10370','ICMP loss','icmppingloss','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33363','3','','10370','ICMP response time','icmppingsec','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33364','17','','10370','SNMP traps (fallback)','snmptrap.fallback','1m','7d','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33365','20','1.3.6.1.2.1.1.4.0','10370','System contact details','system.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33366','20','1.3.6.1.2.1.1.1.0','10370','System description','system.descr','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33367','20','1.3.6.1.2.1.47.1.1.1.1.13.1','10370','Hardware model name','system.hw.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33368','20','1.3.6.1.2.1.47.1.1.1.1.11.1','10370','Hardware serial number','system.hw.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33369','20','1.3.6.1.2.1.1.6.0','10370','System location','system.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33370','20','1.3.6.1.2.1.1.5.0','10370','System name','system.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33371','20','1.3.6.1.2.1.1.2.0','10370','System object ID','system.objectid','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33372','20','1.3.6.1.2.1.1.1.0','10370','Operating system','system.sw.os','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33373','20','1.3.6.1.2.1.1.3.0','10370','Uptime','system.uptime','1m','7d','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33374','5','','10370','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33375','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.109.1.1.1.1.5]','10370','CPU discovery','cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If your IOS device has several CPUs, you must use CISCO-PROCESS-MIB and its object cpmCPUTotal5minRev from the table called cpmCPUTotalTable ,
indexed with cpmCPUTotalIndex .
This table allows CISCO-PROCESS-MIB to keep CPU statistics for different physical entities in the router,
like different CPU chips, group of CPUs, or CPUs in different modules/cards.
In case of a single CPU, cpmCPUTotalTable has only one entry.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33376','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7,{#ENT_SN},1.3.6.1.2.1.47.1.1.1.1.11]','10370','Entity Serial Numbers discovery','entity_sn.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33377','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.4.1.2]','10370','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table of fan status maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33378','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.48.1.1.1.2]','10370','Memory discovery','memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoMemoryPoolTable, a table of memory pool monitoring entries.
http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33379','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10370','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33380','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10370','EtherLike discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33381','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.5.1.2]','10370','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table of power supply status maintained by the environmental monitor card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33382','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.3.1.2]','10370','Temperature discovery','temperature.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoEnvMonTemperatureTable (ciscoEnvMonTemperatureDescr), a table of ambient temperature status
maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33383','20','1.3.6.1.4.1.9.9.109.1.1.1.1.8.{#SNMPINDEX}','10370','#{#SNMPINDEX}: CPU utilization','system.cpu.util[{#SNMPINDEX}]','5m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-PROCESS-MIB
Object name: cpmCPUTotal5minRev
The cpmCPUTotal5minRev MIB object provides a more accurate view of the performance of the router over time than the MIB objects cpmCPUTotal1minRev and cpmCPUTotal5secRev . These MIB objects are not accurate because they look at CPU at one minute and five second intervals, respectively. These MIBs enable you to monitor the trends and plan the capacity of your network. The recommended baseline rising threshold for cpmCPUTotal5minRev is 90 percent. Depending on the platform, some routers that run at 90 percent, for example, 2500s, can exhibit performance degradation versus a high-end router, for example, the 7500 series, which can operate fine.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15215-collect-cpu-util-snmp.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33384','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10370','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB
Object name: entPhysicalSerialNum','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33385','20','1.3.6.1.4.1.9.9.13.1.4.1.3.{#SNMPINDEX}','10370','{#SNMPVALUE}: Fan status','sensor.fan.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonFanState','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33386','20','1.3.6.1.4.1.9.9.48.1.1.1.6.{#SNMPINDEX}','10370','{#SNMPVALUE}: Free memory','vm.memory.free[{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Object name: ciscoMemoryPoolFree
Indicates the number of bytes from the memory pool that are currently unused on the managed device. Note that the sum of ciscoMemoryPoolUsed and ciscoMemoryPoolFree is the total amount of memory in the pool
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33387','20','1.3.6.1.4.1.9.9.48.1.1.1.5.{#SNMPINDEX}','10370','{#SNMPVALUE}: Used memory','vm.memory.used[{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Object name: ciscoMemoryPoolUsed
Indicates the number of bytes from the memory pool that are currently in use by applications on the managed device.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33388','15','','10370','{#SNMPVALUE}: Memory utilization','vm.memory.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.used[{#SNMPINDEX}]")/(last("vm.memory.free[{#SNMPINDEX}]")+last("vm.memory.used[{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33389','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10370','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33390','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10370','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33391','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10370','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33392','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10370','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33393','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10370','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33394','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10370','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33395','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10370','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33396','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10370','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33397','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10370','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33398','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10370','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
Object name: dot3StatsDuplexStatus
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33399','20','1.3.6.1.4.1.9.9.13.1.5.1.3.{#SNMPINDEX}','10370','{#SNMPVALUE}: Power supply status','sensor.psu.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonSupplyState','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33400','20','1.3.6.1.4.1.9.9.13.1.3.1.6.{#SNMPINDEX}','10370','{#SNMPVALUE}: Temperature status','sensor.temp.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonTemperatureState
The current state of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33401','20','1.3.6.1.4.1.9.9.13.1.3.1.3.{#SNMPINDEX}','10370','{#SNMPVALUE}: Temperature','sensor.temp.value[{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
Object name: ciscoEnvMonTemperatureValue
The current measurement of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33402','3','','10251','ICMP ping','icmpping','1m','1w','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33403','3','','10251','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33404','3','','10251','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33405','17','','10251','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33406','20','1.3.6.1.2.1.1.4.0','10251','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33407','20','discovery[{#CPU.UTIL},1.3.6.1.2.1.25.3.3.1.2]','10251','CPU utilization','system.cpu.util','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: HOST-RESOURCES-MIB
The average, over the last minute, of the percentage of time that processors was not idle.
Implementations may approximate this one minute smoothing period if necessary.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33408','20','1.3.6.1.2.1.1.1.0','10251','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33409','20','1.3.6.1.2.1.1.6.0','10251','System location','system.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33410','20','1.3.6.1.2.1.1.5.0','10251','System name','system.name','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33411','20','1.3.6.1.2.1.1.2.0','10251','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33412','20','1.3.6.1.2.1.1.3.0','10251','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33413','5','','10251','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33414','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10251','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33415','20','discovery[{#FSNAME},1.3.6.1.2.1.25.2.3.1.3,{#FSTYPE},1.3.6.1.2.1.25.2.3.1.2,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4]','10251','Storage discovery','vfs.fs.discovery[snmp]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with storage filter.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33416','20','discovery[{#MEMNAME},1.3.6.1.2.1.25.2.3.1.3,{#MEMTYPE},1.3.6.1.2.1.25.2.3.1.2,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4]','10251','Memory discovery','vm.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with memory filter','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33417','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10251','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33418','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10251','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33419','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10251','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33420','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10251','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33421','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10251','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33422','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10251','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33423','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10251','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33424','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10251','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33425','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10251','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','',NULL,'21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33426','15','','10251','{#FSNAME}: Space utilization','vfs.fs.pused[storageUsedPercentage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'(last("vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]")/last("vfs.fs.total[hrStorageSize.{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33427','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10251','{#FSNAME}: Total space','vfs.fs.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in units of hrStorageAllocationUnits.
This object is writable to allow remote configuration of the size of the storage area in those cases where such an operation makes sense and is possible on the underlying system.
For example, the amount of main storage allocated to a buffer pool might be modified or the amount of disk space allocated to virtual storage might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33428','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10251','{#FSNAME}: Used space','vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33429','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10251','{#MEMNAME}: Total memory','vm.memory.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in units of hrStorageAllocationUnits.
This object is writable to allow remote configuration of the size of the storage area in those cases where such an operation makes sense and is possible on the underlying system.
For example, the amount of main memory allocated to a buffer pool might be modified or the amount of disk space allocated to virtual memory might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33430','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10251','{#MEMNAME}: Used memory','vm.memory.used[hrStorageUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33431','15','','10251','{#MEMNAME}: Memory utilization','vm.memory.util[memoryUsedPercentage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("vm.memory.used[hrStorageUsed.{#SNMPINDEX}]")/last("vm.memory.total[hrStorageSize.{#SNMPINDEX}]")*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33433','20','1.3.6.1.4.1.318.1.1.1.4.3.3.0','10371','Output load','output.load[upsHighPrecOutputLoad]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current UPS load expressed as percentage
of rated capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33434','20','1.3.6.1.2.1.1.3.0','10371','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management
portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33435','20','1.3.6.1.4.1.318.1.1.1.1.2.3.0','10371','Serial number','system.sn[upsAdvIdentSerialNumber]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
An 8-character string identifying the serial number of
 the UPS internal microprocessor.  This number is set at
 the factory.  NOTE: This number does NOT correspond to
 the serial number on the rear of the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33436','20','1.3.6.1.2.1.1.2.0','10371','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management
subsystem contained in the entity.  This value is allocated within the SMI enterprises
subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what
kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was
assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1
to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33438','20','1.3.6.1.4.1.318.1.1.1.1.1.1.0','10371','Model','system.model[upsBasicIdentModel]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS model name (e.g. ''APC Smart-UPS 600'').','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33439','20','1.3.6.1.2.1.1.6.0','10371','System location','system.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet,
3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33440','20','1.3.6.1.2.1.1.1.0','10371','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33441','20','1.3.6.1.2.1.1.4.0','10371','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed
node, together with information on how to contact this person.  If no contact
information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33442','17','','10371','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33443','20','1.3.6.1.4.1.318.1.1.1.4.3.1.0','10371','Output voltage','output.voltage[upsHighPrecOutputVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The output voltage of the UPS system in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33444','20','1.3.6.1.4.1.318.1.1.1.4.1.1.0','10371','Output status','output.status[upsBasicOutputStatus]','1m','7d','365d','0','3','','','','',NULL,'159','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current state of the UPS. If the UPS is unable to
 determine the state of the UPS this variable is set
 to unknown(1).
During self-test most UPSes report onBattery(3) but
 some that support it will report onBatteryTest(15).
 To determine self-test status across all UPSes, refer
 to the upsBasicStateOutputState OID.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33445','20','1.3.6.1.4.1.318.1.1.1.4.3.4.0','10371','Output current','output.current[upsHighPrecOutputCurrent]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current in amperes drawn by the load on the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33446','20','1.3.6.1.4.1.318.1.1.1.2.2.5.0','10371','External battery packs count','battery.external_packs_count[upsAdvBatteryNumOfBattPacks]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS. If
 the UPS does not use smart cells then the agent reports
 ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33447','20','1.3.6.1.4.1.318.1.1.1.3.3.1.0','10371','Input voltage','input.voltage[upsHighPrecInputLineVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current utility line voltage in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33448','20','1.3.6.1.4.1.318.1.1.1.3.3.4.0','10371','Input frequency','input.frequency[upsHighPrecInputFrequency]','1m','7d','365d','0','0','','Hz','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current input frequency to the UPS system in Hz.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33449','20','1.3.6.1.4.1.318.1.1.1.3.2.5.0','10371','Input fail cause','input.fail[upsAdvInputLineFailCause]','1m','7d','365d','0','3','','','','',NULL,'157','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The reason for the occurrence of the last transfer to UPS
battery power.  The variable is set to:
- noTransfer(1) -- if there is no transfer yet.
- highLineVoltage(2) -- if the transfer to battery is caused
by an over voltage greater than the high transfer voltage.
- brownout(3) -- if the duration of the outage is greater than
five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- blackout(4) -- if the duration of the outage is greater than five
seconds and the line voltage is between 40% of the rated
output voltage and ground.
- smallMomentarySag(5) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- deepMomentarySag(6) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and ground.  The variable is set to
- smallMomentarySpike(7) -- if the line failure is caused by a
rate of change of input voltage less than ten volts per cycle.
- largeMomentarySpike(8) -- if the line failure is caused by
a rate of change of input voltage greater than ten volts per cycle.
- selfTest(9) -- if the UPS was commanded to do a self test.
- rateOfVoltageChange(10) -- if the failure is due to the rate of change of
the line voltage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33453','20','1.3.6.1.4.1.318.1.1.1.2.3.4.0','10371','Battery voltage','battery.voltage[upsHighPrecBatteryActualVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The actual battery bus voltage in Volts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33454','20','1.3.6.1.4.1.318.1.1.1.2.3.2.0','10371','Battery temperature','battery.temperature[upsHighPrecBatteryTemperature]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current internal UPS temperature in Celsius.
 Temperatures below zero read as 0.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33455','20','1.3.6.1.4.1.318.1.1.1.2.1.1.0','10371','Battery status','battery.status[upsBasicBatteryStatus]','1m','7d','365d','0','3','','','','',NULL,'158','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The status of the UPS batteries. A batteryLow(3) value
 indicates the UPS will be unable to sustain the current
 load, and its services will be lost if power is not restored.
 The amount of run time in reserve at the time of low battery
 can be configured by the upsAdvConfigLowBatteryRunTime.
 A batteryInFaultCondition(4)value indicates that a battery
 installed has an internal error condition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33456','20','1.3.6.1.4.1.318.1.1.1.2.2.3.0','10371','Battery runtime remaining','battery.runtime_remaining[upsAdvBatteryRunTimeRemaining]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS battery run time remaining before battery
 exhaustion.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33457','20','1.3.6.1.4.1.318.1.1.1.2.2.4.0','10371','Battery replace indicator','battery.replace_indicator[upsAdvBatteryReplaceIndicator]','1m','7d','365d','0','3','','','','',NULL,'156','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
Indicates whether the UPS batteries need replacement.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33458','20','1.3.6.1.4.1.318.1.1.1.2.1.3.0','10371','Battery last replace date','battery.last_replace_date[upsBasicBatteryLastReplaceDate]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The date when the UPS system''s batteries were last replaced
 in mm/dd/yy (or yyyy) format. For Smart-UPS models, this value
 is originally set at the factory. When the UPS batteries
 are replaced, this value should be reset by the administrator.
 For Symmetra PX 250/500 this OID is read-only and is configurable in the local display only.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33459','5','','10371','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33460','20','discovery[{#EXTERNAL_PACKS},1.3.6.1.4.1.318.1.1.1.2.2.6]','10371','External bad battery packs discovery','battery.packs.bad.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the number of external defective battery packs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33461','20','discovery[{#CARTRIDGE_STATUS},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7,{#BATTERY_PACK},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.1,{#CARTRIDGE_INDEX},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.2]','10371','External battery packs discovery','battery.packs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33462','20','discovery[{#EXTERNAL_SENSOR1_NAME},1.3.6.1.4.1.318.1.1.25.1.2.1.3]','10371','External sensor port 1 discovery','external.sensor1.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33463','20','discovery[{#EXTERNAL_SENSOR2_NAME},1.3.6.1.4.1.318.1.1.25.1.2.2.3]','10371','External sensor port 2 discovery','external.sensor2.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33464','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.2.3.1.2.1.1]','10371','Input phases discovery','input.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The input phase identifier. OID upsPhaseInputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33465','20','1.3.6.1.4.1.318.1.1.1.2.2.6.0','10371','{#SNMPINDEX}: External battery packs bad','battery.external_packs_bad[upsAdvBatteryNumOfBadBattPacks.{#SNMPINDEX}]','15m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS that
are defective. If the UPS does not use smart cells then the
agent reports ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33466','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.8.{#SNMPINDEX}','10371','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery estimated replace date','battery.estimated_replace_date[upsHighPrecBatteryPackCartridgeReplaceDate.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge estimated battery replace date.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33467','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7.{#SNMPINDEX}','10371','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery pack cartridge health','battery.pack.cartridge_health[upsHighPrecBatteryPackCartridgeHealth.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33468','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.10.{#SNMPINDEX}','10371','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status','battery.pack.status[upsHighPrecBatteryPackCartridgeStatus.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge status.
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33469','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.5.{#SNMPINDEX}','10371','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery temperature','battery.temperature[upsHighPrecBatteryPackTemperature.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack temperature in Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33470','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.4.{#SNMPINDEX}','10371','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Serial number','system.sn[upsHighPrecBatteryPackSerialNumber.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack serial number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33471','20','1.3.6.1.4.1.318.1.1.25.1.2.1.7.1.1','10371','{#EXTERNAL_SENSOR1_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33472','20','1.3.6.1.4.1.318.1.1.25.1.2.1.9.1.1','10371','{#EXTERNAL_SENSOR1_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.1.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33473','20','1.3.6.1.4.1.318.1.1.25.1.2.1.6.1.1','10371','{#EXTERNAL_SENSOR1_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33474','20','1.3.6.1.4.1.318.1.1.25.1.2.2.7.1.1','10371','{#EXTERNAL_SENSOR2_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33475','20','1.3.6.1.4.1.318.1.1.25.1.2.2.9.1.1','10371','{#EXTERNAL_SENSOR2_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.2.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33476','20','1.3.6.1.4.1.318.1.1.25.1.2.2.6.1.1','10371','{#EXTERNAL_SENSOR2_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33477','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.6.1.1.{#PHASEINDEX}','10371','{#PHASEINDEX}: Phase input current','phase.input.current[upsPhaseInputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input current in 0.1 amperes, or -0.1 if it''s
 unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33478','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.3.1.1.{#PHASEINDEX}','10371','{#PHASEINDEX}: Phase input voltage','phase.input.voltage[upsPhaseInputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33479','19','','10372','Get chassis','netapp.chassis.get','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/cluster/chassis?fields=id,state','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33480','15','','10372','Cluster latency, other','netapp.cluster.statistics.latency.other','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last(netapp.cluster.statistics.latency_raw.other) - prev(netapp.cluster.statistics.latency_raw.other)) /
(last(netapp.cluster.statistics.iops_raw.other) - prev(netapp.cluster.statistics.iops_raw.other) +
(last(netapp.cluster.statistics.iops_raw.other) - prev(netapp.cluster.statistics.iops_raw.other) = 0) ) * 0.001','','0','','','','','0',NULL,'The average latency per I/O operation in milliseconds observed at the storage object. Performance metric for other I/O operations. Other I/O operations can be metadata operations, such as directory lookups and so on.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33481','19','','10372','Get SVMs','netapp.svms.get','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/svm/svms?fields=name,state,comment','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33482','19','','10372','Get FC ports','netapp.ports.fc.get','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/network/fc/ports?fields=name,node.name,description,enabled,fabric.switch_port,state','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33483','19','','10372','Get ethernet ports','netapp.ports.eth.get','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/network/ethernet/ports?fields=name,type,node.name,broadcast_domain.name,enabled,state,mtu,speed','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33484','19','','10372','Get nodes','netapp.nodes.get','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/cluster/nodes?fields=*','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33485','19','','10372','Get LUNs','netapp.luns.get','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/storage/luns?fields=name,svm.name,space.size,space.used,status.state,status.container_state','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33486','19','','10372','Get FRUs','netapp.frus.get','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/cluster/chassis?fields=id,frus.id,frus.state','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33487','19','','10372','Get disks','netapp.disks.get','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/storage/disks?fields=state,node.name','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33488','15','','10372','Cluster latency, write','netapp.cluster.statistics.latency.write','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last(netapp.cluster.statistics.latency_raw.write) - prev(netapp.cluster.statistics.latency_raw.write)) /
( last(netapp.cluster.statistics.iops_raw.write) - prev(netapp.cluster.statistics.iops_raw.write) +
(last(netapp.cluster.statistics.iops_raw.write) - prev(netapp.cluster.statistics.iops_raw.write) = 0) ) * 0.001','','0','','','','','0',NULL,'The average latency per I/O operation in milliseconds observed at the storage object. Performance metric for write I/O operations.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33489','15','','10372','Cluster latency, total','netapp.cluster.statistics.latency.total','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last(netapp.cluster.statistics.latency_raw.total) - prev(netapp.cluster.statistics.latency_raw.total)) /
( last(netapp.cluster.statistics.iops_raw.total) - prev(netapp.cluster.statistics.iops_raw.total) +
(last(netapp.cluster.statistics.iops_raw.total) - prev(netapp.cluster.statistics.iops_raw.total) = 0) ) * 0.001','','0','','','','','0',NULL,'The average latency per I/O operation in milliseconds observed at the storage object. Performance metric aggregated over all types of I/O operations.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33490','19','','10372','Get cluster','netapp.cluster.get','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/cluster','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33491','15','','10372','Cluster latency, read','netapp.cluster.statistics.latency.read','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last(netapp.cluster.statistics.latency_raw.read) - prev(netapp.cluster.statistics.latency_raw.read)) /
( last(netapp.cluster.statistics.iops_raw.read) - prev(netapp.cluster.statistics.iops_raw.read) +
(last(netapp.cluster.statistics.iops_raw.read) - prev(netapp.cluster.statistics.iops_raw.read) = 0) ) * 0.001','','0','','','','','0',NULL,'The average latency per I/O operation in milliseconds observed at the storage object. Performance metric for read I/O operations.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33492','19','','10372','Get volumes','netapp.volumes.get','1m','0','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','0',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/storage/volumes?fields=name,comment,state,type,svm.name,space.size,space.available,space.used,statistics','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33513','19','','10372','Chassis discovery','netapp.chassis.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','1',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/cluster/chassis?fields=id','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33514','19','','10372','Disks discovery','netapp.disks.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','1',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/storage/disks?fields=name,node.name','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33516','19','','10372','LUNs discovery','netapp.luns.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','1',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/storage/luns?fields=name,svm.name,space.size,space.used,status.state,status.container_state','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33517','19','','10372','Nodes discovery','netapp.nodes.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','1',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/cluster/nodes?fields=name','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33518','19','','10372','Ethernet ports discovery','netapp.ports.ether.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','1',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/network/ethernet/ports?fields=name,state,node.name','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33519','19','','10372','FC ports discovery','netapp.ports.fc.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','1',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/network/fc/ports?fields=node.name,name,state','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33520','19','','10372','SVMs discovery','netapp.svms.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','1',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/svm/svms?fields=name','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33521','19','','10372','Volumes discovery','netapp.volumes.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','1','{$USERNAME}','{$PASSWORD}','','','1',NULL,'','0','30d','0','',NULL,'{$HTTP.AGENT.TIMEOUT}','{$URL}/api/storage/volumes?fields=name','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33522','15','','10372','{#VOLUMENAME}: Volume latency, total','netapp.volume.statistics.latency.total[{#VOLUMENAME}]','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last(netapp.volume.statistics.latency_raw.total[{#VOLUMENAME}]) - prev(netapp.volume.statistics.latency_raw.total[{#VOLUMENAME}])) /
( last(netapp.volume.statistics.iops_raw.total[{#VOLUMENAME}]) - prev(netapp.volume.statistics.iops_raw.total[{#VOLUMENAME}]) +
(last(netapp.volume.statistics.iops_raw.total[{#VOLUMENAME}]) - prev(netapp.volume.statistics.iops_raw.total[{#VOLUMENAME}]) = 0) ) * 0.001','','0','','','','','2',NULL,'The average latency per I/O operation in milliseconds observed at the storage object. Performance metric aggregated over all types of I/O operations.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33523','15','','10372','{#VOLUMENAME}: Volume latency, write','netapp.volume.statistics.latency.write[{#VOLUMENAME}]','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last(netapp.volume.statistics.latency_raw.write[{#VOLUMENAME}]) - prev(netapp.volume.statistics.latency_raw.write[{#VOLUMENAME}])) /
( last(netapp.volume.statistics.iops_raw.write[{#VOLUMENAME}]) - prev(netapp.volume.statistics.iops_raw.write[{#VOLUMENAME}]) +
(last(netapp.volume.statistics.iops_raw.write[{#VOLUMENAME}]) - prev(netapp.volume.statistics.iops_raw.write[{#VOLUMENAME}]) = 0) ) * 0.001','','0','','','','','2',NULL,'The average latency per I/O operation in milliseconds observed at the storage object. Performance metric for write I/O operations.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33524','15','','10372','{#VOLUMENAME}: Volume latency, read','netapp.volume.statistics.latency.read[{#VOLUMENAME}]','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last(netapp.volume.statistics.latency_raw.read[{#VOLUMENAME}]) - prev(netapp.volume.statistics.latency_raw.read[{#VOLUMENAME}])) /
( last(netapp.volume.statistics.iops_raw.read[{#VOLUMENAME}]) - prev(netapp.volume.statistics.iops_raw.read[{#VOLUMENAME}]) +
(last(netapp.volume.statistics.iops_raw.read[{#VOLUMENAME}]) - prev(netapp.volume.statistics.iops_raw.read[{#VOLUMENAME}]) = 0)) * 0.001','','0','','','','','2',NULL,'The average latency per I/O operation in milliseconds observed at the storage object. Performance metric for read I/O operations.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33525','15','','10372','{#VOLUMENAME}: Volume latency, other','netapp.volume.statistics.latency.other[{#VOLUMENAME}]','1m','7d','365d','0','0','','!ms','','',NULL,NULL,'(last(netapp.volume.statistics.latency_raw.other[{#VOLUMENAME}]) - prev(netapp.volume.statistics.latency_raw.other[{#VOLUMENAME}])) /
( last(netapp.volume.statistics.iops_raw.other[{#VOLUMENAME}]) - prev(netapp.volume.statistics.iops_raw.other[{#VOLUMENAME}]) +
(last(netapp.volume.statistics.iops_raw.other[{#VOLUMENAME}]) - prev(netapp.volume.statistics.iops_raw.other[{#VOLUMENAME}]) = 0) ) * 0.001','','0','','','','','2',NULL,'The average latency per I/O operation in milliseconds observed at the storage object. Performance metric for other I/O operations. Other I/O operations can be metadata operations, such as directory lookups and so on.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33568','20','1.3.6.1.4.1.318.1.1.1.2.3.1.0','10373','Battery capacity','battery.capacity[upsHighPrecBatteryCapacity]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The remaining battery capacity expressed as
 percentage of full capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33569','20','1.3.6.1.4.1.318.1.1.1.4.3.3.0','10373','Output load','output.load[upsHighPrecOutputLoad]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current UPS load expressed as percentage
of rated capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33570','20','1.3.6.1.2.1.1.3.0','10373','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management
portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33571','20','1.3.6.1.4.1.318.1.1.1.1.2.3.0','10373','Serial number','system.sn[upsAdvIdentSerialNumber]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
An 8-character string identifying the serial number of
 the UPS internal microprocessor.  This number is set at
 the factory.  NOTE: This number does NOT correspond to
 the serial number on the rear of the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33572','20','1.3.6.1.2.1.1.2.0','10373','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management
subsystem contained in the entity.  This value is allocated within the SMI enterprises
subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what
kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was
assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1
to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33574','20','1.3.6.1.4.1.318.1.1.1.1.1.1.0','10373','Model','system.model[upsBasicIdentModel]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS model name (e.g. ''APC Smart-UPS 600'').','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33575','20','1.3.6.1.2.1.1.6.0','10373','System location','system.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet,
3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33576','20','1.3.6.1.2.1.1.1.0','10373','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33577','20','1.3.6.1.2.1.1.4.0','10373','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed
node, together with information on how to contact this person.  If no contact
information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33578','17','','10373','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33579','20','1.3.6.1.4.1.318.1.1.1.4.3.1.0','10373','Output voltage','output.voltage[upsHighPrecOutputVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The output voltage of the UPS system in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33580','20','1.3.6.1.4.1.318.1.1.1.4.1.1.0','10373','Output status','output.status[upsBasicOutputStatus]','1m','7d','365d','0','3','','','','',NULL,'159','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current state of the UPS. If the UPS is unable to
 determine the state of the UPS this variable is set
 to unknown(1).
During self-test most UPSes report onBattery(3) but
 some that support it will report onBatteryTest(15).
 To determine self-test status across all UPSes, refer
 to the upsBasicStateOutputState OID.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33581','20','1.3.6.1.4.1.318.1.1.1.4.3.4.0','10373','Output current','output.current[upsHighPrecOutputCurrent]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current in amperes drawn by the load on the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33582','20','1.3.6.1.4.1.318.1.1.1.2.2.5.0','10373','External battery packs count','battery.external_packs_count[upsAdvBatteryNumOfBattPacks]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS. If
 the UPS does not use smart cells then the agent reports
 ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33583','20','1.3.6.1.4.1.318.1.1.1.3.3.1.0','10373','Input voltage','input.voltage[upsHighPrecInputLineVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current utility line voltage in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33584','20','1.3.6.1.4.1.318.1.1.1.3.3.4.0','10373','Input frequency','input.frequency[upsHighPrecInputFrequency]','1m','7d','365d','0','0','','Hz','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current input frequency to the UPS system in Hz.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33585','20','1.3.6.1.4.1.318.1.1.1.3.2.5.0','10373','Input fail cause','input.fail[upsAdvInputLineFailCause]','1m','7d','365d','0','3','','','','',NULL,'157','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The reason for the occurrence of the last transfer to UPS
battery power.  The variable is set to:
- noTransfer(1) -- if there is no transfer yet.
- highLineVoltage(2) -- if the transfer to battery is caused
by an over voltage greater than the high transfer voltage.
- brownout(3) -- if the duration of the outage is greater than
five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- blackout(4) -- if the duration of the outage is greater than five
seconds and the line voltage is between 40% of the rated
output voltage and ground.
- smallMomentarySag(5) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- deepMomentarySag(6) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and ground.  The variable is set to
- smallMomentarySpike(7) -- if the line failure is caused by a
rate of change of input voltage less than ten volts per cycle.
- largeMomentarySpike(8) -- if the line failure is caused by
a rate of change of input voltage greater than ten volts per cycle.
- selfTest(9) -- if the UPS was commanded to do a self test.
- rateOfVoltageChange(10) -- if the failure is due to the rate of change of
the line voltage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33589','20','1.3.6.1.4.1.318.1.1.1.2.3.4.0','10373','Battery voltage','battery.voltage[upsHighPrecBatteryActualVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The actual battery bus voltage in Volts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33590','20','1.3.6.1.4.1.318.1.1.1.2.3.2.0','10373','Battery temperature','battery.temperature[upsHighPrecBatteryTemperature]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current internal UPS temperature in Celsius.
 Temperatures below zero read as 0.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33591','20','1.3.6.1.4.1.318.1.1.1.2.1.1.0','10373','Battery status','battery.status[upsBasicBatteryStatus]','1m','7d','365d','0','3','','','','',NULL,'158','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The status of the UPS batteries. A batteryLow(3) value
 indicates the UPS will be unable to sustain the current
 load, and its services will be lost if power is not restored.
 The amount of run time in reserve at the time of low battery
 can be configured by the upsAdvConfigLowBatteryRunTime.
 A batteryInFaultCondition(4)value indicates that a battery
 installed has an internal error condition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33592','20','1.3.6.1.4.1.318.1.1.1.2.2.3.0','10373','Battery runtime remaining','battery.runtime_remaining[upsAdvBatteryRunTimeRemaining]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS battery run time remaining before battery
 exhaustion.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33593','20','1.3.6.1.4.1.318.1.1.1.2.2.4.0','10373','Battery replace indicator','battery.replace_indicator[upsAdvBatteryReplaceIndicator]','1m','7d','365d','0','3','','','','',NULL,'156','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
Indicates whether the UPS batteries need replacement.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33594','20','1.3.6.1.4.1.318.1.1.1.2.1.3.0','10373','Battery last replace date','battery.last_replace_date[upsBasicBatteryLastReplaceDate]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The date when the UPS system''s batteries were last replaced
 in mm/dd/yy (or yyyy) format. For Smart-UPS models, this value
 is originally set at the factory. When the UPS batteries
 are replaced, this value should be reset by the administrator.
 For Symmetra PX 250/500 this OID is read-only and is configurable in the local display only.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33595','5','','10373','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33596','20','discovery[{#EXTERNAL_PACKS},1.3.6.1.4.1.318.1.1.1.2.2.6]','10373','External bad battery packs discovery','battery.packs.bad.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the number of external defective battery packs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33597','20','discovery[{#CARTRIDGE_STATUS},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7,{#BATTERY_PACK},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.1,{#CARTRIDGE_INDEX},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.2]','10373','External battery packs discovery','battery.packs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33598','20','discovery[{#EXTERNAL_SENSOR1_NAME},1.3.6.1.4.1.318.1.1.25.1.2.1.3]','10373','External sensor port 1 discovery','external.sensor1.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33599','20','discovery[{#EXTERNAL_SENSOR2_NAME},1.3.6.1.4.1.318.1.1.25.1.2.2.3]','10373','External sensor port 2 discovery','external.sensor2.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33600','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.2.3.1.2.1.1]','10373','Input phases discovery','input.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The input phase identifier. OID upsPhaseInputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33601','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.3.3.1.2.1.1]','10373','Output phases discovery','output.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The output phase identifier. OID upsPhaseOutputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33602','20','1.3.6.1.4.1.318.1.1.1.2.2.6.0','10373','{#SNMPINDEX}: External battery packs bad','battery.external_packs_bad[upsAdvBatteryNumOfBadBattPacks.{#SNMPINDEX}]','15m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS that
are defective. If the UPS does not use smart cells then the
agent reports ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33603','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.8.{#SNMPINDEX}','10373','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery estimated replace date','battery.estimated_replace_date[upsHighPrecBatteryPackCartridgeReplaceDate.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge estimated battery replace date.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33604','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7.{#SNMPINDEX}','10373','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery pack cartridge health','battery.pack.cartridge_health[upsHighPrecBatteryPackCartridgeHealth.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33605','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.10.{#SNMPINDEX}','10373','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status','battery.pack.status[upsHighPrecBatteryPackCartridgeStatus.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge status.
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33606','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.5.{#SNMPINDEX}','10373','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery temperature','battery.temperature[upsHighPrecBatteryPackTemperature.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack temperature in Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33607','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.4.{#SNMPINDEX}','10373','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Serial number','system.sn[upsHighPrecBatteryPackSerialNumber.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack serial number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33608','20','1.3.6.1.4.1.318.1.1.25.1.2.1.7.1.1','10373','{#EXTERNAL_SENSOR1_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33609','20','1.3.6.1.4.1.318.1.1.25.1.2.1.9.1.1','10373','{#EXTERNAL_SENSOR1_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.1.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33610','20','1.3.6.1.4.1.318.1.1.25.1.2.1.6.1.1','10373','{#EXTERNAL_SENSOR1_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33611','20','1.3.6.1.4.1.318.1.1.25.1.2.2.7.1.1','10373','{#EXTERNAL_SENSOR2_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33612','20','1.3.6.1.4.1.318.1.1.25.1.2.2.9.1.1','10373','{#EXTERNAL_SENSOR2_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.2.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33613','20','1.3.6.1.4.1.318.1.1.25.1.2.2.6.1.1','10373','{#EXTERNAL_SENSOR2_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33614','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.6.1.1.{#PHASEINDEX}','10373','{#PHASEINDEX}: Phase input current','phase.input.current[upsPhaseInputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input current in 0.1 amperes, or -0.1 if it''s
 unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33615','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.3.1.1.{#PHASEINDEX}','10373','{#PHASEINDEX}: Phase input voltage','phase.input.voltage[upsPhaseInputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33616','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.4.1.1.{#PHASEINDEX}','10373','{#PHASEINDEX}: Phase output current','phase.output.current[upsPhaseOutputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output current in 0.1 amperes drawn
 by the load on the UPS, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33617','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.10.1.1.{#PHASEINDEX}','10373','{#PHASEINDEX}: Phase output load, %','phase.output.load.percent[upsPhaseOutputPercentLoad.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The percentage of the UPS load capacity in VA at
 redundancy @ (n + x) presently being used on this
 output phase, or -1 if it''s unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33618','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.3.1.1.{#PHASEINDEX}','10373','{#PHASEINDEX}: Phase output voltage','phase.output.voltage[upsPhaseOutputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33619','20','1.3.6.1.4.1.318.1.1.1.2.3.1.0','10374','Battery capacity','battery.capacity[upsHighPrecBatteryCapacity]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The remaining battery capacity expressed as
 percentage of full capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33620','20','1.3.6.1.4.1.318.1.1.1.4.3.3.0','10374','Output load','output.load[upsHighPrecOutputLoad]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current UPS load expressed as percentage
of rated capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33621','20','1.3.6.1.2.1.1.3.0','10374','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management
portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33622','20','1.3.6.1.4.1.318.1.1.1.1.2.3.0','10374','Serial number','system.sn[upsAdvIdentSerialNumber]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
An 8-character string identifying the serial number of
 the UPS internal microprocessor.  This number is set at
 the factory.  NOTE: This number does NOT correspond to
 the serial number on the rear of the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33623','20','1.3.6.1.2.1.1.2.0','10374','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management
subsystem contained in the entity.  This value is allocated within the SMI enterprises
subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what
kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was
assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1
to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33625','20','1.3.6.1.4.1.318.1.1.1.1.1.1.0','10374','Model','system.model[upsBasicIdentModel]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS model name (e.g. ''APC Smart-UPS 600'').','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33626','20','1.3.6.1.2.1.1.6.0','10374','System location','system.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet,
3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33627','20','1.3.6.1.2.1.1.1.0','10374','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33628','20','1.3.6.1.2.1.1.4.0','10374','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed
node, together with information on how to contact this person.  If no contact
information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33629','17','','10374','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33630','20','1.3.6.1.4.1.318.1.1.1.4.3.1.0','10374','Output voltage','output.voltage[upsHighPrecOutputVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The output voltage of the UPS system in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33631','20','1.3.6.1.4.1.318.1.1.1.4.1.1.0','10374','Output status','output.status[upsBasicOutputStatus]','1m','7d','365d','0','3','','','','',NULL,'159','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current state of the UPS. If the UPS is unable to
 determine the state of the UPS this variable is set
 to unknown(1).
During self-test most UPSes report onBattery(3) but
 some that support it will report onBatteryTest(15).
 To determine self-test status across all UPSes, refer
 to the upsBasicStateOutputState OID.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33632','20','1.3.6.1.4.1.318.1.1.1.4.3.4.0','10374','Output current','output.current[upsHighPrecOutputCurrent]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current in amperes drawn by the load on the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33633','20','1.3.6.1.4.1.318.1.1.1.2.2.5.0','10374','External battery packs count','battery.external_packs_count[upsAdvBatteryNumOfBattPacks]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS. If
 the UPS does not use smart cells then the agent reports
 ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33634','20','1.3.6.1.4.1.318.1.1.1.3.3.1.0','10374','Input voltage','input.voltage[upsHighPrecInputLineVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current utility line voltage in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33635','20','1.3.6.1.4.1.318.1.1.1.3.3.4.0','10374','Input frequency','input.frequency[upsHighPrecInputFrequency]','1m','7d','365d','0','0','','Hz','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current input frequency to the UPS system in Hz.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33636','20','1.3.6.1.4.1.318.1.1.1.3.2.5.0','10374','Input fail cause','input.fail[upsAdvInputLineFailCause]','1m','7d','365d','0','3','','','','',NULL,'157','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The reason for the occurrence of the last transfer to UPS
battery power.  The variable is set to:
- noTransfer(1) -- if there is no transfer yet.
- highLineVoltage(2) -- if the transfer to battery is caused
by an over voltage greater than the high transfer voltage.
- brownout(3) -- if the duration of the outage is greater than
five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- blackout(4) -- if the duration of the outage is greater than five
seconds and the line voltage is between 40% of the rated
output voltage and ground.
- smallMomentarySag(5) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- deepMomentarySag(6) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and ground.  The variable is set to
- smallMomentarySpike(7) -- if the line failure is caused by a
rate of change of input voltage less than ten volts per cycle.
- largeMomentarySpike(8) -- if the line failure is caused by
a rate of change of input voltage greater than ten volts per cycle.
- selfTest(9) -- if the UPS was commanded to do a self test.
- rateOfVoltageChange(10) -- if the failure is due to the rate of change of
the line voltage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33640','20','1.3.6.1.4.1.318.1.1.1.2.3.4.0','10374','Battery voltage','battery.voltage[upsHighPrecBatteryActualVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The actual battery bus voltage in Volts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33641','20','1.3.6.1.4.1.318.1.1.1.2.3.2.0','10374','Battery temperature','battery.temperature[upsHighPrecBatteryTemperature]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current internal UPS temperature in Celsius.
 Temperatures below zero read as 0.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33642','20','1.3.6.1.4.1.318.1.1.1.2.1.1.0','10374','Battery status','battery.status[upsBasicBatteryStatus]','1m','7d','365d','0','3','','','','',NULL,'158','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The status of the UPS batteries. A batteryLow(3) value
 indicates the UPS will be unable to sustain the current
 load, and its services will be lost if power is not restored.
 The amount of run time in reserve at the time of low battery
 can be configured by the upsAdvConfigLowBatteryRunTime.
 A batteryInFaultCondition(4)value indicates that a battery
 installed has an internal error condition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33643','20','1.3.6.1.4.1.318.1.1.1.2.2.3.0','10374','Battery runtime remaining','battery.runtime_remaining[upsAdvBatteryRunTimeRemaining]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS battery run time remaining before battery
 exhaustion.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33644','20','1.3.6.1.4.1.318.1.1.1.2.2.4.0','10374','Battery replace indicator','battery.replace_indicator[upsAdvBatteryReplaceIndicator]','1m','7d','365d','0','3','','','','',NULL,'156','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
Indicates whether the UPS batteries need replacement.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33645','20','1.3.6.1.4.1.318.1.1.1.2.1.3.0','10374','Battery last replace date','battery.last_replace_date[upsBasicBatteryLastReplaceDate]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The date when the UPS system''s batteries were last replaced
 in mm/dd/yy (or yyyy) format. For Smart-UPS models, this value
 is originally set at the factory. When the UPS batteries
 are replaced, this value should be reset by the administrator.
 For Symmetra PX 250/500 this OID is read-only and is configurable in the local display only.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33646','5','','10374','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33647','20','discovery[{#EXTERNAL_PACKS},1.3.6.1.4.1.318.1.1.1.2.2.6]','10374','External bad battery packs discovery','battery.packs.bad.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the number of external defective battery packs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33648','20','discovery[{#CARTRIDGE_STATUS},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7,{#BATTERY_PACK},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.1,{#CARTRIDGE_INDEX},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.2]','10374','External battery packs discovery','battery.packs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33649','20','discovery[{#EXTERNAL_SENSOR1_NAME},1.3.6.1.4.1.318.1.1.25.1.2.1.3]','10374','External sensor port 1 discovery','external.sensor1.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33650','20','discovery[{#EXTERNAL_SENSOR2_NAME},1.3.6.1.4.1.318.1.1.25.1.2.2.3]','10374','External sensor port 2 discovery','external.sensor2.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33651','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.2.3.1.2.1.1]','10374','Input phases discovery','input.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The input phase identifier. OID upsPhaseInputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33652','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.3.3.1.2.1.1]','10374','Output phases discovery','output.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The output phase identifier. OID upsPhaseOutputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33653','20','1.3.6.1.4.1.318.1.1.1.2.2.6.0','10374','{#SNMPINDEX}: External battery packs bad','battery.external_packs_bad[upsAdvBatteryNumOfBadBattPacks.{#SNMPINDEX}]','15m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS that
are defective. If the UPS does not use smart cells then the
agent reports ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33654','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.8.{#SNMPINDEX}','10374','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery estimated replace date','battery.estimated_replace_date[upsHighPrecBatteryPackCartridgeReplaceDate.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge estimated battery replace date.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33655','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7.{#SNMPINDEX}','10374','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery pack cartridge health','battery.pack.cartridge_health[upsHighPrecBatteryPackCartridgeHealth.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33656','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.10.{#SNMPINDEX}','10374','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status','battery.pack.status[upsHighPrecBatteryPackCartridgeStatus.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge status.
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33657','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.5.{#SNMPINDEX}','10374','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery temperature','battery.temperature[upsHighPrecBatteryPackTemperature.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack temperature in Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33658','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.4.{#SNMPINDEX}','10374','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Serial number','system.sn[upsHighPrecBatteryPackSerialNumber.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack serial number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33659','20','1.3.6.1.4.1.318.1.1.25.1.2.1.7.1.1','10374','{#EXTERNAL_SENSOR1_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33660','20','1.3.6.1.4.1.318.1.1.25.1.2.1.9.1.1','10374','{#EXTERNAL_SENSOR1_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.1.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33661','20','1.3.6.1.4.1.318.1.1.25.1.2.1.6.1.1','10374','{#EXTERNAL_SENSOR1_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33662','20','1.3.6.1.4.1.318.1.1.25.1.2.2.7.1.1','10374','{#EXTERNAL_SENSOR2_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33663','20','1.3.6.1.4.1.318.1.1.25.1.2.2.9.1.1','10374','{#EXTERNAL_SENSOR2_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.2.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33664','20','1.3.6.1.4.1.318.1.1.25.1.2.2.6.1.1','10374','{#EXTERNAL_SENSOR2_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33665','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.6.1.1.{#PHASEINDEX}','10374','{#PHASEINDEX}: Phase input current','phase.input.current[upsPhaseInputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input current in 0.1 amperes, or -0.1 if it''s
 unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33666','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.3.1.1.{#PHASEINDEX}','10374','{#PHASEINDEX}: Phase input voltage','phase.input.voltage[upsPhaseInputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33667','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.4.1.1.{#PHASEINDEX}','10374','{#PHASEINDEX}: Phase output current','phase.output.current[upsPhaseOutputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output current in 0.1 amperes drawn
 by the load on the UPS, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33668','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.10.1.1.{#PHASEINDEX}','10374','{#PHASEINDEX}: Phase output load, %','phase.output.load.percent[upsPhaseOutputPercentLoad.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The percentage of the UPS load capacity in VA at
 redundancy @ (n + x) presently being used on this
 output phase, or -1 if it''s unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33669','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.3.1.1.{#PHASEINDEX}','10374','{#PHASEINDEX}: Phase output voltage','phase.output.voltage[upsPhaseOutputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33670','20','1.3.6.1.4.1.318.1.1.1.2.3.1.0','10375','Battery capacity','battery.capacity[upsHighPrecBatteryCapacity]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The remaining battery capacity expressed as
 percentage of full capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33671','20','1.3.6.1.4.1.318.1.1.1.4.3.3.0','10375','Output load','output.load[upsHighPrecOutputLoad]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current UPS load expressed as percentage
of rated capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33672','20','1.3.6.1.2.1.1.3.0','10375','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management
portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33673','20','1.3.6.1.4.1.318.1.1.1.1.2.3.0','10375','Serial number','system.sn[upsAdvIdentSerialNumber]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
An 8-character string identifying the serial number of
 the UPS internal microprocessor.  This number is set at
 the factory.  NOTE: This number does NOT correspond to
 the serial number on the rear of the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33674','20','1.3.6.1.2.1.1.2.0','10375','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management
subsystem contained in the entity.  This value is allocated within the SMI enterprises
subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what
kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was
assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1
to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33676','20','1.3.6.1.4.1.318.1.1.1.1.1.1.0','10375','Model','system.model[upsBasicIdentModel]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS model name (e.g. ''APC Smart-UPS 600'').','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33677','20','1.3.6.1.2.1.1.6.0','10375','System location','system.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet,
3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33678','20','1.3.6.1.2.1.1.1.0','10375','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33679','20','1.3.6.1.2.1.1.4.0','10375','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed
node, together with information on how to contact this person.  If no contact
information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33680','17','','10375','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33681','20','1.3.6.1.4.1.318.1.1.1.4.3.1.0','10375','Output voltage','output.voltage[upsHighPrecOutputVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The output voltage of the UPS system in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33682','20','1.3.6.1.4.1.318.1.1.1.4.1.1.0','10375','Output status','output.status[upsBasicOutputStatus]','1m','7d','365d','0','3','','','','',NULL,'159','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current state of the UPS. If the UPS is unable to
 determine the state of the UPS this variable is set
 to unknown(1).
During self-test most UPSes report onBattery(3) but
 some that support it will report onBatteryTest(15).
 To determine self-test status across all UPSes, refer
 to the upsBasicStateOutputState OID.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33683','20','1.3.6.1.4.1.318.1.1.1.4.3.4.0','10375','Output current','output.current[upsHighPrecOutputCurrent]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current in amperes drawn by the load on the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33684','20','1.3.6.1.4.1.318.1.1.1.2.2.5.0','10375','External battery packs count','battery.external_packs_count[upsAdvBatteryNumOfBattPacks]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS. If
 the UPS does not use smart cells then the agent reports
 ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33685','20','1.3.6.1.4.1.318.1.1.1.3.3.1.0','10375','Input voltage','input.voltage[upsHighPrecInputLineVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current utility line voltage in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33686','20','1.3.6.1.4.1.318.1.1.1.3.3.4.0','10375','Input frequency','input.frequency[upsHighPrecInputFrequency]','1m','7d','365d','0','0','','Hz','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current input frequency to the UPS system in Hz.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33687','20','1.3.6.1.4.1.318.1.1.1.3.2.5.0','10375','Input fail cause','input.fail[upsAdvInputLineFailCause]','1m','7d','365d','0','3','','','','',NULL,'157','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The reason for the occurrence of the last transfer to UPS
battery power.  The variable is set to:
- noTransfer(1) -- if there is no transfer yet.
- highLineVoltage(2) -- if the transfer to battery is caused
by an over voltage greater than the high transfer voltage.
- brownout(3) -- if the duration of the outage is greater than
five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- blackout(4) -- if the duration of the outage is greater than five
seconds and the line voltage is between 40% of the rated
output voltage and ground.
- smallMomentarySag(5) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- deepMomentarySag(6) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and ground.  The variable is set to
- smallMomentarySpike(7) -- if the line failure is caused by a
rate of change of input voltage less than ten volts per cycle.
- largeMomentarySpike(8) -- if the line failure is caused by
a rate of change of input voltage greater than ten volts per cycle.
- selfTest(9) -- if the UPS was commanded to do a self test.
- rateOfVoltageChange(10) -- if the failure is due to the rate of change of
the line voltage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33691','20','1.3.6.1.4.1.318.1.1.1.2.3.4.0','10375','Battery voltage','battery.voltage[upsHighPrecBatteryActualVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The actual battery bus voltage in Volts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33692','20','1.3.6.1.4.1.318.1.1.1.2.3.2.0','10375','Battery temperature','battery.temperature[upsHighPrecBatteryTemperature]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current internal UPS temperature in Celsius.
 Temperatures below zero read as 0.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33693','20','1.3.6.1.4.1.318.1.1.1.2.1.1.0','10375','Battery status','battery.status[upsBasicBatteryStatus]','1m','7d','365d','0','3','','','','',NULL,'158','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The status of the UPS batteries. A batteryLow(3) value
 indicates the UPS will be unable to sustain the current
 load, and its services will be lost if power is not restored.
 The amount of run time in reserve at the time of low battery
 can be configured by the upsAdvConfigLowBatteryRunTime.
 A batteryInFaultCondition(4)value indicates that a battery
 installed has an internal error condition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33694','20','1.3.6.1.4.1.318.1.1.1.2.2.3.0','10375','Battery runtime remaining','battery.runtime_remaining[upsAdvBatteryRunTimeRemaining]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS battery run time remaining before battery
 exhaustion.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33695','20','1.3.6.1.4.1.318.1.1.1.2.2.4.0','10375','Battery replace indicator','battery.replace_indicator[upsAdvBatteryReplaceIndicator]','1m','7d','365d','0','3','','','','',NULL,'156','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
Indicates whether the UPS batteries need replacement.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33696','20','1.3.6.1.4.1.318.1.1.1.2.1.3.0','10375','Battery last replace date','battery.last_replace_date[upsBasicBatteryLastReplaceDate]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The date when the UPS system''s batteries were last replaced
 in mm/dd/yy (or yyyy) format. For Smart-UPS models, this value
 is originally set at the factory. When the UPS batteries
 are replaced, this value should be reset by the administrator.
 For Symmetra PX 250/500 this OID is read-only and is configurable in the local display only.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33697','5','','10375','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33698','20','discovery[{#EXTERNAL_PACKS},1.3.6.1.4.1.318.1.1.1.2.2.6]','10375','External bad battery packs discovery','battery.packs.bad.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the number of external defective battery packs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33699','20','discovery[{#CARTRIDGE_STATUS},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7,{#BATTERY_PACK},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.1,{#CARTRIDGE_INDEX},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.2]','10375','External battery packs discovery','battery.packs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33700','20','discovery[{#EXTERNAL_SENSOR1_NAME},1.3.6.1.4.1.318.1.1.25.1.2.1.3]','10375','External sensor port 1 discovery','external.sensor1.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33701','20','discovery[{#EXTERNAL_SENSOR2_NAME},1.3.6.1.4.1.318.1.1.25.1.2.2.3]','10375','External sensor port 2 discovery','external.sensor2.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33702','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.2.3.1.2.1.1]','10375','Input phases discovery','input.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The input phase identifier. OID upsPhaseInputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33703','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.3.3.1.2.1.1]','10375','Output phases discovery','output.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The output phase identifier. OID upsPhaseOutputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33704','20','1.3.6.1.4.1.318.1.1.1.2.2.6.0','10375','{#SNMPINDEX}: External battery packs bad','battery.external_packs_bad[upsAdvBatteryNumOfBadBattPacks.{#SNMPINDEX}]','15m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS that
are defective. If the UPS does not use smart cells then the
agent reports ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33705','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.8.{#SNMPINDEX}','10375','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery estimated replace date','battery.estimated_replace_date[upsHighPrecBatteryPackCartridgeReplaceDate.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge estimated battery replace date.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33706','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7.{#SNMPINDEX}','10375','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery pack cartridge health','battery.pack.cartridge_health[upsHighPrecBatteryPackCartridgeHealth.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33707','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.10.{#SNMPINDEX}','10375','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status','battery.pack.status[upsHighPrecBatteryPackCartridgeStatus.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge status.
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33708','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.5.{#SNMPINDEX}','10375','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery temperature','battery.temperature[upsHighPrecBatteryPackTemperature.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack temperature in Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33709','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.4.{#SNMPINDEX}','10375','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Serial number','system.sn[upsHighPrecBatteryPackSerialNumber.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack serial number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33710','20','1.3.6.1.4.1.318.1.1.25.1.2.1.7.1.1','10375','{#EXTERNAL_SENSOR1_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33711','20','1.3.6.1.4.1.318.1.1.25.1.2.1.9.1.1','10375','{#EXTERNAL_SENSOR1_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.1.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33712','20','1.3.6.1.4.1.318.1.1.25.1.2.1.6.1.1','10375','{#EXTERNAL_SENSOR1_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33713','20','1.3.6.1.4.1.318.1.1.25.1.2.2.7.1.1','10375','{#EXTERNAL_SENSOR2_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33714','20','1.3.6.1.4.1.318.1.1.25.1.2.2.9.1.1','10375','{#EXTERNAL_SENSOR2_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.2.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33715','20','1.3.6.1.4.1.318.1.1.25.1.2.2.6.1.1','10375','{#EXTERNAL_SENSOR2_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33716','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.6.1.1.{#PHASEINDEX}','10375','{#PHASEINDEX}: Phase input current','phase.input.current[upsPhaseInputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input current in 0.1 amperes, or -0.1 if it''s
 unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33717','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.3.1.1.{#PHASEINDEX}','10375','{#PHASEINDEX}: Phase input voltage','phase.input.voltage[upsPhaseInputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33718','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.4.1.1.{#PHASEINDEX}','10375','{#PHASEINDEX}: Phase output current','phase.output.current[upsPhaseOutputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output current in 0.1 amperes drawn
 by the load on the UPS, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33719','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.10.1.1.{#PHASEINDEX}','10375','{#PHASEINDEX}: Phase output load, %','phase.output.load.percent[upsPhaseOutputPercentLoad.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The percentage of the UPS load capacity in VA at
 redundancy @ (n + x) presently being used on this
 output phase, or -1 if it''s unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33720','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.3.1.1.{#PHASEINDEX}','10375','{#PHASEINDEX}: Phase output voltage','phase.output.voltage[upsPhaseOutputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33721','20','1.3.6.1.4.1.318.1.1.1.2.3.1.0','10376','Battery capacity','battery.capacity[upsHighPrecBatteryCapacity]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The remaining battery capacity expressed as
 percentage of full capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33722','20','1.3.6.1.4.1.318.1.1.1.4.3.3.0','10376','Output load','output.load[upsHighPrecOutputLoad]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current UPS load expressed as percentage
of rated capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33723','20','1.3.6.1.2.1.1.3.0','10376','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management
portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33724','20','1.3.6.1.4.1.318.1.1.1.1.2.3.0','10376','Serial number','system.sn[upsAdvIdentSerialNumber]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
An 8-character string identifying the serial number of
 the UPS internal microprocessor.  This number is set at
 the factory.  NOTE: This number does NOT correspond to
 the serial number on the rear of the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33725','20','1.3.6.1.2.1.1.2.0','10376','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management
subsystem contained in the entity.  This value is allocated within the SMI enterprises
subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what
kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was
assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1
to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33727','20','1.3.6.1.4.1.318.1.1.1.1.1.1.0','10376','Model','system.model[upsBasicIdentModel]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS model name (e.g. ''APC Smart-UPS 600'').','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33728','20','1.3.6.1.2.1.1.6.0','10376','System location','system.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet,
3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33729','20','1.3.6.1.2.1.1.1.0','10376','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33730','20','1.3.6.1.2.1.1.4.0','10376','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed
node, together with information on how to contact this person.  If no contact
information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33731','17','','10376','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33732','20','1.3.6.1.4.1.318.1.1.1.4.3.1.0','10376','Output voltage','output.voltage[upsHighPrecOutputVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The output voltage of the UPS system in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33733','20','1.3.6.1.4.1.318.1.1.1.4.1.1.0','10376','Output status','output.status[upsBasicOutputStatus]','1m','7d','365d','0','3','','','','',NULL,'159','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current state of the UPS. If the UPS is unable to
 determine the state of the UPS this variable is set
 to unknown(1).
During self-test most UPSes report onBattery(3) but
 some that support it will report onBatteryTest(15).
 To determine self-test status across all UPSes, refer
 to the upsBasicStateOutputState OID.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33734','20','1.3.6.1.4.1.318.1.1.1.4.3.4.0','10376','Output current','output.current[upsHighPrecOutputCurrent]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current in amperes drawn by the load on the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33735','20','1.3.6.1.4.1.318.1.1.1.2.2.5.0','10376','External battery packs count','battery.external_packs_count[upsAdvBatteryNumOfBattPacks]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS. If
 the UPS does not use smart cells then the agent reports
 ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33736','20','1.3.6.1.4.1.318.1.1.1.3.3.1.0','10376','Input voltage','input.voltage[upsHighPrecInputLineVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current utility line voltage in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33737','20','1.3.6.1.4.1.318.1.1.1.3.3.4.0','10376','Input frequency','input.frequency[upsHighPrecInputFrequency]','1m','7d','365d','0','0','','Hz','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current input frequency to the UPS system in Hz.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33738','20','1.3.6.1.4.1.318.1.1.1.3.2.5.0','10376','Input fail cause','input.fail[upsAdvInputLineFailCause]','1m','7d','365d','0','3','','','','',NULL,'157','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The reason for the occurrence of the last transfer to UPS
battery power.  The variable is set to:
- noTransfer(1) -- if there is no transfer yet.
- highLineVoltage(2) -- if the transfer to battery is caused
by an over voltage greater than the high transfer voltage.
- brownout(3) -- if the duration of the outage is greater than
five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- blackout(4) -- if the duration of the outage is greater than five
seconds and the line voltage is between 40% of the rated
output voltage and ground.
- smallMomentarySag(5) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- deepMomentarySag(6) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and ground.  The variable is set to
- smallMomentarySpike(7) -- if the line failure is caused by a
rate of change of input voltage less than ten volts per cycle.
- largeMomentarySpike(8) -- if the line failure is caused by
a rate of change of input voltage greater than ten volts per cycle.
- selfTest(9) -- if the UPS was commanded to do a self test.
- rateOfVoltageChange(10) -- if the failure is due to the rate of change of
the line voltage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33742','20','1.3.6.1.4.1.318.1.1.1.2.3.4.0','10376','Battery voltage','battery.voltage[upsHighPrecBatteryActualVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The actual battery bus voltage in Volts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33743','20','1.3.6.1.4.1.318.1.1.1.2.3.2.0','10376','Battery temperature','battery.temperature[upsHighPrecBatteryTemperature]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current internal UPS temperature in Celsius.
 Temperatures below zero read as 0.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33744','20','1.3.6.1.4.1.318.1.1.1.2.1.1.0','10376','Battery status','battery.status[upsBasicBatteryStatus]','1m','7d','365d','0','3','','','','',NULL,'158','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The status of the UPS batteries. A batteryLow(3) value
 indicates the UPS will be unable to sustain the current
 load, and its services will be lost if power is not restored.
 The amount of run time in reserve at the time of low battery
 can be configured by the upsAdvConfigLowBatteryRunTime.
 A batteryInFaultCondition(4)value indicates that a battery
 installed has an internal error condition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33745','20','1.3.6.1.4.1.318.1.1.1.2.2.3.0','10376','Battery runtime remaining','battery.runtime_remaining[upsAdvBatteryRunTimeRemaining]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS battery run time remaining before battery
 exhaustion.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33746','20','1.3.6.1.4.1.318.1.1.1.2.2.4.0','10376','Battery replace indicator','battery.replace_indicator[upsAdvBatteryReplaceIndicator]','1m','7d','365d','0','3','','','','',NULL,'156','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
Indicates whether the UPS batteries need replacement.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33747','20','1.3.6.1.4.1.318.1.1.1.2.1.3.0','10376','Battery last replace date','battery.last_replace_date[upsBasicBatteryLastReplaceDate]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The date when the UPS system''s batteries were last replaced
 in mm/dd/yy (or yyyy) format. For Smart-UPS models, this value
 is originally set at the factory. When the UPS batteries
 are replaced, this value should be reset by the administrator.
 For Symmetra PX 250/500 this OID is read-only and is configurable in the local display only.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33748','5','','10376','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33749','20','discovery[{#EXTERNAL_PACKS},1.3.6.1.4.1.318.1.1.1.2.2.6]','10376','External bad battery packs discovery','battery.packs.bad.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the number of external defective battery packs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33750','20','discovery[{#CARTRIDGE_STATUS},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7,{#BATTERY_PACK},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.1,{#CARTRIDGE_INDEX},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.2]','10376','External battery packs discovery','battery.packs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33751','20','discovery[{#EXTERNAL_SENSOR1_NAME},1.3.6.1.4.1.318.1.1.25.1.2.1.3]','10376','External sensor port 1 discovery','external.sensor1.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33752','20','discovery[{#EXTERNAL_SENSOR2_NAME},1.3.6.1.4.1.318.1.1.25.1.2.2.3]','10376','External sensor port 2 discovery','external.sensor2.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33753','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.2.3.1.2.1.1]','10376','Input phases discovery','input.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The input phase identifier. OID upsPhaseInputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33754','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.3.3.1.2.1.1]','10376','Output phases discovery','output.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The output phase identifier. OID upsPhaseOutputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33755','20','1.3.6.1.4.1.318.1.1.1.2.2.6.0','10376','{#SNMPINDEX}: External battery packs bad','battery.external_packs_bad[upsAdvBatteryNumOfBadBattPacks.{#SNMPINDEX}]','15m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS that
are defective. If the UPS does not use smart cells then the
agent reports ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33756','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.8.{#SNMPINDEX}','10376','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery estimated replace date','battery.estimated_replace_date[upsHighPrecBatteryPackCartridgeReplaceDate.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge estimated battery replace date.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33757','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7.{#SNMPINDEX}','10376','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery pack cartridge health','battery.pack.cartridge_health[upsHighPrecBatteryPackCartridgeHealth.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33758','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.10.{#SNMPINDEX}','10376','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status','battery.pack.status[upsHighPrecBatteryPackCartridgeStatus.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge status.
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33759','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.5.{#SNMPINDEX}','10376','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery temperature','battery.temperature[upsHighPrecBatteryPackTemperature.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack temperature in Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33760','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.4.{#SNMPINDEX}','10376','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Serial number','system.sn[upsHighPrecBatteryPackSerialNumber.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack serial number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33761','20','1.3.6.1.4.1.318.1.1.25.1.2.1.7.1.1','10376','{#EXTERNAL_SENSOR1_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33762','20','1.3.6.1.4.1.318.1.1.25.1.2.1.9.1.1','10376','{#EXTERNAL_SENSOR1_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.1.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33763','20','1.3.6.1.4.1.318.1.1.25.1.2.1.6.1.1','10376','{#EXTERNAL_SENSOR1_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33764','20','1.3.6.1.4.1.318.1.1.25.1.2.2.7.1.1','10376','{#EXTERNAL_SENSOR2_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33765','20','1.3.6.1.4.1.318.1.1.25.1.2.2.9.1.1','10376','{#EXTERNAL_SENSOR2_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.2.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33766','20','1.3.6.1.4.1.318.1.1.25.1.2.2.6.1.1','10376','{#EXTERNAL_SENSOR2_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33767','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.6.1.1.{#PHASEINDEX}','10376','{#PHASEINDEX}: Phase input current','phase.input.current[upsPhaseInputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input current in 0.1 amperes, or -0.1 if it''s
 unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33768','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.3.1.1.{#PHASEINDEX}','10376','{#PHASEINDEX}: Phase input voltage','phase.input.voltage[upsPhaseInputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33769','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.4.1.1.{#PHASEINDEX}','10376','{#PHASEINDEX}: Phase output current','phase.output.current[upsPhaseOutputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output current in 0.1 amperes drawn
 by the load on the UPS, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33770','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.10.1.1.{#PHASEINDEX}','10376','{#PHASEINDEX}: Phase output load, %','phase.output.load.percent[upsPhaseOutputPercentLoad.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The percentage of the UPS load capacity in VA at
 redundancy @ (n + x) presently being used on this
 output phase, or -1 if it''s unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33771','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.3.1.1.{#PHASEINDEX}','10376','{#PHASEINDEX}: Phase output voltage','phase.output.voltage[upsPhaseOutputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33772','20','1.3.6.1.4.1.318.1.1.1.2.3.1.0','10377','Battery capacity','battery.capacity[upsHighPrecBatteryCapacity]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The remaining battery capacity expressed as
 percentage of full capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33773','20','1.3.6.1.4.1.318.1.1.1.4.3.3.0','10377','Output load','output.load[upsHighPrecOutputLoad]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current UPS load expressed as percentage
of rated capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33774','20','1.3.6.1.2.1.1.3.0','10377','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management
portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33775','20','1.3.6.1.4.1.318.1.1.1.1.2.3.0','10377','Serial number','system.sn[upsAdvIdentSerialNumber]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
An 8-character string identifying the serial number of
 the UPS internal microprocessor.  This number is set at
 the factory.  NOTE: This number does NOT correspond to
 the serial number on the rear of the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33776','20','1.3.6.1.2.1.1.2.0','10377','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management
subsystem contained in the entity.  This value is allocated within the SMI enterprises
subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what
kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was
assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1
to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33778','20','1.3.6.1.4.1.318.1.1.1.1.1.1.0','10377','Model','system.model[upsBasicIdentModel]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS model name (e.g. ''APC Smart-UPS 600'').','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33779','20','1.3.6.1.2.1.1.6.0','10377','System location','system.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet,
3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33780','20','1.3.6.1.2.1.1.1.0','10377','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33781','20','1.3.6.1.2.1.1.4.0','10377','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed
node, together with information on how to contact this person.  If no contact
information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33782','17','','10377','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33783','20','1.3.6.1.4.1.318.1.1.1.4.3.1.0','10377','Output voltage','output.voltage[upsHighPrecOutputVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The output voltage of the UPS system in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33784','20','1.3.6.1.4.1.318.1.1.1.4.1.1.0','10377','Output status','output.status[upsBasicOutputStatus]','1m','7d','365d','0','3','','','','',NULL,'159','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current state of the UPS. If the UPS is unable to
 determine the state of the UPS this variable is set
 to unknown(1).
During self-test most UPSes report onBattery(3) but
 some that support it will report onBatteryTest(15).
 To determine self-test status across all UPSes, refer
 to the upsBasicStateOutputState OID.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33785','20','1.3.6.1.4.1.318.1.1.1.4.3.4.0','10377','Output current','output.current[upsHighPrecOutputCurrent]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current in amperes drawn by the load on the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33786','20','1.3.6.1.4.1.318.1.1.1.2.2.5.0','10377','External battery packs count','battery.external_packs_count[upsAdvBatteryNumOfBattPacks]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS. If
 the UPS does not use smart cells then the agent reports
 ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33787','20','1.3.6.1.4.1.318.1.1.1.3.3.1.0','10377','Input voltage','input.voltage[upsHighPrecInputLineVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current utility line voltage in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33788','20','1.3.6.1.4.1.318.1.1.1.3.3.4.0','10377','Input frequency','input.frequency[upsHighPrecInputFrequency]','1m','7d','365d','0','0','','Hz','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current input frequency to the UPS system in Hz.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33789','20','1.3.6.1.4.1.318.1.1.1.3.2.5.0','10377','Input fail cause','input.fail[upsAdvInputLineFailCause]','1m','7d','365d','0','3','','','','',NULL,'157','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The reason for the occurrence of the last transfer to UPS
battery power.  The variable is set to:
- noTransfer(1) -- if there is no transfer yet.
- highLineVoltage(2) -- if the transfer to battery is caused
by an over voltage greater than the high transfer voltage.
- brownout(3) -- if the duration of the outage is greater than
five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- blackout(4) -- if the duration of the outage is greater than five
seconds and the line voltage is between 40% of the rated
output voltage and ground.
- smallMomentarySag(5) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- deepMomentarySag(6) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and ground.  The variable is set to
- smallMomentarySpike(7) -- if the line failure is caused by a
rate of change of input voltage less than ten volts per cycle.
- largeMomentarySpike(8) -- if the line failure is caused by
a rate of change of input voltage greater than ten volts per cycle.
- selfTest(9) -- if the UPS was commanded to do a self test.
- rateOfVoltageChange(10) -- if the failure is due to the rate of change of
the line voltage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33793','20','1.3.6.1.4.1.318.1.1.1.2.3.4.0','10377','Battery voltage','battery.voltage[upsHighPrecBatteryActualVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The actual battery bus voltage in Volts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33794','20','1.3.6.1.4.1.318.1.1.1.2.3.2.0','10377','Battery temperature','battery.temperature[upsHighPrecBatteryTemperature]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current internal UPS temperature in Celsius.
 Temperatures below zero read as 0.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33795','20','1.3.6.1.4.1.318.1.1.1.2.1.1.0','10377','Battery status','battery.status[upsBasicBatteryStatus]','1m','7d','365d','0','3','','','','',NULL,'158','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The status of the UPS batteries. A batteryLow(3) value
 indicates the UPS will be unable to sustain the current
 load, and its services will be lost if power is not restored.
 The amount of run time in reserve at the time of low battery
 can be configured by the upsAdvConfigLowBatteryRunTime.
 A batteryInFaultCondition(4)value indicates that a battery
 installed has an internal error condition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33796','20','1.3.6.1.4.1.318.1.1.1.2.2.3.0','10377','Battery runtime remaining','battery.runtime_remaining[upsAdvBatteryRunTimeRemaining]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS battery run time remaining before battery
 exhaustion.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33797','20','1.3.6.1.4.1.318.1.1.1.2.2.4.0','10377','Battery replace indicator','battery.replace_indicator[upsAdvBatteryReplaceIndicator]','1m','7d','365d','0','3','','','','',NULL,'156','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
Indicates whether the UPS batteries need replacement.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33798','20','1.3.6.1.4.1.318.1.1.1.2.1.3.0','10377','Battery last replace date','battery.last_replace_date[upsBasicBatteryLastReplaceDate]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The date when the UPS system''s batteries were last replaced
 in mm/dd/yy (or yyyy) format. For Smart-UPS models, this value
 is originally set at the factory. When the UPS batteries
 are replaced, this value should be reset by the administrator.
 For Symmetra PX 250/500 this OID is read-only and is configurable in the local display only.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33799','5','','10377','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33800','20','discovery[{#EXTERNAL_PACKS},1.3.6.1.4.1.318.1.1.1.2.2.6]','10377','External bad battery packs discovery','battery.packs.bad.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the number of external defective battery packs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33801','20','discovery[{#CARTRIDGE_STATUS},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7,{#BATTERY_PACK},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.1,{#CARTRIDGE_INDEX},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.2]','10377','External battery packs discovery','battery.packs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33802','20','discovery[{#EXTERNAL_SENSOR1_NAME},1.3.6.1.4.1.318.1.1.25.1.2.1.3]','10377','External sensor port 1 discovery','external.sensor1.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33803','20','discovery[{#EXTERNAL_SENSOR2_NAME},1.3.6.1.4.1.318.1.1.25.1.2.2.3]','10377','External sensor port 2 discovery','external.sensor2.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33804','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.2.3.1.2.1.1]','10377','Input phases discovery','input.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The input phase identifier. OID upsPhaseInputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33805','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.3.3.1.2.1.1]','10377','Output phases discovery','output.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The output phase identifier. OID upsPhaseOutputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33806','20','1.3.6.1.4.1.318.1.1.1.2.2.6.0','10377','{#SNMPINDEX}: External battery packs bad','battery.external_packs_bad[upsAdvBatteryNumOfBadBattPacks.{#SNMPINDEX}]','15m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS that
are defective. If the UPS does not use smart cells then the
agent reports ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33807','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.8.{#SNMPINDEX}','10377','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery estimated replace date','battery.estimated_replace_date[upsHighPrecBatteryPackCartridgeReplaceDate.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge estimated battery replace date.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33808','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7.{#SNMPINDEX}','10377','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery pack cartridge health','battery.pack.cartridge_health[upsHighPrecBatteryPackCartridgeHealth.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33809','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.10.{#SNMPINDEX}','10377','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status','battery.pack.status[upsHighPrecBatteryPackCartridgeStatus.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge status.
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33810','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.5.{#SNMPINDEX}','10377','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery temperature','battery.temperature[upsHighPrecBatteryPackTemperature.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack temperature in Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33811','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.4.{#SNMPINDEX}','10377','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Serial number','system.sn[upsHighPrecBatteryPackSerialNumber.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack serial number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33812','20','1.3.6.1.4.1.318.1.1.25.1.2.1.7.1.1','10377','{#EXTERNAL_SENSOR1_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33813','20','1.3.6.1.4.1.318.1.1.25.1.2.1.9.1.1','10377','{#EXTERNAL_SENSOR1_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.1.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33814','20','1.3.6.1.4.1.318.1.1.25.1.2.1.6.1.1','10377','{#EXTERNAL_SENSOR1_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33815','20','1.3.6.1.4.1.318.1.1.25.1.2.2.7.1.1','10377','{#EXTERNAL_SENSOR2_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33816','20','1.3.6.1.4.1.318.1.1.25.1.2.2.9.1.1','10377','{#EXTERNAL_SENSOR2_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.2.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33817','20','1.3.6.1.4.1.318.1.1.25.1.2.2.6.1.1','10377','{#EXTERNAL_SENSOR2_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33818','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.6.1.1.{#PHASEINDEX}','10377','{#PHASEINDEX}: Phase input current','phase.input.current[upsPhaseInputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input current in 0.1 amperes, or -0.1 if it''s
 unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33819','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.3.1.1.{#PHASEINDEX}','10377','{#PHASEINDEX}: Phase input voltage','phase.input.voltage[upsPhaseInputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33820','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.4.1.1.{#PHASEINDEX}','10377','{#PHASEINDEX}: Phase output current','phase.output.current[upsPhaseOutputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output current in 0.1 amperes drawn
 by the load on the UPS, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33821','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.10.1.1.{#PHASEINDEX}','10377','{#PHASEINDEX}: Phase output load, %','phase.output.load.percent[upsPhaseOutputPercentLoad.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The percentage of the UPS load capacity in VA at
 redundancy @ (n + x) presently being used on this
 output phase, or -1 if it''s unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33822','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.3.1.1.{#PHASEINDEX}','10377','{#PHASEINDEX}: Phase output voltage','phase.output.voltage[upsPhaseOutputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33823','20','1.3.6.1.4.1.318.1.1.1.2.3.1.0','10378','Battery capacity','battery.capacity[upsHighPrecBatteryCapacity]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The remaining battery capacity expressed as
 percentage of full capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33824','20','1.3.6.1.4.1.318.1.1.1.4.3.3.0','10378','Output load','output.load[upsHighPrecOutputLoad]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current UPS load expressed as percentage
of rated capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33825','20','1.3.6.1.2.1.1.3.0','10378','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management
portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33826','20','1.3.6.1.4.1.318.1.1.1.1.2.3.0','10378','Serial number','system.sn[upsAdvIdentSerialNumber]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
An 8-character string identifying the serial number of
 the UPS internal microprocessor.  This number is set at
 the factory.  NOTE: This number does NOT correspond to
 the serial number on the rear of the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33827','20','1.3.6.1.2.1.1.2.0','10378','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management
subsystem contained in the entity.  This value is allocated within the SMI enterprises
subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what
kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was
assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1
to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33829','20','1.3.6.1.4.1.318.1.1.1.1.1.1.0','10378','Model','system.model[upsBasicIdentModel]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS model name (e.g. ''APC Smart-UPS 600'').','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33830','20','1.3.6.1.2.1.1.6.0','10378','System location','system.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet,
3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33831','20','1.3.6.1.2.1.1.1.0','10378','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33832','20','1.3.6.1.2.1.1.4.0','10378','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed
node, together with information on how to contact this person.  If no contact
information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33833','17','','10378','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33834','20','1.3.6.1.4.1.318.1.1.1.4.3.1.0','10378','Output voltage','output.voltage[upsHighPrecOutputVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The output voltage of the UPS system in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33835','20','1.3.6.1.4.1.318.1.1.1.4.1.1.0','10378','Output status','output.status[upsBasicOutputStatus]','1m','7d','365d','0','3','','','','',NULL,'159','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current state of the UPS. If the UPS is unable to
 determine the state of the UPS this variable is set
 to unknown(1).
During self-test most UPSes report onBattery(3) but
 some that support it will report onBatteryTest(15).
 To determine self-test status across all UPSes, refer
 to the upsBasicStateOutputState OID.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33836','20','1.3.6.1.4.1.318.1.1.1.4.3.4.0','10378','Output current','output.current[upsHighPrecOutputCurrent]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current in amperes drawn by the load on the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33837','20','1.3.6.1.4.1.318.1.1.1.2.2.5.0','10378','External battery packs count','battery.external_packs_count[upsAdvBatteryNumOfBattPacks]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS. If
 the UPS does not use smart cells then the agent reports
 ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33838','20','1.3.6.1.4.1.318.1.1.1.3.3.1.0','10378','Input voltage','input.voltage[upsHighPrecInputLineVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current utility line voltage in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33839','20','1.3.6.1.4.1.318.1.1.1.3.3.4.0','10378','Input frequency','input.frequency[upsHighPrecInputFrequency]','1m','7d','365d','0','0','','Hz','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current input frequency to the UPS system in Hz.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33840','20','1.3.6.1.4.1.318.1.1.1.3.2.5.0','10378','Input fail cause','input.fail[upsAdvInputLineFailCause]','1m','7d','365d','0','3','','','','',NULL,'157','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The reason for the occurrence of the last transfer to UPS
battery power.  The variable is set to:
- noTransfer(1) -- if there is no transfer yet.
- highLineVoltage(2) -- if the transfer to battery is caused
by an over voltage greater than the high transfer voltage.
- brownout(3) -- if the duration of the outage is greater than
five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- blackout(4) -- if the duration of the outage is greater than five
seconds and the line voltage is between 40% of the rated
output voltage and ground.
- smallMomentarySag(5) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- deepMomentarySag(6) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and ground.  The variable is set to
- smallMomentarySpike(7) -- if the line failure is caused by a
rate of change of input voltage less than ten volts per cycle.
- largeMomentarySpike(8) -- if the line failure is caused by
a rate of change of input voltage greater than ten volts per cycle.
- selfTest(9) -- if the UPS was commanded to do a self test.
- rateOfVoltageChange(10) -- if the failure is due to the rate of change of
the line voltage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33844','20','1.3.6.1.4.1.318.1.1.1.2.3.4.0','10378','Battery voltage','battery.voltage[upsHighPrecBatteryActualVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The actual battery bus voltage in Volts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33845','20','1.3.6.1.4.1.318.1.1.1.2.3.2.0','10378','Battery temperature','battery.temperature[upsHighPrecBatteryTemperature]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current internal UPS temperature in Celsius.
 Temperatures below zero read as 0.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33846','20','1.3.6.1.4.1.318.1.1.1.2.1.1.0','10378','Battery status','battery.status[upsBasicBatteryStatus]','1m','7d','365d','0','3','','','','',NULL,'158','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The status of the UPS batteries. A batteryLow(3) value
 indicates the UPS will be unable to sustain the current
 load, and its services will be lost if power is not restored.
 The amount of run time in reserve at the time of low battery
 can be configured by the upsAdvConfigLowBatteryRunTime.
 A batteryInFaultCondition(4)value indicates that a battery
 installed has an internal error condition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33847','20','1.3.6.1.4.1.318.1.1.1.2.2.3.0','10378','Battery runtime remaining','battery.runtime_remaining[upsAdvBatteryRunTimeRemaining]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS battery run time remaining before battery
 exhaustion.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33848','20','1.3.6.1.4.1.318.1.1.1.2.2.4.0','10378','Battery replace indicator','battery.replace_indicator[upsAdvBatteryReplaceIndicator]','1m','7d','365d','0','3','','','','',NULL,'156','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
Indicates whether the UPS batteries need replacement.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33849','20','1.3.6.1.4.1.318.1.1.1.2.1.3.0','10378','Battery last replace date','battery.last_replace_date[upsBasicBatteryLastReplaceDate]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The date when the UPS system''s batteries were last replaced
 in mm/dd/yy (or yyyy) format. For Smart-UPS models, this value
 is originally set at the factory. When the UPS batteries
 are replaced, this value should be reset by the administrator.
 For Symmetra PX 250/500 this OID is read-only and is configurable in the local display only.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33850','5','','10378','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33851','20','discovery[{#EXTERNAL_PACKS},1.3.6.1.4.1.318.1.1.1.2.2.6]','10378','External bad battery packs discovery','battery.packs.bad.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the number of external defective battery packs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33852','20','discovery[{#CARTRIDGE_STATUS},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7,{#BATTERY_PACK},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.1,{#CARTRIDGE_INDEX},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.2]','10378','External battery packs discovery','battery.packs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33853','20','discovery[{#EXTERNAL_SENSOR1_NAME},1.3.6.1.4.1.318.1.1.25.1.2.1.3]','10378','External sensor port 1 discovery','external.sensor1.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33854','20','discovery[{#EXTERNAL_SENSOR2_NAME},1.3.6.1.4.1.318.1.1.25.1.2.2.3]','10378','External sensor port 2 discovery','external.sensor2.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33855','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.2.3.1.2.1.1]','10378','Input phases discovery','input.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The input phase identifier. OID upsPhaseInputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33856','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.3.3.1.2.1.1]','10378','Output phases discovery','output.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The output phase identifier. OID upsPhaseOutputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33857','20','1.3.6.1.4.1.318.1.1.1.2.2.6.0','10378','{#SNMPINDEX}: External battery packs bad','battery.external_packs_bad[upsAdvBatteryNumOfBadBattPacks.{#SNMPINDEX}]','15m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS that
are defective. If the UPS does not use smart cells then the
agent reports ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33858','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.8.{#SNMPINDEX}','10378','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery estimated replace date','battery.estimated_replace_date[upsHighPrecBatteryPackCartridgeReplaceDate.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge estimated battery replace date.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33859','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7.{#SNMPINDEX}','10378','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery pack cartridge health','battery.pack.cartridge_health[upsHighPrecBatteryPackCartridgeHealth.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33860','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.10.{#SNMPINDEX}','10378','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status','battery.pack.status[upsHighPrecBatteryPackCartridgeStatus.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge status.
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33861','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.5.{#SNMPINDEX}','10378','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery temperature','battery.temperature[upsHighPrecBatteryPackTemperature.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack temperature in Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33862','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.4.{#SNMPINDEX}','10378','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Serial number','system.sn[upsHighPrecBatteryPackSerialNumber.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack serial number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33863','20','1.3.6.1.4.1.318.1.1.25.1.2.1.7.1.1','10378','{#EXTERNAL_SENSOR1_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33864','20','1.3.6.1.4.1.318.1.1.25.1.2.1.9.1.1','10378','{#EXTERNAL_SENSOR1_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.1.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33865','20','1.3.6.1.4.1.318.1.1.25.1.2.1.6.1.1','10378','{#EXTERNAL_SENSOR1_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33866','20','1.3.6.1.4.1.318.1.1.25.1.2.2.7.1.1','10378','{#EXTERNAL_SENSOR2_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33867','20','1.3.6.1.4.1.318.1.1.25.1.2.2.9.1.1','10378','{#EXTERNAL_SENSOR2_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.2.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33868','20','1.3.6.1.4.1.318.1.1.25.1.2.2.6.1.1','10378','{#EXTERNAL_SENSOR2_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33869','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.6.1.1.{#PHASEINDEX}','10378','{#PHASEINDEX}: Phase input current','phase.input.current[upsPhaseInputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input current in 0.1 amperes, or -0.1 if it''s
 unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33870','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.3.1.1.{#PHASEINDEX}','10378','{#PHASEINDEX}: Phase input voltage','phase.input.voltage[upsPhaseInputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33871','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.4.1.1.{#PHASEINDEX}','10378','{#PHASEINDEX}: Phase output current','phase.output.current[upsPhaseOutputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output current in 0.1 amperes drawn
 by the load on the UPS, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33872','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.10.1.1.{#PHASEINDEX}','10378','{#PHASEINDEX}: Phase output load, %','phase.output.load.percent[upsPhaseOutputPercentLoad.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The percentage of the UPS load capacity in VA at
 redundancy @ (n + x) presently being used on this
 output phase, or -1 if it''s unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33873','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.3.1.1.{#PHASEINDEX}','10378','{#PHASEINDEX}: Phase output voltage','phase.output.voltage[upsPhaseOutputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33874','20','1.3.6.1.4.1.318.1.1.1.2.3.1.0','10379','Battery capacity','battery.capacity[upsHighPrecBatteryCapacity]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The remaining battery capacity expressed as
 percentage of full capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33875','20','1.3.6.1.4.1.318.1.1.1.4.3.3.0','10379','Output load','output.load[upsHighPrecOutputLoad]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current UPS load expressed as percentage
of rated capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33876','20','1.3.6.1.2.1.1.3.0','10379','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management
portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33877','20','1.3.6.1.4.1.318.1.1.1.1.2.3.0','10379','Serial number','system.sn[upsAdvIdentSerialNumber]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
An 8-character string identifying the serial number of
 the UPS internal microprocessor.  This number is set at
 the factory.  NOTE: This number does NOT correspond to
 the serial number on the rear of the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33878','20','1.3.6.1.2.1.1.2.0','10379','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management
subsystem contained in the entity.  This value is allocated within the SMI enterprises
subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what
kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was
assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1
to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33880','20','1.3.6.1.4.1.318.1.1.1.1.1.1.0','10379','Model','system.model[upsBasicIdentModel]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS model name (e.g. ''APC Smart-UPS 600'').','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33881','20','1.3.6.1.2.1.1.6.0','10379','System location','system.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet,
3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33882','20','1.3.6.1.2.1.1.1.0','10379','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33883','20','1.3.6.1.2.1.1.4.0','10379','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed
node, together with information on how to contact this person.  If no contact
information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33884','17','','10379','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33885','20','1.3.6.1.4.1.318.1.1.1.4.3.1.0','10379','Output voltage','output.voltage[upsHighPrecOutputVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The output voltage of the UPS system in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33886','20','1.3.6.1.4.1.318.1.1.1.4.1.1.0','10379','Output status','output.status[upsBasicOutputStatus]','1m','7d','365d','0','3','','','','',NULL,'159','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current state of the UPS. If the UPS is unable to
 determine the state of the UPS this variable is set
 to unknown(1).
During self-test most UPSes report onBattery(3) but
 some that support it will report onBatteryTest(15).
 To determine self-test status across all UPSes, refer
 to the upsBasicStateOutputState OID.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33887','20','1.3.6.1.4.1.318.1.1.1.4.3.4.0','10379','Output current','output.current[upsHighPrecOutputCurrent]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current in amperes drawn by the load on the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33888','20','1.3.6.1.4.1.318.1.1.1.2.2.5.0','10379','External battery packs count','battery.external_packs_count[upsAdvBatteryNumOfBattPacks]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS. If
 the UPS does not use smart cells then the agent reports
 ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33889','20','1.3.6.1.4.1.318.1.1.1.3.3.1.0','10379','Input voltage','input.voltage[upsHighPrecInputLineVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current utility line voltage in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33890','20','1.3.6.1.4.1.318.1.1.1.3.3.4.0','10379','Input frequency','input.frequency[upsHighPrecInputFrequency]','1m','7d','365d','0','0','','Hz','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current input frequency to the UPS system in Hz.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33891','20','1.3.6.1.4.1.318.1.1.1.3.2.5.0','10379','Input fail cause','input.fail[upsAdvInputLineFailCause]','1m','7d','365d','0','3','','','','',NULL,'157','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The reason for the occurrence of the last transfer to UPS
battery power.  The variable is set to:
- noTransfer(1) -- if there is no transfer yet.
- highLineVoltage(2) -- if the transfer to battery is caused
by an over voltage greater than the high transfer voltage.
- brownout(3) -- if the duration of the outage is greater than
five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- blackout(4) -- if the duration of the outage is greater than five
seconds and the line voltage is between 40% of the rated
output voltage and ground.
- smallMomentarySag(5) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- deepMomentarySag(6) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and ground.  The variable is set to
- smallMomentarySpike(7) -- if the line failure is caused by a
rate of change of input voltage less than ten volts per cycle.
- largeMomentarySpike(8) -- if the line failure is caused by
a rate of change of input voltage greater than ten volts per cycle.
- selfTest(9) -- if the UPS was commanded to do a self test.
- rateOfVoltageChange(10) -- if the failure is due to the rate of change of
the line voltage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33895','20','1.3.6.1.4.1.318.1.1.1.2.3.4.0','10379','Battery voltage','battery.voltage[upsHighPrecBatteryActualVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The actual battery bus voltage in Volts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33896','20','1.3.6.1.4.1.318.1.1.1.2.3.2.0','10379','Battery temperature','battery.temperature[upsHighPrecBatteryTemperature]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current internal UPS temperature in Celsius.
 Temperatures below zero read as 0.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33897','20','1.3.6.1.4.1.318.1.1.1.2.1.1.0','10379','Battery status','battery.status[upsBasicBatteryStatus]','1m','7d','365d','0','3','','','','',NULL,'158','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The status of the UPS batteries. A batteryLow(3) value
 indicates the UPS will be unable to sustain the current
 load, and its services will be lost if power is not restored.
 The amount of run time in reserve at the time of low battery
 can be configured by the upsAdvConfigLowBatteryRunTime.
 A batteryInFaultCondition(4)value indicates that a battery
 installed has an internal error condition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33898','20','1.3.6.1.4.1.318.1.1.1.2.2.3.0','10379','Battery runtime remaining','battery.runtime_remaining[upsAdvBatteryRunTimeRemaining]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS battery run time remaining before battery
 exhaustion.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33899','20','1.3.6.1.4.1.318.1.1.1.2.2.4.0','10379','Battery replace indicator','battery.replace_indicator[upsAdvBatteryReplaceIndicator]','1m','7d','365d','0','3','','','','',NULL,'156','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
Indicates whether the UPS batteries need replacement.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33900','20','1.3.6.1.4.1.318.1.1.1.2.1.3.0','10379','Battery last replace date','battery.last_replace_date[upsBasicBatteryLastReplaceDate]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The date when the UPS system''s batteries were last replaced
 in mm/dd/yy (or yyyy) format. For Smart-UPS models, this value
 is originally set at the factory. When the UPS batteries
 are replaced, this value should be reset by the administrator.
 For Symmetra PX 250/500 this OID is read-only and is configurable in the local display only.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33901','5','','10379','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33902','20','discovery[{#EXTERNAL_PACKS},1.3.6.1.4.1.318.1.1.1.2.2.6]','10379','External bad battery packs discovery','battery.packs.bad.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the number of external defective battery packs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33903','20','discovery[{#CARTRIDGE_STATUS},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7,{#BATTERY_PACK},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.1,{#CARTRIDGE_INDEX},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.2]','10379','External battery packs discovery','battery.packs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33904','20','discovery[{#EXTERNAL_SENSOR1_NAME},1.3.6.1.4.1.318.1.1.25.1.2.1.3]','10379','External sensor port 1 discovery','external.sensor1.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33905','20','discovery[{#EXTERNAL_SENSOR2_NAME},1.3.6.1.4.1.318.1.1.25.1.2.2.3]','10379','External sensor port 2 discovery','external.sensor2.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33906','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.2.3.1.2.1.1]','10379','Input phases discovery','input.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The input phase identifier. OID upsPhaseInputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33907','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.3.3.1.2.1.1]','10379','Output phases discovery','output.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The output phase identifier. OID upsPhaseOutputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33908','20','1.3.6.1.4.1.318.1.1.1.2.2.6.0','10379','{#SNMPINDEX}: External battery packs bad','battery.external_packs_bad[upsAdvBatteryNumOfBadBattPacks.{#SNMPINDEX}]','15m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS that
are defective. If the UPS does not use smart cells then the
agent reports ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33909','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.8.{#SNMPINDEX}','10379','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery estimated replace date','battery.estimated_replace_date[upsHighPrecBatteryPackCartridgeReplaceDate.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge estimated battery replace date.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33910','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7.{#SNMPINDEX}','10379','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery pack cartridge health','battery.pack.cartridge_health[upsHighPrecBatteryPackCartridgeHealth.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33911','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.10.{#SNMPINDEX}','10379','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status','battery.pack.status[upsHighPrecBatteryPackCartridgeStatus.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge status.
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33912','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.5.{#SNMPINDEX}','10379','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery temperature','battery.temperature[upsHighPrecBatteryPackTemperature.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack temperature in Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33913','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.4.{#SNMPINDEX}','10379','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Serial number','system.sn[upsHighPrecBatteryPackSerialNumber.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack serial number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33914','20','1.3.6.1.4.1.318.1.1.25.1.2.1.7.1.1','10379','{#EXTERNAL_SENSOR1_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33915','20','1.3.6.1.4.1.318.1.1.25.1.2.1.9.1.1','10379','{#EXTERNAL_SENSOR1_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.1.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33916','20','1.3.6.1.4.1.318.1.1.25.1.2.1.6.1.1','10379','{#EXTERNAL_SENSOR1_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33917','20','1.3.6.1.4.1.318.1.1.25.1.2.2.7.1.1','10379','{#EXTERNAL_SENSOR2_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33918','20','1.3.6.1.4.1.318.1.1.25.1.2.2.9.1.1','10379','{#EXTERNAL_SENSOR2_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.2.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33919','20','1.3.6.1.4.1.318.1.1.25.1.2.2.6.1.1','10379','{#EXTERNAL_SENSOR2_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33920','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.6.1.1.{#PHASEINDEX}','10379','{#PHASEINDEX}: Phase input current','phase.input.current[upsPhaseInputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input current in 0.1 amperes, or -0.1 if it''s
 unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33921','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.3.1.1.{#PHASEINDEX}','10379','{#PHASEINDEX}: Phase input voltage','phase.input.voltage[upsPhaseInputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33922','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.4.1.1.{#PHASEINDEX}','10379','{#PHASEINDEX}: Phase output current','phase.output.current[upsPhaseOutputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output current in 0.1 amperes drawn
 by the load on the UPS, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33923','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.10.1.1.{#PHASEINDEX}','10379','{#PHASEINDEX}: Phase output load, %','phase.output.load.percent[upsPhaseOutputPercentLoad.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The percentage of the UPS load capacity in VA at
 redundancy @ (n + x) presently being used on this
 output phase, or -1 if it''s unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33924','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.3.1.1.{#PHASEINDEX}','10379','{#PHASEINDEX}: Phase output voltage','phase.output.voltage[upsPhaseOutputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33925','20','1.3.6.1.4.1.318.1.1.1.2.3.1.0','10371','Battery capacity','battery.capacity[upsHighPrecBatteryCapacity]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The remaining battery capacity expressed as
 percentage of full capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33926','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.3.3.1.2.1.1]','10371','Output phases discovery','output.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The output phase identifier. OID upsPhaseOutputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33927','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.4.1.1.{#PHASEINDEX}','10371','{#PHASEINDEX}: Phase output current','phase.output.current[upsPhaseOutputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output current in 0.1 amperes drawn
 by the load on the UPS, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33928','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.10.1.1.{#PHASEINDEX}','10371','{#PHASEINDEX}: Phase output load, %','phase.output.load.percent[upsPhaseOutputPercentLoad.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The percentage of the UPS load capacity in VA at
 redundancy @ (n + x) presently being used on this
 output phase, or -1 if it''s unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33929','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.3.1.1.{#PHASEINDEX}','10371','{#PHASEINDEX}: Phase output voltage','phase.output.voltage[upsPhaseOutputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33930','20','1.3.6.1.4.1.318.1.1.1.2.3.1.0','10380','Battery capacity','battery.capacity[upsHighPrecBatteryCapacity]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The remaining battery capacity expressed as
 percentage of full capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33931','20','1.3.6.1.4.1.318.1.1.1.4.3.3.0','10380','Output load','output.load[upsHighPrecOutputLoad]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current UPS load expressed as percentage
of rated capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33932','20','1.3.6.1.2.1.1.3.0','10380','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management
portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33933','20','1.3.6.1.4.1.318.1.1.1.1.2.3.0','10380','Serial number','system.sn[upsAdvIdentSerialNumber]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
An 8-character string identifying the serial number of
 the UPS internal microprocessor.  This number is set at
 the factory.  NOTE: This number does NOT correspond to
 the serial number on the rear of the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33934','20','1.3.6.1.2.1.1.2.0','10380','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management
subsystem contained in the entity.  This value is allocated within the SMI enterprises
subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what
kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was
assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1
to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33936','20','1.3.6.1.4.1.318.1.1.1.1.1.1.0','10380','Model','system.model[upsBasicIdentModel]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS model name (e.g. ''APC Smart-UPS 600'').','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33937','20','1.3.6.1.2.1.1.6.0','10380','System location','system.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet,
3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33938','20','1.3.6.1.2.1.1.1.0','10380','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33939','20','1.3.6.1.2.1.1.4.0','10380','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed
node, together with information on how to contact this person.  If no contact
information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33940','17','','10380','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33941','20','1.3.6.1.4.1.318.1.1.1.4.3.1.0','10380','Output voltage','output.voltage[upsHighPrecOutputVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The output voltage of the UPS system in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33942','20','1.3.6.1.4.1.318.1.1.1.4.1.1.0','10380','Output status','output.status[upsBasicOutputStatus]','1m','7d','365d','0','3','','','','',NULL,'159','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current state of the UPS. If the UPS is unable to
 determine the state of the UPS this variable is set
 to unknown(1).
During self-test most UPSes report onBattery(3) but
 some that support it will report onBatteryTest(15).
 To determine self-test status across all UPSes, refer
 to the upsBasicStateOutputState OID.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33943','20','1.3.6.1.4.1.318.1.1.1.4.3.4.0','10380','Output current','output.current[upsHighPrecOutputCurrent]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current in amperes drawn by the load on the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33944','20','1.3.6.1.4.1.318.1.1.1.2.2.5.0','10380','External battery packs count','battery.external_packs_count[upsAdvBatteryNumOfBattPacks]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS. If
 the UPS does not use smart cells then the agent reports
 ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33945','20','1.3.6.1.4.1.318.1.1.1.3.3.1.0','10380','Input voltage','input.voltage[upsHighPrecInputLineVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current utility line voltage in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33946','20','1.3.6.1.4.1.318.1.1.1.3.3.4.0','10380','Input frequency','input.frequency[upsHighPrecInputFrequency]','1m','7d','365d','0','0','','Hz','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current input frequency to the UPS system in Hz.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33947','20','1.3.6.1.4.1.318.1.1.1.3.2.5.0','10380','Input fail cause','input.fail[upsAdvInputLineFailCause]','1m','7d','365d','0','3','','','','',NULL,'157','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The reason for the occurrence of the last transfer to UPS
battery power.  The variable is set to:
- noTransfer(1) -- if there is no transfer yet.
- highLineVoltage(2) -- if the transfer to battery is caused
by an over voltage greater than the high transfer voltage.
- brownout(3) -- if the duration of the outage is greater than
five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- blackout(4) -- if the duration of the outage is greater than five
seconds and the line voltage is between 40% of the rated
output voltage and ground.
- smallMomentarySag(5) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- deepMomentarySag(6) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and ground.  The variable is set to
- smallMomentarySpike(7) -- if the line failure is caused by a
rate of change of input voltage less than ten volts per cycle.
- largeMomentarySpike(8) -- if the line failure is caused by
a rate of change of input voltage greater than ten volts per cycle.
- selfTest(9) -- if the UPS was commanded to do a self test.
- rateOfVoltageChange(10) -- if the failure is due to the rate of change of
the line voltage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33951','20','1.3.6.1.4.1.318.1.1.1.2.3.4.0','10380','Battery voltage','battery.voltage[upsHighPrecBatteryActualVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The actual battery bus voltage in Volts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33952','20','1.3.6.1.4.1.318.1.1.1.2.3.2.0','10380','Battery temperature','battery.temperature[upsHighPrecBatteryTemperature]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current internal UPS temperature in Celsius.
 Temperatures below zero read as 0.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33953','20','1.3.6.1.4.1.318.1.1.1.2.1.1.0','10380','Battery status','battery.status[upsBasicBatteryStatus]','1m','7d','365d','0','3','','','','',NULL,'158','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The status of the UPS batteries. A batteryLow(3) value
 indicates the UPS will be unable to sustain the current
 load, and its services will be lost if power is not restored.
 The amount of run time in reserve at the time of low battery
 can be configured by the upsAdvConfigLowBatteryRunTime.
 A batteryInFaultCondition(4)value indicates that a battery
 installed has an internal error condition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33954','20','1.3.6.1.4.1.318.1.1.1.2.2.3.0','10380','Battery runtime remaining','battery.runtime_remaining[upsAdvBatteryRunTimeRemaining]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS battery run time remaining before battery
 exhaustion.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33955','20','1.3.6.1.4.1.318.1.1.1.2.2.4.0','10380','Battery replace indicator','battery.replace_indicator[upsAdvBatteryReplaceIndicator]','1m','7d','365d','0','3','','','','',NULL,'156','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
Indicates whether the UPS batteries need replacement.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33956','20','1.3.6.1.4.1.318.1.1.1.2.1.3.0','10380','Battery last replace date','battery.last_replace_date[upsBasicBatteryLastReplaceDate]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The date when the UPS system''s batteries were last replaced
 in mm/dd/yy (or yyyy) format. For Smart-UPS models, this value
 is originally set at the factory. When the UPS batteries
 are replaced, this value should be reset by the administrator.
 For Symmetra PX 250/500 this OID is read-only and is configurable in the local display only.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33957','5','','10380','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33958','20','discovery[{#EXTERNAL_PACKS},1.3.6.1.4.1.318.1.1.1.2.2.6]','10380','External bad battery packs discovery','battery.packs.bad.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the number of external defective battery packs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33959','20','discovery[{#CARTRIDGE_STATUS},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7,{#BATTERY_PACK},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.1,{#CARTRIDGE_INDEX},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.2]','10380','External battery packs discovery','battery.packs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33960','20','discovery[{#EXTERNAL_SENSOR1_NAME},1.3.6.1.4.1.318.1.1.25.1.2.1.3]','10380','External sensor port 1 discovery','external.sensor1.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33961','20','discovery[{#EXTERNAL_SENSOR2_NAME},1.3.6.1.4.1.318.1.1.25.1.2.2.3]','10380','External sensor port 2 discovery','external.sensor2.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33962','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.2.3.1.2.1.1]','10380','Input phases discovery','input.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The input phase identifier. OID upsPhaseInputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33963','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.3.3.1.2.1.1]','10380','Output phases discovery','output.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The output phase identifier. OID upsPhaseOutputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33964','20','1.3.6.1.4.1.318.1.1.1.2.2.6.0','10380','{#SNMPINDEX}: External battery packs bad','battery.external_packs_bad[upsAdvBatteryNumOfBadBattPacks.{#SNMPINDEX}]','15m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS that
are defective. If the UPS does not use smart cells then the
agent reports ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33965','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.8.{#SNMPINDEX}','10380','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery estimated replace date','battery.estimated_replace_date[upsHighPrecBatteryPackCartridgeReplaceDate.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge estimated battery replace date.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33966','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7.{#SNMPINDEX}','10380','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery pack cartridge health','battery.pack.cartridge_health[upsHighPrecBatteryPackCartridgeHealth.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33967','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.10.{#SNMPINDEX}','10380','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status','battery.pack.status[upsHighPrecBatteryPackCartridgeStatus.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge status.
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33968','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.5.{#SNMPINDEX}','10380','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery temperature','battery.temperature[upsHighPrecBatteryPackTemperature.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack temperature in Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33969','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.4.{#SNMPINDEX}','10380','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Serial number','system.sn[upsHighPrecBatteryPackSerialNumber.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack serial number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33970','20','1.3.6.1.4.1.318.1.1.25.1.2.1.7.1.1','10380','{#EXTERNAL_SENSOR1_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33971','20','1.3.6.1.4.1.318.1.1.25.1.2.1.9.1.1','10380','{#EXTERNAL_SENSOR1_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.1.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33972','20','1.3.6.1.4.1.318.1.1.25.1.2.1.6.1.1','10380','{#EXTERNAL_SENSOR1_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33973','20','1.3.6.1.4.1.318.1.1.25.1.2.2.7.1.1','10380','{#EXTERNAL_SENSOR2_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33974','20','1.3.6.1.4.1.318.1.1.25.1.2.2.9.1.1','10380','{#EXTERNAL_SENSOR2_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.2.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33975','20','1.3.6.1.4.1.318.1.1.25.1.2.2.6.1.1','10380','{#EXTERNAL_SENSOR2_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33976','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.6.1.1.{#PHASEINDEX}','10380','{#PHASEINDEX}: Phase input current','phase.input.current[upsPhaseInputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input current in 0.1 amperes, or -0.1 if it''s
 unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33977','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.3.1.1.{#PHASEINDEX}','10380','{#PHASEINDEX}: Phase input voltage','phase.input.voltage[upsPhaseInputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33978','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.4.1.1.{#PHASEINDEX}','10380','{#PHASEINDEX}: Phase output current','phase.output.current[upsPhaseOutputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output current in 0.1 amperes drawn
 by the load on the UPS, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33979','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.10.1.1.{#PHASEINDEX}','10380','{#PHASEINDEX}: Phase output load, %','phase.output.load.percent[upsPhaseOutputPercentLoad.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The percentage of the UPS load capacity in VA at
 redundancy @ (n + x) presently being used on this
 output phase, or -1 if it''s unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33980','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.3.1.1.{#PHASEINDEX}','10380','{#PHASEINDEX}: Phase output voltage','phase.output.voltage[upsPhaseOutputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33981','20','1.3.6.1.4.1.318.1.1.1.2.3.1.0','10381','Battery capacity','battery.capacity[upsHighPrecBatteryCapacity]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The remaining battery capacity expressed as
 percentage of full capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33982','20','1.3.6.1.4.1.318.1.1.1.4.3.3.0','10381','Output load','output.load[upsHighPrecOutputLoad]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current UPS load expressed as percentage
of rated capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33983','20','1.3.6.1.2.1.1.3.0','10381','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management
portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33984','20','1.3.6.1.4.1.318.1.1.1.1.2.3.0','10381','Serial number','system.sn[upsAdvIdentSerialNumber]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
An 8-character string identifying the serial number of
 the UPS internal microprocessor.  This number is set at
 the factory.  NOTE: This number does NOT correspond to
 the serial number on the rear of the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33985','20','1.3.6.1.2.1.1.2.0','10381','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management
subsystem contained in the entity.  This value is allocated within the SMI enterprises
subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what
kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was
assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1
to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33987','20','1.3.6.1.4.1.318.1.1.1.1.1.1.0','10381','Model','system.model[upsBasicIdentModel]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS model name (e.g. ''APC Smart-UPS 600'').','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33988','20','1.3.6.1.2.1.1.6.0','10381','System location','system.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet,
3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33989','20','1.3.6.1.2.1.1.1.0','10381','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33990','20','1.3.6.1.2.1.1.4.0','10381','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed
node, together with information on how to contact this person.  If no contact
information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33991','17','','10381','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33992','20','1.3.6.1.4.1.318.1.1.1.4.3.1.0','10381','Output voltage','output.voltage[upsHighPrecOutputVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The output voltage of the UPS system in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33993','20','1.3.6.1.4.1.318.1.1.1.4.1.1.0','10381','Output status','output.status[upsBasicOutputStatus]','1m','7d','365d','0','3','','','','',NULL,'159','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current state of the UPS. If the UPS is unable to
 determine the state of the UPS this variable is set
 to unknown(1).
During self-test most UPSes report onBattery(3) but
 some that support it will report onBatteryTest(15).
 To determine self-test status across all UPSes, refer
 to the upsBasicStateOutputState OID.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33994','20','1.3.6.1.4.1.318.1.1.1.4.3.4.0','10381','Output current','output.current[upsHighPrecOutputCurrent]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current in amperes drawn by the load on the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33995','20','1.3.6.1.4.1.318.1.1.1.2.2.5.0','10381','External battery packs count','battery.external_packs_count[upsAdvBatteryNumOfBattPacks]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS. If
 the UPS does not use smart cells then the agent reports
 ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33996','20','1.3.6.1.4.1.318.1.1.1.3.3.1.0','10381','Input voltage','input.voltage[upsHighPrecInputLineVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current utility line voltage in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33997','20','1.3.6.1.4.1.318.1.1.1.3.3.4.0','10381','Input frequency','input.frequency[upsHighPrecInputFrequency]','1m','7d','365d','0','0','','Hz','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current input frequency to the UPS system in Hz.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33998','20','1.3.6.1.4.1.318.1.1.1.3.2.5.0','10381','Input fail cause','input.fail[upsAdvInputLineFailCause]','1m','7d','365d','0','3','','','','',NULL,'157','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The reason for the occurrence of the last transfer to UPS
battery power.  The variable is set to:
- noTransfer(1) -- if there is no transfer yet.
- highLineVoltage(2) -- if the transfer to battery is caused
by an over voltage greater than the high transfer voltage.
- brownout(3) -- if the duration of the outage is greater than
five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- blackout(4) -- if the duration of the outage is greater than five
seconds and the line voltage is between 40% of the rated
output voltage and ground.
- smallMomentarySag(5) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- deepMomentarySag(6) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and ground.  The variable is set to
- smallMomentarySpike(7) -- if the line failure is caused by a
rate of change of input voltage less than ten volts per cycle.
- largeMomentarySpike(8) -- if the line failure is caused by
a rate of change of input voltage greater than ten volts per cycle.
- selfTest(9) -- if the UPS was commanded to do a self test.
- rateOfVoltageChange(10) -- if the failure is due to the rate of change of
the line voltage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34002','20','1.3.6.1.4.1.318.1.1.1.2.3.4.0','10381','Battery voltage','battery.voltage[upsHighPrecBatteryActualVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The actual battery bus voltage in Volts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34003','20','1.3.6.1.4.1.318.1.1.1.2.3.2.0','10381','Battery temperature','battery.temperature[upsHighPrecBatteryTemperature]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current internal UPS temperature in Celsius.
 Temperatures below zero read as 0.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34004','20','1.3.6.1.4.1.318.1.1.1.2.1.1.0','10381','Battery status','battery.status[upsBasicBatteryStatus]','1m','7d','365d','0','3','','','','',NULL,'158','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The status of the UPS batteries. A batteryLow(3) value
 indicates the UPS will be unable to sustain the current
 load, and its services will be lost if power is not restored.
 The amount of run time in reserve at the time of low battery
 can be configured by the upsAdvConfigLowBatteryRunTime.
 A batteryInFaultCondition(4)value indicates that a battery
 installed has an internal error condition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34005','20','1.3.6.1.4.1.318.1.1.1.2.2.3.0','10381','Battery runtime remaining','battery.runtime_remaining[upsAdvBatteryRunTimeRemaining]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS battery run time remaining before battery
 exhaustion.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34006','20','1.3.6.1.4.1.318.1.1.1.2.2.4.0','10381','Battery replace indicator','battery.replace_indicator[upsAdvBatteryReplaceIndicator]','1m','7d','365d','0','3','','','','',NULL,'156','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
Indicates whether the UPS batteries need replacement.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34007','20','1.3.6.1.4.1.318.1.1.1.2.1.3.0','10381','Battery last replace date','battery.last_replace_date[upsBasicBatteryLastReplaceDate]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The date when the UPS system''s batteries were last replaced
 in mm/dd/yy (or yyyy) format. For Smart-UPS models, this value
 is originally set at the factory. When the UPS batteries
 are replaced, this value should be reset by the administrator.
 For Symmetra PX 250/500 this OID is read-only and is configurable in the local display only.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34008','5','','10381','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34009','20','discovery[{#EXTERNAL_PACKS},1.3.6.1.4.1.318.1.1.1.2.2.6]','10381','External bad battery packs discovery','battery.packs.bad.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the number of external defective battery packs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34010','20','discovery[{#CARTRIDGE_STATUS},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7,{#BATTERY_PACK},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.1,{#CARTRIDGE_INDEX},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.2]','10381','External battery packs discovery','battery.packs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34011','20','discovery[{#EXTERNAL_SENSOR1_NAME},1.3.6.1.4.1.318.1.1.25.1.2.1.3]','10381','External sensor port 1 discovery','external.sensor1.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34012','20','discovery[{#EXTERNAL_SENSOR2_NAME},1.3.6.1.4.1.318.1.1.25.1.2.2.3]','10381','External sensor port 2 discovery','external.sensor2.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34013','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.2.3.1.2.1.1]','10381','Input phases discovery','input.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The input phase identifier. OID upsPhaseInputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34014','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.3.3.1.2.1.1]','10381','Output phases discovery','output.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The output phase identifier. OID upsPhaseOutputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34015','20','1.3.6.1.4.1.318.1.1.1.2.2.6.0','10381','{#SNMPINDEX}: External battery packs bad','battery.external_packs_bad[upsAdvBatteryNumOfBadBattPacks.{#SNMPINDEX}]','15m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS that
are defective. If the UPS does not use smart cells then the
agent reports ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34016','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.8.{#SNMPINDEX}','10381','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery estimated replace date','battery.estimated_replace_date[upsHighPrecBatteryPackCartridgeReplaceDate.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge estimated battery replace date.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34017','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7.{#SNMPINDEX}','10381','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery pack cartridge health','battery.pack.cartridge_health[upsHighPrecBatteryPackCartridgeHealth.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34018','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.10.{#SNMPINDEX}','10381','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status','battery.pack.status[upsHighPrecBatteryPackCartridgeStatus.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge status.
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34019','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.5.{#SNMPINDEX}','10381','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery temperature','battery.temperature[upsHighPrecBatteryPackTemperature.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack temperature in Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34020','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.4.{#SNMPINDEX}','10381','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Serial number','system.sn[upsHighPrecBatteryPackSerialNumber.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack serial number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34021','20','1.3.6.1.4.1.318.1.1.25.1.2.1.7.1.1','10381','{#EXTERNAL_SENSOR1_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34022','20','1.3.6.1.4.1.318.1.1.25.1.2.1.9.1.1','10381','{#EXTERNAL_SENSOR1_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.1.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34023','20','1.3.6.1.4.1.318.1.1.25.1.2.1.6.1.1','10381','{#EXTERNAL_SENSOR1_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34024','20','1.3.6.1.4.1.318.1.1.25.1.2.2.7.1.1','10381','{#EXTERNAL_SENSOR2_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34025','20','1.3.6.1.4.1.318.1.1.25.1.2.2.9.1.1','10381','{#EXTERNAL_SENSOR2_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.2.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34026','20','1.3.6.1.4.1.318.1.1.25.1.2.2.6.1.1','10381','{#EXTERNAL_SENSOR2_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34027','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.6.1.1.{#PHASEINDEX}','10381','{#PHASEINDEX}: Phase input current','phase.input.current[upsPhaseInputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input current in 0.1 amperes, or -0.1 if it''s
 unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34028','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.3.1.1.{#PHASEINDEX}','10381','{#PHASEINDEX}: Phase input voltage','phase.input.voltage[upsPhaseInputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34029','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.4.1.1.{#PHASEINDEX}','10381','{#PHASEINDEX}: Phase output current','phase.output.current[upsPhaseOutputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output current in 0.1 amperes drawn
 by the load on the UPS, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34030','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.10.1.1.{#PHASEINDEX}','10381','{#PHASEINDEX}: Phase output load, %','phase.output.load.percent[upsPhaseOutputPercentLoad.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The percentage of the UPS load capacity in VA at
 redundancy @ (n + x) presently being used on this
 output phase, or -1 if it''s unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34031','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.3.1.1.{#PHASEINDEX}','10381','{#PHASEINDEX}: Phase output voltage','phase.output.voltage[upsPhaseOutputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34032','20','1.3.6.1.4.1.318.1.1.1.2.3.1.0','10382','Battery capacity','battery.capacity[upsHighPrecBatteryCapacity]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The remaining battery capacity expressed as
 percentage of full capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34033','20','1.3.6.1.4.1.318.1.1.1.4.3.3.0','10382','Output load','output.load[upsHighPrecOutputLoad]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current UPS load expressed as percentage
of rated capacity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34034','20','1.3.6.1.2.1.1.3.0','10382','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management
portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34035','20','1.3.6.1.4.1.318.1.1.1.1.2.3.0','10382','Serial number','system.sn[upsAdvIdentSerialNumber]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
An 8-character string identifying the serial number of
 the UPS internal microprocessor.  This number is set at
 the factory.  NOTE: This number does NOT correspond to
 the serial number on the rear of the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34036','20','1.3.6.1.2.1.1.2.0','10382','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management
subsystem contained in the entity.  This value is allocated within the SMI enterprises
subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what
kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was
assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1
to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34038','20','1.3.6.1.4.1.318.1.1.1.1.1.1.0','10382','Model','system.model[upsBasicIdentModel]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS model name (e.g. ''APC Smart-UPS 600'').','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34039','20','1.3.6.1.2.1.1.6.0','10382','System location','system.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet,
3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34040','20','1.3.6.1.2.1.1.1.0','10382','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34041','20','1.3.6.1.2.1.1.4.0','10382','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed
node, together with information on how to contact this person.  If no contact
information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34042','17','','10382','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34043','20','1.3.6.1.4.1.318.1.1.1.4.3.1.0','10382','Output voltage','output.voltage[upsHighPrecOutputVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The output voltage of the UPS system in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34044','20','1.3.6.1.4.1.318.1.1.1.4.1.1.0','10382','Output status','output.status[upsBasicOutputStatus]','1m','7d','365d','0','3','','','','',NULL,'159','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current state of the UPS. If the UPS is unable to
 determine the state of the UPS this variable is set
 to unknown(1).
During self-test most UPSes report onBattery(3) but
 some that support it will report onBatteryTest(15).
 To determine self-test status across all UPSes, refer
 to the upsBasicStateOutputState OID.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34045','20','1.3.6.1.4.1.318.1.1.1.4.3.4.0','10382','Output current','output.current[upsHighPrecOutputCurrent]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current in amperes drawn by the load on the UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34046','20','1.3.6.1.4.1.318.1.1.1.2.2.5.0','10382','External battery packs count','battery.external_packs_count[upsAdvBatteryNumOfBattPacks]','1h','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS. If
 the UPS does not use smart cells then the agent reports
 ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34047','20','1.3.6.1.4.1.318.1.1.1.3.3.1.0','10382','Input voltage','input.voltage[upsHighPrecInputLineVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current utility line voltage in VAC.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34048','20','1.3.6.1.4.1.318.1.1.1.3.3.4.0','10382','Input frequency','input.frequency[upsHighPrecInputFrequency]','1m','7d','365d','0','0','','Hz','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current input frequency to the UPS system in Hz.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34049','20','1.3.6.1.4.1.318.1.1.1.3.2.5.0','10382','Input fail cause','input.fail[upsAdvInputLineFailCause]','1m','7d','365d','0','3','','','','',NULL,'157','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The reason for the occurrence of the last transfer to UPS
battery power.  The variable is set to:
- noTransfer(1) -- if there is no transfer yet.
- highLineVoltage(2) -- if the transfer to battery is caused
by an over voltage greater than the high transfer voltage.
- brownout(3) -- if the duration of the outage is greater than
five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- blackout(4) -- if the duration of the outage is greater than five
seconds and the line voltage is between 40% of the rated
output voltage and ground.
- smallMomentarySag(5) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and the low transfer voltage.
- deepMomentarySag(6) -- if the duration of the outage is less
than five seconds and the line voltage is between 40% of the
rated output voltage and ground.  The variable is set to
- smallMomentarySpike(7) -- if the line failure is caused by a
rate of change of input voltage less than ten volts per cycle.
- largeMomentarySpike(8) -- if the line failure is caused by
a rate of change of input voltage greater than ten volts per cycle.
- selfTest(9) -- if the UPS was commanded to do a self test.
- rateOfVoltageChange(10) -- if the failure is due to the rate of change of
the line voltage.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34053','20','1.3.6.1.4.1.318.1.1.1.2.3.4.0','10382','Battery voltage','battery.voltage[upsHighPrecBatteryActualVoltage]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The actual battery bus voltage in Volts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34054','20','1.3.6.1.4.1.318.1.1.1.2.3.2.0','10382','Battery temperature','battery.temperature[upsHighPrecBatteryTemperature]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The current internal UPS temperature in Celsius.
 Temperatures below zero read as 0.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34055','20','1.3.6.1.4.1.318.1.1.1.2.1.1.0','10382','Battery status','battery.status[upsBasicBatteryStatus]','1m','7d','365d','0','3','','','','',NULL,'158','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The status of the UPS batteries. A batteryLow(3) value
 indicates the UPS will be unable to sustain the current
 load, and its services will be lost if power is not restored.
 The amount of run time in reserve at the time of low battery
 can be configured by the upsAdvConfigLowBatteryRunTime.
 A batteryInFaultCondition(4)value indicates that a battery
 installed has an internal error condition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34056','20','1.3.6.1.4.1.318.1.1.1.2.2.3.0','10382','Battery runtime remaining','battery.runtime_remaining[upsAdvBatteryRunTimeRemaining]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The UPS battery run time remaining before battery
 exhaustion.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34057','20','1.3.6.1.4.1.318.1.1.1.2.2.4.0','10382','Battery replace indicator','battery.replace_indicator[upsAdvBatteryReplaceIndicator]','1m','7d','365d','0','3','','','','',NULL,'156','','','0','','','','','0',NULL,'MIB: PowerNet-MIB
Indicates whether the UPS batteries need replacement.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34058','20','1.3.6.1.4.1.318.1.1.1.2.1.3.0','10382','Battery last replace date','battery.last_replace_date[upsBasicBatteryLastReplaceDate]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: PowerNet-MIB
The date when the UPS system''s batteries were last replaced
 in mm/dd/yy (or yyyy) format. For Smart-UPS models, this value
 is originally set at the factory. When the UPS batteries
 are replaced, this value should be reset by the administrator.
 For Symmetra PX 250/500 this OID is read-only and is configurable in the local display only.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34059','5','','10382','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34060','20','discovery[{#EXTERNAL_PACKS},1.3.6.1.4.1.318.1.1.1.2.2.6]','10382','External bad battery packs discovery','battery.packs.bad.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the number of external defective battery packs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34061','20','discovery[{#CARTRIDGE_STATUS},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7,{#BATTERY_PACK},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.1,{#CARTRIDGE_INDEX},1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.2]','10382','External battery packs discovery','battery.packs.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34062','20','discovery[{#EXTERNAL_SENSOR1_NAME},1.3.6.1.4.1.318.1.1.25.1.2.1.3]','10382','External sensor port 1 discovery','external.sensor1.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34063','20','discovery[{#EXTERNAL_SENSOR2_NAME},1.3.6.1.4.1.318.1.1.25.1.2.2.3]','10382','External sensor port 2 discovery','external.sensor2.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'uioSensorStatusTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34064','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.2.3.1.2.1.1]','10382','Input phases discovery','input.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The input phase identifier. OID upsPhaseInputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34065','20','discovery[{#PHASEINDEX},1.3.6.1.4.1.318.1.1.1.9.3.3.1.2.1.1]','10382','Output phases discovery','output.phases.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The output phase identifier. OID upsPhaseOutputPhaseIndex.1.1','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34066','20','1.3.6.1.4.1.318.1.1.1.2.2.6.0','10382','{#SNMPINDEX}: External battery packs bad','battery.external_packs_bad[upsAdvBatteryNumOfBadBattPacks.{#SNMPINDEX}]','15m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The number of external battery packs connected to the UPS that
are defective. If the UPS does not use smart cells then the
agent reports ERROR_NO_SUCH_NAME.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34067','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.8.{#SNMPINDEX}','10382','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery estimated replace date','battery.estimated_replace_date[upsHighPrecBatteryPackCartridgeReplaceDate.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge estimated battery replace date.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34068','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.7.{#SNMPINDEX}','10382','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery pack cartridge health','battery.pack.cartridge_health[upsHighPrecBatteryPackCartridgeHealth.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34069','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.10.{#SNMPINDEX}','10382','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status','battery.pack.status[upsHighPrecBatteryPackCartridgeStatus.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery cartridge status.
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34070','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.5.{#SNMPINDEX}','10382','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery temperature','battery.temperature[upsHighPrecBatteryPackTemperature.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack temperature in Celsius.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34071','20','1.3.6.1.4.1.318.1.1.1.2.3.10.2.1.4.{#SNMPINDEX}','10382','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Serial number','system.sn[upsHighPrecBatteryPackSerialNumber.{#BATTERY_PACK}.{#CARTRIDGE_INDEX}]','15m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The battery pack serial number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34072','20','1.3.6.1.4.1.318.1.1.25.1.2.1.7.1.1','10382','{#EXTERNAL_SENSOR1_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34073','20','1.3.6.1.4.1.318.1.1.25.1.2.1.9.1.1','10382','{#EXTERNAL_SENSOR1_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.1.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34074','20','1.3.6.1.4.1.318.1.1.25.1.2.1.6.1.1','10382','{#EXTERNAL_SENSOR1_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.1.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34075','20','1.3.6.1.4.1.318.1.1.25.1.2.2.7.1.1','10382','{#EXTERNAL_SENSOR2_NAME}: Humidity sensor','external.sensor.humidity[uioSensorStatusHumidity.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current humidity reading - a relative humidity
 percentage. -1 indicates an invalid reading due to either a
 sensor that doesn''t read humidity or lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34076','20','1.3.6.1.4.1.318.1.1.25.1.2.2.9.1.1','10382','{#EXTERNAL_SENSOR2_NAME}: Sensor alarm status','external.sensor.status[uioSensorStatusAlarmStatus.2.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'155','','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The alarm status of the sensor. Possible values:
uioNormal                 (1),
uioWarning                (2),
uioCritical               (3),
sensorStatusNotApplicable (4)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34077','20','1.3.6.1.4.1.318.1.1.25.1.2.2.6.1.1','10382','{#EXTERNAL_SENSOR2_NAME}: Temperature sensor','external.sensor.temperature[uioSensorStatusTemperatureDegC.2.{#SNMPINDEX}]','1m','7d','365d','0','0','','℃','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The sensor''s current temperature reading in Celsius.
 -1 indicates an invalid reading due to lost communications.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34078','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.6.1.1.{#PHASEINDEX}','10382','{#PHASEINDEX}: Phase input current','phase.input.current[upsPhaseInputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input current in 0.1 amperes, or -0.1 if it''s
 unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34079','20','1.3.6.1.4.1.318.1.1.1.9.2.3.1.3.1.1.{#PHASEINDEX}','10382','{#PHASEINDEX}: Phase input voltage','phase.input.voltage[upsPhaseInputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The input voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34080','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.4.1.1.{#PHASEINDEX}','10382','{#PHASEINDEX}: Phase output current','phase.output.current[upsPhaseOutputCurrent.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','A','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output current in 0.1 amperes drawn
 by the load on the UPS, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34081','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.10.1.1.{#PHASEINDEX}','10382','{#PHASEINDEX}: Phase output load, %','phase.output.load.percent[upsPhaseOutputPercentLoad.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The percentage of the UPS load capacity in VA at
 redundancy @ (n + x) presently being used on this
 output phase, or -1 if it''s unsupported by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34082','20','1.3.6.1.4.1.318.1.1.1.9.3.3.1.3.1.1.{#PHASEINDEX}','10382','{#PHASEINDEX}: Phase output voltage','phase.output.voltage[upsPhaseOutputVoltage.1.1.{#PHASEINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: PowerNet-MIB
The output voltage in VAC, or -1 if it''s unsupported
 by this UPS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34083','20','1.3.6.1.2.1.1.5.0','10373','System name','system.name[sysName.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By
convention, this is the node''s fully-qualified domain name.  If the name is unknown,
the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34084','20','1.3.6.1.2.1.1.5.0','10374','System name','system.name[sysName.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By
convention, this is the node''s fully-qualified domain name.  If the name is unknown,
the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34085','20','1.3.6.1.2.1.1.5.0','10375','System name','system.name[sysName.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By
convention, this is the node''s fully-qualified domain name.  If the name is unknown,
the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34086','20','1.3.6.1.2.1.1.5.0','10376','System name','system.name[sysName.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By
convention, this is the node''s fully-qualified domain name.  If the name is unknown,
the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34087','20','1.3.6.1.2.1.1.5.0','10377','System name','system.name[sysName.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By
convention, this is the node''s fully-qualified domain name.  If the name is unknown,
the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34088','20','1.3.6.1.2.1.1.5.0','10378','System name','system.name[sysName.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By
convention, this is the node''s fully-qualified domain name.  If the name is unknown,
the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34089','20','1.3.6.1.2.1.1.5.0','10379','System name','system.name[sysName.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By
convention, this is the node''s fully-qualified domain name.  If the name is unknown,
the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34090','20','1.3.6.1.2.1.1.5.0','10371','System name','system.name[sysName.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By
convention, this is the node''s fully-qualified domain name.  If the name is unknown,
the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34091','20','1.3.6.1.2.1.1.5.0','10380','System name','system.name[sysName.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By
convention, this is the node''s fully-qualified domain name.  If the name is unknown,
the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34092','20','1.3.6.1.2.1.1.5.0','10381','System name','system.name[sysName.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By
convention, this is the node''s fully-qualified domain name.  If the name is unknown,
the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34093','20','1.3.6.1.2.1.1.5.0','10382','System name','system.name[sysName.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By
convention, this is the node''s fully-qualified domain name.  If the name is unknown,
the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34094','16','','10383','WildFly: Uptime','jmx["java.lang:type=Runtime","Uptime"]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'WildFly server uptime.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34095','16','','10383','WildFly: Launch type','jmx["jboss.as:management-root=server","launchType"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The manner in which the server process was launched. Either "DOMAIN" for a domain mode server launched by a Host Controller, "STANDALONE" for a standalone server launched from the command line, or "EMBEDDED" for a standalone server launched as an embedded part of an application running in the same virtual machine.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34096','16','','10383','WildFly: Name','jmx["jboss.as:management-root=server","name"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'For standalone mode: The name of this server. If not set, defaults to the runtime value of InetAddress.getLocalHost().getHostName().
For domain mode: The name given to this domain','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34097','16','','10383','WildFly: Process type','jmx["jboss.as:management-root=server","processType"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The type of process represented by this root resource.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34098','16','','10383','WildFly: Version','jmx["jboss.as:management-root=server","productVersion"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The version of the WildFly Core based product release','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34099','16','','10383','Servers discovery','jmx.get[beans,"jboss.as:host=master,server-config=*"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','1',NULL,'Discovery instances in domain.','0','30d','1','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34100','16','','10383','Deployments discovery','jmx.get[beans,"jboss.as.expr:deployment=*,server-group=*"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','1',NULL,'Discovery deployments metrics.','0','30d','1','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34101','16','','10383','WildFly domain: Server {#SERVER}: Autostart','jmx["{#JMXOBJ}",autoStart]','1m','7d','365d','0','3','','','','',NULL,'160','','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'Whether or not this server should be started when the Host Controller starts.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34102','16','','10383','WildFly domain: Server {#SERVER}: Server group','jmx["{#JMXOBJ}",group]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The name of a server group from the domain model.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34103','16','','10383','WildFly domain: Server {#SERVER}: Status','jmx["{#JMXOBJ}",status]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The current status of the server.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34104','16','','10383','WildFly deployment [{#DEPLOYMENT}]: Enabled','jmx["{#JMXOBJ}",enabled]','1m','7d','365d','0','3','','','','',NULL,'160','','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'Boolean indicating whether the deployment content is currently deployed in the runtime (or should be deployed in the runtime the next time the server starts.)','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34105','16','','10383','WildFly deployment [{#DEPLOYMENT}]: Managed','jmx["{#JMXOBJ}",managed]','1m','7d','365d','0','3','','','','',NULL,'160','','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'Indicates if the deployment is managed (aka uses the ContentRepository).','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34106','16','','10384','WildFly: Uptime','jmx["java.lang:type=Runtime","Uptime"]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'WildFly server uptime.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34107','16','','10384','WildFly: Transactions: Committed, rate','jmx["jboss.as:subsystem=transactions","numberOfCommittedTransactions"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The number of committed transactions','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34108','16','','10384','WildFly: Transactions: Timed out, rate','jmx["jboss.as:subsystem=transactions","numberOfTimedOutTransactions"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The number of transactions that have rolled back due to timeout.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34109','16','','10384','WildFly: Transactions: System rollbacks, rate','jmx["jboss.as:subsystem=transactions","numberOfSystemRollbacks"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The number of transactions that have been rolled back due to internal system errors.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34110','16','','10384','WildFly: Transactions: ResourceRollbacks, rate','jmx["jboss.as:subsystem=transactions","numberOfResourceRollbacks"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The number of transactions that rolled back due to resource (participant) failure.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34111','16','','10384','WildFly: Transactions: Nested, rate','jmx["jboss.as:subsystem=transactions","numberOfNestedTransactions"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The total number of nested (sub) transactions created.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34112','16','','10384','WildFly: Transactions: Current','jmx["jboss.as:subsystem=transactions","numberOfInflightTransactions"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The number of transactions that have begun but not yet terminated.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34113','16','','10384','WildFly: Transactions: Heuristics, rate','jmx["jboss.as:subsystem=transactions","numberOfHeuristics"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The number of transactions which have terminated with heuristic outcomes.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34114','16','','10384','WildFly: Transactions: Application rollbacks, rate','jmx["jboss.as:subsystem=transactions","numberOfApplicationRollbacks"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The number of transactions that have been rolled back by application request. This includes those that timeout, since the timeout behavior is considered an attribute of the application configuration.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34115','16','','10384','WildFly: Launch type','jmx["jboss.as:management-root=server","launchType"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The manner in which the server process was launched. Either "DOMAIN" for a domain mode server launched by a Host Controller, "STANDALONE" for a standalone server launched from the command line, or "EMBEDDED" for a standalone server launched as an embedded part of an application running in the same virtual machine.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34116','16','','10384','WildFly: Transactions: Aborted, rate','jmx["jboss.as:subsystem=transactions","numberOfAbortedTransactions"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The number of aborted (i.e. rolledback) transactions per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34117','16','','10384','WildFly: Server controller state','jmx["jboss.as:management-root=server","serverState"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The current state of the server controller; either STARTING, RUNNING, RESTART_REQUIRED, RELOAD_REQUIRED or STOPPING.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34118','16','','10384','WildFly: Runtime configuration state','jmx["jboss.as:management-root=server","runtimeConfigurationState"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The current persistent configuration state, one of starting, ok, reload-required, restart-required, stopping or stopped.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34119','16','','10384','WildFly: Version','jmx["jboss.as:management-root=server","productVersion"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The version of the WildFly Core based product release','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34120','16','','10384','WildFly: Process type','jmx["jboss.as:management-root=server","processType"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The type of process represented by this root resource.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34121','16','','10384','WildFly: Name','jmx["jboss.as:management-root=server","name"]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'For standalone mode: The name of this server. If not set, defaults to the runtime value of InetAddress.getLocalHost().getHostName().
For domain mode: The name given to this domain','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34122','16','','10384','WildFly: Transactions: Total, rate','jmx["jboss.as:subsystem=transactions","numberOfTransactions"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','0',NULL,'The total number of transactions (top-level and nested) created per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34123','16','','10384','JDBC metrics discovery','jmx.get[beans,"jboss.as:subsystem=datasources,data-source=*,statistics=jdbc"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34124','16','','10384','Pools metrics discovery','jmx.get[beans,"jboss.as:subsystem=datasources,data-source=*,statistics=pool"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34125','16','','10384','Undertow metrics discovery','jmx.get[beans,"jboss.as:subsystem=undertow,server=*,http-listener=*"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34126','16','','10384','Deployments discovery','jmx.get[beans,"jboss.as.expr:deployment=*"]','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','1',NULL,'Discovery deployments metrics.','0','30d','1','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34127','16','','10384','WildFly {#JMX_DATA_SOURCE}: Cache access, rate','jmx["{#JMXOBJ}",PreparedStatementCacheAccessCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of times that the statement cache was accessed  per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34128','16','','10384','WildFly {#JMX_DATA_SOURCE}: Cache add, rate','jmx["{#JMXOBJ}",PreparedStatementCacheAddCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of statements added to the statement cache per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34129','16','','10384','WildFly {#JMX_DATA_SOURCE}: Cache current size','jmx["{#JMXOBJ}",PreparedStatementCacheCurrentSize]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of prepared and callable statements currently cached in the statement cache.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34130','16','','10384','WildFly {#JMX_DATA_SOURCE}: Cache delete, rate','jmx["{#JMXOBJ}",PreparedStatementCacheDeleteCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of statements discarded from the cache per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34131','16','','10384','WildFly {#JMX_DATA_SOURCE}: Cache hit, rate','jmx["{#JMXOBJ}",PreparedStatementCacheHitCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of times that statements from the cache were used per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34132','16','','10384','WildFly {#JMX_DATA_SOURCE}: Cache miss, rate','jmx["{#JMXOBJ}",PreparedStatementCacheMissCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of times that a statement request could not be satisfied with a statement from the cache per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34134','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Active','jmx["{#JMXOBJ}",ActiveCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of open connections.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34135','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: Commit time, avg','jmx["{#JMXOBJ}",XACommitAverageTime]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The average time for a XAResource commit invocation.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34136','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: Start time, avg','jmx["{#JMXOBJ}",XAStartAverageTime]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The average time for a XAResource start invocation.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34137','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: Rollback, rate','jmx["{#JMXOBJ}",XARollbackCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of XAResource rollback invocations per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34138','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: Rollback time, avg','jmx["{#JMXOBJ}",XARollbackAverageTime]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The average time for a XAResource rollback invocation.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34139','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: Recover, rate','jmx["{#JMXOBJ}",XARecoverCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of XAResource recover invocationsper second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34140','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: Recover time, avg','jmx["{#JMXOBJ}",XARecoverAverageTime]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The average time for a XAResource recover invocation.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34141','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: Prepare, rate','jmx["{#JMXOBJ}",XAPrepareCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of XAResource prepare invocations per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34142','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: Prepare time, avg','jmx["{#JMXOBJ}",XAPrepareAverageTime]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The average time for a XAResource prepare invocation.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34143','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: Forget, rate','jmx["{#JMXOBJ}",XAForgetCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of XAResource forget invocations per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34144','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: Forget time, avg','jmx["{#JMXOBJ}",XAForgetAverageTime]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The average time for a XAResource forget invocation.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34145','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: End, rate','jmx["{#JMXOBJ}",XAEndCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of XAResource end invocations per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34146','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: End time, avg','jmx["{#JMXOBJ}",XAEndAverageTime]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The average time for a XAResource end invocation.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34147','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: Commit, rate','jmx["{#JMXOBJ}",XACommitCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of XAResource commit invocations per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34148','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Wait','jmx["{#JMXOBJ}",WaitCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of requests that had to wait to obtain a physical connection.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34149','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Available','jmx["{#JMXOBJ}",AvailableCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The available count.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34150','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Timed out, rate','jmx["{#JMXOBJ}",TimedOut]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The timed out connections per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34151','16','','10384','WildFly {#JMX_DATA_SOURCE}: Statistics enabled','jmx["{#JMXOBJ}",statisticsEnabled]','1m','7d','365d','0','0','','','','',NULL,'160','','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'Define whether runtime statistics are enabled or not.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34152','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Used, max','jmx["{#JMXOBJ}",MaxUsedCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The maximum number of connections used.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34153','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: In use','jmx["{#JMXOBJ}",InUseCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of physical connections currently in use.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34154','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Idle','jmx["{#JMXOBJ}",IdleCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of physical connections currently idle.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34155','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Destroyed, rate','jmx["{#JMXOBJ}",DestroyedCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The destroyed count.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34156','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Created, rate','jmx["{#JMXOBJ}",CreatedCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The created per second','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34157','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Blocking failure, rate','jmx["{#JMXOBJ}",BlockingFailureCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of failures trying to obtain a physical connection per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34158','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Usage time, avg','jmx["{#JMXOBJ}",AverageUsageTime]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The average time spent using a physical connection','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34159','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Pool time, avg','jmx["{#JMXOBJ}",AveragePoolTime]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The average time for a physical connection spent in the pool.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34160','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Get time, avg','jmx["{#JMXOBJ}",AverageGetTime]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The average time spent obtaining a physical connection.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34161','16','','10384','WildFly {#JMX_DATA_SOURCE}: Connections: Creating time, avg','jmx["{#JMXOBJ}",AverageCreationTime]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The average time spent creating a physical connection.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34162','16','','10384','WildFly {#JMX_DATA_SOURCE}: Blocking time, avg','jmx["{#JMXOBJ}",AverageBlockingTime]','1m','7d','365d','0','0','','s','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'Average Blocking Time for pool.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34163','16','','10384','WildFly {#JMX_DATA_SOURCE}: XA: Start rate','jmx["{#JMXOBJ}",XAStartCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of XAResource start invocations per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34164','16','','10384','WildFly listener {#HTTP_LISTENER}: Bytes received, rate','jmx["{#JMXOBJ}",bytesReceived]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of bytes that have been received by this listener per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34165','16','','10384','WildFly listener {#HTTP_LISTENER}: Bytes sent, rate','jmx["{#JMXOBJ}",bytesSent]','1m','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of bytes that have been sent out on this listener per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34166','16','','10384','WildFly listener {#HTTP_LISTENER}: Errors, rate','jmx["{#JMXOBJ}",errorCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of 500 responses that have been sent by this listener per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34167','16','','10384','WildFly listener {#HTTP_LISTENER}: Requests, rate','jmx["{#JMXOBJ}",requestCount]','1m','7d','365d','0','0','','Rps','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The number of requests this listener has served per second.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34168','16','','10384','WildFly deployment [{#DEPLOYMENT}]: Enabled','jmx["{#JMXOBJ}",enabled]','1m','7d','365d','0','3','','','','',NULL,'160','','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'Boolean indicating whether the deployment content is currently deployed in the runtime (or should be deployed in the runtime the next time the server starts.)','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34169','16','','10384','WildFly deployment [{#DEPLOYMENT}]: Enabled time','jmx["{#JMXOBJ}",enabledTime]','1m','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'Indicates if the deployment is managed (aka uses the ContentRepository).','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34170','16','','10384','WildFly deployment [{#DEPLOYMENT}]: Managed','jmx["{#JMXOBJ}",managed]','1m','7d','365d','0','3','','','','',NULL,'160','','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'Indicates if the deployment is managed (aka uses the ContentRepository).','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34171','16','','10384','WildFly deployment [{#DEPLOYMENT}]: Persistent','jmx["{#JMXOBJ}",persistent]','1m','7d','365d','0','3','','','','',NULL,'160','','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'Indicates if the deployment is managed (aka uses the ContentRepository).','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34172','16','','10384','WildFly deployment [{#DEPLOYMENT}]: Status','jmx["{#JMXOBJ}",status]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$WILDFLY.USER}','{$WILDFLY.PASSWORD}','','','2',NULL,'The current runtime status of a deployment. 
Possible status modes are OK, FAILED, and STOPPED. 
FAILED indicates a dependency is missing or a service could not start. 
STOPPED indicates that the deployment was not enabled or was manually stopped.','0','30d','0','service:jmx:{$WILDFLY.JMX.PROTOCOL}://{HOST.CONN}:{HOST.PORT}',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34173','11','','10327','MSSQL: Get job status','db.odbc.get[get_job_status,"{$MSSQL.DSN}"]','10m','0','0','0','4','','','','',NULL,NULL,'SELECT sj.name AS JobName
, sj.enabled AS Enabled
, sjs.last_run_outcome AS RunStatus
, sjs.last_outcome_message AS LastRunStatusMessage
, sjs.last_run_duration/10000*3600 + sjs.last_run_duration/100%100*60 + sjs.last_run_duration%100 AS RunDuration
, CASE sjs.last_run_date
    WHEN 0 THEN NULL
    ELSE msdb.dbo.agent_datetime(sjs.last_run_date,sjs.last_run_time)
    END AS LastRunDateTime
, sja.next_scheduled_run_date AS NextRunDateTime
FROM msdb..sysjobs AS sj
LEFT JOIN msdb..sysjobservers AS sjs ON sj.job_id = sjs.job_id
LEFT JOIN ( SELECT job.job_id,
    max(act.session_id) AS s_id,
    max(act.next_scheduled_run_date) AS next_scheduled_run_date
    FROM msdb..sysjobs AS job
    LEFT JOIN msdb..sysjobactivity AS act ON act.job_id = job.job_id
    GROUP BY job.job_id ) AS sja ON sja.job_id = sj.job_id
WHERE Enabled = 1','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','0',NULL,'The item gets sql agent job status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34174','11','','10327','MSSQL: Get last backup','db.odbc.get[get_last_backup,"{$MSSQL.DSN}"]','10m','0','0','0','4','','','','',NULL,NULL,'SELECT bs.database_name as dbname,[type], DATEDIFF(SECOND, bs.backup_finish_date, getdate()) as timesincelastbackup, (DATEDIFF(SECOND, bs.backup_start_date, bs.backup_finish_date)) as duration
FROM msdb.dbo.backupset as bs WHERE bs.database_name not in (
SELECT
AGDatabases.database_name AS Databasename
FROM sys.dm_hadr_availability_group_states States
INNER JOIN master.sys.availability_groups Groups ON States.group_id = Groups.group_id
INNER JOIN sys.availability_databases_cluster AGDatabases ON Groups.group_id = AGDatabases.group_id
WHERE primary_replica != @@Servername OR primary_replica is NULL
)
GROUP BY bs.database_name, backup_finish_date, [type], backup_start_date
HAVING backup_finish_date = (SELECT MAX(backup_finish_date) from msdb.dbo.backupset WHERE database_name = bs.database_name AND bs.type = [type])
ORDER BY bs.database_name','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','0',NULL,'The item gets information about backup processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34175','11','','10327','Job discovery','db.odbc.discovery[jobname,"{$MSSQL.DSN}"]','1h','90d','0','0','4','','','','',NULL,NULL,'SELECT name AS jobname FROM msdb..sysjobs WHERE enabled = 1','','0','{$MSSQL.USER}','{$MSSQL.PASSWORD}','','','1',NULL,'Scanning jobs in DBMS.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34189','5','','10047','Zabbix server: Version','zabbix[version]','1m','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of Zabbix server.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34207','5','','10385','ZYXEL AAM1212-51 / IES-612: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34208','20','.1.3.6.1.2.1.1.4.0','10385','ZYXEL AAM1212-51 / IES-612: Contact','zyxel.aam1212.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34209','20','.1.3.6.1.4.1.890.1.5.13.1.1.3.1.4.0.0','10385','ZYXEL AAM1212-51 / IES-612: ZyNOS F/W Version','zyxel.aam1212.fwversion','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-IESCOMMON-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34210','20','.1.3.6.1.2.1.1.6.0','10385','ZYXEL AAM1212-51 / IES-612: Location','zyxel.aam1212.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34211','20','.1.3.6.1.2.1.2.2.1.6.1','10385','ZYXEL AAM1212-51 / IES-612: MAC address','zyxel.aam1212.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34212','20','.1.3.6.1.2.1.1.1.0','10385','ZYXEL AAM1212-51 / IES-612: Hardware model name','zyxel.aam1212.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34213','20','.1.3.6.1.2.1.1.5.0','10385','ZYXEL AAM1212-51 / IES-612: Host name','zyxel.aam1212.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34214','20','.1.3.6.1.4.1.890.1.5.13.1.1.2.1.3.0','10385','ZYXEL AAM1212-51 / IES-612: Hardware serial number','zyxel.aam1212.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-IESCOMMON-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34215','20','.1.3.6.1.4.1.890.1.5.13.1.1.3.1.8.0.0','10385','ZYXEL AAM1212-51 / IES-612: Alarm status','zyxel.aam1212.slot.alarm','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-IESCOMMON-MIB
This variable indicates the alarm status of the module.
It is a bit map represented a sum, therefore, it can represent
multiple defects simultaneously. The moduleNoDefect should be set
if and only if no other flag is set.
The various bit positions are:
1   moduleNoDefect
2   moduleOverHeat
3   moduleFanRpmLow
4   moduleVoltageLow
5   moduleThermalSensorFailure
6   modulePullOut
7   powerDC48VAFailure
8   powerDC48VBFailure
9   extAlarmInputTrigger
10   moduleDown
11   mscSwitchOverOK
12   networkTopologyChange
13   macSpoof
14   cpuHigh
15   memoryUsageHigh
16   packetBufferUsageHigh
17   loopguardOccurence','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34216','20','.1.3.6.1.2.1.1.3.0','10385','ZYXEL AAM1212-51 / IES-612: Uptime','zyxel.aam1212.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34217','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.2.2.1.2,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8]','10385','ADSL interface discovery','zyxel.aam1212.net.adsl.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34218','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.2.2.1.2,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8]','10385','Ethernet interface discovery','zyxel.aam1212.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34219','20','discovery[{#ZYXEL.TEMP.ID}, .1.3.6.1.4.1.890.1.5.13.1.2.3.1.1,{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.13.1.2.3.1.5]','10385','Temperature discovery','zyxel.aam1212.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34220','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.13.1.2.2.1.6,{#ZYXEL.VOLT.NOMINAL}, .1.3.6.1.4.1.890.1.5.13.1.2.2.1.5]','10385','Voltage discovery','zyxel.aam1212.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34221','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: Administrative status','zyxel.aam1212.net.adsl.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'166','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34222','20','.1.3.6.1.2.1.10.94.1.1.2.1.5.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: ATUC attenuation','zyxel.aam1212.net.adsl.atuc.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL AAM1212-51 / IES-612, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34223','20','.1.3.6.1.2.1.10.94.1.1.2.1.7.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: ATUC output power','zyxel.aam1212.net.adsl.atuc.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL AAM1212-51 / IES-612, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34224','20','.1.3.6.1.2.1.10.94.1.1.2.1.4.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: ATUC noise margin','zyxel.aam1212.net.adsl.atuc.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL AAM1212-51 / IES-612, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34225','20','.1.3.6.1.2.1.10.94.1.1.3.1.5.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: ATUR attenuation','zyxel.aam1212.net.adsl.atur.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34226','20','.1.3.6.1.2.1.10.94.1.1.3.1.7.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: ATUR output power','zyxel.aam1212.net.adsl.atur.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34227','20','.1.3.6.1.2.1.10.94.1.1.3.1.4.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: ATUR noise margin','zyxel.aam1212.net.adsl.atur.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34228','20','.1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: Incoming traffic','zyxel.aam1212.net.adsl.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34229','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: Interface name','zyxel.aam1212.net.adsl.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34230','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: Operational status','zyxel.aam1212.net.adsl.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'167','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34231','20','.1.3.6.1.2.1.2.2.1.16.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: Outgoing traffic','zyxel.aam1212.net.adsl.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34232','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#ZYXEL.IF.NAME}: Administrative status','zyxel.aam1212.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'166','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34233','20','.1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#ZYXEL.IF.NAME}: Incoming traffic','zyxel.aam1212.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34234','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#ZYXEL.IF.NAME}: Interface name','zyxel.aam1212.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34235','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#ZYXEL.IF.NAME}: Operational status','zyxel.aam1212.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'167','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34236','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Port {#ZYXEL.IF.NAME}: Outgoing traffic','zyxel.aam1212.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34237','20','.1.3.6.1.4.1.890.1.5.13.1.2.3.1.2.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.aam1212.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IESCOMMON-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34238','20','.1.3.6.1.4.1.890.1.5.13.1.2.2.1.2.{#SNMPINDEX}','10385','ZYXEL AAM1212-51 / IES-612: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.aam1212.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IESCOMMON-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34239','5','','10386','ZYXEL ES3500-8PD: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34240','20','.1.3.6.1.2.1.1.4.0','10386','ZYXEL ES3500-8PD: Contact','zyxel.3500_8pd.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34241','20','.1.3.6.1.4.1.890.1.5.8.72.12.7.0','10386','ZYXEL ES3500-8PD: CPU utilization','zyxel.3500_8pd.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34242','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.72.1]','10386','ZYXEL ES3500-8PD: ZyNOS F/W Version','zyxel.3500_8pd.fwversion','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES3500-8PD-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34243','20','.1.3.6.1.2.1.1.6.0','10386','ZYXEL ES3500-8PD: Location','zyxel.3500_8pd.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34244','20','.1.3.6.1.2.1.2.2.1.6.1','10386','ZYXEL ES3500-8PD: MAC address','zyxel.3500_8pd.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34245','20','.1.3.6.1.2.1.1.1.0','10386','ZYXEL ES3500-8PD: Hardware model name','zyxel.3500_8pd.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34246','20','.1.3.6.1.2.1.1.5.0','10386','ZYXEL ES3500-8PD: Host name','zyxel.3500_8pd.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34247','20','.1.3.6.1.4.1.890.1.5.8.72.1.10.0','10386','ZYXEL ES3500-8PD: Hardware serial number','zyxel.3500_8pd.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34248','20','.1.3.6.1.2.1.1.3.0','10386','ZYXEL ES3500-8PD: Uptime','zyxel.3500_8pd.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34249','20','discovery[{#ZYXEL.MEMORY.NAME},.1.3.6.1.4.1.890.1.5.8.72.124.1.1.2]','10386','Memory pool discovery','zyxel.3500_8pd.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34250','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.72.24.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.72.24.1.1.5]','10386','Interface discovery','zyxel.3500_8pd.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34251','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.72.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.72.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.72.117.2.1.8]','10386','SFP with DDM discovery','zyxel.3500_8pd.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34252','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.72.117.1.1.2]','10386','SFP without DDM discovery','zyxel.3500_8pd.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34253','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.72.9.2.1.5]','10386','Temperature discovery','zyxel.3500_8pd.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34254','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.72.9.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.72.9.3.1.5]','10386','Voltage discovery','zyxel.3500_8pd.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34255','20','.1.3.6.1.4.1.890.1.5.8.72.124.1.1.5.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Memory "{#ZYXEL.MEMORY.NAME}" utilization','zyxel.3500_8pd.memory[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Utilization of memory pool in %.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34256','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Administrative status','zyxel.3500_8pd.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'170','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34257','20','.1.3.6.1.4.1.890.1.5.8.72.24.1.1.3.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Interface description','zyxel.3500_8pd.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  ZYXEL-ES3500-8PD-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34258','15','','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3500_8pd.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3500_8pd.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34259','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3500_8pd.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34260','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3500_8pd.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34261','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3500_8pd.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34262','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3500_8pd.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34263','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Operational status','zyxel.3500_8pd.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'171','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34264','20','.1.3.6.1.4.1.890.1.5.8.72.24.1.1.5.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Link type','zyxel.3500_8pd.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'169','','','0','','','','','2',NULL,'MIB:  ZYXEL-ES3500-8PD-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34265','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Interface name','zyxel.3500_8pd.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34266','15','','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Incoming utilization','zyxel.3500_8pd.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3500_8pd.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34267','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3500_8pd.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34268','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Incoming traffic','zyxel.3500_8pd.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34269','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3500_8pd.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34270','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3500_8pd.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34271','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Link speed','zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34272','20','.1.3.6.1.4.1.890.1.5.8.72.24.1.1.1.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Speed Duplex','zyxel.3500_8pd.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'168','','','0','','','','','2',NULL,'MIB:  ZYXEL-ES3500-8PD-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34273','20','.1.3.6.1.4.1.890.1.5.8.72.117.2.1.7.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3500_8pd.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34274','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.7.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Date code','zyxel.3500_8pd.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34275','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.4.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Part number','zyxel.3500_8pd.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34276','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.6.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Revision','zyxel.3500_8pd.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34277','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.5.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Serial number','zyxel.3500_8pd.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34278','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.2.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Status','zyxel.3500_8pd.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'172','','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34279','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.8.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Transceiver','zyxel.3500_8pd.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34280','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.3.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Vendor','zyxel.3500_8pd.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34281','20','.1.3.6.1.4.1.890.1.5.8.72.9.2.1.2.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.3500_8pd.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34282','20','.1.3.6.1.4.1.890.1.5.8.72.9.3.1.2.{#SNMPINDEX}','10386','ZYXEL ES3500-8PD: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.3500_8pd.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34283','5','','10387','ZYXEL GS-4012F: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34284','20','.1.3.6.1.2.1.1.4.0','10387','ZYXEL GS-4012F: Contact','zyxel.4012f.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34285','20','.1.3.6.1.4.1.890.1.5.8.20.12.7.0','10387','ZYXEL GS-4012F: CPU utilization','zyxel.4012f.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-GS4012F-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34286','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.20.1]','10387','ZYXEL GS-4012F: ZyNOS F/W Version','zyxel.4012f.fwversion','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-GS4012F-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34287','20','.1.3.6.1.2.1.1.6.0','10387','ZYXEL GS-4012F: Location','zyxel.4012f.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34288','20','.1.3.6.1.2.1.2.2.1.6.1','10387','ZYXEL GS-4012F: MAC address','zyxel.4012f.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34289','20','.1.3.6.1.2.1.1.1.0','10387','ZYXEL GS-4012F: Hardware model name','zyxel.4012f.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34290','20','.1.3.6.1.2.1.1.5.0','10387','ZYXEL GS-4012F: Host name','zyxel.4012f.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34291','20','.1.3.6.1.4.1.890.1.5.8.20.1.10.0','10387','ZYXEL GS-4012F: Hardware serial number','zyxel.4012f.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-GS4012F-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34292','20','.1.3.6.1.2.1.1.3.0','10387','ZYXEL GS-4012F: Uptime','zyxel.4012f.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34293','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.20.9.1.1.5]','10387','Fan discovery','zyxel.4012f.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34294','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.20.23.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.20.23.1.1.5]','10387','Interface discovery','zyxel.4012f.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34295','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.20.9.2.1.5]','10387','Temperature discovery','zyxel.4012f.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34296','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.20.9.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.20.9.3.1.5]','10387','Voltage discovery','zyxel.4012f.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34297','20','.1.3.6.1.4.1.890.1.5.8.20.9.1.1.2.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Fan #{#SNMPINDEX}','zyxel.4012f.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-GS4012F-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34298','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Administrative status','zyxel.4012f.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'175','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34299','20','.1.3.6.1.4.1.890.1.5.8.20.23.1.1.3.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Interface description','zyxel.4012f.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-GS4012F-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34300','15','','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Outgoing utilization','zyxel.4012f.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.4012f.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34301','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.4012f.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34302','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Outgoing traffic','zyxel.4012f.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34303','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.4012f.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34304','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.4012f.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34305','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Operational status','zyxel.4012f.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'176','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34306','20','.1.3.6.1.4.1.890.1.5.8.20.23.1.1.5.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Link type','zyxel.4012f.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'174','','','0','','','','','2',NULL,'MIB: ZYXEL-GS4012F-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34307','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Interface name','zyxel.4012f.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34308','15','','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Incoming utilization','zyxel.4012f.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.4012f.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34309','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.4012f.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34310','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Incoming traffic','zyxel.4012f.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34311','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.4012f.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34312','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.4012f.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34313','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Link speed','zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34314','20','.1.3.6.1.4.1.890.1.5.8.20.23.1.1.1.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Port {#SNMPINDEX}: Speed Duplex','zyxel.4012f.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'173','','','0','','','','','2',NULL,'MIB: ZYXEL-GS4012F-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34315','20','.1.3.6.1.4.1.890.1.5.8.20.9.2.1.2.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.4012f.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-GS4012F-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34316','20','.1.3.6.1.4.1.890.1.5.8.20.9.3.1.2.{#SNMPINDEX}','10387','ZYXEL GS-4012F: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.4012f.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-GS4012F-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34317','5','','10388','ZYXEL IES-500x: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34318','20','.1.3.6.1.2.1.1.4.0','10388','ZYXEL IES-500x: Contact','zyxel.ies500x.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34319','20','.1.3.6.1.2.1.1.6.0','10388','ZYXEL IES-500x: Location','zyxel.ies500x.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34320','20','.1.3.6.1.2.1.2.2.1.6.1','10388','ZYXEL IES-500x: MAC address','zyxel.ies500x.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34321','20','.1.3.6.1.2.1.1.1.0','10388','ZYXEL IES-500x: Hardware model name','zyxel.ies500x.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34322','20','.1.3.6.1.2.1.1.5.0','10388','ZYXEL IES-500x: Host name','zyxel.ies500x.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34323','20','.1.3.6.1.2.1.1.3.0','10388','ZYXEL IES-500x: Uptime','zyxel.ies500x.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34324','20','discovery[{#ZYXEL.BUFFERHIGHTHRESH}, .1.3.6.1.4.1.890.1.5.13.5.11.3.5.1.4]','10388','Packet buffer discovery','zyxel.ies500x.buffer.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table that contains packet buffer usage information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34325','20','discovery[{#ZYXEL.CPU.THRESH.HIGH}, .1.3.6.1.4.1.890.1.5.13.5.11.3.4.1.4]','10388','CPU discovery','zyxel.ies500x.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table that contains CPU utilization information.
This table is supported by R1.03 and later versions.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34326','20','discovery[{#ZYXEL.FANRPM.THRESH.HIGH}, .1.3.6.1.4.1.890.1.5.13.5.11.3.1.1.7,{#ZYXEL.FANRPM.THRESH.LOW}, .1.3.6.1.4.1.890.1.5.13.5.11.3.1.1.5]','10388','Fan discovery','zyxel.ies500x.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34327','20','discovery[{#ZYXEL.MEMORYHIGHTHRESH},  .1.3.6.1.4.1.890.1.5.13.5.11.3.6.1.4]','10388','Memory discovery','zyxel.ies500x.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table that contains memory usage information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34328','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.31.1.1.1.1,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8,{#ZYXEL.IF.DESC},.1.3.6.1.2.1.31.1.1.1.18]','10388','ADSL interface discovery','zyxel.ies500x.net.adsl.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34329','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.31.1.1.1.1,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8,{#ZYXEL.IF.DESC},.1.3.6.1.2.1.31.1.1.1.18]','10388','Ethernet interface discovery','zyxel.ies500x.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34330','20','discovery[{#ZYXEL.SLOTSTATUS},.1.3.6.1.4.1.890.1.5.13.5.6.3.1.7,{#ZYXEL.SLOT.ID},.1.3.6.1.4.1.890.1.5.13.5.6.3.1.1]','10388','Slot discovery','zyxel.ies500x.slot.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table which contains the slot information in a chassis.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34331','20','discovery[{#ZYXEL.TEMP.THRESH.LOW},.1.3.6.1.4.1.890.1.5.13.5.11.3.3.1.7,{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.13.5.11.3.3.1.5]','10388','Temperature discovery','zyxel.ies500x.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34332','20','discovery[{#ZYXEL.VOLT.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.8,{#ZYXEL.VOLT.THRESH.LOW}, .1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.5]','10388','Voltage discovery','zyxel.ies500x.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34333','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.5.1.2.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Packet buffer utilization','zyxel.ies500x.buffer[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The packet buffer usage in the past 60 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34334','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.4.1.2.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: CPU utilization','zyxel.ies500x.cpu[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The CPU utilization in the past 60 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34335','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.1.1.2.{#SNMPINDEX}','10388','ZYXEL IES-500x: Fan #{#SNMPINDEX}','zyxel.ies500x.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34336','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.6.1.2.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Memory utilization','zyxel.ies500x.memory[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The memory usage in the past 60 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34337','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Administrative status','zyxel.ies500x.net.adsl.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'182','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34338','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming traffic','zyxel.ies500x.net.adsl.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34339','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing traffic','zyxel.ies500x.net.adsl.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34340','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing multicast packages','zyxel.ies500x.net.adsl.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34341','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing broadcast packages','zyxel.ies500x.net.adsl.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34342','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Operational status','zyxel.ies500x.net.adsl.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'183','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34343','20','.1.3.6.1.2.1.31.1.1.1.1.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Interface name','zyxel.ies500x.net.adsl.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34344','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming unicast packages','zyxel.ies500x.net.adsl.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34345','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming multicast packages','zyxel.ies500x.net.adsl.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34346','20','.1.3.6.1.2.1.10.94.1.1.2.1.5.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUC attenuation','zyxel.ies500x.net.adsl.atuc.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES-500x, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34347','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming broadcast packages','zyxel.ies500x.net.adsl.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34348','20','.1.3.6.1.2.1.31.1.1.1.18.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Interface description','zyxel.ies500x.net.adsl.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34349','20','.1.3.6.1.2.1.10.94.1.1.3.1.4.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUR noise margin','zyxel.ies500x.net.adsl.atur.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34350','20','.1.3.6.1.2.1.10.94.1.1.3.1.7.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUR output power','zyxel.ies500x.net.adsl.atur.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34351','20','.1.3.6.1.2.1.10.94.1.1.3.1.5.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUR attenuation','zyxel.ies500x.net.adsl.atur.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34352','20','.1.3.6.1.2.1.10.94.1.1.2.1.4.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUC noise margin','zyxel.ies500x.net.adsl.atuc.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES-500x, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34353','20','.1.3.6.1.2.1.10.94.1.1.2.1.7.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUC output power','zyxel.ies500x.net.adsl.atuc.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES-500x, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34354','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing unicast packages','zyxel.ies500x.net.adsl.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34355','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Administrative status','zyxel.ies500x.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'182','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34356','20','.1.3.6.1.2.1.31.1.1.1.18.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Interface description','zyxel.ies500x.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34357','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Link speed','zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34358','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.ies500x.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34359','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.ies500x.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34360','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Incoming traffic','zyxel.ies500x.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34361','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.ies500x.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34362','15','','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Incoming utilization','zyxel.ies500x.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.ies500x.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]) <> 0) /
( last(zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34363','20','.1.3.6.1.2.1.31.1.1.1.1.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Interface name','zyxel.ies500x.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34364','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Operational status','zyxel.ies500x.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'183','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34365','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.ies500x.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34366','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.ies500x.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34367','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Outgoing traffic','zyxel.ies500x.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34368','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.ies500x.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34369','15','','10388','ZYXEL IES-500x: Port {#SNMPINDEX}: Outgoing utilization','zyxel.ies500x.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.ies500x.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]) <> 0) /
( last(zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34370','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.8.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Alarm status','zyxel.ies500x.slot.alarm[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
This variable indicates the alarm status of the module.
It is a bit map represented a sum, therefore, it can represent
multiple defects simultaneously. The moduleNoDefect should be set
if and only if no other flag is set.
The various bit positions are:
1   moduleNoDefect
2   moduleOverHeat
3   moduleFanRpmLow
4   moduleVoltageLow
5   moduleThermalSensorFailure
6   modulePullOut
7   powerDC48VAFailure
8   powerDC48VBFailure
9   extAlarmInputTrigger
10   moduleDown
11   mscSwitchOverOK
12   networkTopologyChange
13   macSpoof
14   cpuHigh
15   memoryUsageHigh
16   packetBufferUsageHigh
17   loopguardOccurence','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34371','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.6.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: DSL modem code version','zyxel.ies500x.slot.cv.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The DSL modem code version of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34372','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.3.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Description','zyxel.ies500x.slot.desc[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The descriptions of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34373','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.5.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Driver version','zyxel.ies500x.slot.dv.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The DSL driver of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34374','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.4.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Firmware version','zyxel.ies500x.slot.fw.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The firmware version of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34375','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.10.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Hardware version','zyxel.ies500x.slot.hw.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The hardware version of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34376','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.12.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: MAC address 1','zyxel.ies500x.slot.mac1[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The MAC Address of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34377','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.13.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: MAC address 2','zyxel.ies500x.slot.mac2[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The MAC Address of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34378','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.9.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Serial number','zyxel.ies500x.slot.serial[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The serial number of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34379','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.7.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Status','zyxel.ies500x.slot.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'178','','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The module state of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34380','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.2.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Type','zyxel.ies500x.slot.type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'179','','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
Card type of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34381','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.11.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Uptime','zyxel.ies500x.slot.uptime[{#SNMPINDEX}]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The time (in seconds) since the plug-in card was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34382','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.3.1.2.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.ies500x.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34383','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.2.{#SNMPINDEX}','10388','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.ies500x.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34384','5','','10389','ZYXEL IES-6000: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34385','20','.1.3.6.1.2.1.1.4.0','10389','ZYXEL IES-6000: Contact','zyxel.ies6000.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34386','20','.1.3.6.1.2.1.1.6.0','10389','ZYXEL IES-6000: Location','zyxel.ies6000.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34387','20','.1.3.6.1.2.1.2.2.1.6.1','10389','ZYXEL IES-6000: MAC address','zyxel.ies6000.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34388','20','.1.3.6.1.2.1.1.1.0','10389','ZYXEL IES-6000: Hardware model name','zyxel.ies6000.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34389','20','.1.3.6.1.2.1.1.5.0','10389','ZYXEL IES-6000: Host name','zyxel.ies6000.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34390','20','.1.3.6.1.2.1.1.3.0','10389','ZYXEL IES-6000: Uptime','zyxel.ies6000.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34391','20','discovery[{#ZYXEL.BUFFERHIGHTHRESH}, .1.3.6.1.4.1.890.1.5.13.5.11.3.5.1.4]','10389','Packet buffer discovery','zyxel.ies6000.buffer.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table that contains packet buffer usage information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34392','20','discovery[{#ZYXEL.CPU.THRESH.HIGH}, .1.3.6.1.4.1.890.1.5.13.5.11.3.4.1.4]','10389','CPU discovery','zyxel.ies6000.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table that contains CPU utilization information.
This table is supported by R1.03 and later versions.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34393','20','discovery[{#ZYXEL.FANRPM.THRESH.HIGH}, .1.3.6.1.4.1.890.1.5.13.5.11.3.1.1.7,{#ZYXEL.FANRPM.THRESH.LOW}, .1.3.6.1.4.1.890.1.5.13.5.11.3.1.1.5]','10389','Fan discovery','zyxel.ies6000.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34394','20','discovery[{#ZYXEL.MEMORYHIGHTHRESH},  .1.3.6.1.4.1.890.1.5.13.5.11.3.6.1.4]','10389','Memory discovery','zyxel.ies6000.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table that contains memory usage information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34395','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.31.1.1.1.1,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8,{#ZYXEL.IF.DESC},.1.3.6.1.2.1.31.1.1.1.18]','10389','ADSL interface discovery','zyxel.ies6000.net.adsl.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34396','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.31.1.1.1.1,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8,{#ZYXEL.IF.DESC},.1.3.6.1.2.1.31.1.1.1.18]','10389','Ethernet interface discovery','zyxel.ies6000.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34397','20','discovery[{#ZYXEL.SLOTSTATUS},.1.3.6.1.4.1.890.1.5.13.5.6.3.1.7,{#ZYXEL.SLOT.ID},.1.3.6.1.4.1.890.1.5.13.5.6.3.1.1]','10389','Slot discovery','zyxel.ies6000.slot.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table which contains the slot information in a chassis.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34398','20','discovery[{#ZYXEL.TEMP.THRESH.LOW},.1.3.6.1.4.1.890.1.5.13.5.11.3.3.1.7,{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.13.5.11.3.3.1.5]','10389','Temperature discovery','zyxel.ies6000.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34399','20','discovery[{#ZYXEL.VOLT.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.8,{#ZYXEL.VOLT.THRESH.LOW}, .1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.5]','10389','Voltage discovery','zyxel.ies6000.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34400','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.5.1.2.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Packet buffer utilization','zyxel.ies6000.buffer[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The packet buffer usage in the past 60 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34401','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.4.1.2.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: CPU utilization','zyxel.ies6000.cpu[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The CPU utilization in the past 60 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34402','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.1.1.2.{#SNMPINDEX}','10389','ZYXEL IES-6000: Fan #{#SNMPINDEX}','zyxel.ies6000.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34403','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.6.1.2.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Memory utilization','zyxel.ies6000.memory[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The memory usage in the past 60 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34404','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Administrative status','zyxel.ies6000.net.adsl.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'188','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34405','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming traffic','zyxel.ies6000.net.adsl.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34406','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing traffic','zyxel.ies6000.net.adsl.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34407','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing multicast packages','zyxel.ies6000.net.adsl.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34408','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing broadcast packages','zyxel.ies6000.net.adsl.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34409','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Operational status','zyxel.ies6000.net.adsl.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'189','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34410','20','.1.3.6.1.2.1.31.1.1.1.1.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Interface name','zyxel.ies6000.net.adsl.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34411','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming unicast packages','zyxel.ies6000.net.adsl.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34412','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming multicast packages','zyxel.ies6000.net.adsl.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34413','20','.1.3.6.1.2.1.10.94.1.1.2.1.5.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUC attenuation','zyxel.ies6000.net.adsl.atuc.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES-6000, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34414','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming broadcast packages','zyxel.ies6000.net.adsl.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34415','20','.1.3.6.1.2.1.31.1.1.1.18.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Interface description','zyxel.ies6000.net.adsl.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34416','20','.1.3.6.1.2.1.10.94.1.1.3.1.4.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUR noise margin','zyxel.ies6000.net.adsl.atur.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34417','20','.1.3.6.1.2.1.10.94.1.1.3.1.7.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUR output power','zyxel.ies6000.net.adsl.atur.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34418','20','.1.3.6.1.2.1.10.94.1.1.3.1.5.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUR attenuation','zyxel.ies6000.net.adsl.atur.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34419','20','.1.3.6.1.2.1.10.94.1.1.2.1.4.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUC noise margin','zyxel.ies6000.net.adsl.atuc.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES-6000, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34420','20','.1.3.6.1.2.1.10.94.1.1.2.1.7.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUC output power','zyxel.ies6000.net.adsl.atuc.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES-6000, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34421','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing unicast packages','zyxel.ies6000.net.adsl.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34422','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Administrative status','zyxel.ies6000.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'188','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34423','20','.1.3.6.1.2.1.31.1.1.1.18.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Interface description','zyxel.ies6000.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34424','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Link speed','zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34425','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.ies6000.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34426','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.ies6000.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34427','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Incoming traffic','zyxel.ies6000.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34428','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.ies6000.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34429','15','','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Incoming utilization','zyxel.ies6000.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.ies6000.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]) <> 0) /
( last(zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34430','20','.1.3.6.1.2.1.31.1.1.1.1.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Interface name','zyxel.ies6000.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34431','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Operational status','zyxel.ies6000.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'189','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34432','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.ies6000.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34433','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.ies6000.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34434','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Outgoing traffic','zyxel.ies6000.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34435','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.ies6000.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34436','15','','10389','ZYXEL IES-6000: Port {#SNMPINDEX}: Outgoing utilization','zyxel.ies6000.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.ies6000.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]) <> 0) /
( last(zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34437','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.8.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Alarm status','zyxel.ies6000.slot.alarm[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
This variable indicates the alarm status of the module.
It is a bit map represented a sum, therefore, it can represent
multiple defects simultaneously. The moduleNoDefect should be set
if and only if no other flag is set.
The various bit positions are:
1   moduleNoDefect
2   moduleOverHeat
3   moduleFanRpmLow
4   moduleVoltageLow
5   moduleThermalSensorFailure
6   modulePullOut
7   powerDC48VAFailure
8   powerDC48VBFailure
9   extAlarmInputTrigger
10   moduleDown
11   mscSwitchOverOK
12   networkTopologyChange
13   macSpoof
14   cpuHigh
15   memoryUsageHigh
16   packetBufferUsageHigh
17   loopguardOccurence','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34438','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.6.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: DSL modem code version','zyxel.ies6000.slot.cv.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The DSL modem code version of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34439','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.3.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Description','zyxel.ies6000.slot.desc[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The descriptions of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34440','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.5.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Driver version','zyxel.ies6000.slot.dv.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The DSL driver of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34441','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.4.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Firmware version','zyxel.ies6000.slot.fw.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The firmware version of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34442','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.10.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Hardware version','zyxel.ies6000.slot.hw.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The hardware version of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34443','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.12.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: MAC address 1','zyxel.ies6000.slot.mac1[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The MAC Address of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34444','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.13.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: MAC address 2','zyxel.ies6000.slot.mac2[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The MAC Address of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34445','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.9.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Serial number','zyxel.ies6000.slot.serial[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The serial number of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34446','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.7.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Status','zyxel.ies6000.slot.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'184','','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The module state of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34447','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.2.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Type','zyxel.ies6000.slot.type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'185','','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
Card type of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34448','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.11.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Uptime','zyxel.ies6000.slot.uptime[{#SNMPINDEX}]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The time (in seconds) since the plug-in card was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34449','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.3.1.2.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.ies6000.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34450','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.2.{#SNMPINDEX}','10389','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.ies6000.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34451','5','','10390','ZYXEL IES1248-51: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34452','20','.1.3.6.1.2.1.1.4.0','10390','ZYXEL IES1248-51: Contact','zyxel.ies1248.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34453','20','.1.3.6.1.4.1.890.1.5.13.1.1.3.1.4.0.0','10390','ZYXEL IES1248-51: ZyNOS F/W Version','zyxel.ies1248.fwversion','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-IESCOMMON-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34454','20','.1.3.6.1.2.1.1.6.0','10390','ZYXEL IES1248-51: Location','zyxel.ies1248.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34455','20','.1.3.6.1.2.1.2.2.1.6.1','10390','ZYXEL IES1248-51: MAC address','zyxel.ies1248.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34456','20','.1.3.6.1.2.1.1.1.0','10390','ZYXEL IES1248-51: Hardware model name','zyxel.ies1248.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34457','20','.1.3.6.1.2.1.1.5.0','10390','ZYXEL IES1248-51: Host name','zyxel.ies1248.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34458','20','.1.3.6.1.4.1.890.1.5.13.1.1.2.1.3.0','10390','ZYXEL IES1248-51: Hardware serial number','zyxel.ies1248.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-IESCOMMON-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34459','20','.1.3.6.1.4.1.890.1.5.13.1.1.3.1.8.0.0','10390','ZYXEL IES1248-51: Alarm status','zyxel.ies1248.slot.alarm','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-IESCOMMON-MIB
This variable indicates the alarm status of the module.
It is a bit map represented a sum, therefore, it can represent
multiple defects simultaneously. The moduleNoDefect should be set
if and only if no other flag is set.
The various bit positions are:
1   moduleNoDefect
2   moduleOverHeat
3   moduleFanRpmLow
4   moduleVoltageLow
5   moduleThermalSensorFailure
6   modulePullOut
7   powerDC48VAFailure
8   powerDC48VBFailure
9   extAlarmInputTrigger
10   moduleDown
11   mscSwitchOverOK
12   networkTopologyChange
13   macSpoof
14   cpuHigh
15   memoryUsageHigh
16   packetBufferUsageHigh
17   loopguardOccurence','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34460','20','.1.3.6.1.2.1.1.3.0','10390','ZYXEL IES1248-51: Uptime','zyxel.ies1248.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34461','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.5.13.1.2.1.1.5]','10390','Fan discovery','zyxel.ies1248.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34462','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.2.2.1.2,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8]','10390','ADSL interface discovery','zyxel.ies1248.net.adsl.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34463','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.2.2.1.2,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8]','10390','Ethernet interface discovery','zyxel.ies1248.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34464','20','discovery[{#ZYXEL.TEMP.ID}, .1.3.6.1.4.1.890.1.5.13.1.2.3.1.1,{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.13.1.2.3.1.5]','10390','Temperature discovery','zyxel.ies1248.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34465','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.13.1.2.2.1.6,{#ZYXEL.VOLT.NOMINAL}, .1.3.6.1.4.1.890.1.5.13.1.2.2.1.5]','10390','Voltage discovery','zyxel.ies1248.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34466','20','.1.3.6.1.4.1.890.1.5.13.1.2.1.1.2.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Fan #{#SNMPINDEX}','zyxel.ies1248.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IESCOMMON-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34467','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#SNMPINDEX}: Administrative status','zyxel.ies1248.net.adsl.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'193','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34468','20','.1.3.6.1.2.1.10.94.1.1.2.1.5.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#SNMPINDEX}: ATUC attenuation','zyxel.ies1248.net.adsl.atuc.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES1248-51, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34469','20','.1.3.6.1.2.1.10.94.1.1.2.1.7.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#SNMPINDEX}: ATUC output power','zyxel.ies1248.net.adsl.atuc.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES1248-51, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34470','20','.1.3.6.1.2.1.10.94.1.1.2.1.4.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#SNMPINDEX}: ATUC noise margin','zyxel.ies1248.net.adsl.atuc.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES1248-51, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34471','20','.1.3.6.1.2.1.10.94.1.1.3.1.5.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#SNMPINDEX}: ATUR attenuation','zyxel.ies1248.net.adsl.atur.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34472','20','.1.3.6.1.2.1.10.94.1.1.3.1.7.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#SNMPINDEX}: ATUR output power','zyxel.ies1248.net.adsl.atur.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34473','20','.1.3.6.1.2.1.10.94.1.1.3.1.4.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#SNMPINDEX}: ATUR noise margin','zyxel.ies1248.net.adsl.atur.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34474','20','.1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#SNMPINDEX}: Incoming traffic','zyxel.ies1248.net.adsl.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34475','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#SNMPINDEX}: Interface name','zyxel.ies1248.net.adsl.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34476','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#SNMPINDEX}: Operational status','zyxel.ies1248.net.adsl.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'194','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34477','20','.1.3.6.1.2.1.2.2.1.16.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#SNMPINDEX}: Outgoing traffic','zyxel.ies1248.net.adsl.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34478','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#ZYXEL.IF.NAME}: Administrative status','zyxel.ies1248.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'193','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34479','20','.1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#ZYXEL.IF.NAME}: Incoming traffic','zyxel.ies1248.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34480','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#SNMPINDEX}: Interface name','zyxel.ies1248.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34481','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#ZYXEL.IF.NAME}: Operational status','zyxel.ies1248.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'194','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34482','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Port {#ZYXEL.IF.NAME}: Outgoing traffic','zyxel.ies1248.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34483','20','.1.3.6.1.4.1.890.1.5.13.1.2.3.1.2.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.ies1248.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IESCOMMON-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34484','20','.1.3.6.1.4.1.890.1.5.13.1.2.2.1.2.{#SNMPINDEX}','10390','ZYXEL IES1248-51: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.ies1248.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IESCOMMON-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34485','5','','10391','ZYXEL MES-3528: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34486','20','.1.3.6.1.2.1.1.4.0','10391','ZYXEL MES-3528: Contact','zyxel.3528.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34487','20','.1.3.6.1.4.1.890.1.5.8.51.12.7.0','10391','ZYXEL MES-3528: CPU utilization','zyxel.3528.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3528-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34488','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.51.1]','10391','ZYXEL MES-3528: ZyNOS F/W Version','zyxel.3528.fwversion','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3528-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34489','20','.1.3.6.1.2.1.1.6.0','10391','ZYXEL MES-3528: Location','zyxel.3528.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34490','20','.1.3.6.1.2.1.2.2.1.6.1','10391','ZYXEL MES-3528: MAC address','zyxel.3528.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34491','20','.1.3.6.1.2.1.1.1.0','10391','ZYXEL MES-3528: Hardware model name','zyxel.3528.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34492','20','.1.3.6.1.2.1.1.5.0','10391','ZYXEL MES-3528: Host name','zyxel.3528.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34493','20','.1.3.6.1.4.1.890.1.5.8.51.1.10.0','10391','ZYXEL MES-3528: Hardware serial number','zyxel.3528.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3528-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34494','20','.1.3.6.1.2.1.1.3.0','10391','ZYXEL MES-3528: Uptime','zyxel.3528.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34495','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.51.24.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.51.24.1.1.5]','10391','Interface discovery','zyxel.3528.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34496','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.51.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.51.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.51.117.2.1.8]','10391','SFP with DDM discovery','zyxel.3528.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34497','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.51.117.1.1.2]','10391','SFP without DDM discovery','zyxel.3528.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34498','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Administrative status','zyxel.3528.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'197','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34499','20','.1.3.6.1.4.1.890.1.5.8.51.24.1.1.3.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Interface description','zyxel.3528.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3528-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34500','15','','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3528.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3528.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3528.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3528.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3528.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34501','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3528.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34502','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3528.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34503','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3528.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34504','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3528.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34505','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Operational status','zyxel.3528.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'198','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34506','20','.1.3.6.1.4.1.890.1.5.8.51.24.1.1.5.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Link type','zyxel.3528.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'196','','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3528-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34507','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Interface name','zyxel.3528.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34508','15','','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Incoming utilization','zyxel.3528.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3528.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3528.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3528.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3528.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34509','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3528.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34510','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Incoming traffic','zyxel.3528.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34511','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3528.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34512','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3528.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34513','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Link speed','zyxel.3528.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34514','20','.1.3.6.1.4.1.890.1.5.8.51.24.1.1.1.{#SNMPINDEX}','10391','ZYXEL MES-3528: Port {#SNMPINDEX}: Speed Duplex','zyxel.3528.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'195','','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3528-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34515','20','.1.3.6.1.4.1.890.1.5.8.51.117.2.1.7.{#SNMPINDEX}','10391','ZYXEL MES-3528: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3528.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34516','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.7.{#SNMPINDEX}','10391','ZYXEL MES-3528: SFP {#SNMPINDEX}: Date code','zyxel.3528.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34517','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.4.{#SNMPINDEX}','10391','ZYXEL MES-3528: SFP {#SNMPINDEX}: Part number','zyxel.3528.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34518','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.6.{#SNMPINDEX}','10391','ZYXEL MES-3528: SFP {#SNMPINDEX}: Revision','zyxel.3528.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34519','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.5.{#SNMPINDEX}','10391','ZYXEL MES-3528: SFP {#SNMPINDEX}: Serial number','zyxel.3528.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34520','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.2.{#SNMPINDEX}','10391','ZYXEL MES-3528: SFP {#SNMPINDEX}: Status','zyxel.3528.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'199','','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34521','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.8.{#SNMPINDEX}','10391','ZYXEL MES-3528: SFP {#SNMPINDEX}: Transceiver','zyxel.3528.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34522','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.3.{#SNMPINDEX}','10391','ZYXEL MES-3528: SFP {#SNMPINDEX}: Vendor','zyxel.3528.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34523','5','','10392','ZYXEL MES3500-10: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34524','20','.1.3.6.1.2.1.1.4.0','10392','ZYXEL MES3500-10: Contact','zyxel.3500_10.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34525','20','.1.3.6.1.4.1.890.1.5.8.80.12.7.0','10392','ZYXEL MES3500-10: CPU utilization','zyxel.3500_10.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3500-10-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34526','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.80.1]','10392','ZYXEL MES3500-10: ZyNOS F/W Version','zyxel.3500_10.fwversion','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3500-10-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34527','20','.1.3.6.1.2.1.1.6.0','10392','ZYXEL MES3500-10: Location','zyxel.3500_10.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34528','20','.1.3.6.1.2.1.2.2.1.6.1','10392','ZYXEL MES3500-10: MAC address','zyxel.3500_10.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34529','20','.1.3.6.1.2.1.1.1.0','10392','ZYXEL MES3500-10: Hardware model name','zyxel.3500_10.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34530','20','.1.3.6.1.2.1.1.5.0','10392','ZYXEL MES3500-10: Host name','zyxel.3500_10.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34531','20','.1.3.6.1.4.1.890.1.5.8.80.1.10.0','10392','ZYXEL MES3500-10: Hardware serial number','zyxel.3500_10.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3500-10-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34532','20','.1.3.6.1.2.1.1.3.0','10392','ZYXEL MES3500-10: Uptime','zyxel.3500_10.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34533','20','discovery[{#ZYXEL.MEMORY.NAME},.1.3.6.1.4.1.890.1.5.8.80.124.1.1.2]','10392','Memory pool discovery','zyxel.3500_10.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34534','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.80.24.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.80.24.1.1.5]','10392','Interface discovery','zyxel.3500_10.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34535','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.80.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.80.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.80.117.2.1.8]','10392','SFP with DDM discovery','zyxel.3500_10.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34536','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.80.117.1.1.2]','10392','SFP without DDM discovery','zyxel.3500_10.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34537','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.80.9.2.1.5]','10392','Temperature discovery','zyxel.3500_10.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34538','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.80.9.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.80.9.3.1.5]','10392','Voltage discovery','zyxel.3500_10.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34539','20','.1.3.6.1.4.1.890.1.5.8.80.124.1.1.5.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Memory "{#ZYXEL.MEMORY.NAME}" utilization','zyxel.3500_10.memory[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Utilization of memory pool in %.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34540','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Administrative status','zyxel.3500_10.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'202','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34541','20','.1.3.6.1.4.1.890.1.5.8.80.24.1.1.3.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Interface description','zyxel.3500_10.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3500-10-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34542','15','','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3500_10.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3500_10.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34543','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3500_10.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34544','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3500_10.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34545','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3500_10.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34546','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3500_10.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34547','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Operational status','zyxel.3500_10.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'203','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34548','20','.1.3.6.1.4.1.890.1.5.8.80.24.1.1.5.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Link type','zyxel.3500_10.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'201','','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3500-10-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34549','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Interface name','zyxel.3500_10.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34550','15','','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Incoming utilization','zyxel.3500_10.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3500_10.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34551','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3500_10.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34552','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Incoming traffic','zyxel.3500_10.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34553','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3500_10.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34554','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3500_10.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34555','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Link speed','zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34556','20','.1.3.6.1.4.1.890.1.5.8.80.24.1.1.1.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Port {#SNMPINDEX}: Speed Duplex','zyxel.3500_10.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'200','','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3500-10-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34557','20','.1.3.6.1.4.1.890.1.5.8.80.117.2.1.7.{#SNMPINDEX}','10392','ZYXEL MES3500-10: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3500_10.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34558','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.7.{#SNMPINDEX}','10392','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Date code','zyxel.3500_10.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34559','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.4.{#SNMPINDEX}','10392','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Part number','zyxel.3500_10.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34560','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.6.{#SNMPINDEX}','10392','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Revision','zyxel.3500_10.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34561','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.5.{#SNMPINDEX}','10392','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Serial number','zyxel.3500_10.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34562','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.2.{#SNMPINDEX}','10392','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Status','zyxel.3500_10.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'204','','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34563','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.8.{#SNMPINDEX}','10392','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Transceiver','zyxel.3500_10.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34564','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.3.{#SNMPINDEX}','10392','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Vendor','zyxel.3500_10.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34565','20','.1.3.6.1.4.1.890.1.5.8.80.9.2.1.2.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.3500_10.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34566','20','.1.3.6.1.4.1.890.1.5.8.80.9.3.1.2.{#SNMPINDEX}','10392','ZYXEL MES3500-10: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.3500_10.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34567','5','','10393','ZYXEL MES3500-24: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34568','20','.1.3.6.1.2.1.1.4.0','10393','ZYXEL MES3500-24: Contact','zyxel.3500_24.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34569','20','.1.3.6.1.4.1.890.1.5.8.68.12.7.0','10393','ZYXEL MES3500-24: CPU utilization','zyxel.3500_24.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3500-24-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34570','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.68.1]','10393','ZYXEL MES3500-24: ZyNOS F/W Version','zyxel.3500_24.fwversion','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3500-24-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34571','20','.1.3.6.1.2.1.1.6.0','10393','ZYXEL MES3500-24: Location','zyxel.3500_24.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34572','20','.1.3.6.1.2.1.2.2.1.6.1','10393','ZYXEL MES3500-24: MAC address','zyxel.3500_24.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34573','20','.1.3.6.1.2.1.1.1.0','10393','ZYXEL MES3500-24: Hardware model name','zyxel.3500_24.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34574','20','.1.3.6.1.2.1.1.5.0','10393','ZYXEL MES3500-24: Host name','zyxel.3500_24.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34575','20','.1.3.6.1.4.1.890.1.5.8.68.1.10.0','10393','ZYXEL MES3500-24: Hardware serial number','zyxel.3500_24.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3500-24-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34576','20','.1.3.6.1.2.1.1.3.0','10393','ZYXEL MES3500-24: Uptime','zyxel.3500_24.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34577','20','discovery[{#ZYXEL.MEMORY.NAME},.1.3.6.1.4.1.890.1.5.8.68.124.1.1.2]','10393','Memory pool discovery','zyxel.3500_24.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34578','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.68.24.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.68.24.1.1.5]','10393','Interface discovery','zyxel.3500_24.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34579','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.68.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.68.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.68.117.2.1.8]','10393','SFP with DDM discovery','zyxel.3500_24.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34580','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.68.117.1.1.2]','10393','SFP without DDM discovery','zyxel.3500_24.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34581','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.68.9.2.1.5]','10393','Temperature discovery','zyxel.3500_24.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34582','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.68.9.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.68.9.3.1.5]','10393','Voltage discovery','zyxel.3500_24.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34583','20','.1.3.6.1.4.1.890.1.5.8.68.124.1.1.5.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Memory "{#ZYXEL.MEMORY.NAME}" utilization','zyxel.3500_24.memory[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Utilization of memory pool in %.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34584','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Administrative status','zyxel.3500_24.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'207','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34585','20','.1.3.6.1.4.1.890.1.5.8.68.24.1.1.3.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Interface description','zyxel.3500_24.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3500-24-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34586','15','','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3500_24.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3500_24.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34587','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3500_24.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34588','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3500_24.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34589','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3500_24.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34590','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3500_24.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34591','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Operational status','zyxel.3500_24.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'208','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34592','20','.1.3.6.1.4.1.890.1.5.8.68.24.1.1.5.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Link type','zyxel.3500_24.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'206','','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3500-24-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34593','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Interface name','zyxel.3500_24.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34594','15','','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Incoming utilization','zyxel.3500_24.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3500_24.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34595','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3500_24.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34596','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Incoming traffic','zyxel.3500_24.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34597','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3500_24.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34598','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3500_24.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34599','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Link speed','zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34600','20','.1.3.6.1.4.1.890.1.5.8.68.24.1.1.1.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Port {#SNMPINDEX}: Speed Duplex','zyxel.3500_24.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'205','','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3500-24-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34601','20','.1.3.6.1.4.1.890.1.5.8.68.117.2.1.7.{#SNMPINDEX}','10393','ZYXEL MES3500-24: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3500_24.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34602','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.7.{#SNMPINDEX}','10393','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Date code','zyxel.3500_24.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34603','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.4.{#SNMPINDEX}','10393','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Part number','zyxel.3500_24.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34604','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.6.{#SNMPINDEX}','10393','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Revision','zyxel.3500_24.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34605','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.5.{#SNMPINDEX}','10393','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Serial number','zyxel.3500_24.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34606','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.2.{#SNMPINDEX}','10393','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Status','zyxel.3500_24.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'209','','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34607','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.8.{#SNMPINDEX}','10393','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Transceiver','zyxel.3500_24.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34608','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.3.{#SNMPINDEX}','10393','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Vendor','zyxel.3500_24.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34609','20','.1.3.6.1.4.1.890.1.5.8.68.9.2.1.2.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.3500_24.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34610','20','.1.3.6.1.4.1.890.1.5.8.68.9.3.1.2.{#SNMPINDEX}','10393','ZYXEL MES3500-24: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.3500_24.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34611','5','','10394','ZYXEL MGS-3712: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34612','20','.1.3.6.1.2.1.1.4.0','10394','ZYXEL MGS-3712: Contact','zyxel.3712.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34613','20','.1.3.6.1.4.1.890.1.5.8.47.11.7.0','10394','ZYXEL MGS-3712: CPU utilization','zyxel.3712.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MGS3712F-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34614','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.47.1]','10394','ZYXEL MGS-3712: ZyNOS F/W Version','zyxel.3712.fwversion','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MGS3712F-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34615','20','.1.3.6.1.2.1.1.6.0','10394','ZYXEL MGS-3712: Location','zyxel.3712.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34616','20','.1.3.6.1.2.1.2.2.1.6.1','10394','ZYXEL MGS-3712: MAC address','zyxel.3712.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34617','20','.1.3.6.1.2.1.1.1.0','10394','ZYXEL MGS-3712: Hardware model name','zyxel.3712.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34618','20','.1.3.6.1.2.1.1.5.0','10394','ZYXEL MGS-3712: Host name','zyxel.3712.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34619','20','.1.3.6.1.4.1.890.1.5.8.47.1.10.0','10394','ZYXEL MGS-3712: Hardware serial number','zyxel.3712.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MGS3712F-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34620','20','.1.3.6.1.2.1.1.3.0','10394','ZYXEL MGS-3712: Uptime','zyxel.3712.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34621','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.47.8.1.1.5]','10394','Fan discovery','zyxel.3712.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34622','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.47.22.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.47.22.1.1.5]','10394','Interface discovery','zyxel.3712.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34623','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.47.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.47.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.47.117.2.1.8]','10394','SFP with DDM discovery','zyxel.3712.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34624','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.47.117.1.1.2]','10394','SFP without DDM discovery','zyxel.3712.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34625','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.47.8.2.1.5]','10394','Temperature discovery','zyxel.3712.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34626','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.47.8.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.47.8.3.1.5]','10394','Voltage discovery','zyxel.3712.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34627','20','.1.3.6.1.4.1.890.1.5.8.47.8.1.1.2.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Fan #{#SNMPINDEX}','zyxel.3712.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34628','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Administrative status','zyxel.3712.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'212','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34629','20','.1.3.6.1.4.1.890.1.5.8.47.22.1.1.3.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Interface description','zyxel.3712.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34630','15','','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3712.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3712.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3712.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3712.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3712.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34631','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3712.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34632','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3712.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34633','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3712.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34634','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3712.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34635','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Operational status','zyxel.3712.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'213','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34636','20','.1.3.6.1.4.1.890.1.5.8.47.22.1.1.5.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Link type','zyxel.3712.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'211','','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34637','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Interface name','zyxel.3712.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34638','15','','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Incoming utilization','zyxel.3712.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3712.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3712.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3712.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3712.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34639','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3712.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34640','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Incoming traffic','zyxel.3712.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34641','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3712.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34642','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3712.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34643','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Link speed','zyxel.3712.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34644','20','.1.3.6.1.4.1.890.1.5.8.47.22.1.1.1.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Port {#SNMPINDEX}: Speed Duplex','zyxel.3712.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'210','','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34645','20','.1.3.6.1.4.1.890.1.5.8.47.117.2.1.7.{#SNMPINDEX}','10394','ZYXEL MGS-3712: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3712.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34646','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.7.{#SNMPINDEX}','10394','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Date code','zyxel.3712.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34647','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.4.{#SNMPINDEX}','10394','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Part number','zyxel.3712.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34648','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.6.{#SNMPINDEX}','10394','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Revision','zyxel.3712.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34649','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.5.{#SNMPINDEX}','10394','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Serial number','zyxel.3712.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34650','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.2.{#SNMPINDEX}','10394','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Status','zyxel.3712.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'214','','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34651','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.8.{#SNMPINDEX}','10394','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Transceiver','zyxel.3712.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34652','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.3.{#SNMPINDEX}','10394','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Vendor','zyxel.3712.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34653','20','.1.3.6.1.4.1.890.1.5.8.47.8.2.1.2.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.3712.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34654','20','.1.3.6.1.4.1.890.1.5.8.47.8.3.1.2.{#SNMPINDEX}','10394','ZYXEL MGS-3712: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.3712.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34655','5','','10395','ZYXEL MGS-3712F: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34656','20','.1.3.6.1.2.1.1.4.0','10395','ZYXEL MGS-3712F: Contact','zyxel.3712f.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34657','20','.1.3.6.1.4.1.890.1.5.8.48.11.7.0','10395','ZYXEL MGS-3712F: CPU utilization','zyxel.3712f.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MGS3712F-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34658','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.48.1]','10395','ZYXEL MGS-3712F: ZyNOS F/W Version','zyxel.3712f.fwversion','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MGS3712F-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34659','20','.1.3.6.1.2.1.1.6.0','10395','ZYXEL MGS-3712F: Location','zyxel.3712f.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34660','20','.1.3.6.1.2.1.2.2.1.6.1','10395','ZYXEL MGS-3712F: MAC address','zyxel.3712f.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34661','20','.1.3.6.1.2.1.1.1.0','10395','ZYXEL MGS-3712F: Hardware model name','zyxel.3712f.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34662','20','.1.3.6.1.2.1.1.5.0','10395','ZYXEL MGS-3712F: Host name','zyxel.3712f.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34663','20','.1.3.6.1.4.1.890.1.5.8.48.1.10.0','10395','ZYXEL MGS-3712F: Hardware serial number','zyxel.3712f.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MGS3712F-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34664','20','.1.3.6.1.2.1.1.3.0','10395','ZYXEL MGS-3712F: Uptime','zyxel.3712f.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34665','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.48.8.1.1.5]','10395','Fan discovery','zyxel.3712f.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34666','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.48.22.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.48.22.1.1.5]','10395','Interface discovery','zyxel.3712f.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34667','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.48.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.48.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.48.117.2.1.8]','10395','SFP with DDM discovery','zyxel.3712f.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34668','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.48.117.1.1.2]','10395','SFP without DDM discovery','zyxel.3712f.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34669','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.48.8.2.1.5]','10395','Temperature discovery','zyxel.3712f.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34670','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.48.8.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.48.8.3.1.5]','10395','Voltage discovery','zyxel.3712f.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34671','20','.1.3.6.1.4.1.890.1.5.8.48.8.1.1.2.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Fan #{#SNMPINDEX}','zyxel.3712f.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34672','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Administrative status','zyxel.3712f.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'217','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34673','20','.1.3.6.1.4.1.890.1.5.8.48.22.1.1.3.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Interface description','zyxel.3712f.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34674','15','','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3712f.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3712f.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34675','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3712f.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34676','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3712f.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34677','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3712f.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34678','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3712f.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34679','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Operational status','zyxel.3712f.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'218','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34680','20','.1.3.6.1.4.1.890.1.5.8.48.22.1.1.5.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Link type','zyxel.3712f.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'216','','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34681','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Interface name','zyxel.3712f.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34682','15','','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Incoming utilization','zyxel.3712f.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3712f.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34683','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3712f.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34684','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Incoming traffic','zyxel.3712f.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34685','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3712f.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34686','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3712f.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34687','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Link speed','zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34688','20','.1.3.6.1.4.1.890.1.5.8.48.22.1.1.1.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Speed Duplex','zyxel.3712f.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'215','','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34689','20','.1.3.6.1.4.1.890.1.5.8.48.117.2.1.7.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3712f.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34690','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.7.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Date code','zyxel.3712f.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34691','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.4.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Part number','zyxel.3712f.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34692','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.6.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Revision','zyxel.3712f.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34693','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.5.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Serial number','zyxel.3712f.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34694','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.2.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Status','zyxel.3712f.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'219','','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34695','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.8.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Transceiver','zyxel.3712f.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34696','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.3.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Vendor','zyxel.3712f.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34697','20','.1.3.6.1.4.1.890.1.5.8.48.8.2.1.2.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.3712f.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34698','20','.1.3.6.1.4.1.890.1.5.8.48.8.3.1.2.{#SNMPINDEX}','10395','ZYXEL MGS-3712F: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.3712f.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34699','5','','10396','ZYXEL MES3500-24S: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34700','20','.1.3.6.1.2.1.1.4.0','10396','ZYXEL MES3500-24S: Contact','zyxel.3500_24s.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34701','20','.1.3.6.1.4.1.890.1.15.3.2.4.0','10396','ZYXEL MES3500-24S: CPU utilization','zyxel.3500_24s.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34702','20','.1.3.6.1.4.1.890.1.15.3.1.6.0','10396','ZYXEL MES3500-24S: ZyNOS F/W Version','zyxel.3500_24s.fwversion','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34703','20','.1.3.6.1.2.1.1.6.0','10396','ZYXEL MES3500-24S: Location','zyxel.3500_24s.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34704','20','.1.3.6.1.2.1.2.2.1.6.1','10396','ZYXEL MES3500-24S: MAC address','zyxel.3500_24s.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34705','20','.1.3.6.1.4.1.890.1.15.3.2.5.0','10396','ZYXEL MES3500-24S: Memory utilization','zyxel.3500_24s.memusage','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON
Show device memory usage in %.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34706','20','.1.3.6.1.2.1.1.1.0','10396','ZYXEL MES3500-24S: Hardware model name','zyxel.3500_24s.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34707','20','.1.3.6.1.2.1.1.5.0','10396','ZYXEL MES3500-24S: Host name','zyxel.3500_24s.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34708','20','.1.3.6.1.4.1.890.1.15.3.1.12.0','10396','ZYXEL MES3500-24S: Hardware serial number','zyxel.3500_24s.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34709','20','.1.3.6.1.2.1.1.3.0','10396','ZYXEL MES3500-24S: Uptime','zyxel.3500_24s.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34710','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.15.3.26.1.1.1.6,{#ZYXEL.FAN.DESCRIPTION},.1.3.6.1.4.1.890.1.15.3.26.1.1.1.2]','10396','Fan discovery','zyxel.3500_24s.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34711','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.15.3.61.1.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.15.3.61.2.1.1.2]','10396','Interface discovery','zyxel.3500_24s.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34712','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.15.3.84.1.2.1.4,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.15.3.84.1.2.1.5,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.15.3.84.1.2.1.7]','10396','SFP with DDM discovery','zyxel.3500_24s.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34713','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.15.3.84.1.1.1.1]','10396','SFP without DDM discovery','zyxel.3500_24s.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34714','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.15.3.26.1.2.1.6,{#ZYXEL.TEMPDESCRIPTION},.1.3.6.1.4.1.890.1.15.3.26.1.2.1.2]','10396','Temperature discovery','zyxel.3500_24s.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34715','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.15.3.26.1.3.1.7,{#ZYXEL.DESCRIPTION},.1.3.6.1.4.1.890.1.15.3.26.1.3.1.2]','10396','Voltage discovery','zyxel.3500_24s.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34716','20','.1.3.6.1.4.1.890.1.15.3.26.1.1.1.3.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: {#ZYXEL.FAN.DESCRIPTION}','zyxel.3500_24s.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-HW-MONITOR-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34717','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Administrative status','zyxel.3500_24s.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'222','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34718','20','.1.3.6.1.4.1.890.1.15.3.61.1.1.1.3.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Interface description','zyxel.3500_24s.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-PORT-MIB
Descriptive name that identifies this port.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34719','15','','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3500_24s.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3500_24s.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34720','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3500_24s.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34721','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3500_24s.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34722','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3500_24s.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34723','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3500_24s.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34724','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Operational status','zyxel.3500_24s.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'223','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34725','20','.1.3.6.1.4.1.890.1.15.3.61.2.1.1.2.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Link type','zyxel.3500_24s.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'221','','','0','','','','','2',NULL,'MIB: ZYXEL-PORT-MIB
The entry shows the linkUp cable type (copper, fiber, xfp or cx4) for the combo ports.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34726','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Interface name','zyxel.3500_24s.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34727','15','','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Incoming utilization','zyxel.3500_24s.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3500_24s.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34728','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3500_24s.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34729','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Incoming traffic','zyxel.3500_24s.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34730','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3500_24s.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34731','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3500_24s.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34732','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Link speed','zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34733','20','.1.3.6.1.4.1.890.1.15.3.61.1.1.1.1.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Speed Duplex','zyxel.3500_24s.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'220','','','0','','','','','2',NULL,'MIB: ZYXEL-PORT-MIB
Select The speed and the duplex mode of the Ethernet connection on this port. Selecting Auto 
(auto-negotiation) allows one port to negotiate with a peer port automatically to obtain the 
connection speed and duplex mode that both ends support. When auto-negotiation is turned on, 
a port on the Switch negotiates with the peer automatically to determine the connection speed 
and duplex mode. If the peer port does not support auto-negotiation or turns off this feature, 
the Switch determines the connection speed by detecting the signal on the cable and using half 
duplex mode. Thus requiring you to make sure that the settings of the peer port are the same in 
order to connect.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34734','20','.1.3.6.1.4.1.890.1.15.3.84.1.2.1.6.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3500_24s.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34735','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.6.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Date code','zyxel.3500_24s.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34736','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.3.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Part number','zyxel.3500_24s.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34737','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.5.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Revision','zyxel.3500_24s.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34738','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.4.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Serial number','zyxel.3500_24s.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34739','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.1.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Status','zyxel.3500_24s.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'224','','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module type.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34740','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.7.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Transceiver','zyxel.3500_24s.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34741','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.2.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Vendor','zyxel.3500_24s.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34742','20','.1.3.6.1.4.1.890.1.15.3.26.1.2.1.3.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Temperature "{#ZYXEL.TEMPDESCRIPTION}"','zyxel.3500_24s.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-HW-MONITOR-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34743','20','.1.3.6.1.4.1.890.1.15.3.26.1.3.1.3.{#SNMPINDEX}','10396','ZYXEL MES3500-24S: Nominal "{#ZYXEL.DESCRIPTION}"','zyxel.3500_24s.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-HW-MONITOR-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34744','5','','10397','ZYXEL MGS3520-28x: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34745','20','.1.3.6.1.2.1.1.4.0','10397','ZYXEL MGS3520-28x: Contact','zyxel.3520_28.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34746','20','.1.3.6.1.4.1.890.1.15.3.2.4.0','10397','ZYXEL MGS3520-28x: CPU utilization','zyxel.3520_28.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34747','20','.1.3.6.1.4.1.890.1.15.3.1.6.0','10397','ZYXEL MGS3520-28x: ZyNOS F/W Version','zyxel.3520_28.fwversion','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34748','20','.1.3.6.1.2.1.1.6.0','10397','ZYXEL MGS3520-28x: Location','zyxel.3520_28.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34749','20','.1.3.6.1.2.1.2.2.1.6.1','10397','ZYXEL MGS3520-28x: MAC address','zyxel.3520_28.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34750','20','.1.3.6.1.4.1.890.1.15.3.2.5.0','10397','ZYXEL MGS3520-28x: Memory utilization','zyxel.3520_28.memusage','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON
Show device memory usage in %.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34751','20','.1.3.6.1.2.1.1.1.0','10397','ZYXEL MGS3520-28x: Hardware model name','zyxel.3520_28.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34752','20','.1.3.6.1.2.1.1.5.0','10397','ZYXEL MGS3520-28x: Host name','zyxel.3520_28.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34753','20','.1.3.6.1.4.1.890.1.15.3.1.12.0','10397','ZYXEL MGS3520-28x: Hardware serial number','zyxel.3520_28.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34754','20','.1.3.6.1.2.1.1.3.0','10397','ZYXEL MGS3520-28x: Uptime','zyxel.3520_28.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34755','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.15.3.26.1.1.1.6,{#ZYXEL.FAN.DESCRIPTION},.1.3.6.1.4.1.890.1.15.3.26.1.1.1.2]','10397','Fan discovery','zyxel.3520_28.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34756','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.15.3.61.1.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.15.3.61.2.1.1.2]','10397','Interface discovery','zyxel.3520_28.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34757','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.15.3.84.1.2.1.4,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.15.3.84.1.2.1.5,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.15.3.84.1.2.1.7]','10397','SFP with DDM discovery','zyxel.3520_28.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34758','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.15.3.84.1.1.1.1]','10397','SFP without DDM discovery','zyxel.3520_28.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34759','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.15.3.26.1.2.1.6,{#ZYXEL.TEMPDESCRIPTION},.1.3.6.1.4.1.890.1.15.3.26.1.2.1.2]','10397','Temperature discovery','zyxel.3520_28.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34760','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.15.3.26.1.3.1.7,{#ZYXEL.DESCRIPTION},.1.3.6.1.4.1.890.1.15.3.26.1.3.1.2]','10397','Voltage discovery','zyxel.3520_28.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34761','20','.1.3.6.1.4.1.890.1.15.3.26.1.1.1.3.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: {#ZYXEL.FAN.DESCRIPTION}','zyxel.3520_28.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-HW-MONITOR-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34762','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Administrative status','zyxel.3520_28.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'227','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34763','20','.1.3.6.1.4.1.890.1.15.3.61.1.1.1.3.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Interface description','zyxel.3520_28.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-PORT-MIB
Descriptive name that identifies this port.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34764','15','','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3520_28.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3520_28.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34765','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3520_28.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34766','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3520_28.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34767','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3520_28.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34768','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3520_28.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34769','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Operational status','zyxel.3520_28.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'228','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34770','20','.1.3.6.1.4.1.890.1.15.3.61.2.1.1.2.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Link type','zyxel.3520_28.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'226','','','0','','','','','2',NULL,'MIB: ZYXEL-PORT-MIB
The entry shows the linkUp cable type (copper, fiber, xfp or cx4) for the combo ports.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34771','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Interface name','zyxel.3520_28.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34772','15','','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Incoming utilization','zyxel.3520_28.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.3520_28.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34773','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3520_28.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34774','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Incoming traffic','zyxel.3520_28.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34775','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3520_28.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34776','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3520_28.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34777','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Link speed','zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34778','20','.1.3.6.1.4.1.890.1.15.3.61.1.1.1.1.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Speed Duplex','zyxel.3520_28.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'225','','','0','','','','','2',NULL,'MIB: ZYXEL-PORT-MIB
Select The speed and the duplex mode of the Ethernet connection on this port. Selecting Auto 
(auto-negotiation) allows one port to negotiate with a peer port automatically to obtain the 
connection speed and duplex mode that both ends support. When auto-negotiation is turned on, 
a port on the Switch negotiates with the peer automatically to determine the connection speed 
and duplex mode. If the peer port does not support auto-negotiation or turns off this feature, 
the Switch determines the connection speed by detecting the signal on the cable and using half 
duplex mode. Thus requiring you to make sure that the settings of the peer port are the same in 
order to connect.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34779','20','.1.3.6.1.4.1.890.1.15.3.84.1.2.1.6.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3520_28.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34780','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.6.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Date code','zyxel.3520_28.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34781','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.3.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Part number','zyxel.3520_28.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34782','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.5.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Revision','zyxel.3520_28.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34783','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.4.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Serial number','zyxel.3520_28.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34784','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.1.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Status','zyxel.3520_28.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'229','','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module type.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34785','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.7.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Transceiver','zyxel.3520_28.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34786','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.2.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Vendor','zyxel.3520_28.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34787','20','.1.3.6.1.4.1.890.1.15.3.26.1.2.1.3.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Temperature "{#ZYXEL.TEMPDESCRIPTION}"','zyxel.3520_28.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-HW-MONITOR-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34788','20','.1.3.6.1.4.1.890.1.15.3.26.1.3.1.3.{#SNMPINDEX}','10397','ZYXEL MGS3520-28x: Nominal "{#ZYXEL.DESCRIPTION}"','zyxel.3520_28.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-HW-MONITOR-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34789','5','','10398','ZYXEL XGS-4728F: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34790','20','.1.3.6.1.2.1.1.4.0','10398','ZYXEL XGS-4728F: Contact','zyxel.4728f.contact','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34791','20','.1.3.6.1.4.1.890.1.5.8.46.12.7.0','10398','ZYXEL XGS-4728F: CPU utilization','zyxel.4728f.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-XGS4728F-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34792','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.46.1]','10398','ZYXEL XGS-4728F: ZyNOS F/W Version','zyxel.4728f.fwversion','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-XGS4728F-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34793','20','.1.3.6.1.2.1.1.6.0','10398','ZYXEL XGS-4728F: Location','zyxel.4728f.location','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34794','20','.1.3.6.1.2.1.2.2.1.6.1','10398','ZYXEL XGS-4728F: MAC address','zyxel.4728f.mac','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34795','20','.1.3.6.1.2.1.1.1.0','10398','ZYXEL XGS-4728F: Hardware model name','zyxel.4728f.model','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34796','20','.1.3.6.1.2.1.1.5.0','10398','ZYXEL XGS-4728F: Host name','zyxel.4728f.name','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34797','20','.1.3.6.1.4.1.890.1.5.8.46.1.10.0','10398','ZYXEL XGS-4728F: Hardware serial number','zyxel.4728f.serialnumber','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-XGS4728F-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34798','20','.1.3.6.1.2.1.1.3.0','10398','ZYXEL XGS-4728F: Uptime','zyxel.4728f.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34799','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.46.9.1.1.5]','10398','Fan discovery','zyxel.4728f.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34800','20','discovery[{#ZYXEL.MEMORY.NAME},.1.3.6.1.4.1.890.1.5.8.46.124.1.1.2]','10398','Memory pool discovery','zyxel.4728f.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34801','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.46.23.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.46.23.1.1.5]','10398','Interface discovery','zyxel.4728f.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34802','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.46.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.46.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.46.117.2.1.8]','10398','SFP with DDM discovery','zyxel.4728f.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34803','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.46.117.1.1.2]','10398','SFP without DDM discovery','zyxel.4728f.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34804','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.46.9.2.1.5]','10398','Temperature discovery','zyxel.4728f.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34805','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.46.9.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.46.9.3.1.5]','10398','Voltage discovery','zyxel.4728f.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34806','20','.1.3.6.1.4.1.890.1.5.8.46.9.1.1.2.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Fan #{#SNMPINDEX}','zyxel.4728f.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34807','20','.1.3.6.1.4.1.890.1.5.8.46.124.1.1.5.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Memory "{#ZYXEL.MEMORY.NAME}" utilization','zyxel.4728f.memory[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Utilization of memory pool in %.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34808','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Administrative status','zyxel.4728f.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'232','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34809','20','.1.3.6.1.4.1.890.1.5.8.46.23.1.1.3.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Interface description','zyxel.4728f.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  ZYXEL-XGS4728F-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34810','15','','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Outgoing utilization','zyxel.4728f.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.4728f.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34811','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.4728f.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34812','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Outgoing traffic','zyxel.4728f.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34813','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.4728f.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34814','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.4728f.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34815','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Operational status','zyxel.4728f.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'233','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34816','20','.1.3.6.1.4.1.890.1.5.8.46.23.1.1.5.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Link type','zyxel.4728f.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'231','','','0','','','','','2',NULL,'MIB:  ZYXEL-XGS4728F-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34817','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Interface name','zyxel.4728f.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34818','15','','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Incoming utilization','zyxel.4728f.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'last(zyxel.4728f.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34819','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.4728f.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34820','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Incoming traffic','zyxel.4728f.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34821','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.4728f.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34822','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.4728f.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34823','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Link speed','zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34824','20','.1.3.6.1.4.1.890.1.5.8.46.23.1.1.1.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Speed Duplex','zyxel.4728f.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'230','','','0','','','','','2',NULL,'MIB:  ZYXEL-XGS4728F-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34825','20','.1.3.6.1.4.1.890.1.5.8.46.117.2.1.7.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.4728f.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34826','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.7.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Date code','zyxel.4728f.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34827','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.4.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Part number','zyxel.4728f.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34828','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.6.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Revision','zyxel.4728f.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34829','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.5.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Serial number','zyxel.4728f.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34830','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.2.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Status','zyxel.4728f.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'234','','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34831','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.8.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Transceiver','zyxel.4728f.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34832','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.3.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Vendor','zyxel.4728f.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34833','20','.1.3.6.1.4.1.890.1.5.8.46.9.2.1.2.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.4728f.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34834','20','.1.3.6.1.4.1.890.1.5.8.46.9.3.1.2.{#SNMPINDEX}','10398','ZYXEL XGS-4728F: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.4728f.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34835','19','','10399','Nginx: Get connections','nginx.connections','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns statistics of client connections.','0','30d','0','',NULL,'3s','{$NGINX.API.ENDPOINT}/6/connections/','','','200,404','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34836','19','','10399','Nginx: Get info','nginx.info','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Return status of nginx running instance.','0','30d','0','',NULL,'3s','{$NGINX.API.ENDPOINT}/6/nginx/','','','200,404','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34837','19','','10399','Nginx: Get Stream server zones','nginx.stream.server_zones','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns status information for each stream server zone.','0','30d','0','',NULL,'3s','{$NGINX.API.ENDPOINT}/6/stream/server_zones/','','','200,404','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34838','19','','10399','Nginx: Get SSL','nginx.ssl','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns SSL statistics.','0','30d','0','',NULL,'3s','{$NGINX.API.ENDPOINT}/6/ssl/','','','200,404','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34839','19','','10399','Nginx: Get resolvers','nginx.resolvers','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns status information for each resolver zone.','0','30d','0','',NULL,'3s','{$NGINX.API.ENDPOINT}/6/resolvers/','','','200,404','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34840','19','','10399','Nginx: Get requests','nginx.requests','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns status of client HTTP requests.','0','30d','0','',NULL,'3s','{$NGINX.API.ENDPOINT}/6/http/requests/','','','200,404','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34841','19','','10399','Nginx: Get Stream upstreams','nginx.stream.upstreams','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns status of each stream upstream server group and its servers.','0','30d','0','',NULL,'3s','{$NGINX.API.ENDPOINT}/6/stream/upstreams/','','','200,404','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34842','19','','10399','Nginx: Get HTTP upstreams','nginx.http.upstreams','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns status of each HTTP upstream server group and its servers.','0','30d','0','',NULL,'3s','{$NGINX.API.ENDPOINT}/6/http/upstreams/','','','200,404','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34843','19','','10399','Nginx: Get HTTP location zones','nginx.http.location_zones','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns status information for each HTTP location zone.','0','30d','0','',NULL,'3s','{$NGINX.API.ENDPOINT}/6/http/location_zones/','','','200,404','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34844','19','','10399','Nginx: Get HTTP zones','nginx.http.server_zones','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns status information for each HTTP server zone.','0','30d','0','',NULL,'3s','{$NGINX.API.ENDPOINT}/6/http/server_zones/','','','200,404','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34944','0','','10328','PostgreSQL: Cache hit','pgsql.cache.hit["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34945','0','','10328','PostgreSQL: Age of oldest xid','pgsql.oldest.xid["{$PG.URI}","{$PG.USER}","{$PG.PASSWORD}"]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Age of oldest xid.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34946','20','1.3.6.1.2.1.1.4.0','10400','System contact details','cisco.ucs.contact[sysContact.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed
node, together with information on how to contact this person.  If no contact
information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34947','20','1.3.6.1.2.1.1.1.0','10400','System description','cisco.ucs.descr[sysDescr.0]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34948','20','1.3.6.1.2.1.1.6.0','10400','System location','cisco.ucs.location[sysLocation.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet,
3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34949','20','1.3.6.1.2.1.1.5.0','10400','System name','cisco.ucs.name[sysName.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By
convention, this is the node''s fully-qualified domain name.  If the name is unknown,
the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34950','20','1.3.6.1.2.1.1.2.0','10400','System object ID','cisco.ucs.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management
subsystem contained in the entity.  This value is allocated within the SMI enterprises
subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining ''what
kind of box'' is being managed. For example, if vendor ''Flintstones, Inc.'' was
assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1
to its ''Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34951','20','1.3.6.1.2.1.1.3.0','10400','Uptime','cisco.ucs.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time in seconds since the network management
portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34952','17','','10400','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34953','5','','10400','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'Availability of SNMP checks on the host. The value of this item corresponds to availability icons in the host list.
Possible value:
0 - not available
1 - available
2 - unknown','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34954','20','discovery[{#DISKARRAY_CACHE_LOCATION},1.3.6.1.4.1.9.9.719.1.45.11.1.2]','10400','Array controller cache discovery','cisco.ucs.array.cache.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CISCO-UNIFIED-COMPUTING-STORAGE-MIB::cucsStorageControllerTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34955','20','discovery[{#DISKARRAY_LOCATION},1.3.6.1.4.1.9.9.719.1.45.1.1.2]','10400','Array controller discovery','cisco.ucs.array.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CISCO-UNIFIED-COMPUTING-STORAGE-MIB::cucsStorageControllerTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34956','20','discovery[{#FAN_LOCATION},1.3.6.1.4.1.9.9.719.1.15.12.1.2]','10400','FAN discovery','cisco.ucs.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34957','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10400','Network interface discovery','cisco.ucs.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34958','20','discovery[{#DISK_LOCATION},1.3.6.1.4.1.9.9.719.1.45.4.1.2]','10400','Physical disk discovery','cisco.ucs.physicalDisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of physical drive entries CISCO-UNIFIED-COMPUTING-STORAGE-MIB::cucsStorageLocalDiskTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34959','20','discovery[{#PSU_LOCATION},1.3.6.1.4.1.9.9.719.1.15.56.1.2]','10400','PSU discovery','cisco.ucs.psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34960','20','discovery[{#SENSOR_LOCATION},1.3.6.1.4.1.9.9.719.1.41.2.1.2]','10400','Temperature CPU discovery','cisco.ucs.temp.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34961','20','discovery[{#SENSOR_LOCATION},1.3.6.1.4.1.9.9.719.1.9.44.1.2]','10400','Temperature discovery','cisco.ucs.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34962','20','discovery[{#UNIT_LOCATION},1.3.6.1.4.1.9.9.719.1.9.35.1.2]','10400','Unit discovery','cisco.ucs.unit.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34963','20','discovery[{#VDISK_LOCATION},1.3.6.1.4.1.9.9.719.1.45.8.1.2]','10400','Virtual disk discovery','cisco.ucs.virtualDisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CISCO-UNIFIED-COMPUTING-STORAGE-MIB::cucsStorageLocalLunTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34964','20','1.3.6.1.4.1.9.9.719.1.45.11.1.9.{#SNMPINDEX}','10400','{#DISKARRAY_CACHE_LOCATION}: Disk array cache controller battery status','cisco.ucs.hw.diskarray.cache.battery.status[cucsStorageRaidBatteryOperability.{#SNMPINDEX}]','1m','1w','0d','0','3','','','','',NULL,'84','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34965','20','1.3.6.1.4.1.9.9.719.1.45.1.1.5.{#SNMPINDEX}','10400','{#DISKARRAY_LOCATION}: Disk array controller model','cisco.ucs.hw.diskarray.model[cucsStorageControllerModel.{#SNMPINDEX}]','1d','90d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34966','20','1.3.6.1.4.1.9.9.719.1.45.1.1.6.{#SNMPINDEX}','10400','{#DISKARRAY_LOCATION}: Disk array controller status','cisco.ucs.hw.diskarray.status[cucsStorageControllerOperState.{#SNMPINDEX}]','1m','1w','0d','0','3','','','','',NULL,'84','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:RaidBattery:operability managed object property.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34967','20','1.3.6.1.4.1.9.9.719.1.15.12.1.9.{#SNMPINDEX}','10400','{#FAN_LOCATION}: Fan status','cisco.ucs.sensor.fan.status[cucsEquipmentFanOperState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'84','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-EQUIPMENT-MIB
Cisco UCS equipment:Fan:operState managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34968','20','1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Interface description','cisco.ucs.if.descr[ifDescr.{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the
interface.  This string should include the name of the
manufacturer, the product name and the version of the
interface hardware/software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34969','20','1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Broadcast packets received','cisco.ucs.if.in.broadcast[ifHCInBroadcastPkts.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.  This object is a 64-bit version
of ifInBroadcastPkts.

Discontinuities in the value of this counter can occur at
re-initialization of the management system, and at other
times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34970','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','cisco.ucs.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34971','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','cisco.ucs.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34972','20','1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Multicast packets received','cisco.ucs.if.in.multicast[ifHCInMulticastPkts.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.  This object
is a 64-bit version of ifInMulticastPkts.

Discontinuities in the value of this counter can occur at
re-initialization of the management system, and at other
times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34973','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Bits received','cisco.ucs.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34974','20','1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Broadcast packets sent','cisco.ucs.if.out.broadcast[ifHCOutBroadcastPkts.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.  This object is a 64-bit version
of ifOutBroadcastPkts.

Discontinuities in the value of this counter can occur at
re-initialization of the management system, and at other
times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34975','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','cisco.ucs.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34976','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','cisco.ucs.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34977','20','1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Multicast packets sent','cisco.ucs.if.out.multicast[ifHCOutMulticastPkts.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.  This object
is a 64-bit version of ifOutMulticastPkts.

Discontinuities in the value of this counter can occur at
re-initialization of the management system, and at other
times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34978','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Bits sent','cisco.ucs.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34979','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Speed','cisco.ucs.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34980','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Operational status','cisco.ucs.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34981','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10400','Interface {#IFNAME}({#IFALIAS}): Interface type','cisco.ucs.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','',NULL,'21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34982','20','1.3.6.1.4.1.9.9.719.1.45.4.1.17.{#SNMPINDEX}','10400','{#DISK_LOCATION}: Physical disk media type','cisco.ucs.hw.physicaldisk.media_type[cucsStorageLocalDiskDeviceType.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,'235','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalDisk:deviceType managed object property. Actually returns ''HDD'' or ''SSD''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34983','20','1.3.6.1.4.1.9.9.719.1.45.4.1.7.{#SNMPINDEX}','10400','{#DISK_LOCATION}: Physical disk model name','cisco.ucs.hw.physicaldisk.model[cucsStorageLocalDiskModel.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalDisk:model managed object property.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34984','20','1.3.6.1.4.1.9.9.719.1.45.4.1.12.{#SNMPINDEX}','10400','{#DISK_LOCATION}: Physical disk serial number','cisco.ucs.hw.physicaldisk.serialnumber[cucsStorageLocalDiskSerial.{#SNMPINDEX}]','1h','90d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalDisk:serial managed object property. Actually returns part number code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34985','20','1.3.6.1.4.1.9.9.719.1.45.4.1.13.{#SNMPINDEX}','10400','{#DISK_LOCATION}: Disk size','cisco.ucs.hw.physicaldisk.size[cucsStorageLocalDiskSize.{#SNMPINDEX}]','1h','2w','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalDisk:size managed object property. In MB.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34986','20','1.3.6.1.4.1.9.9.719.1.45.4.1.18.{#SNMPINDEX}','10400','{#DISK_LOCATION}: Physical disk status','cisco.ucs.hw.physicaldisk.status[cucsStorageLocalDiskDiskState.{#SNMPINDEX}]','3m','90d','0d','0','3','','','','',NULL,'86','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalDisk:diskState managed object property.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34987','20','1.3.6.1.4.1.9.9.719.1.15.56.1.7.{#SNMPINDEX}','10400','{#PSU_LOCATION}: Power supply status','cisco.ucs.sensor.psu.status[cucsEquipmentPsuOperState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','',NULL,'84','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-EQUIPMENT-MIB
Cisco UCS equipment:Psu:operState managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34988','20','1.3.6.1.4.1.9.9.719.1.41.2.1.10.{#SNMPINDEX}','10400','{#SENSOR_LOCATION}: Temperature','cisco.ucs.sensor.temp.value[cucsProcessorEnvStatsTemperature.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-PROCESSOR-MIB
Cisco UCS processor:EnvStats:temperature managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34989','20','1.3.6.1.4.1.9.9.719.1.9.44.1.13.{#SNMPINDEX}','10400','{#SENSOR_LOCATION}.IOH: Temperature','cisco.ucs.sensor.temp.value[cucsComputeRackUnitMbTempSltatsIoh1Temp.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Cisco UCS compute:RackUnitMbTempStats:ioh1Temp managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34990','20','1.3.6.1.4.1.9.9.719.1.9.44.1.4.{#SNMPINDEX}','10400','{#SENSOR_LOCATION}.Ambient: Temperature','cisco.ucs.sensor.temp.value[cucsComputeRackUnitMbTempStatsAmbientTemp.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Temperature readings of testpoint: {#SENSOR_LOCATION}.Ambient','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34991','20','1.3.6.1.4.1.9.9.719.1.9.44.1.8.{#SNMPINDEX}','10400','{#SENSOR_LOCATION}.Front: Temperature','cisco.ucs.sensor.temp.value[cucsComputeRackUnitMbTempStatsFrontTemp.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Cisco UCS compute:RackUnitMbTempStats:frontTemp managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34992','20','1.3.6.1.4.1.9.9.719.1.9.44.1.21.{#SNMPINDEX}','10400','{#SENSOR_LOCATION}.Rear: Temperature','cisco.ucs.sensor.temp.value[cucsComputeRackUnitMbTempStatsRearTemp.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Cisco UCS compute:RackUnitMbTempStats:rearTemp managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34993','20','1.3.6.1.4.1.9.9.719.1.9.35.1.32.{#SNMPINDEX}','10400','{#UNIT_LOCATION}: Hardware model name','cisco.ucs.hw.model[cucsComputeRackUnitModel.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Cisco UCS compute:RackUnit:model managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34994','20','1.3.6.1.4.1.9.9.719.1.9.35.1.47.{#SNMPINDEX}','10400','{#UNIT_LOCATION}: Hardware serial number','cisco.ucs.hw.serialnumber[cucsComputeRackUnitSerial.{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Cisco UCS compute:RackUnit:serial managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34995','20','1.3.6.1.4.1.9.9.719.1.9.35.1.42.{#SNMPINDEX}','10400','{#UNIT_LOCATION}: Overall system health status','cisco.ucs.status[cucsComputeRackUnitOperState.{#SNMPINDEX}]','30s','2w','0d','0','3','','','','',NULL,'85','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-COMPUTE-MIB
Cisco UCS compute:RackUnit:operState managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34996','20','1.3.6.1.4.1.9.9.719.1.45.8.1.14.{#SNMPINDEX}','10400','{#VDISK_LOCATION}: Layout type','cisco.ucs.hw.virtualdisk.layout[cucsStorageLocalLunType.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,'87','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalLun:type managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34997','20','1.3.6.1.4.1.9.9.719.1.45.8.1.13.{#SNMPINDEX}','10400','{#VDISK_LOCATION}: Disk size','cisco.ucs.hw.virtualdisk.size[cucsStorageLocalLunSize.{#SNMPINDEX}]','1h','2w','0d','0','3','','B','','',NULL,'87','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalLun:size managed object property in MB.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34998','20','1.3.6.1.4.1.9.9.719.1.45.8.1.10.{#SNMPINDEX}','10400','{#VDISK_LOCATION}: Status','cisco.ucs.hw.virtualdisk.status[cucsStorageLocalLunPresence.{#SNMPINDEX}]','3m','2w','365d','0','3','','','','',NULL,'88','','','0','','','','','2',NULL,'MIB: CISCO-UNIFIED-COMPUTING-STORAGE-MIB
Cisco UCS storage:LocalLun:presence managed object property','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35041','20','1.3.6.1.2.1.1.4.0','10402','Dell R720: System contact details','dell.server.contact[sysContact]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person. If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35042','20','1.3.6.1.2.1.1.1.0','10402','Dell R720: System description','dell.server.descr[sysDescr]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35043','20','1.3.6.1.4.1.674.10892.5.1.1.8.0','10402','Dell R720: Firmware version','dell.server.hw.firmware[racFirmwareVersion]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the firmware version of a remote access card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35044','20','1.3.6.1.4.1.674.10892.5.1.3.12.0','10402','Dell R720: Hardware model name','dell.server.hw.model[systemModelName]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the model name of the system.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35045','20','1.3.6.1.4.1.674.10892.5.1.3.2.0','10402','Dell R720: Hardware serial number','dell.server.hw.serialnumber[systemServiceTag]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the service tag of the system.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35046','20','1.3.6.1.2.1.1.6.0','10402','Dell R720: System location','dell.server.location[sysLocation]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., ''telephone closet, 3rd floor''). If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35047','20','1.3.6.1.2.1.1.5.0','10402','Dell R720: System name','dell.server.name[sysName]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node. By convention, this is the node''s fully-qualified domain name. If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35048','20','1.3.6.1.2.1.1.2.0','10402','Dell R720: System object ID','dell.server.objectid[sysObjectID]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity. This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining ''what kind of box'' is being managed. For example, if vendor ''Flintstones, Inc.'' was assigned the subtree 1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its ''Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35049','20','1.3.6.1.4.1.674.10892.5.2.1.0','10402','Dell R720: Overall system health status','dell.server.status[globalSystemStatus]','1m','7d','0d','0','3','','','','',NULL,'59','','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the overall rollup status of all components in the system being monitored by the remote access card. Includes system, storage, IO devices, iDRAC, CPU, memory, etc.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35050','20','1.3.6.1.4.1.674.10892.5.1.3.6.0','10402','Dell R720: Operating system','dell.server.sw.os[systemOSName]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the name of the operating system that the host is running.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35051','20','1.3.6.1.2.1.1.3.0','10402','Dell R720: Uptime','dell.server.uptime[sysUpTime]','1m','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35052','17','','10402','Dell R720: SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'The item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35053','5','','10402','Dell R720: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35054','20','discovery[{#BATTERY_NUM},1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.1,{#BATTERY_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.21]','10402','Array controller cache discovery','array.cache.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: IDRAC-MIB-SMIv2::batteryTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35055','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.38,{#CNTLR_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.79]','10402','Array controller discovery','array.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: IDRAC-MIB-SMIv2::controllerTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35056','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.700.12.1.5,{#FAN_DESCR},1.3.6.1.4.1.674.10892.5.4.700.12.1.8,{#TYPE},1.3.6.1.4.1.674.10892.5.4.700.12.1.7]','10402','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::coolingDeviceTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35057','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.1,{#DISK_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.2]','10402','Physical disk discovery','physicaldisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning  table of physical drive entries IDRAC-MIB-SMIv2::physicalDiskTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35058','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.600.12.1.5,{#PSU_DESCR},1.3.6.1.4.1.674.10892.5.4.600.12.1.8]','10402','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::powerSupplyTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35059','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.700.20.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.674.10892.5.4.700.20.1.8]','10402','Temperature discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Probe Table IDRAC-MIB-SMIv2::temperatureProbeTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35060','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.1,{#DISK_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.2]','10402','Virtual disk discovery','virtualdisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::virtualDiskTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35061','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.4.{#SNMPINDEX}','10402','Dell R720: {#BATTERY_NAME} Status','dell.server.hw.diskarray.cache.battery.status[batteryState.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'64','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
Current state of battery.
Possible values:
1: The current state could not be determined.
2: The battery is operating normally.
3: The battery has failed and needs to be replaced.
4: The battery temperature is high or charge level is depleting.
5: The battery is missing or not detected.
6: The battery is undergoing the re-charge phase.
7: The battery voltage or charge level is below the threshold.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35062','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.2.{#SNMPINDEX}','10402','Dell R720: {#CNTLR_NAME} Model','dell.server.hw.diskarray.model[controllerName.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The controller''s name as represented in Storage Management.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35063','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.38.{#SNMPINDEX}','10402','Dell R720: {#CNTLR_NAME} Status','dell.server.hw.diskarray.status[controllerComponentStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'59','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The status of the controller itself without the propagation of any contained component status.
Possible values:
1: Other
2: Unknown
3: OK
4: Non-critical
5: Critical
6: Non-recoverable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35064','20','1.3.6.1.4.1.674.10892.5.4.700.12.1.6.{#SNMPINDEX}','10402','Dell R720: {#FAN_DESCR} Speed','dell.server.sensor.fan.speed[coolingDeviceReading.{#SNMPINDEX}]','1m','7d','365d','0','3','','rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the reading for a cooling device
of subtype other than coolingDeviceSubTypeIsDiscrete. When the value
for coolingDeviceSubType is other than coolingDeviceSubTypeIsDiscrete, the
value returned for this attribute is the speed in RPM or the OFF/ON value
of the cooling device. When the value for coolingDeviceSubType is
coolingDeviceSubTypeIsDiscrete, a value is not returned for this attribute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35065','20','1.3.6.1.4.1.674.10892.5.4.700.12.1.5.{#SNMPINDEX}','10402','Dell R720: {#FAN_DESCR} Status','dell.server.sensor.fan.status[coolingDeviceStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the probe status of the cooling device.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35066','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.35.{#SNMPINDEX}','10402','Dell R720: {#DISK_NAME} Media type','dell.server.hw.physicaldisk.media_type[physicalDiskMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'63','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The media type of the physical disk. Possible Values:
1: The media type could not be determined.
2: Hard Disk Drive (HDD).
3: Solid State Drive (SSD).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35067','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.6.{#SNMPINDEX}','10402','Dell R720: {#DISK_NAME} Model name','dell.server.hw.physicaldisk.model[physicalDiskProductID.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The model number of the physical disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35068','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.7.{#SNMPINDEX}','10402','Dell R720: {#DISK_NAME} Serial number','dell.server.hw.physicaldisk.serialnumber[physicalDiskSerialNo.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The physical disk''s unique identification number from the manufacturer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35069','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.11.{#SNMPINDEX}','10402','Dell R720: {#DISK_NAME} Size','dell.server.hw.physicaldisk.size[physicalDiskCapacityInMB.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The size of the physical disk in megabytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35070','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.31.{#SNMPINDEX}','10402','Dell R720: {#DISK_NAME} S.M.A.R.T. Status','dell.server.hw.physicaldisk.smart_status[physicalDiskSmartAlertIndication.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'62','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
Indicates whether the physical disk has received a predictive failure alert.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35071','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.24.{#SNMPINDEX}','10402','Dell R720: {#DISK_NAME} Status','dell.server.hw.physicaldisk.status[physicalDiskComponentStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'61','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The status of the physical disk itself without the propagation of any contained component status.
Possible values:
1: Other
2: Unknown
3: OK
4: Non-critical
5: Critical
6: Non-recoverable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35072','20','1.3.6.1.4.1.674.10892.5.4.600.12.1.5.{#SNMPINDEX}','10402','Dell R720: {#PSU_DESCR}','dell.server.sensor.psu.status[powerSupplyStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'59','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
0600.0012.0001.0005 This attribute defines the status of the power supply.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35073','20','1.3.6.1.4.1.674.10892.5.4.700.20.1.5.{#SNMPINDEX}','10402','Dell R720: {#SENSOR_LOCALE} Status','dell.server.sensor.temp.status[temperatureProbeStatus.{#SNMPINDEX}]','1m','7d','0d','0','0','','','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the probe status of the temperature probe.
Possible values:
other(1),               -- probe status is not one of the following:
unknown(2),             -- probe status is unknown (not known or monitored)
ok(3),                  -- probe is reporting a value within the thresholds
nonCriticalUpper(4),    -- probe has crossed the upper noncritical threshold
criticalUpper(5),       -- probe has crossed the upper critical threshold
nonRecoverableUpper(6), -- probe has crossed the upper non-recoverable threshold
nonCriticalLower(7),    -- probe has crossed the lower noncritical threshold
criticalLower(8),       -- probe has crossed the lower critical threshold
nonRecoverableLower(9), -- probe has crossed the lower non-recoverable threshold
failed(10)              -- probe is not functional','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35074','20','1.3.6.1.4.1.674.10892.5.4.700.20.1.6.{#SNMPINDEX}','10402','Dell R720: {#SENSOR_LOCALE} Value','dell.server.sensor.temp.value[temperatureProbeReading.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the reading for a temperature probe of type other than temperatureProbeTypeIsDiscrete. When the value for temperatureProbeType is other than temperatureProbeTypeIsDiscrete, the value returned for this attribute is the temperature that the probe is reading in Centigrade. When the value for temperatureProbeType is temperatureProbeTypeIsDiscrete, a value is not returned for this attribute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35075','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.13.{#SNMPINDEX}','10402','Dell R720: {#DISK_NAME} Layout type','dell.server.hw.virtualdisk.layout[virtualDiskLayout.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'65','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The virtual disk''s RAID type.
Possible values:
1: Not one of the following
2: RAID-0
3: RAID-1
4: RAID-5
5: RAID-6
6: RAID-10
7: RAID-50
8: RAID-60
9: Concatenated RAID 1
10: Concatenated RAID 5','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35076','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.11.{#SNMPINDEX}','10402','Dell R720: {#DISK_NAME} Read policy','dell.server.hw.virtualdisk.readpolicy[virtualDiskReadPolicy.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,'68','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The read policy used by the controller for read operations on this virtual disk.
Possible values:
1: No Read Ahead.
2: Read Ahead.
3: Adaptive Read Ahead.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35077','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.6.{#SNMPINDEX}','10402','Dell R720: {#DISK_NAME} Size','dell.server.hw.virtualdisk.size[virtualDiskSizeInMB.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The size of the virtual disk in megabytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35078','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.30.{#SNMPINDEX}','10402','Dell R720: {#DISK_NAME} Current state','dell.server.hw.virtualdisk.state[virtualDiskOperationalState.{#SNMPINDEX}]','3m','2w','365d','0','3','','','','',NULL,'66','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The state of the virtual disk when there are progressive operations ongoing.
Possible values:
1: There is no active operation running.
2: The virtual disk configuration has changed. The physical disks included in the virtual disk are being modified to support the new configuration.
3: A Consistency Check (CC) is being performed on the virtual disk.
4: The virtual disk is being initialized.
5: BackGround Initialization (BGI) is being performed on the virtual disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35079','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.4.{#SNMPINDEX}','10402','Dell R720: {#DISK_NAME} Status','dell.server.hw.virtualdisk.status[virtualDiskState.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'69','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The current state of this virtual disk (which includes any member physical disks.)
Possible states:
1: The current state could not be determined.
2: The virtual disk is operating normally or optimally.
3: The virtual disk has encountered a failure. Data on the disk is lost or is about to be lost.
4: The virtual disk encountered a failure with one or all of the constituent redundant physical disks.
The data on the virtual disk might no longer be fault tolerant.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35080','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.10.{#SNMPINDEX}','10402','Dell R720: {#DISK_NAME} Write policy','dell.server.hw.virtualdisk.writepolicy[virtualDiskWritePolicy.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,'67','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The write policy used by the controller for write operations on this virtual disk.
Possible values:
1: Write Through.
2: Write Back.
3: Force Write Back.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35123','20','1.3.6.1.2.1.1.4.0','10404','Dell R740: System contact details','dell.server.contact[sysContact]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person. If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35124','20','1.3.6.1.2.1.1.1.0','10404','Dell R740: System description','dell.server.descr[sysDescr]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35125','20','1.3.6.1.4.1.674.10892.5.1.1.8.0','10404','Dell R740: Firmware version','dell.server.hw.firmware[racFirmwareVersion]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the firmware version of a remote access card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35126','20','1.3.6.1.4.1.674.10892.5.1.3.12.0','10404','Dell R740: Hardware model name','dell.server.hw.model[systemModelName]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the model name of the system.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35127','20','1.3.6.1.4.1.674.10892.5.1.3.2.0','10404','Dell R740: Hardware serial number','dell.server.hw.serialnumber[systemServiceTag]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the service tag of the system.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35128','20','1.3.6.1.2.1.1.6.0','10404','Dell R740: System location','dell.server.location[sysLocation]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., ''telephone closet, 3rd floor''). If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35129','20','1.3.6.1.2.1.1.5.0','10404','Dell R740: System name','dell.server.name[sysName]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node. By convention, this is the node''s fully-qualified domain name. If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35130','20','1.3.6.1.2.1.1.2.0','10404','Dell R740: System object ID','dell.server.objectid[sysObjectID]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity. This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining ''what kind of box'' is being managed. For example, if vendor ''Flintstones, Inc.'' was assigned the subtree 1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its ''Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35131','20','1.3.6.1.4.1.674.10892.5.2.1.0','10404','Dell R740: Overall system health status','dell.server.status[globalSystemStatus]','1m','7d','0d','0','3','','','','',NULL,'59','','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the overall rollup status of all components in the system being monitored by the remote access card. Includes system, storage, IO devices, iDRAC, CPU, memory, etc.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35132','20','1.3.6.1.4.1.674.10892.5.1.3.6.0','10404','Dell R740: Operating system','dell.server.sw.os[systemOSName]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the name of the operating system that the host is running.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35133','20','1.3.6.1.2.1.1.3.0','10404','Dell R740: Uptime','dell.server.uptime[sysUpTime]','1m','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35134','17','','10404','Dell R740: SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'The item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35135','5','','10404','Dell R740: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35136','20','discovery[{#BATTERY_NUM},1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.1,{#BATTERY_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.21]','10404','Array controller cache discovery','array.cache.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: IDRAC-MIB-SMIv2::batteryTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35137','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.38,{#CNTLR_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.79]','10404','Array controller discovery','array.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: IDRAC-MIB-SMIv2::controllerTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35138','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.700.12.1.5,{#FAN_DESCR},1.3.6.1.4.1.674.10892.5.4.700.12.1.8,{#TYPE},1.3.6.1.4.1.674.10892.5.4.700.12.1.7]','10404','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::coolingDeviceTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35139','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.1,{#DISK_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.2]','10404','Physical disk discovery','physicaldisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning  table of physical drive entries IDRAC-MIB-SMIv2::physicalDiskTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35140','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.600.12.1.5,{#PSU_DESCR},1.3.6.1.4.1.674.10892.5.4.600.12.1.8]','10404','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::powerSupplyTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35141','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.700.20.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.674.10892.5.4.700.20.1.8]','10404','Temperature discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Probe Table IDRAC-MIB-SMIv2::temperatureProbeTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35142','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.1,{#DISK_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.2]','10404','Virtual disk discovery','virtualdisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::virtualDiskTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35143','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.4.{#SNMPINDEX}','10404','Dell R740: {#BATTERY_NAME} Status','dell.server.hw.diskarray.cache.battery.status[batteryState.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'64','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
Current state of battery.
Possible values:
1: The current state could not be determined.
2: The battery is operating normally.
3: The battery has failed and needs to be replaced.
4: The battery temperature is high or charge level is depleting.
5: The battery is missing or not detected.
6: The battery is undergoing the re-charge phase.
7: The battery voltage or charge level is below the threshold.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35144','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.2.{#SNMPINDEX}','10404','Dell R740: {#CNTLR_NAME} Model','dell.server.hw.diskarray.model[controllerName.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The controller''s name as represented in Storage Management.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35145','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.38.{#SNMPINDEX}','10404','Dell R740: {#CNTLR_NAME} Status','dell.server.hw.diskarray.status[controllerComponentStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'59','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The status of the controller itself without the propagation of any contained component status.
Possible values:
1: Other
2: Unknown
3: OK
4: Non-critical
5: Critical
6: Non-recoverable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35146','20','1.3.6.1.4.1.674.10892.5.4.700.12.1.6.{#SNMPINDEX}','10404','Dell R740: {#FAN_DESCR} Speed','dell.server.sensor.fan.speed[coolingDeviceReading.{#SNMPINDEX}]','1m','7d','365d','0','3','','rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the reading for a cooling device
of subtype other than coolingDeviceSubTypeIsDiscrete. When the value
for coolingDeviceSubType is other than coolingDeviceSubTypeIsDiscrete, the
value returned for this attribute is the speed in RPM or the OFF/ON value
of the cooling device. When the value for coolingDeviceSubType is
coolingDeviceSubTypeIsDiscrete, a value is not returned for this attribute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35147','20','1.3.6.1.4.1.674.10892.5.4.700.12.1.5.{#SNMPINDEX}','10404','Dell R740: {#FAN_DESCR} Status','dell.server.sensor.fan.status[coolingDeviceStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the probe status of the cooling device.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35148','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.35.{#SNMPINDEX}','10404','Dell R740: {#DISK_NAME} Media type','dell.server.hw.physicaldisk.media_type[physicalDiskMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'63','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The media type of the physical disk. Possible Values:
1: The media type could not be determined.
2: Hard Disk Drive (HDD).
3: Solid State Drive (SSD).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35149','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.6.{#SNMPINDEX}','10404','Dell R740: {#DISK_NAME} Model name','dell.server.hw.physicaldisk.model[physicalDiskProductID.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The model number of the physical disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35150','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.7.{#SNMPINDEX}','10404','Dell R740: {#DISK_NAME} Serial number','dell.server.hw.physicaldisk.serialnumber[physicalDiskSerialNo.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The physical disk''s unique identification number from the manufacturer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35151','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.11.{#SNMPINDEX}','10404','Dell R740: {#DISK_NAME} Size','dell.server.hw.physicaldisk.size[physicalDiskCapacityInMB.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The size of the physical disk in megabytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35152','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.31.{#SNMPINDEX}','10404','Dell R740: {#DISK_NAME} S.M.A.R.T. Status','dell.server.hw.physicaldisk.smart_status[physicalDiskSmartAlertIndication.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'62','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
Indicates whether the physical disk has received a predictive failure alert.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35153','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.24.{#SNMPINDEX}','10404','Dell R740: {#DISK_NAME} Status','dell.server.hw.physicaldisk.status[physicalDiskComponentStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'61','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The status of the physical disk itself without the propagation of any contained component status.
Possible values:
1: Other
2: Unknown
3: OK
4: Non-critical
5: Critical
6: Non-recoverable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35154','20','1.3.6.1.4.1.674.10892.5.4.600.12.1.5.{#SNMPINDEX}','10404','Dell R740: {#PSU_DESCR}','dell.server.sensor.psu.status[powerSupplyStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'59','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
0600.0012.0001.0005 This attribute defines the status of the power supply.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35155','20','1.3.6.1.4.1.674.10892.5.4.700.20.1.5.{#SNMPINDEX}','10404','Dell R740: {#SENSOR_LOCALE} Status','dell.server.sensor.temp.status[temperatureProbeStatus.{#SNMPINDEX}]','1m','7d','0d','0','0','','','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the probe status of the temperature probe.
Possible values:
other(1),               -- probe status is not one of the following:
unknown(2),             -- probe status is unknown (not known or monitored)
ok(3),                  -- probe is reporting a value within the thresholds
nonCriticalUpper(4),    -- probe has crossed the upper noncritical threshold
criticalUpper(5),       -- probe has crossed the upper critical threshold
nonRecoverableUpper(6), -- probe has crossed the upper non-recoverable threshold
nonCriticalLower(7),    -- probe has crossed the lower noncritical threshold
criticalLower(8),       -- probe has crossed the lower critical threshold
nonRecoverableLower(9), -- probe has crossed the lower non-recoverable threshold
failed(10)              -- probe is not functional','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35156','20','1.3.6.1.4.1.674.10892.5.4.700.20.1.6.{#SNMPINDEX}','10404','Dell R740: {#SENSOR_LOCALE} Value','dell.server.sensor.temp.value[temperatureProbeReading.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the reading for a temperature probe of type other than temperatureProbeTypeIsDiscrete. When the value for temperatureProbeType is other than temperatureProbeTypeIsDiscrete, the value returned for this attribute is the temperature that the probe is reading in Centigrade. When the value for temperatureProbeType is temperatureProbeTypeIsDiscrete, a value is not returned for this attribute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35157','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.13.{#SNMPINDEX}','10404','Dell R740: {#DISK_NAME} Layout type','dell.server.hw.virtualdisk.layout[virtualDiskLayout.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'65','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The virtual disk''s RAID type.
Possible values:
1: Not one of the following
2: RAID-0
3: RAID-1
4: RAID-5
5: RAID-6
6: RAID-10
7: RAID-50
8: RAID-60
9: Concatenated RAID 1
10: Concatenated RAID 5','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35158','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.11.{#SNMPINDEX}','10404','Dell R740: {#DISK_NAME} Read policy','dell.server.hw.virtualdisk.readpolicy[virtualDiskReadPolicy.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,'68','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The read policy used by the controller for read operations on this virtual disk.
Possible values:
1: No Read Ahead.
2: Read Ahead.
3: Adaptive Read Ahead.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35159','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.6.{#SNMPINDEX}','10404','Dell R740: {#DISK_NAME} Size','dell.server.hw.virtualdisk.size[virtualDiskSizeInMB.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The size of the virtual disk in megabytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35160','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.30.{#SNMPINDEX}','10404','Dell R740: {#DISK_NAME} Current state','dell.server.hw.virtualdisk.state[virtualDiskOperationalState.{#SNMPINDEX}]','3m','2w','365d','0','3','','','','',NULL,'66','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The state of the virtual disk when there are progressive operations ongoing.
Possible values:
1: There is no active operation running.
2: The virtual disk configuration has changed. The physical disks included in the virtual disk are being modified to support the new configuration.
3: A Consistency Check (CC) is being performed on the virtual disk.
4: The virtual disk is being initialized.
5: BackGround Initialization (BGI) is being performed on the virtual disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35161','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.4.{#SNMPINDEX}','10404','Dell R740: {#DISK_NAME} Status','dell.server.hw.virtualdisk.status[virtualDiskState.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'69','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The current state of this virtual disk (which includes any member physical disks.)
Possible states:
1: The current state could not be determined.
2: The virtual disk is operating normally or optimally.
3: The virtual disk has encountered a failure. Data on the disk is lost or is about to be lost.
4: The virtual disk encountered a failure with one or all of the constituent redundant physical disks.
The data on the virtual disk might no longer be fault tolerant.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35162','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.10.{#SNMPINDEX}','10404','Dell R740: {#DISK_NAME} Write policy','dell.server.hw.virtualdisk.writepolicy[virtualDiskWritePolicy.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,'67','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The write policy used by the controller for write operations on this virtual disk.
Possible values:
1: Write Through.
2: Write Back.
3: Force Write Back.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35205','20','1.3.6.1.2.1.1.4.0','10406','Dell R820: System contact details','dell.server.contact[sysContact]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person. If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35206','20','1.3.6.1.2.1.1.1.0','10406','Dell R820: System description','dell.server.descr[sysDescr]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35207','20','1.3.6.1.4.1.674.10892.5.1.1.8.0','10406','Dell R820: Firmware version','dell.server.hw.firmware[racFirmwareVersion]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the firmware version of a remote access card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35208','20','1.3.6.1.4.1.674.10892.5.1.3.12.0','10406','Dell R820: Hardware model name','dell.server.hw.model[systemModelName]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the model name of the system.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35209','20','1.3.6.1.4.1.674.10892.5.1.3.2.0','10406','Dell R820: Hardware serial number','dell.server.hw.serialnumber[systemServiceTag]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the service tag of the system.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35210','20','1.3.6.1.2.1.1.6.0','10406','Dell R820: System location','dell.server.location[sysLocation]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., ''telephone closet, 3rd floor''). If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35211','20','1.3.6.1.2.1.1.5.0','10406','Dell R820: System name','dell.server.name[sysName]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node. By convention, this is the node''s fully-qualified domain name. If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35212','20','1.3.6.1.2.1.1.2.0','10406','Dell R820: System object ID','dell.server.objectid[sysObjectID]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity. This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining ''what kind of box'' is being managed. For example, if vendor ''Flintstones, Inc.'' was assigned the subtree 1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its ''Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35213','20','1.3.6.1.4.1.674.10892.5.2.1.0','10406','Dell R820: Overall system health status','dell.server.status[globalSystemStatus]','1m','7d','0d','0','3','','','','',NULL,'59','','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the overall rollup status of all components in the system being monitored by the remote access card. Includes system, storage, IO devices, iDRAC, CPU, memory, etc.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35214','20','1.3.6.1.4.1.674.10892.5.1.3.6.0','10406','Dell R820: Operating system','dell.server.sw.os[systemOSName]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the name of the operating system that the host is running.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35215','20','1.3.6.1.2.1.1.3.0','10406','Dell R820: Uptime','dell.server.uptime[sysUpTime]','1m','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35216','17','','10406','Dell R820: SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'The item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35217','5','','10406','Dell R820: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35218','20','discovery[{#BATTERY_NUM},1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.1,{#BATTERY_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.21]','10406','Array controller cache discovery','array.cache.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: IDRAC-MIB-SMIv2::batteryTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35219','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.38,{#CNTLR_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.79]','10406','Array controller discovery','array.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: IDRAC-MIB-SMIv2::controllerTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35220','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.700.12.1.5,{#FAN_DESCR},1.3.6.1.4.1.674.10892.5.4.700.12.1.8,{#TYPE},1.3.6.1.4.1.674.10892.5.4.700.12.1.7]','10406','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::coolingDeviceTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35221','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.1,{#DISK_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.2]','10406','Physical disk discovery','physicaldisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning  table of physical drive entries IDRAC-MIB-SMIv2::physicalDiskTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35222','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.600.12.1.5,{#PSU_DESCR},1.3.6.1.4.1.674.10892.5.4.600.12.1.8]','10406','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::powerSupplyTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35223','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.700.20.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.674.10892.5.4.700.20.1.8]','10406','Temperature discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Probe Table IDRAC-MIB-SMIv2::temperatureProbeTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35224','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.1,{#DISK_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.2]','10406','Virtual disk discovery','virtualdisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::virtualDiskTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35225','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.4.{#SNMPINDEX}','10406','Dell R820: {#BATTERY_NAME} Status','dell.server.hw.diskarray.cache.battery.status[batteryState.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'64','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
Current state of battery.
Possible values:
1: The current state could not be determined.
2: The battery is operating normally.
3: The battery has failed and needs to be replaced.
4: The battery temperature is high or charge level is depleting.
5: The battery is missing or not detected.
6: The battery is undergoing the re-charge phase.
7: The battery voltage or charge level is below the threshold.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35226','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.2.{#SNMPINDEX}','10406','Dell R820: {#CNTLR_NAME} Model','dell.server.hw.diskarray.model[controllerName.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The controller''s name as represented in Storage Management.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35227','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.38.{#SNMPINDEX}','10406','Dell R820: {#CNTLR_NAME} Status','dell.server.hw.diskarray.status[controllerComponentStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'59','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The status of the controller itself without the propagation of any contained component status.
Possible values:
1: Other
2: Unknown
3: OK
4: Non-critical
5: Critical
6: Non-recoverable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35228','20','1.3.6.1.4.1.674.10892.5.4.700.12.1.6.{#SNMPINDEX}','10406','Dell R820: {#FAN_DESCR} Speed','dell.server.sensor.fan.speed[coolingDeviceReading.{#SNMPINDEX}]','1m','7d','365d','0','3','','rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the reading for a cooling device
of subtype other than coolingDeviceSubTypeIsDiscrete. When the value
for coolingDeviceSubType is other than coolingDeviceSubTypeIsDiscrete, the
value returned for this attribute is the speed in RPM or the OFF/ON value
of the cooling device. When the value for coolingDeviceSubType is
coolingDeviceSubTypeIsDiscrete, a value is not returned for this attribute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35229','20','1.3.6.1.4.1.674.10892.5.4.700.12.1.5.{#SNMPINDEX}','10406','Dell R820: {#FAN_DESCR} Status','dell.server.sensor.fan.status[coolingDeviceStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the probe status of the cooling device.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35230','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.35.{#SNMPINDEX}','10406','Dell R820: {#DISK_NAME} Media type','dell.server.hw.physicaldisk.media_type[physicalDiskMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'63','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The media type of the physical disk. Possible Values:
1: The media type could not be determined.
2: Hard Disk Drive (HDD).
3: Solid State Drive (SSD).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35231','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.6.{#SNMPINDEX}','10406','Dell R820: {#DISK_NAME} Model name','dell.server.hw.physicaldisk.model[physicalDiskProductID.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The model number of the physical disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35232','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.7.{#SNMPINDEX}','10406','Dell R820: {#DISK_NAME} Serial number','dell.server.hw.physicaldisk.serialnumber[physicalDiskSerialNo.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The physical disk''s unique identification number from the manufacturer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35233','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.11.{#SNMPINDEX}','10406','Dell R820: {#DISK_NAME} Size','dell.server.hw.physicaldisk.size[physicalDiskCapacityInMB.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The size of the physical disk in megabytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35234','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.31.{#SNMPINDEX}','10406','Dell R820: {#DISK_NAME} S.M.A.R.T. Status','dell.server.hw.physicaldisk.smart_status[physicalDiskSmartAlertIndication.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'62','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
Indicates whether the physical disk has received a predictive failure alert.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35235','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.24.{#SNMPINDEX}','10406','Dell R820: {#DISK_NAME} Status','dell.server.hw.physicaldisk.status[physicalDiskComponentStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'61','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The status of the physical disk itself without the propagation of any contained component status.
Possible values:
1: Other
2: Unknown
3: OK
4: Non-critical
5: Critical
6: Non-recoverable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35236','20','1.3.6.1.4.1.674.10892.5.4.600.12.1.5.{#SNMPINDEX}','10406','Dell R820: {#PSU_DESCR}','dell.server.sensor.psu.status[powerSupplyStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'59','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
0600.0012.0001.0005 This attribute defines the status of the power supply.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35237','20','1.3.6.1.4.1.674.10892.5.4.700.20.1.5.{#SNMPINDEX}','10406','Dell R820: {#SENSOR_LOCALE} Status','dell.server.sensor.temp.status[temperatureProbeStatus.{#SNMPINDEX}]','1m','7d','0d','0','0','','','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the probe status of the temperature probe.
Possible values:
other(1),               -- probe status is not one of the following:
unknown(2),             -- probe status is unknown (not known or monitored)
ok(3),                  -- probe is reporting a value within the thresholds
nonCriticalUpper(4),    -- probe has crossed the upper noncritical threshold
criticalUpper(5),       -- probe has crossed the upper critical threshold
nonRecoverableUpper(6), -- probe has crossed the upper non-recoverable threshold
nonCriticalLower(7),    -- probe has crossed the lower noncritical threshold
criticalLower(8),       -- probe has crossed the lower critical threshold
nonRecoverableLower(9), -- probe has crossed the lower non-recoverable threshold
failed(10)              -- probe is not functional','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35238','20','1.3.6.1.4.1.674.10892.5.4.700.20.1.6.{#SNMPINDEX}','10406','Dell R820: {#SENSOR_LOCALE} Value','dell.server.sensor.temp.value[temperatureProbeReading.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the reading for a temperature probe of type other than temperatureProbeTypeIsDiscrete. When the value for temperatureProbeType is other than temperatureProbeTypeIsDiscrete, the value returned for this attribute is the temperature that the probe is reading in Centigrade. When the value for temperatureProbeType is temperatureProbeTypeIsDiscrete, a value is not returned for this attribute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35239','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.13.{#SNMPINDEX}','10406','Dell R820: {#DISK_NAME} Layout type','dell.server.hw.virtualdisk.layout[virtualDiskLayout.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'65','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The virtual disk''s RAID type.
Possible values:
1: Not one of the following
2: RAID-0
3: RAID-1
4: RAID-5
5: RAID-6
6: RAID-10
7: RAID-50
8: RAID-60
9: Concatenated RAID 1
10: Concatenated RAID 5','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35240','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.11.{#SNMPINDEX}','10406','Dell R820: {#DISK_NAME} Read policy','dell.server.hw.virtualdisk.readpolicy[virtualDiskReadPolicy.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,'68','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The read policy used by the controller for read operations on this virtual disk.
Possible values:
1: No Read Ahead.
2: Read Ahead.
3: Adaptive Read Ahead.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35241','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.6.{#SNMPINDEX}','10406','Dell R820: {#DISK_NAME} Size','dell.server.hw.virtualdisk.size[virtualDiskSizeInMB.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The size of the virtual disk in megabytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35242','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.30.{#SNMPINDEX}','10406','Dell R820: {#DISK_NAME} Current state','dell.server.hw.virtualdisk.state[virtualDiskOperationalState.{#SNMPINDEX}]','3m','2w','365d','0','3','','','','',NULL,'66','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The state of the virtual disk when there are progressive operations ongoing.
Possible values:
1: There is no active operation running.
2: The virtual disk configuration has changed. The physical disks included in the virtual disk are being modified to support the new configuration.
3: A Consistency Check (CC) is being performed on the virtual disk.
4: The virtual disk is being initialized.
5: BackGround Initialization (BGI) is being performed on the virtual disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35243','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.4.{#SNMPINDEX}','10406','Dell R820: {#DISK_NAME} Status','dell.server.hw.virtualdisk.status[virtualDiskState.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'69','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The current state of this virtual disk (which includes any member physical disks.)
Possible states:
1: The current state could not be determined.
2: The virtual disk is operating normally or optimally.
3: The virtual disk has encountered a failure. Data on the disk is lost or is about to be lost.
4: The virtual disk encountered a failure with one or all of the constituent redundant physical disks.
The data on the virtual disk might no longer be fault tolerant.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35244','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.10.{#SNMPINDEX}','10406','Dell R820: {#DISK_NAME} Write policy','dell.server.hw.virtualdisk.writepolicy[virtualDiskWritePolicy.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,'67','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The write policy used by the controller for write operations on this virtual disk.
Possible values:
1: Write Through.
2: Write Back.
3: Force Write Back.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35287','20','1.3.6.1.2.1.1.4.0','10408','Dell R840: System contact details','dell.server.contact[sysContact]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person. If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35288','20','1.3.6.1.2.1.1.1.0','10408','Dell R840: System description','dell.server.descr[sysDescr]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35289','20','1.3.6.1.4.1.674.10892.5.1.1.8.0','10408','Dell R840: Firmware version','dell.server.hw.firmware[racFirmwareVersion]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the firmware version of a remote access card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35290','20','1.3.6.1.4.1.674.10892.5.1.3.12.0','10408','Dell R840: Hardware model name','dell.server.hw.model[systemModelName]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the model name of the system.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35291','20','1.3.6.1.4.1.674.10892.5.1.3.2.0','10408','Dell R840: Hardware serial number','dell.server.hw.serialnumber[systemServiceTag]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the service tag of the system.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35292','20','1.3.6.1.2.1.1.6.0','10408','Dell R840: System location','dell.server.location[sysLocation]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., ''telephone closet, 3rd floor''). If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35293','20','1.3.6.1.2.1.1.5.0','10408','Dell R840: System name','dell.server.name[sysName]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node. By convention, this is the node''s fully-qualified domain name. If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35294','20','1.3.6.1.2.1.1.2.0','10408','Dell R840: System object ID','dell.server.objectid[sysObjectID]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity. This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining ''what kind of box'' is being managed. For example, if vendor ''Flintstones, Inc.'' was assigned the subtree 1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its ''Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35295','20','1.3.6.1.4.1.674.10892.5.2.1.0','10408','Dell R840: Overall system health status','dell.server.status[globalSystemStatus]','1m','7d','0d','0','3','','','','',NULL,'59','','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the overall rollup status of all components in the system being monitored by the remote access card. Includes system, storage, IO devices, iDRAC, CPU, memory, etc.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35296','20','1.3.6.1.4.1.674.10892.5.1.3.6.0','10408','Dell R840: Operating system','dell.server.sw.os[systemOSName]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the name of the operating system that the host is running.','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35297','20','1.3.6.1.2.1.1.3.0','10408','Dell R840: Uptime','dell.server.uptime[sysUpTime]','1m','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35298','17','','10408','Dell R840: SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'The item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35299','5','','10408','Dell R840: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35300','20','discovery[{#BATTERY_NUM},1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.1,{#BATTERY_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.21]','10408','Array controller cache discovery','array.cache.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: IDRAC-MIB-SMIv2::batteryTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35301','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.38,{#CNTLR_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.79]','10408','Array controller discovery','array.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: IDRAC-MIB-SMIv2::controllerTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35302','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.700.12.1.5,{#FAN_DESCR},1.3.6.1.4.1.674.10892.5.4.700.12.1.8,{#TYPE},1.3.6.1.4.1.674.10892.5.4.700.12.1.7]','10408','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::coolingDeviceTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35303','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.1,{#DISK_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.2]','10408','Physical disk discovery','physicaldisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning  table of physical drive entries IDRAC-MIB-SMIv2::physicalDiskTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35304','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.600.12.1.5,{#PSU_DESCR},1.3.6.1.4.1.674.10892.5.4.600.12.1.8]','10408','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::powerSupplyTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35305','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.4.700.20.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.674.10892.5.4.700.20.1.8]','10408','Temperature discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Probe Table IDRAC-MIB-SMIv2::temperatureProbeTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35306','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.1,{#DISK_NAME},1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.2]','10408','Virtual disk discovery','virtualdisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'IDRAC-MIB-SMIv2::virtualDiskTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35307','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.15.1.4.{#SNMPINDEX}','10408','Dell R840: {#BATTERY_NAME} Status','dell.server.hw.diskarray.cache.battery.status[batteryState.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'64','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
Current state of battery.
Possible values:
1: The current state could not be determined.
2: The battery is operating normally.
3: The battery has failed and needs to be replaced.
4: The battery temperature is high or charge level is depleting.
5: The battery is missing or not detected.
6: The battery is undergoing the re-charge phase.
7: The battery voltage or charge level is below the threshold.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35308','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.2.{#SNMPINDEX}','10408','Dell R840: {#CNTLR_NAME} Model','dell.server.hw.diskarray.model[controllerName.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The controller''s name as represented in Storage Management.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35309','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.1.1.38.{#SNMPINDEX}','10408','Dell R840: {#CNTLR_NAME} Status','dell.server.hw.diskarray.status[controllerComponentStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'59','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The status of the controller itself without the propagation of any contained component status.
Possible values:
1: Other
2: Unknown
3: OK
4: Non-critical
5: Critical
6: Non-recoverable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35310','20','1.3.6.1.4.1.674.10892.5.4.700.12.1.6.{#SNMPINDEX}','10408','Dell R840: {#FAN_DESCR} Speed','dell.server.sensor.fan.speed[coolingDeviceReading.{#SNMPINDEX}]','1m','7d','365d','0','3','','rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the reading for a cooling device
of subtype other than coolingDeviceSubTypeIsDiscrete. When the value
for coolingDeviceSubType is other than coolingDeviceSubTypeIsDiscrete, the
value returned for this attribute is the speed in RPM or the OFF/ON value
of the cooling device. When the value for coolingDeviceSubType is
coolingDeviceSubTypeIsDiscrete, a value is not returned for this attribute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35311','20','1.3.6.1.4.1.674.10892.5.4.700.12.1.5.{#SNMPINDEX}','10408','Dell R840: {#FAN_DESCR} Status','dell.server.sensor.fan.status[coolingDeviceStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the probe status of the cooling device.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35312','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.35.{#SNMPINDEX}','10408','Dell R840: {#DISK_NAME} Media type','dell.server.hw.physicaldisk.media_type[physicalDiskMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'63','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The media type of the physical disk. Possible Values:
1: The media type could not be determined.
2: Hard Disk Drive (HDD).
3: Solid State Drive (SSD).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35313','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.6.{#SNMPINDEX}','10408','Dell R840: {#DISK_NAME} Model name','dell.server.hw.physicaldisk.model[physicalDiskProductID.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The model number of the physical disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35314','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.7.{#SNMPINDEX}','10408','Dell R840: {#DISK_NAME} Serial number','dell.server.hw.physicaldisk.serialnumber[physicalDiskSerialNo.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The physical disk''s unique identification number from the manufacturer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35315','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.11.{#SNMPINDEX}','10408','Dell R840: {#DISK_NAME} Size','dell.server.hw.physicaldisk.size[physicalDiskCapacityInMB.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The size of the physical disk in megabytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35316','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.31.{#SNMPINDEX}','10408','Dell R840: {#DISK_NAME} S.M.A.R.T. Status','dell.server.hw.physicaldisk.smart_status[physicalDiskSmartAlertIndication.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'62','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
Indicates whether the physical disk has received a predictive failure alert.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35317','20','1.3.6.1.4.1.674.10892.5.5.1.20.130.4.1.24.{#SNMPINDEX}','10408','Dell R840: {#DISK_NAME} Status','dell.server.hw.physicaldisk.status[physicalDiskComponentStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'61','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The status of the physical disk itself without the propagation of any contained component status.
Possible values:
1: Other
2: Unknown
3: OK
4: Non-critical
5: Critical
6: Non-recoverable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35318','20','1.3.6.1.4.1.674.10892.5.4.600.12.1.5.{#SNMPINDEX}','10408','Dell R840: {#PSU_DESCR}','dell.server.sensor.psu.status[powerSupplyStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'59','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
0600.0012.0001.0005 This attribute defines the status of the power supply.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35319','20','1.3.6.1.4.1.674.10892.5.4.700.20.1.5.{#SNMPINDEX}','10408','Dell R840: {#SENSOR_LOCALE} Status','dell.server.sensor.temp.status[temperatureProbeStatus.{#SNMPINDEX}]','1m','7d','0d','0','0','','','','',NULL,'60','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the probe status of the temperature probe.
Possible values:
other(1),               -- probe status is not one of the following:
unknown(2),             -- probe status is unknown (not known or monitored)
ok(3),                  -- probe is reporting a value within the thresholds
nonCriticalUpper(4),    -- probe has crossed the upper noncritical threshold
criticalUpper(5),       -- probe has crossed the upper critical threshold
nonRecoverableUpper(6), -- probe has crossed the upper non-recoverable threshold
nonCriticalLower(7),    -- probe has crossed the lower noncritical threshold
criticalLower(8),       -- probe has crossed the lower critical threshold
nonRecoverableLower(9), -- probe has crossed the lower non-recoverable threshold
failed(10)              -- probe is not functional','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35320','20','1.3.6.1.4.1.674.10892.5.4.700.20.1.6.{#SNMPINDEX}','10408','Dell R840: {#SENSOR_LOCALE} Value','dell.server.sensor.temp.value[temperatureProbeReading.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
This attribute defines the reading for a temperature probe of type other than temperatureProbeTypeIsDiscrete. When the value for temperatureProbeType is other than temperatureProbeTypeIsDiscrete, the value returned for this attribute is the temperature that the probe is reading in Centigrade. When the value for temperatureProbeType is temperatureProbeTypeIsDiscrete, a value is not returned for this attribute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35321','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.13.{#SNMPINDEX}','10408','Dell R840: {#DISK_NAME} Layout type','dell.server.hw.virtualdisk.layout[virtualDiskLayout.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'65','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The virtual disk''s RAID type.
Possible values:
1: Not one of the following
2: RAID-0
3: RAID-1
4: RAID-5
5: RAID-6
6: RAID-10
7: RAID-50
8: RAID-60
9: Concatenated RAID 1
10: Concatenated RAID 5','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35322','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.11.{#SNMPINDEX}','10408','Dell R840: {#DISK_NAME} Read policy','dell.server.hw.virtualdisk.readpolicy[virtualDiskReadPolicy.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,'68','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The read policy used by the controller for read operations on this virtual disk.
Possible values:
1: No Read Ahead.
2: Read Ahead.
3: Adaptive Read Ahead.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35323','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.6.{#SNMPINDEX}','10408','Dell R840: {#DISK_NAME} Size','dell.server.hw.virtualdisk.size[virtualDiskSizeInMB.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The size of the virtual disk in megabytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35324','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.30.{#SNMPINDEX}','10408','Dell R840: {#DISK_NAME} Current state','dell.server.hw.virtualdisk.state[virtualDiskOperationalState.{#SNMPINDEX}]','3m','2w','365d','0','3','','','','',NULL,'66','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The state of the virtual disk when there are progressive operations ongoing.
Possible values:
1: There is no active operation running.
2: The virtual disk configuration has changed. The physical disks included in the virtual disk are being modified to support the new configuration.
3: A Consistency Check (CC) is being performed on the virtual disk.
4: The virtual disk is being initialized.
5: BackGround Initialization (BGI) is being performed on the virtual disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35325','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.4.{#SNMPINDEX}','10408','Dell R840: {#DISK_NAME} Status','dell.server.hw.virtualdisk.status[virtualDiskState.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'69','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The current state of this virtual disk (which includes any member physical disks.)
Possible states:
1: The current state could not be determined.
2: The virtual disk is operating normally or optimally.
3: The virtual disk has encountered a failure. Data on the disk is lost or is about to be lost.
4: The virtual disk encountered a failure with one or all of the constituent redundant physical disks.
The data on the virtual disk might no longer be fault tolerant.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35326','20','1.3.6.1.4.1.674.10892.5.5.1.20.140.1.1.10.{#SNMPINDEX}','10408','Dell R840: {#DISK_NAME} Write policy','dell.server.hw.virtualdisk.writepolicy[virtualDiskWritePolicy.{#SNMPINDEX}]','1h','2w','365d','0','3','','','','',NULL,'67','','','0','','','','','2',NULL,'MIB: IDRAC-MIB-SMIv2
The write policy used by the controller for write operations on this virtual disk.
Possible values:
1: Write Through.
2: Write Back.
3: Force Write Back.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35327','20','1.3.6.1.2.1.1.4.0','10409','System contact details','hp.server.contact[sysContact]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35328','20','1.3.6.1.2.1.1.1.0','10409','System description','hp.server.descr[sysDescr]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35329','20','1.3.6.1.4.1.232.2.2.4.2.0','10409','Hardware model name','hp.server.hw.model[cpqSiProductName]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: CPQSINFO-MIB
The machine product name. The name of the machine used in this system.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35330','20','1.3.6.1.4.1.232.2.2.2.1.0','10409','Hardware serial number','hp.server.hw.serialnumber[cpqSiSysSerialNum]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: CPQSINFO-MIB
The serial number of the physical system unit. The string will be empty if the system does not report the serial number function.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35331','20','1.3.6.1.2.1.1.6.0','10409','System location','hp.server.location[sysLocation]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35332','20','1.3.6.1.2.1.1.5.0','10409','System name','hp.server.name[sysName]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35333','20','1.3.6.1.2.1.1.2.0','10409','System object ID','hp.server.objectid[sysObjectID]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35334','20','1.3.6.1.4.1.232.6.2.6.1.0','10409','System temperature status','hp.server.sensor.temp.status[cpqHeThermalCondition]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','0',NULL,'MIB: CPQHLTH-MIB
This value specifies the overall condition of the system''s thermal environment.
This value will be one of the following:
other(1)  Temperature could not be determined.
ok(2)  The temperature sensor is within normal operating range.
degraded(3)  The temperature sensor is outside of normal operating range.
failed(4)  The temperature sensor detects a condition that could  permanently damage the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35335','20','1.3.6.1.4.1.232.6.1.3.0','10409','Overall system health status','hp.server.status[cpqHeMibCondition]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','0',NULL,'MIB: CPQHLTH-MIB
The overall condition. This object represents the overall status of the server information represented by this MIB.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35336','20','1.3.6.1.2.1.1.3.0','10409','Uptime','hp.server.uptime[sysUpTime]','1m','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35337','17','','10409','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'The item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35338','5','','10409','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35339','20','discovery[{#CACHE_STATUS},1.3.6.1.4.1.232.3.2.2.2.1.2,{#CACHE_CNTRL_INDEX},1.3.6.1.4.1.232.3.2.2.2.1.1]','10409','Array controller cache discovery','array.cache.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CPQIDA-MIB::cpqDaAccelTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35340','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.2.1.1.1,{#CNTLR_SLOT},1.3.6.1.4.1.232.3.2.2.1.1.5,{#CNTLR_LOCATION},1.3.6.1.4.1.232.3.2.2.1.1.20]','10409','Array controller discovery','array.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CPQIDA-MIB::cpqDaCntlrTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35341','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.7.1.9]','10409','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQHLTH-MIB::cpqHeFltTolFanCondition','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35342','20','discovery[{#ADAPTER_INDEX},1.3.6.1.4.1.232.18.2.3.1.1.1,{#ADAPTER_NAME},1.3.6.1.4.1.232.18.2.3.1.1.39]','10409','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQIDA-MIB::cpqNicIfPhysAdapterTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35343','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.5.1.1.5,{#DISK_LOCATION},1.3.6.1.4.1.232.3.2.5.1.1.64]','10409','Physical disk discovery','physicaldisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning  table of physical drive entries CPQIDA-MIB::cpqDaPhyDrvTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35344','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.9.3.1.5,{#CHASSIS_NUM},1.3.6.1.4.1.232.6.2.9.3.1.1,{#BAY_NUM},1.3.6.1.4.1.232.6.2.9.3.1.2]','10409','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQHLTH-MIB::cpqHeFltTolPowerSupplyStatus','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35345','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10409','Temperature ambient discovery','temp.ambient.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with ambient(11) and 0.1 index filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35346','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10409','Temperature CPU discovery','temp.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with cpu(6) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35347','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10409','Temperature discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35348','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10409','Temperature I/O discovery','temp.io.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with ioBoard(5) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35349','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10409','Temperature memory discovery','temp.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with memory(7) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35350','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10409','Temperature PSU discovery','temp.psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with powerSupply(10) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35351','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10409','Temperature system discovery','temp.system.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with system(3) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35352','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.3.1.1.2,{#DISK_NAME},1.3.6.1.4.1.232.3.2.3.1.1.14]','10409','Virtual disk discovery','virtualdisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQIDA-MIB::cpqDaLogDrvTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35353','20','1.3.6.1.4.1.232.3.2.2.2.1.6.{#SNMPINDEX}','10409','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery status','hp.server.hw.diskarray.cache.battery.status[cpqDaAccelBattery.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'72','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Cache Module Board Backup Power Status. This monitors the status of each backup power source on the board.
The backup power source can only recharge when the system has power applied. The type of backup power source used is indicated by cpqDaAccelBackupPowerSource.
The following values are valid:
Other (1)  Indicates that the instrument agent does not recognize  backup power status.  You may need to update your software.

Ok (2)  The backup power source is fully charged.

Recharging (3)  The array controller has one or more cache module backup power  sources that are recharging.
Cache module operations such as Battery/Flash Backed Write Cache, Expansion, Extension and Migration are temporarily suspended until the backup power source is fully charged.
Cache module operations will automatically resume  when charging is complete.

Failed (4)  The battery pack is below the sufficient voltage level and  has not recharged in 36 hours.
Your Cache Module board  needs to be serviced.

Degraded (5)  The battery is still operating, however, one of the batteries  in the pack has failed to recharge properly.
Your Cache  Module board should be serviced as soon as possible.

NotPresent (6)  A backup power source is not present on the cache module board. Some controllers do not have backup power sources.

Capacitor Failed (7)  The flash backed cache module capacitor is below the sufficient voltage level and has not recharged in 10 minutes.  Your Cache Module board needs to be serviced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35354','20','1.3.6.1.4.1.232.3.2.2.2.1.2.{#SNMPINDEX}','10409','#{#CACHE_CNTRL_INDEX}: Disk array cache controller status','hp.server.hw.diskarray.cache.status[cpqDaAccelStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'71','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Cache Module/Operations Status. This describes the status of the cache module and/or cache operations.


The status can be:
Other (1)
 Indicates that the instrument agent does not recognize the status of the cache module.

Invalid (2)
 Indicates that a cache module board has not been installed in this system or is present but not configured.

Enabled (3)
 Indicates that cache operations are currently configured and enabled for at least one logical drive.

Temporarily Disabled (4)
 Indicates that cache operations have been temporarily disabled. (5)
 Indicates that cache operations have been permanently disabled. 

Cache Module Flash Memory Not Attached (6)
 Indicates that the flash memory component of the flash backed cache module is not attached. This status will be set when the flash memory is not attached and the Supercap is attached. This value is only used on flash backed cache modules that support removable flash memory.

Cache Module Degraded Failsafe Speed (7)
 Indicates that the cache module board is currently degraded and operating at a failsafe speed. 

Cache Module Critical Failure (8)
 Indicates that the cache module board has encountered a critical failure. The controller is currently operating in Zero Memory Raid mode.

Read Cache Could Not Be Mapped (9)
 Indicates that the read cache memory in a split cache configuration could not be mapped by the operating system and as a result is not available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35355','20','1.3.6.1.4.1.232.3.2.2.1.1.2.{#SNMPINDEX}','10409','{#CNTLR_LOCATION}: Disk array controller model','hp.server.hw.diskarray.model[cpqDaCntlrModel.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'56','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Array Controller Model. The type of controller card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35356','20','1.3.6.1.4.1.232.3.2.2.1.1.6.{#SNMPINDEX}','10409','{#CNTLR_LOCATION}: Disk array controller status','hp.server.hw.diskarray.status[cpqDaCntlrCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
This value represents the overall condition of this controller,
and any associated logical drives, physical drives, and array accelerators.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35357','20','1.3.6.1.4.1.232.6.2.6.7.1.9.{#SNMPINDEX}','10409','Fan {#SNMPINDEX}: Fan status','hp.server.sensor.fan.status[cpqHeFltTolFanCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The condition of the fan.
This value will be one of the following:
other(1)  Fan status detection is not supported by this system or driver.
ok(2)  The fan is operating properly.
degraded(2)  A redundant fan is not operating properly.
failed(4)  A non-redundant fan is not operating properly.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35358','20','1.3.6.1.4.1.232.18.2.3.1.1.14.{#SNMPINDEX}','10409','{#ADAPTER_NAME} port {#ADAPTER_INDEX}: Status','hp.server.net.if.status[cpqNicIfPhysAdapterStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'236','','','0','','','','','2',NULL,'MIB: CPQNIC-MIB
The physical adapter status. The following values are valid:
unknown(1)
  The instrument agent was not able to determine the status of the adapter. The instrument agent may need to be upgraded.
ok(2)
  The physical adapter is operating properly.
generalFailure(3)
  The physical adapter has failed.
linkFailure(4)
  The physical adapter has lost link. Check the cable connections to this adapter.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35359','20','1.3.6.1.4.1.232.3.2.5.1.1.69.{#SNMPINDEX}','10409','{#DISK_LOCATION}: Physical disk media type','hp.server.hw.physicaldisk.media_type[cpqDaPhyDrvMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'73','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Drive Array Physical Drive Media Type. The following values are defined:
other(1)  The instrument agent is unable to determine the physical drive’s media type.
rotatingPlatters(2)  The physical drive media is composed of rotating platters.
solidState(3)  The physical drive media is composed of solid state electronics.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35360','20','1.3.6.1.4.1.232.3.2.5.1.1.3.{#SNMPINDEX}','10409','{#DISK_LOCATION}: Physical disk model name','hp.server.hw.physicaldisk.model[cpqDaPhyDrvModel.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Model. This is a text description of the physical drive.
The text that appears depends upon who manufactured the drive and the drive type.
If a drive fails, note the model to identify the type of drive necessary for replacement.
If a model number is not present, you may not have properly initialized the drive array to which the physical drive is attached for monitoring.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35361','20','1.3.6.1.4.1.232.3.2.5.1.1.51.{#SNMPINDEX}','10409','{#DISK_LOCATION}: Physical disk serial number','hp.server.hw.physicaldisk.serialnumber[cpqDaPhyDrvSerialNum.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Serial Number.
This is the serial number assigned to the physical drive.
This value is based upon the serial number as returned by the SCSI inquiry command
but may have been modified due to space limitations.  This can be used for identification purposes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35362','20','1.3.6.1.4.1.232.3.2.5.1.1.45.{#SNMPINDEX}','10409','{#DISK_LOCATION}: Disk size','hp.server.hw.physicaldisk.size[cpqDaPhyDrvMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Size in MB.
This is the size of the physical drive in megabytes.
This value is calculated using the value 1,048,576 (2^20) as a megabyte.
Drive manufacturers sometimes use the number 1,000,000 as a megabyte when giving drive capacities so this value may differ
from the advertised size of a drive. This field is only applicable for controllers which support SCSI drives,
and therefore is not supported by the IDA or IDA-2 controllers. The field will contain 0xFFFFFFFF if the drive capacity cannot be calculated
or if the controller does not support SCSI drives.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35363','20','1.3.6.1.4.1.232.3.2.5.1.1.57.{#SNMPINDEX}','10409','{#DISK_LOCATION}: Physical disk S.M.A.R.T. status','hp.server.hw.physicaldisk.smart_status[cpqDaPhyDrvSmartStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'70','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive S.M.A.R.T Status. The following values are defined:
other(1)  The agent is unable to determine if the status of S.M.A.R.T  predictive failure monitoring for this drive.
ok(2)  Indicates the drive is functioning properly.
replaceDrive(3)  Indicates that the drive has a S.M.A.R.T predictive failure  error and should be replaced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35364','20','1.3.6.1.4.1.232.3.2.5.1.1.6.{#SNMPINDEX}','10409','{#DISK_LOCATION}: Physical disk status','hp.server.hw.physicaldisk.status[cpqDaPhyDrvStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'57','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Status. This shows the status of the physical drive. The following values are valid for the physical drive status:
other (1)  Indicates that the instrument agent does not recognize  the drive.
You may need to upgrade your instrument agent  and/or driver software.
ok (2)  Indicates the drive is functioning properly.
failed (3)  Indicates that the drive is no longer operating and  should be replaced.
predictiveFailure(4)  Indicates that the drive has a predictive failure error and  should be replaced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35365','20','1.3.6.1.4.1.232.6.2.9.3.1.4.{#SNMPINDEX}','10409','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply status','hp.server.sensor.psu.status[cpqHeFltTolPowerSupplyCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The condition of the power supply. This value will be one of the following:
other(1)  The status could not be determined or not present.
ok(2)  The power supply is operating normally.
degraded(3)  A temperature sensor, fan or other power supply component is  outside of normal operating range.
failed(4)  A power supply component detects a condition that could  permanently damage the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35366','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10409','Ambient: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.Ambient.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35367','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10409','Ambient: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.Ambient.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: Ambient','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35368','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10409','CPU-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.CPU.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35369','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10409','CPU-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.CPU.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: CPU-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35370','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10409','{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35371','20','1.3.6.1.4.1.232.6.2.6.8.1.3.{#SNMPINDEX}','10409','{#SNMPINDEX}: Temperature sensor location','hp.server.sensor.temp.locale[cpqHeTemperatureLocale.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'55','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
This specifies the location of the temperature sensor present in the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35372','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10409','{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: {#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35373','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10409','I/O-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition."I/O.{#SNMPINDEX}"]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35374','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10409','I/O-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius."I/O.{#SNMPINDEX}"]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: I/O-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35375','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10409','Memory-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.Memory.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35376','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10409','Memory-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.Memory.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: Memory-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35377','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10409','PSU-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.PSU.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35378','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10409','PSU-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.PSU.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: PSU-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35379','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10409','System-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.System.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35380','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10409','System-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.System.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: System-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35381','20','1.3.6.1.4.1.232.3.2.3.1.1.3.{#SNMPINDEX}','10409','Disk {#SNMPINDEX}({#DISK_NAME}): Layout type','hp.server.hw.virtualdisk.layout[cpqDaLogDrvFaultTol.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'74','','','0','','','','','2',NULL,'Logical Drive Fault Tolerance.
This shows the fault tolerance mode of the logical drive.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35382','20','1.3.6.1.4.1.232.3.2.3.1.1.9.{#SNMPINDEX}','10409','Disk {#SNMPINDEX}({#DISK_NAME}): Disk size','hp.server.hw.virtualdisk.size[cpqDaLogDrvSize.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Logical Drive Size.
This is the size of the logical drive in megabytes.  This value
is calculated using the value 1,048,576 (2^20) as a megabyte.
Drive manufacturers sometimes use the number 1,000,000 as a
megabyte when giving drive capacities so this value may
differ from the advertised size of a drive.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35383','20','1.3.6.1.4.1.232.3.2.3.1.1.4.{#SNMPINDEX}','10409','Disk {#SNMPINDEX}({#DISK_NAME}): Status','hp.server.hw.virtualdisk.status[cpqDaLogDrvStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'75','','','0','','','','','2',NULL,'Logical Drive Status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35384','20','1.3.6.1.2.1.1.4.0','10410','System contact details','hp.server.contact[sysContact]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35385','20','1.3.6.1.2.1.1.1.0','10410','System description','hp.server.descr[sysDescr]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35386','20','1.3.6.1.4.1.232.2.2.4.2.0','10410','Hardware model name','hp.server.hw.model[cpqSiProductName]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: CPQSINFO-MIB
The machine product name. The name of the machine used in this system.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35387','20','1.3.6.1.4.1.232.2.2.2.1.0','10410','Hardware serial number','hp.server.hw.serialnumber[cpqSiSysSerialNum]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: CPQSINFO-MIB
The serial number of the physical system unit. The string will be empty if the system does not report the serial number function.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35388','20','1.3.6.1.2.1.1.6.0','10410','System location','hp.server.location[sysLocation]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35389','20','1.3.6.1.2.1.1.5.0','10410','System name','hp.server.name[sysName]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35390','20','1.3.6.1.2.1.1.2.0','10410','System object ID','hp.server.objectid[sysObjectID]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35391','20','1.3.6.1.4.1.232.6.2.6.1.0','10410','System temperature status','hp.server.sensor.temp.status[cpqHeThermalCondition]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','0',NULL,'MIB: CPQHLTH-MIB
This value specifies the overall condition of the system''s thermal environment.
This value will be one of the following:
other(1)  Temperature could not be determined.
ok(2)  The temperature sensor is within normal operating range.
degraded(3)  The temperature sensor is outside of normal operating range.
failed(4)  The temperature sensor detects a condition that could  permanently damage the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35392','20','1.3.6.1.4.1.232.6.1.3.0','10410','Overall system health status','hp.server.status[cpqHeMibCondition]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','0',NULL,'MIB: CPQHLTH-MIB
The overall condition. This object represents the overall status of the server information represented by this MIB.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35393','20','1.3.6.1.2.1.1.3.0','10410','Uptime','hp.server.uptime[sysUpTime]','1m','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35394','17','','10410','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'The item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35395','5','','10410','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35396','20','discovery[{#CACHE_STATUS},1.3.6.1.4.1.232.3.2.2.2.1.2,{#CACHE_CNTRL_INDEX},1.3.6.1.4.1.232.3.2.2.2.1.1]','10410','Array controller cache discovery','array.cache.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CPQIDA-MIB::cpqDaAccelTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35397','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.2.1.1.1,{#CNTLR_SLOT},1.3.6.1.4.1.232.3.2.2.1.1.5,{#CNTLR_LOCATION},1.3.6.1.4.1.232.3.2.2.1.1.20]','10410','Array controller discovery','array.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CPQIDA-MIB::cpqDaCntlrTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35398','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.7.1.9]','10410','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQHLTH-MIB::cpqHeFltTolFanCondition','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35399','20','discovery[{#ADAPTER_INDEX},1.3.6.1.4.1.232.18.2.3.1.1.1,{#ADAPTER_NAME},1.3.6.1.4.1.232.18.2.3.1.1.39]','10410','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQIDA-MIB::cpqNicIfPhysAdapterTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35400','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.5.1.1.5,{#DISK_LOCATION},1.3.6.1.4.1.232.3.2.5.1.1.64]','10410','Physical disk discovery','physicaldisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning  table of physical drive entries CPQIDA-MIB::cpqDaPhyDrvTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35401','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.9.3.1.5,{#CHASSIS_NUM},1.3.6.1.4.1.232.6.2.9.3.1.1,{#BAY_NUM},1.3.6.1.4.1.232.6.2.9.3.1.2]','10410','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQHLTH-MIB::cpqHeFltTolPowerSupplyStatus','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35402','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10410','Temperature ambient discovery','temp.ambient.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with ambient(11) and 0.1 index filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35403','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10410','Temperature CPU discovery','temp.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with cpu(6) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35404','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10410','Temperature discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35405','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10410','Temperature I/O discovery','temp.io.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with ioBoard(5) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35406','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10410','Temperature memory discovery','temp.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with memory(7) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35407','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10410','Temperature PSU discovery','temp.psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with powerSupply(10) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35408','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10410','Temperature system discovery','temp.system.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with system(3) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35409','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.3.1.1.2,{#DISK_NAME},1.3.6.1.4.1.232.3.2.3.1.1.14]','10410','Virtual disk discovery','virtualdisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQIDA-MIB::cpqDaLogDrvTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35410','20','1.3.6.1.4.1.232.3.2.2.2.1.6.{#SNMPINDEX}','10410','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery status','hp.server.hw.diskarray.cache.battery.status[cpqDaAccelBattery.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'72','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Cache Module Board Backup Power Status. This monitors the status of each backup power source on the board.
The backup power source can only recharge when the system has power applied. The type of backup power source used is indicated by cpqDaAccelBackupPowerSource.
The following values are valid:
Other (1)  Indicates that the instrument agent does not recognize  backup power status.  You may need to update your software.

Ok (2)  The backup power source is fully charged.

Recharging (3)  The array controller has one or more cache module backup power  sources that are recharging.
Cache module operations such as Battery/Flash Backed Write Cache, Expansion, Extension and Migration are temporarily suspended until the backup power source is fully charged.
Cache module operations will automatically resume  when charging is complete.

Failed (4)  The battery pack is below the sufficient voltage level and  has not recharged in 36 hours.
Your Cache Module board  needs to be serviced.

Degraded (5)  The battery is still operating, however, one of the batteries  in the pack has failed to recharge properly.
Your Cache  Module board should be serviced as soon as possible.

NotPresent (6)  A backup power source is not present on the cache module board. Some controllers do not have backup power sources.

Capacitor Failed (7)  The flash backed cache module capacitor is below the sufficient voltage level and has not recharged in 10 minutes.  Your Cache Module board needs to be serviced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35411','20','1.3.6.1.4.1.232.3.2.2.2.1.2.{#SNMPINDEX}','10410','#{#CACHE_CNTRL_INDEX}: Disk array cache controller status','hp.server.hw.diskarray.cache.status[cpqDaAccelStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'71','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Cache Module/Operations Status. This describes the status of the cache module and/or cache operations.


The status can be:
Other (1)
 Indicates that the instrument agent does not recognize the status of the cache module.

Invalid (2)
 Indicates that a cache module board has not been installed in this system or is present but not configured.

Enabled (3)
 Indicates that cache operations are currently configured and enabled for at least one logical drive.

Temporarily Disabled (4)
 Indicates that cache operations have been temporarily disabled. (5)
 Indicates that cache operations have been permanently disabled. 

Cache Module Flash Memory Not Attached (6)
 Indicates that the flash memory component of the flash backed cache module is not attached. This status will be set when the flash memory is not attached and the Supercap is attached. This value is only used on flash backed cache modules that support removable flash memory.

Cache Module Degraded Failsafe Speed (7)
 Indicates that the cache module board is currently degraded and operating at a failsafe speed. 

Cache Module Critical Failure (8)
 Indicates that the cache module board has encountered a critical failure. The controller is currently operating in Zero Memory Raid mode.

Read Cache Could Not Be Mapped (9)
 Indicates that the read cache memory in a split cache configuration could not be mapped by the operating system and as a result is not available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35412','20','1.3.6.1.4.1.232.3.2.2.1.1.2.{#SNMPINDEX}','10410','{#CNTLR_LOCATION}: Disk array controller model','hp.server.hw.diskarray.model[cpqDaCntlrModel.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'56','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Array Controller Model. The type of controller card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35413','20','1.3.6.1.4.1.232.3.2.2.1.1.6.{#SNMPINDEX}','10410','{#CNTLR_LOCATION}: Disk array controller status','hp.server.hw.diskarray.status[cpqDaCntlrCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
This value represents the overall condition of this controller,
and any associated logical drives, physical drives, and array accelerators.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35414','20','1.3.6.1.4.1.232.6.2.6.7.1.9.{#SNMPINDEX}','10410','Fan {#SNMPINDEX}: Fan status','hp.server.sensor.fan.status[cpqHeFltTolFanCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The condition of the fan.
This value will be one of the following:
other(1)  Fan status detection is not supported by this system or driver.
ok(2)  The fan is operating properly.
degraded(2)  A redundant fan is not operating properly.
failed(4)  A non-redundant fan is not operating properly.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35415','20','1.3.6.1.4.1.232.18.2.3.1.1.14.{#SNMPINDEX}','10410','{#ADAPTER_NAME} port {#ADAPTER_INDEX}: Status','hp.server.net.if.status[cpqNicIfPhysAdapterStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'236','','','0','','','','','2',NULL,'MIB: CPQNIC-MIB
The physical adapter status. The following values are valid:
unknown(1)
  The instrument agent was not able to determine the status of the adapter. The instrument agent may need to be upgraded.
ok(2)
  The physical adapter is operating properly.
generalFailure(3)
  The physical adapter has failed.
linkFailure(4)
  The physical adapter has lost link. Check the cable connections to this adapter.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35416','20','1.3.6.1.4.1.232.3.2.5.1.1.69.{#SNMPINDEX}','10410','{#DISK_LOCATION}: Physical disk media type','hp.server.hw.physicaldisk.media_type[cpqDaPhyDrvMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'73','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Drive Array Physical Drive Media Type. The following values are defined:
other(1)  The instrument agent is unable to determine the physical drive’s media type.
rotatingPlatters(2)  The physical drive media is composed of rotating platters.
solidState(3)  The physical drive media is composed of solid state electronics.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35417','20','1.3.6.1.4.1.232.3.2.5.1.1.3.{#SNMPINDEX}','10410','{#DISK_LOCATION}: Physical disk model name','hp.server.hw.physicaldisk.model[cpqDaPhyDrvModel.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Model. This is a text description of the physical drive.
The text that appears depends upon who manufactured the drive and the drive type.
If a drive fails, note the model to identify the type of drive necessary for replacement.
If a model number is not present, you may not have properly initialized the drive array to which the physical drive is attached for monitoring.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35418','20','1.3.6.1.4.1.232.3.2.5.1.1.51.{#SNMPINDEX}','10410','{#DISK_LOCATION}: Physical disk serial number','hp.server.hw.physicaldisk.serialnumber[cpqDaPhyDrvSerialNum.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Serial Number.
This is the serial number assigned to the physical drive.
This value is based upon the serial number as returned by the SCSI inquiry command
but may have been modified due to space limitations.  This can be used for identification purposes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35419','20','1.3.6.1.4.1.232.3.2.5.1.1.45.{#SNMPINDEX}','10410','{#DISK_LOCATION}: Disk size','hp.server.hw.physicaldisk.size[cpqDaPhyDrvMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Size in MB.
This is the size of the physical drive in megabytes.
This value is calculated using the value 1,048,576 (2^20) as a megabyte.
Drive manufacturers sometimes use the number 1,000,000 as a megabyte when giving drive capacities so this value may differ
from the advertised size of a drive. This field is only applicable for controllers which support SCSI drives,
and therefore is not supported by the IDA or IDA-2 controllers. The field will contain 0xFFFFFFFF if the drive capacity cannot be calculated
or if the controller does not support SCSI drives.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35420','20','1.3.6.1.4.1.232.3.2.5.1.1.57.{#SNMPINDEX}','10410','{#DISK_LOCATION}: Physical disk S.M.A.R.T. status','hp.server.hw.physicaldisk.smart_status[cpqDaPhyDrvSmartStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'70','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive S.M.A.R.T Status. The following values are defined:
other(1)  The agent is unable to determine if the status of S.M.A.R.T  predictive failure monitoring for this drive.
ok(2)  Indicates the drive is functioning properly.
replaceDrive(3)  Indicates that the drive has a S.M.A.R.T predictive failure  error and should be replaced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35421','20','1.3.6.1.4.1.232.3.2.5.1.1.6.{#SNMPINDEX}','10410','{#DISK_LOCATION}: Physical disk status','hp.server.hw.physicaldisk.status[cpqDaPhyDrvStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'57','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Status. This shows the status of the physical drive. The following values are valid for the physical drive status:
other (1)  Indicates that the instrument agent does not recognize  the drive.
You may need to upgrade your instrument agent  and/or driver software.
ok (2)  Indicates the drive is functioning properly.
failed (3)  Indicates that the drive is no longer operating and  should be replaced.
predictiveFailure(4)  Indicates that the drive has a predictive failure error and  should be replaced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35422','20','1.3.6.1.4.1.232.6.2.9.3.1.4.{#SNMPINDEX}','10410','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply status','hp.server.sensor.psu.status[cpqHeFltTolPowerSupplyCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The condition of the power supply. This value will be one of the following:
other(1)  The status could not be determined or not present.
ok(2)  The power supply is operating normally.
degraded(3)  A temperature sensor, fan or other power supply component is  outside of normal operating range.
failed(4)  A power supply component detects a condition that could  permanently damage the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35423','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10410','Ambient: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.Ambient.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35424','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10410','Ambient: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.Ambient.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: Ambient','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35425','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10410','CPU-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.CPU.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35426','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10410','CPU-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.CPU.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: CPU-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35427','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10410','{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35428','20','1.3.6.1.4.1.232.6.2.6.8.1.3.{#SNMPINDEX}','10410','{#SNMPINDEX}: Temperature sensor location','hp.server.sensor.temp.locale[cpqHeTemperatureLocale.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'55','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
This specifies the location of the temperature sensor present in the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35429','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10410','{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: {#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35430','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10410','I/O-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition."I/O.{#SNMPINDEX}"]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35431','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10410','I/O-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius."I/O.{#SNMPINDEX}"]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: I/O-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35432','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10410','Memory-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.Memory.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35433','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10410','Memory-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.Memory.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: Memory-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35434','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10410','PSU-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.PSU.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35435','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10410','PSU-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.PSU.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: PSU-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35436','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10410','System-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.System.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35437','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10410','System-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.System.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: System-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35438','20','1.3.6.1.4.1.232.3.2.3.1.1.3.{#SNMPINDEX}','10410','Disk {#SNMPINDEX}({#DISK_NAME}): Layout type','hp.server.hw.virtualdisk.layout[cpqDaLogDrvFaultTol.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'74','','','0','','','','','2',NULL,'Logical Drive Fault Tolerance.
This shows the fault tolerance mode of the logical drive.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35439','20','1.3.6.1.4.1.232.3.2.3.1.1.9.{#SNMPINDEX}','10410','Disk {#SNMPINDEX}({#DISK_NAME}): Disk size','hp.server.hw.virtualdisk.size[cpqDaLogDrvSize.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Logical Drive Size.
This is the size of the logical drive in megabytes.  This value
is calculated using the value 1,048,576 (2^20) as a megabyte.
Drive manufacturers sometimes use the number 1,000,000 as a
megabyte when giving drive capacities so this value may
differ from the advertised size of a drive.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35440','20','1.3.6.1.4.1.232.3.2.3.1.1.4.{#SNMPINDEX}','10410','Disk {#SNMPINDEX}({#DISK_NAME}): Status','hp.server.hw.virtualdisk.status[cpqDaLogDrvStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'75','','','0','','','','','2',NULL,'Logical Drive Status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35441','20','1.3.6.1.2.1.1.4.0','10411','System contact details','hp.server.contact[sysContact]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35442','20','1.3.6.1.2.1.1.1.0','10411','System description','hp.server.descr[sysDescr]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35443','20','1.3.6.1.4.1.232.2.2.4.2.0','10411','Hardware model name','hp.server.hw.model[cpqSiProductName]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: CPQSINFO-MIB
The machine product name. The name of the machine used in this system.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35444','20','1.3.6.1.4.1.232.2.2.2.1.0','10411','Hardware serial number','hp.server.hw.serialnumber[cpqSiSysSerialNum]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: CPQSINFO-MIB
The serial number of the physical system unit. The string will be empty if the system does not report the serial number function.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35445','20','1.3.6.1.2.1.1.6.0','10411','System location','hp.server.location[sysLocation]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35446','20','1.3.6.1.2.1.1.5.0','10411','System name','hp.server.name[sysName]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35447','20','1.3.6.1.2.1.1.2.0','10411','System object ID','hp.server.objectid[sysObjectID]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35448','20','1.3.6.1.4.1.232.6.2.6.1.0','10411','System temperature status','hp.server.sensor.temp.status[cpqHeThermalCondition]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','0',NULL,'MIB: CPQHLTH-MIB
This value specifies the overall condition of the system''s thermal environment.
This value will be one of the following:
other(1)  Temperature could not be determined.
ok(2)  The temperature sensor is within normal operating range.
degraded(3)  The temperature sensor is outside of normal operating range.
failed(4)  The temperature sensor detects a condition that could  permanently damage the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35449','20','1.3.6.1.4.1.232.6.1.3.0','10411','Overall system health status','hp.server.status[cpqHeMibCondition]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','0',NULL,'MIB: CPQHLTH-MIB
The overall condition. This object represents the overall status of the server information represented by this MIB.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35450','20','1.3.6.1.2.1.1.3.0','10411','Uptime','hp.server.uptime[sysUpTime]','1m','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35451','17','','10411','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'The item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35452','5','','10411','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35453','20','discovery[{#CACHE_STATUS},1.3.6.1.4.1.232.3.2.2.2.1.2,{#CACHE_CNTRL_INDEX},1.3.6.1.4.1.232.3.2.2.2.1.1]','10411','Array controller cache discovery','array.cache.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CPQIDA-MIB::cpqDaAccelTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35454','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.2.1.1.1,{#CNTLR_SLOT},1.3.6.1.4.1.232.3.2.2.1.1.5,{#CNTLR_LOCATION},1.3.6.1.4.1.232.3.2.2.1.1.20]','10411','Array controller discovery','array.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CPQIDA-MIB::cpqDaCntlrTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35455','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.7.1.9]','10411','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQHLTH-MIB::cpqHeFltTolFanCondition','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35456','20','discovery[{#ADAPTER_INDEX},1.3.6.1.4.1.232.18.2.3.1.1.1,{#ADAPTER_NAME},1.3.6.1.4.1.232.18.2.3.1.1.39]','10411','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQIDA-MIB::cpqNicIfPhysAdapterTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35457','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.5.1.1.5,{#DISK_LOCATION},1.3.6.1.4.1.232.3.2.5.1.1.64]','10411','Physical disk discovery','physicaldisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning  table of physical drive entries CPQIDA-MIB::cpqDaPhyDrvTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35458','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.9.3.1.5,{#CHASSIS_NUM},1.3.6.1.4.1.232.6.2.9.3.1.1,{#BAY_NUM},1.3.6.1.4.1.232.6.2.9.3.1.2]','10411','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQHLTH-MIB::cpqHeFltTolPowerSupplyStatus','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35459','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10411','Temperature ambient discovery','temp.ambient.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with ambient(11) and 0.1 index filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35460','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10411','Temperature CPU discovery','temp.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with cpu(6) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35461','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10411','Temperature discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35462','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10411','Temperature I/O discovery','temp.io.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with ioBoard(5) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35463','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10411','Temperature memory discovery','temp.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with memory(7) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35464','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10411','Temperature PSU discovery','temp.psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with powerSupply(10) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35465','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10411','Temperature system discovery','temp.system.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with system(3) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35466','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.3.1.1.2,{#DISK_NAME},1.3.6.1.4.1.232.3.2.3.1.1.14]','10411','Virtual disk discovery','virtualdisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQIDA-MIB::cpqDaLogDrvTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35467','20','1.3.6.1.4.1.232.3.2.2.2.1.6.{#SNMPINDEX}','10411','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery status','hp.server.hw.diskarray.cache.battery.status[cpqDaAccelBattery.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'72','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Cache Module Board Backup Power Status. This monitors the status of each backup power source on the board.
The backup power source can only recharge when the system has power applied. The type of backup power source used is indicated by cpqDaAccelBackupPowerSource.
The following values are valid:
Other (1)  Indicates that the instrument agent does not recognize  backup power status.  You may need to update your software.

Ok (2)  The backup power source is fully charged.

Recharging (3)  The array controller has one or more cache module backup power  sources that are recharging.
Cache module operations such as Battery/Flash Backed Write Cache, Expansion, Extension and Migration are temporarily suspended until the backup power source is fully charged.
Cache module operations will automatically resume  when charging is complete.

Failed (4)  The battery pack is below the sufficient voltage level and  has not recharged in 36 hours.
Your Cache Module board  needs to be serviced.

Degraded (5)  The battery is still operating, however, one of the batteries  in the pack has failed to recharge properly.
Your Cache  Module board should be serviced as soon as possible.

NotPresent (6)  A backup power source is not present on the cache module board. Some controllers do not have backup power sources.

Capacitor Failed (7)  The flash backed cache module capacitor is below the sufficient voltage level and has not recharged in 10 minutes.  Your Cache Module board needs to be serviced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35468','20','1.3.6.1.4.1.232.3.2.2.2.1.2.{#SNMPINDEX}','10411','#{#CACHE_CNTRL_INDEX}: Disk array cache controller status','hp.server.hw.diskarray.cache.status[cpqDaAccelStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'71','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Cache Module/Operations Status. This describes the status of the cache module and/or cache operations.


The status can be:
Other (1)
 Indicates that the instrument agent does not recognize the status of the cache module.

Invalid (2)
 Indicates that a cache module board has not been installed in this system or is present but not configured.

Enabled (3)
 Indicates that cache operations are currently configured and enabled for at least one logical drive.

Temporarily Disabled (4)
 Indicates that cache operations have been temporarily disabled. (5)
 Indicates that cache operations have been permanently disabled. 

Cache Module Flash Memory Not Attached (6)
 Indicates that the flash memory component of the flash backed cache module is not attached. This status will be set when the flash memory is not attached and the Supercap is attached. This value is only used on flash backed cache modules that support removable flash memory.

Cache Module Degraded Failsafe Speed (7)
 Indicates that the cache module board is currently degraded and operating at a failsafe speed. 

Cache Module Critical Failure (8)
 Indicates that the cache module board has encountered a critical failure. The controller is currently operating in Zero Memory Raid mode.

Read Cache Could Not Be Mapped (9)
 Indicates that the read cache memory in a split cache configuration could not be mapped by the operating system and as a result is not available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35469','20','1.3.6.1.4.1.232.3.2.2.1.1.2.{#SNMPINDEX}','10411','{#CNTLR_LOCATION}: Disk array controller model','hp.server.hw.diskarray.model[cpqDaCntlrModel.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'56','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Array Controller Model. The type of controller card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35470','20','1.3.6.1.4.1.232.3.2.2.1.1.6.{#SNMPINDEX}','10411','{#CNTLR_LOCATION}: Disk array controller status','hp.server.hw.diskarray.status[cpqDaCntlrCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
This value represents the overall condition of this controller,
and any associated logical drives, physical drives, and array accelerators.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35471','20','1.3.6.1.4.1.232.6.2.6.7.1.9.{#SNMPINDEX}','10411','Fan {#SNMPINDEX}: Fan status','hp.server.sensor.fan.status[cpqHeFltTolFanCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The condition of the fan.
This value will be one of the following:
other(1)  Fan status detection is not supported by this system or driver.
ok(2)  The fan is operating properly.
degraded(2)  A redundant fan is not operating properly.
failed(4)  A non-redundant fan is not operating properly.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35472','20','1.3.6.1.4.1.232.18.2.3.1.1.14.{#SNMPINDEX}','10411','{#ADAPTER_NAME} port {#ADAPTER_INDEX}: Status','hp.server.net.if.status[cpqNicIfPhysAdapterStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'236','','','0','','','','','2',NULL,'MIB: CPQNIC-MIB
The physical adapter status. The following values are valid:
unknown(1)
  The instrument agent was not able to determine the status of the adapter. The instrument agent may need to be upgraded.
ok(2)
  The physical adapter is operating properly.
generalFailure(3)
  The physical adapter has failed.
linkFailure(4)
  The physical adapter has lost link. Check the cable connections to this adapter.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35473','20','1.3.6.1.4.1.232.3.2.5.1.1.69.{#SNMPINDEX}','10411','{#DISK_LOCATION}: Physical disk media type','hp.server.hw.physicaldisk.media_type[cpqDaPhyDrvMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'73','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Drive Array Physical Drive Media Type. The following values are defined:
other(1)  The instrument agent is unable to determine the physical drive’s media type.
rotatingPlatters(2)  The physical drive media is composed of rotating platters.
solidState(3)  The physical drive media is composed of solid state electronics.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35474','20','1.3.6.1.4.1.232.3.2.5.1.1.3.{#SNMPINDEX}','10411','{#DISK_LOCATION}: Physical disk model name','hp.server.hw.physicaldisk.model[cpqDaPhyDrvModel.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Model. This is a text description of the physical drive.
The text that appears depends upon who manufactured the drive and the drive type.
If a drive fails, note the model to identify the type of drive necessary for replacement.
If a model number is not present, you may not have properly initialized the drive array to which the physical drive is attached for monitoring.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35475','20','1.3.6.1.4.1.232.3.2.5.1.1.51.{#SNMPINDEX}','10411','{#DISK_LOCATION}: Physical disk serial number','hp.server.hw.physicaldisk.serialnumber[cpqDaPhyDrvSerialNum.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Serial Number.
This is the serial number assigned to the physical drive.
This value is based upon the serial number as returned by the SCSI inquiry command
but may have been modified due to space limitations.  This can be used for identification purposes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35476','20','1.3.6.1.4.1.232.3.2.5.1.1.45.{#SNMPINDEX}','10411','{#DISK_LOCATION}: Disk size','hp.server.hw.physicaldisk.size[cpqDaPhyDrvMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Size in MB.
This is the size of the physical drive in megabytes.
This value is calculated using the value 1,048,576 (2^20) as a megabyte.
Drive manufacturers sometimes use the number 1,000,000 as a megabyte when giving drive capacities so this value may differ
from the advertised size of a drive. This field is only applicable for controllers which support SCSI drives,
and therefore is not supported by the IDA or IDA-2 controllers. The field will contain 0xFFFFFFFF if the drive capacity cannot be calculated
or if the controller does not support SCSI drives.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35477','20','1.3.6.1.4.1.232.3.2.5.1.1.57.{#SNMPINDEX}','10411','{#DISK_LOCATION}: Physical disk S.M.A.R.T. status','hp.server.hw.physicaldisk.smart_status[cpqDaPhyDrvSmartStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'70','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive S.M.A.R.T Status. The following values are defined:
other(1)  The agent is unable to determine if the status of S.M.A.R.T  predictive failure monitoring for this drive.
ok(2)  Indicates the drive is functioning properly.
replaceDrive(3)  Indicates that the drive has a S.M.A.R.T predictive failure  error and should be replaced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35478','20','1.3.6.1.4.1.232.3.2.5.1.1.6.{#SNMPINDEX}','10411','{#DISK_LOCATION}: Physical disk status','hp.server.hw.physicaldisk.status[cpqDaPhyDrvStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'57','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Status. This shows the status of the physical drive. The following values are valid for the physical drive status:
other (1)  Indicates that the instrument agent does not recognize  the drive.
You may need to upgrade your instrument agent  and/or driver software.
ok (2)  Indicates the drive is functioning properly.
failed (3)  Indicates that the drive is no longer operating and  should be replaced.
predictiveFailure(4)  Indicates that the drive has a predictive failure error and  should be replaced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35479','20','1.3.6.1.4.1.232.6.2.9.3.1.4.{#SNMPINDEX}','10411','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply status','hp.server.sensor.psu.status[cpqHeFltTolPowerSupplyCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The condition of the power supply. This value will be one of the following:
other(1)  The status could not be determined or not present.
ok(2)  The power supply is operating normally.
degraded(3)  A temperature sensor, fan or other power supply component is  outside of normal operating range.
failed(4)  A power supply component detects a condition that could  permanently damage the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35480','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10411','Ambient: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.Ambient.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35481','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10411','Ambient: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.Ambient.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: Ambient','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35482','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10411','CPU-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.CPU.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35483','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10411','CPU-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.CPU.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: CPU-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35484','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10411','{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35485','20','1.3.6.1.4.1.232.6.2.6.8.1.3.{#SNMPINDEX}','10411','{#SNMPINDEX}: Temperature sensor location','hp.server.sensor.temp.locale[cpqHeTemperatureLocale.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'55','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
This specifies the location of the temperature sensor present in the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35486','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10411','{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: {#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35487','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10411','I/O-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition."I/O.{#SNMPINDEX}"]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35488','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10411','I/O-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius."I/O.{#SNMPINDEX}"]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: I/O-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35489','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10411','Memory-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.Memory.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35490','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10411','Memory-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.Memory.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: Memory-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35491','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10411','PSU-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.PSU.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35492','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10411','PSU-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.PSU.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: PSU-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35493','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10411','System-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.System.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35494','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10411','System-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.System.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: System-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35495','20','1.3.6.1.4.1.232.3.2.3.1.1.3.{#SNMPINDEX}','10411','Disk {#SNMPINDEX}({#DISK_NAME}): Layout type','hp.server.hw.virtualdisk.layout[cpqDaLogDrvFaultTol.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'74','','','0','','','','','2',NULL,'Logical Drive Fault Tolerance.
This shows the fault tolerance mode of the logical drive.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35496','20','1.3.6.1.4.1.232.3.2.3.1.1.9.{#SNMPINDEX}','10411','Disk {#SNMPINDEX}({#DISK_NAME}): Disk size','hp.server.hw.virtualdisk.size[cpqDaLogDrvSize.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Logical Drive Size.
This is the size of the logical drive in megabytes.  This value
is calculated using the value 1,048,576 (2^20) as a megabyte.
Drive manufacturers sometimes use the number 1,000,000 as a
megabyte when giving drive capacities so this value may
differ from the advertised size of a drive.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35497','20','1.3.6.1.4.1.232.3.2.3.1.1.4.{#SNMPINDEX}','10411','Disk {#SNMPINDEX}({#DISK_NAME}): Status','hp.server.hw.virtualdisk.status[cpqDaLogDrvStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'75','','','0','','','','','2',NULL,'Logical Drive Status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35498','20','1.3.6.1.2.1.1.4.0','10412','System contact details','hp.server.contact[sysContact]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35499','20','1.3.6.1.2.1.1.1.0','10412','System description','hp.server.descr[sysDescr]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35500','20','1.3.6.1.4.1.232.2.2.4.2.0','10412','Hardware model name','hp.server.hw.model[cpqSiProductName]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: CPQSINFO-MIB
The machine product name. The name of the machine used in this system.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35501','20','1.3.6.1.4.1.232.2.2.2.1.0','10412','Hardware serial number','hp.server.hw.serialnumber[cpqSiSysSerialNum]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: CPQSINFO-MIB
The serial number of the physical system unit. The string will be empty if the system does not report the serial number function.','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35502','20','1.3.6.1.2.1.1.6.0','10412','System location','hp.server.location[sysLocation]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35503','20','1.3.6.1.2.1.1.5.0','10412','System name','hp.server.name[sysName]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35504','20','1.3.6.1.2.1.1.2.0','10412','System object ID','hp.server.objectid[sysObjectID]','15m','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35505','20','1.3.6.1.4.1.232.6.2.6.1.0','10412','System temperature status','hp.server.sensor.temp.status[cpqHeThermalCondition]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','0',NULL,'MIB: CPQHLTH-MIB
This value specifies the overall condition of the system''s thermal environment.
This value will be one of the following:
other(1)  Temperature could not be determined.
ok(2)  The temperature sensor is within normal operating range.
degraded(3)  The temperature sensor is outside of normal operating range.
failed(4)  The temperature sensor detects a condition that could  permanently damage the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35506','20','1.3.6.1.4.1.232.6.1.3.0','10412','Overall system health status','hp.server.status[cpqHeMibCondition]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','0',NULL,'MIB: CPQHLTH-MIB
The overall condition. This object represents the overall status of the server information represented by this MIB.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35507','20','1.3.6.1.2.1.1.3.0','10412','Uptime','hp.server.uptime[sysUpTime]','1m','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35508','17','','10412','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd',NULL,NULL,'','','0','','','','','0',NULL,'The item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35509','5','','10412','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35510','20','discovery[{#CACHE_STATUS},1.3.6.1.4.1.232.3.2.2.2.1.2,{#CACHE_CNTRL_INDEX},1.3.6.1.4.1.232.3.2.2.2.1.1]','10412','Array controller cache discovery','array.cache.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CPQIDA-MIB::cpqDaAccelTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35511','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.2.1.1.1,{#CNTLR_SLOT},1.3.6.1.4.1.232.3.2.2.1.1.5,{#CNTLR_LOCATION},1.3.6.1.4.1.232.3.2.2.1.1.20]','10412','Array controller discovery','array.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Array controllers: CPQIDA-MIB::cpqDaCntlrTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35512','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.7.1.9]','10412','FAN discovery','fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQHLTH-MIB::cpqHeFltTolFanCondition','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35513','20','discovery[{#ADAPTER_INDEX},1.3.6.1.4.1.232.18.2.3.1.1.1,{#ADAPTER_NAME},1.3.6.1.4.1.232.18.2.3.1.1.39]','10412','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQIDA-MIB::cpqNicIfPhysAdapterTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35514','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.5.1.1.5,{#DISK_LOCATION},1.3.6.1.4.1.232.3.2.5.1.1.64]','10412','Physical disk discovery','physicaldisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning  table of physical drive entries CPQIDA-MIB::cpqDaPhyDrvTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35515','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.9.3.1.5,{#CHASSIS_NUM},1.3.6.1.4.1.232.6.2.9.3.1.1,{#BAY_NUM},1.3.6.1.4.1.232.6.2.9.3.1.2]','10412','PSU discovery','psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQHLTH-MIB::cpqHeFltTolPowerSupplyStatus','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35516','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10412','Temperature ambient discovery','temp.ambient.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with ambient(11) and 0.1 index filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35517','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10412','Temperature CPU discovery','temp.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with cpu(6) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35518','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10412','Temperature discovery','temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35519','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10412','Temperature I/O discovery','temp.io.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with ioBoard(5) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35520','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10412','Temperature memory discovery','temp.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with memory(7) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35521','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10412','Temperature PSU discovery','temp.psu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with powerSupply(10) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35522','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.6.2.6.8.1.1,{#SENSOR_LOCALE},1.3.6.1.4.1.232.6.2.6.8.1.3]','10412','Temperature system discovery','temp.system.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Scanning table of Temperature Sensor Entries:
CPQHLTH-MIB::cpqHeTemperatureTable with system(3) filter','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35523','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.232.3.2.3.1.1.2,{#DISK_NAME},1.3.6.1.4.1.232.3.2.3.1.1.14]','10412','Virtual disk discovery','virtualdisk.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'CPQIDA-MIB::cpqDaLogDrvTable','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35524','20','1.3.6.1.4.1.232.3.2.2.2.1.6.{#SNMPINDEX}','10412','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery status','hp.server.hw.diskarray.cache.battery.status[cpqDaAccelBattery.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'72','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Cache Module Board Backup Power Status. This monitors the status of each backup power source on the board.
The backup power source can only recharge when the system has power applied. The type of backup power source used is indicated by cpqDaAccelBackupPowerSource.
The following values are valid:
Other (1)  Indicates that the instrument agent does not recognize  backup power status.  You may need to update your software.

Ok (2)  The backup power source is fully charged.

Recharging (3)  The array controller has one or more cache module backup power  sources that are recharging.
Cache module operations such as Battery/Flash Backed Write Cache, Expansion, Extension and Migration are temporarily suspended until the backup power source is fully charged.
Cache module operations will automatically resume  when charging is complete.

Failed (4)  The battery pack is below the sufficient voltage level and  has not recharged in 36 hours.
Your Cache Module board  needs to be serviced.

Degraded (5)  The battery is still operating, however, one of the batteries  in the pack has failed to recharge properly.
Your Cache  Module board should be serviced as soon as possible.

NotPresent (6)  A backup power source is not present on the cache module board. Some controllers do not have backup power sources.

Capacitor Failed (7)  The flash backed cache module capacitor is below the sufficient voltage level and has not recharged in 10 minutes.  Your Cache Module board needs to be serviced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35525','20','1.3.6.1.4.1.232.3.2.2.2.1.2.{#SNMPINDEX}','10412','#{#CACHE_CNTRL_INDEX}: Disk array cache controller status','hp.server.hw.diskarray.cache.status[cpqDaAccelStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'71','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Cache Module/Operations Status. This describes the status of the cache module and/or cache operations.


The status can be:
Other (1)
 Indicates that the instrument agent does not recognize the status of the cache module.

Invalid (2)
 Indicates that a cache module board has not been installed in this system or is present but not configured.

Enabled (3)
 Indicates that cache operations are currently configured and enabled for at least one logical drive.

Temporarily Disabled (4)
 Indicates that cache operations have been temporarily disabled. (5)
 Indicates that cache operations have been permanently disabled. 

Cache Module Flash Memory Not Attached (6)
 Indicates that the flash memory component of the flash backed cache module is not attached. This status will be set when the flash memory is not attached and the Supercap is attached. This value is only used on flash backed cache modules that support removable flash memory.

Cache Module Degraded Failsafe Speed (7)
 Indicates that the cache module board is currently degraded and operating at a failsafe speed. 

Cache Module Critical Failure (8)
 Indicates that the cache module board has encountered a critical failure. The controller is currently operating in Zero Memory Raid mode.

Read Cache Could Not Be Mapped (9)
 Indicates that the read cache memory in a split cache configuration could not be mapped by the operating system and as a result is not available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35526','20','1.3.6.1.4.1.232.3.2.2.1.1.2.{#SNMPINDEX}','10412','{#CNTLR_LOCATION}: Disk array controller model','hp.server.hw.diskarray.model[cpqDaCntlrModel.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'56','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Array Controller Model. The type of controller card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35527','20','1.3.6.1.4.1.232.3.2.2.1.1.6.{#SNMPINDEX}','10412','{#CNTLR_LOCATION}: Disk array controller status','hp.server.hw.diskarray.status[cpqDaCntlrCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
This value represents the overall condition of this controller,
and any associated logical drives, physical drives, and array accelerators.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35528','20','1.3.6.1.4.1.232.6.2.6.7.1.9.{#SNMPINDEX}','10412','Fan {#SNMPINDEX}: Fan status','hp.server.sensor.fan.status[cpqHeFltTolFanCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The condition of the fan.
This value will be one of the following:
other(1)  Fan status detection is not supported by this system or driver.
ok(2)  The fan is operating properly.
degraded(2)  A redundant fan is not operating properly.
failed(4)  A non-redundant fan is not operating properly.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35529','20','1.3.6.1.4.1.232.18.2.3.1.1.14.{#SNMPINDEX}','10412','{#ADAPTER_NAME} port {#ADAPTER_INDEX}: Status','hp.server.net.if.status[cpqNicIfPhysAdapterStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'236','','','0','','','','','2',NULL,'MIB: CPQNIC-MIB
The physical adapter status. The following values are valid:
unknown(1)
  The instrument agent was not able to determine the status of the adapter. The instrument agent may need to be upgraded.
ok(2)
  The physical adapter is operating properly.
generalFailure(3)
  The physical adapter has failed.
linkFailure(4)
  The physical adapter has lost link. Check the cable connections to this adapter.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35530','20','1.3.6.1.4.1.232.3.2.5.1.1.69.{#SNMPINDEX}','10412','{#DISK_LOCATION}: Physical disk media type','hp.server.hw.physicaldisk.media_type[cpqDaPhyDrvMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'73','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Drive Array Physical Drive Media Type. The following values are defined:
other(1)  The instrument agent is unable to determine the physical drive’s media type.
rotatingPlatters(2)  The physical drive media is composed of rotating platters.
solidState(3)  The physical drive media is composed of solid state electronics.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35531','20','1.3.6.1.4.1.232.3.2.5.1.1.3.{#SNMPINDEX}','10412','{#DISK_LOCATION}: Physical disk model name','hp.server.hw.physicaldisk.model[cpqDaPhyDrvModel.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Model. This is a text description of the physical drive.
The text that appears depends upon who manufactured the drive and the drive type.
If a drive fails, note the model to identify the type of drive necessary for replacement.
If a model number is not present, you may not have properly initialized the drive array to which the physical drive is attached for monitoring.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35532','20','1.3.6.1.4.1.232.3.2.5.1.1.51.{#SNMPINDEX}','10412','{#DISK_LOCATION}: Physical disk serial number','hp.server.hw.physicaldisk.serialnumber[cpqDaPhyDrvSerialNum.{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Serial Number.
This is the serial number assigned to the physical drive.
This value is based upon the serial number as returned by the SCSI inquiry command
but may have been modified due to space limitations.  This can be used for identification purposes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35533','20','1.3.6.1.4.1.232.3.2.5.1.1.45.{#SNMPINDEX}','10412','{#DISK_LOCATION}: Disk size','hp.server.hw.physicaldisk.size[cpqDaPhyDrvMediaType.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Size in MB.
This is the size of the physical drive in megabytes.
This value is calculated using the value 1,048,576 (2^20) as a megabyte.
Drive manufacturers sometimes use the number 1,000,000 as a megabyte when giving drive capacities so this value may differ
from the advertised size of a drive. This field is only applicable for controllers which support SCSI drives,
and therefore is not supported by the IDA or IDA-2 controllers. The field will contain 0xFFFFFFFF if the drive capacity cannot be calculated
or if the controller does not support SCSI drives.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35534','20','1.3.6.1.4.1.232.3.2.5.1.1.57.{#SNMPINDEX}','10412','{#DISK_LOCATION}: Physical disk S.M.A.R.T. status','hp.server.hw.physicaldisk.smart_status[cpqDaPhyDrvSmartStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'70','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive S.M.A.R.T Status. The following values are defined:
other(1)  The agent is unable to determine if the status of S.M.A.R.T  predictive failure monitoring for this drive.
ok(2)  Indicates the drive is functioning properly.
replaceDrive(3)  Indicates that the drive has a S.M.A.R.T predictive failure  error and should be replaced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35535','20','1.3.6.1.4.1.232.3.2.5.1.1.6.{#SNMPINDEX}','10412','{#DISK_LOCATION}: Physical disk status','hp.server.hw.physicaldisk.status[cpqDaPhyDrvStatus.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'57','','','0','','','','','2',NULL,'MIB: CPQIDA-MIB
Physical Drive Status. This shows the status of the physical drive. The following values are valid for the physical drive status:
other (1)  Indicates that the instrument agent does not recognize  the drive.
You may need to upgrade your instrument agent  and/or driver software.
ok (2)  Indicates the drive is functioning properly.
failed (3)  Indicates that the drive is no longer operating and  should be replaced.
predictiveFailure(4)  Indicates that the drive has a predictive failure error and  should be replaced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35536','20','1.3.6.1.4.1.232.6.2.9.3.1.4.{#SNMPINDEX}','10412','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply status','hp.server.sensor.psu.status[cpqHeFltTolPowerSupplyCondition.{#SNMPINDEX}]','1m','7d','0d','0','3','','','','',NULL,'54','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The condition of the power supply. This value will be one of the following:
other(1)  The status could not be determined or not present.
ok(2)  The power supply is operating normally.
degraded(3)  A temperature sensor, fan or other power supply component is  outside of normal operating range.
failed(4)  A power supply component detects a condition that could  permanently damage the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35537','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10412','Ambient: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.Ambient.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35538','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10412','Ambient: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.Ambient.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: Ambient','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35539','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10412','CPU-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.CPU.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35540','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10412','CPU-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.CPU.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: CPU-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35541','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10412','{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35542','20','1.3.6.1.4.1.232.6.2.6.8.1.3.{#SNMPINDEX}','10412','{#SNMPINDEX}: Temperature sensor location','hp.server.sensor.temp.locale[cpqHeTemperatureLocale.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'55','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
This specifies the location of the temperature sensor present in the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35543','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10412','{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: {#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35544','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10412','I/O-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition."I/O.{#SNMPINDEX}"]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35545','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10412','I/O-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius."I/O.{#SNMPINDEX}"]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: I/O-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35546','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10412','Memory-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.Memory.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35547','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10412','Memory-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.Memory.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: Memory-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35548','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10412','PSU-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.PSU.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35549','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10412','PSU-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.PSU.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: PSU-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35550','20','1.3.6.1.4.1.232.6.2.6.8.1.6.{#SNMPINDEX}','10412','System-{#SNMPINDEX}: Temperature sensor condition','hp.server.sensor.temp.condition[cpqHeTemperatureCondition.System.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'148','','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
The Temperature sensor condition.
This value will be one of the following:
other(1)
  Temperature could not be determined.
ok(2)
  The temperature sensor is within normal operating range.
degraded(3)
  The temperature sensor is outside of normal operating range.
failed(4)
  The temperature sensor detects a condition that could
  permanently damage the system.
The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.  If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35551','20','1.3.6.1.4.1.232.6.2.6.8.1.4.{#SNMPINDEX}','10412','System-{#SNMPINDEX}: Temperature','hp.server.sensor.temp.value[cpqHeTemperatureCelsius.System.{#SNMPINDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CPQHLTH-MIB
Temperature readings of testpoint: System-{#SNMPINDEX}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35552','20','1.3.6.1.4.1.232.3.2.3.1.1.3.{#SNMPINDEX}','10412','Disk {#SNMPINDEX}({#DISK_NAME}): Layout type','hp.server.hw.virtualdisk.layout[cpqDaLogDrvFaultTol.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'74','','','0','','','','','2',NULL,'Logical Drive Fault Tolerance.
This shows the fault tolerance mode of the logical drive.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35553','20','1.3.6.1.4.1.232.3.2.3.1.1.9.{#SNMPINDEX}','10412','Disk {#SNMPINDEX}({#DISK_NAME}): Disk size','hp.server.hw.virtualdisk.size[cpqDaLogDrvSize.{#SNMPINDEX}]','1m','7d','0d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Logical Drive Size.
This is the size of the logical drive in megabytes.  This value
is calculated using the value 1,048,576 (2^20) as a megabyte.
Drive manufacturers sometimes use the number 1,000,000 as a
megabyte when giving drive capacities so this value may
differ from the advertised size of a drive.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35554','20','1.3.6.1.4.1.232.3.2.3.1.1.4.{#SNMPINDEX}','10412','Disk {#SNMPINDEX}({#DISK_NAME}): Status','hp.server.hw.virtualdisk.status[cpqDaLogDrvStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'75','','','0','','','','','2',NULL,'Logical Drive Status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35558','0','','10413','Service units discovery','systemd.unit.discovery[service]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discover systemd service units and their details.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35559','0','','10413','Socket units discovery','systemd.unit.discovery[socket]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discover systemd socket units and their details.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35560','0','','10413','{#UNIT.NAME}: Get unit info','systemd.unit.get["{#UNIT.NAME}"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Returns all properties of a systemd service unit.
 Unit description: {#UNIT.DESCRIPTION}.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35561','0','','10413','{#UNIT.NAME}: Get unit info','systemd.unit.get["{#UNIT.NAME}",Socket]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Returns all properties of a systemd socket unit.
 Unit description: {#UNIT.DESCRIPTION}.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35568','16','','10414','Cache groups','jmx.discovery[beans,"org.apache:group=\"Cache groups\",*"]','10m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','1',NULL,'','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35569','16','','10414','Thread pool metrics','jmx.discovery[beans,"org.apache:group=\"Thread Pools\",*"]','10m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','1',NULL,'','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35570','16','','10414','Data region metrics','jmx.discovery[beans,"org.apache:group=DataRegionMetrics,*"]','10m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','1',NULL,'','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35571','16','','10414','Local node metrics','jmx.discovery[beans,"org.apache:group=Kernal,name=ClusterLocalNodeMetricsMXBeanImpl,*"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35572','16','','10414','Cluster metrics','jmx.discovery[beans,"org.apache:group=Kernal,name=ClusterMetricsMXBeanImpl,*"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35573','16','','10414','GridGain kernal metrics','jmx.discovery[beans,"org.apache:group=Kernal,name=IgniteKernal,*"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35574','16','','10414','TCP Ccmmunication SPI metrics','jmx.discovery[beans,"org.apache:group=SPIs,name=TcpCommunicationSpi,*"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35575','16','','10414','TCP discovery SPI','jmx.discovery[beans,"org.apache:group=SPIs,name=TcpDiscoverySpi,*"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35576','16','','10414','Transaction metrics','jmx.discovery[beans,"org.apache:group=TransactionMetrics,name=TransactionMetricsMxBeanImpl,*"]','30m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','1',NULL,'','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35577','16','','10414','Cache metrics','jmx.discovery[beans,"org.apache:name=\"org.apache.gridgain.internal.processors.cache.CacheLocalMetricsMXBeanImpl\",*"]','10m','90d','0','0','4','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','1',NULL,'','0','30d','1','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35578','16','','10414','Cache group [{#JMXNAME}]: Backups','jmx["{#JMXOBJ}",Backups]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Count of backups configured for cache group.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35579','16','','10414','Cache group [{#JMXNAME}]: Caches','jmx["{#JMXOBJ}",Caches]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'List of caches.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35580','16','','10414','Cache group [{#JMXNAME}]: Local node partitions, moving','jmx["{#JMXOBJ}",LocalNodeMovingPartitionsCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Count of partitions with state MOVING for this cache group located on this node.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35581','16','','10414','Cache group [{#JMXNAME}]: Local node partitions, owning','jmx["{#JMXOBJ}",LocalNodeOwningPartitionsCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Count of partitions with state OWNING for this cache group located on this node.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35582','16','','10414','Cache group [{#JMXNAME}]: Local node entries, renting','jmx["{#JMXOBJ}",LocalNodeRentingEntriesCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Count of entries remains to evict in RENTING partitions located on this node for this cache group.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35583','16','','10414','Cache group [{#JMXNAME}]: Local node partitions, renting','jmx["{#JMXOBJ}",LocalNodeRentingPartitionsCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Count of partitions with state RENTING for this cache group located on this node.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35584','16','','10414','Cache group [{#JMXNAME}]: Partition copies, max','jmx["{#JMXOBJ}",MaximumNumberOfPartitionCopies]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Maximum number of partition copies for all partitions of this cache group.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35585','16','','10414','Cache group [{#JMXNAME}]: Partition copies, min','jmx["{#JMXOBJ}",MinimumNumberOfPartitionCopies]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Minimum number of partition copies for all partitions of this cache group.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35586','16','','10414','Cache group [{#JMXNAME}]: Partitions','jmx["{#JMXOBJ}",Partitions]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Count of partitions for cache group.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35587','16','','10414','Thread pool [{#JMXNAME}]: Pool size, core','jmx["{#JMXOBJ}",CorePoolSize]','1m','7d','365d','0','3','','!msg','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The core number of threads.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35588','16','','10414','Thread pool [{#JMXNAME}]: Pool size, max','jmx["{#JMXOBJ}",MaximumPoolSize]','1m','7d','365d','0','3','','!msg','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The maximum allowed number of threads.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35589','16','','10414','Thread pool [{#JMXNAME}]: Pool size','jmx["{#JMXOBJ}",PoolSize]','1m','7d','365d','0','3','','!msg','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Current number of threads in the pool.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35590','16','','10414','Thread pool [{#JMXNAME}]: Queue size','jmx["{#JMXOBJ}",QueueSize]','1m','7d','365d','0','3','','!msg','','',NULL,NULL,'','','0','{$IGNITE.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Current size of the execution queue.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35591','16','','10414','Data region {#JMXNAME}: Allocation, rate','jmx["{#JMXOBJ}",AllocationRate]','1m','7d','365d','0','0','','!pps','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Allocation rate (pages per second) averaged across rateTimeInternal.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35592','16','','10414','Data region {#JMXNAME}: Checkpoint buffer size','jmx["{#JMXOBJ}",CheckpointBufferSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Total size in bytes for checkpoint buffer.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35593','16','','10414','Data region {#JMXNAME}: Dirty pages','jmx["{#JMXOBJ}",DirtyPages]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Number of pages in memory not yet synchronized with persistent storage.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35594','16','','10414','Data region {#JMXNAME}: Eviction, rate','jmx["{#JMXOBJ}",EvictionRate]','1m','7d','365d','0','0','','!pps','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Eviction rate (pages per second).','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35595','16','','10414','Data region {#JMXNAME}: Size, max','jmx["{#JMXOBJ}",MaxSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Maximum memory region size defined by its data region.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35596','16','','10414','Data region {#JMXNAME}: Offheap size','jmx["{#JMXOBJ}",OffHeapSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Offheap size in bytes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35597','16','','10414','Data region {#JMXNAME}: Offheap used size','jmx["{#JMXOBJ}",OffheapUsedSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Total used offheap size in bytes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35598','16','','10414','Data region {#JMXNAME}: Pages fill factor','jmx["{#JMXOBJ}",PagesFillFactor]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The percentage of the used space.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35599','16','','10414','Data region {#JMXNAME}: Pages replace, rate','jmx["{#JMXOBJ}",PagesReplaceRate]','1m','7d','365d','0','0','','!pps','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Rate at which pages in memory are replaced with pages from persistent storage (pages per second).','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35600','16','','10414','Data region {#JMXNAME}: Allocated, bytes','jmx["{#JMXOBJ}",TotalAllocatedSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Total size of memory allocated in bytes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35601','16','','10414','Data region {#JMXNAME}: Used checkpoint buffer size','jmx["{#JMXOBJ}",UsedCheckpointBufferSize]','1m','7d','365d','0','0','','B','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Used checkpoint buffer size in bytes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35602','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Jobs active, current','jmx["{#JMXOBJ}",CurrentActiveJobs]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Number of currently active jobs concurrently executing on the node.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35603','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Jobs cancelled, current','jmx["{#JMXOBJ}",CurrentCancelledJobs]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Number of cancelled jobs that are still running.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35604','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: PME duration, current','jmx["{#JMXOBJ}",CurrentPmeDuration]','1m','7d','365d','0','3','','ms','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Current PME duration in milliseconds.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35605','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Jobs rejected, current','jmx["{#JMXOBJ}",CurrentRejectedJobs]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Number of jobs rejected after more recent collision resolution operation.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35606','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Threads count, current','jmx["{#JMXOBJ}",CurrentThreadCount]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Current number of live threads.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35607','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Jobs waiting, current','jmx["{#JMXOBJ}",CurrentWaitingJobs]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Number of queued jobs currently waiting to be executed.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35608','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Heap memory used','jmx["{#JMXOBJ}",HeapMemoryUsed]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Current heap size that is used for object allocation.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35609','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Jobs cancelled, rate','jmx["{#JMXOBJ}",TotalCancelledJobs]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Total number of jobs cancelled by the node per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35610','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Jobs executed, rate','jmx["{#JMXOBJ}",TotalExecutedJobs]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Total number of jobs handled by the node per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35611','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Jobs rejects, rate','jmx["{#JMXOBJ}",TotalRejectedJobs]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Total number of jobs this node rejects during collision resolution operations since node startup per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35612','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Nodes, Active baseline','jmx["{#JMXOBJ}",ActiveBaselineNodes]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of nodes that are currently active in the baseline topology.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35613','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Nodes, Baseline','jmx["{#JMXOBJ}",TotalBaselineNodes]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Total baseline nodes that are registered in the baseline topology.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35614','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Nodes, Client','jmx["{#JMXOBJ}",TotalClientNodes]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of client nodes in the cluster.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35615','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Nodes, total','jmx["{#JMXOBJ}",TotalNodes]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Total number of nodes.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35616','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Nodes, Server','jmx["{#JMXOBJ}",TotalServerNodes]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of server nodes in the cluster.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35617','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Version','jmx["{#JMXOBJ}",FullVersion]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Version of GridGain instance.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35618','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Local node ID','jmx["{#JMXOBJ}",LocalNodeId]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Unique identifier for this node within grid.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35619','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Uptime','jmx["{#JMXOBJ}",UpTime]','1m','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Uptime of GridGain instance.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35620','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Communication outbound messages queue','jmx["{#JMXOBJ}",OutboundMessagesQueueSize]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Outbound messages queue size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35621','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Communication messages received, rate','jmx["{#JMXOBJ}",ReceivedMessagesCount]','1m','7d','365d','0','0','','!msg/s','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of  messages received per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35623','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Communication messages sent, rate','jmx["{#JMXOBJ}",SentMessagesCount]','1m','7d','365d','0','0','','!msg/s','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of  messages sent per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35624','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Coordinator','jmx["{#JMXOBJ}",Coordinator]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Current coordinator UUID.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35625','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Discovery message worker queue','jmx["{#JMXOBJ}",MessageWorkerQueueSize]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Message worker queue current size.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35626','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Nodes failed','jmx["{#JMXOBJ}",NodesFailed]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Nodes failed count.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35627','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Nodes joined','jmx["{#JMXOBJ}",NodesJoined]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Nodes join count.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35628','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Nodes left','jmx["{#JMXOBJ}",NodesLeft]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Nodes left count.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35629','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Discovery reconnect, rate','jmx["{#JMXOBJ}",ReconnectCount]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Number of times node tries to (re)establish connection to another node per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35630','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: TotalProcessedMessages','jmx["{#JMXOBJ}",TotalProcessedMessages]','1m','7d','365d','0','0','','!msg/s','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of messages received per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35631','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Discovery messages received, rate','jmx["{#JMXOBJ}",TotalReceivedMessages]','1m','7d','365d','0','0','','!msg/s','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of messages processed per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35632','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Locked keys','jmx["{#JMXOBJ}",LockedKeysNumber]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of keys locked on the node.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35633','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Transactions owner, current','jmx["{#JMXOBJ}",OwnerTransactionsNumber]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of active transactions for which this node is the initiator.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35634','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Transactions committed, rate','jmx["{#JMXOBJ}",TransactionsCommittedNumber]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of transactions which were committed per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35635','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Transactions holding lock, current','jmx["{#JMXOBJ}",TransactionsHoldingLockNumber]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of active transactions holding at least one key lock.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35636','16','','10414','GridGain [{#JMXIGNITEINSTANCENAME}]: Transactions rolledback, rate','jmx["{#JMXOBJ}",TransactionsRolledBackNumber]','1m','7d','365d','0','0','','','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of transactions which were rollback per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35637','16','','10414','Cache group [{#JMXGROUP}]: Cache gets, rate','jmx["{#JMXOBJ}",CacheGets]','1m','7d','365d','0','0','','ops','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of gets to the cache per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35638','16','','10414','Cache group [{#JMXGROUP}]: Cache hits, pct','jmx["{#JMXOBJ}",CacheHitPercentage]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Percentage of successful hits.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35639','16','','10414','Cache group [{#JMXGROUP}]: Cache misses, pct','jmx["{#JMXOBJ}",CacheMissPercentage]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'Percentage of accesses that failed to find anything.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35640','16','','10414','Cache group [{#JMXGROUP}]: Cache puts, rate','jmx["{#JMXOBJ}",CachePuts]','1m','7d','365d','0','0','','ops','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of puts to the cache per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35641','16','','10414','Cache group [{#JMXGROUP}]: Cache removals, rate','jmx["{#JMXOBJ}",CacheRemovals]','1m','7d','365d','0','0','','ops','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of removals from the cache per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35642','16','','10414','Cache group [{#JMXGROUP}]: Cache size','jmx["{#JMXOBJ}",CacheSize]','1m','7d','365d','0','3','','!keys','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of non-null values in the cache as a long value.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35643','16','','10414','Cache group [{#JMXGROUP}]: Cache transaction commits, rate','jmx["{#JMXOBJ}",CacheTxCommits]','1m','7d','365d','0','0','','!tps','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of transaction commits per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35644','16','','10414','Cache group [{#JMXGROUP}]: Cache transaction rollbacks, rate','jmx["{#JMXOBJ}",CacheTxRollbacks]','1m','7d','365d','0','0','','!tps','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of transaction rollback per second.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35645','16','','10414','Cache group [{#JMXGROUP}]: Cache heap entries','jmx["{#JMXOBJ}",HeapEntriesCount]','1m','7d','365d','0','3','','!keys','','',NULL,NULL,'','','0','{$GRIDGAIN.USER}','{$GRIDGAIN.PASSWORD}','','','2',NULL,'The number of entries in heap memory.','0','30d','0','service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35646','20','.1.3.6.1.2.1.1.4.0','10415','F5 BIG-IP: Contact','bigip.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35647','20','.1.3.6.1.4.1.3375.2.1.1.2.12.3.0','10415','F5 BIG-IP: TCP connections, CLOSE-WAIT/LAST-ACK','bigip.tcp.close_wait','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of current TCP connections in CLOSE-WAIT/LAST-ACK.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35648','20','.1.3.6.1.4.1.3375.2.1.6.6.0','10415','F5 BIG-IP: Uptime','bigip.uptime','1m','7d','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The system up time in 1/100 seconds since boot.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35649','20','.1.3.6.1.4.1.3375.2.1.1.2.13.2.0','10415','F5 BIG-IP: Open UDP connections','bigip.udp.open','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of current open UDP connections.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35650','20','.1.3.6.1.4.1.3375.2.1.1.2.12.5.0','10415','F5 BIG-IP: TCP connections, TIME-WAIT','bigip.tcp.time_wait','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of current TCP connections in TIME-WAIT.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35651','20','.1.3.6.1.4.1.3375.2.1.1.2.12.2.0','10415','F5 BIG-IP: Open TCP connections','bigip.tcp.open','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of current open TCP connections.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35652','20','.1.3.6.1.4.1.3375.2.1.1.2.12.20.0','10415','F5 BIG-IP: TCP connections, FIN-WAIT-2','bigip.tcp.fin2_wait','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of current TCP connections in FIN-WAIT-2.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35653','20','.1.3.6.1.4.1.3375.2.1.1.2.12.4.0','10415','F5 BIG-IP: TCP connections, FIN-WAIT-1/CLOSING','bigip.tcp.fin1_wait','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of current TCP connections in FIN-WAIT-1/CLOSING.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35654','20','.1.3.6.1.4.1.3375.2.1.3.3.3.0','10415','F5 BIG-IP: Chassis serial number','bigip.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35655','20','.1.3.6.1.2.1.1.6.0','10415','F5 BIG-IP: Location','bigip.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35656','20','.1.3.6.1.4.1.3375.2.1.4.2.0','10415','F5 BIG-IP: Product version','bigip.product.version','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The product version.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35657','20','.1.3.6.1.4.1.3375.2.1.4.1.0','10415','F5 BIG-IP: Product name','bigip.product.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The product name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35658','20','.1.3.6.1.4.1.3375.2.1.4.4.0','10415','F5 BIG-IP: Product edition','bigip.product.edition','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The product edition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35659','20','.1.3.6.1.4.1.3375.2.1.4.5.0','10415','F5 BIG-IP: Product build date','bigip.product.date','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The product build date.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35660','20','.1.3.6.1.4.1.3375.2.1.4.3.0','10415','F5 BIG-IP: Product build','bigip.product.build','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The product build number.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35661','20','.1.3.6.1.2.1.1.5.0','10415','F5 BIG-IP: Host name','bigip.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35662','20','.1.3.6.1.2.1.1.1.0','10415','F5 BIG-IP: Hardware model name','bigip.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35663','5','','10415','F5 BIG-IP: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35664','20','discovery[{#TEMP.INDEX},.1.3.6.1.4.1.3375.2.1.3.2.4.2.1.1,{#SLOT.INDEX},.1.3.6.1.4.1.3375.2.1.3.2.4.2.1.4,{#TEMP.LOCATION},.1.3.6.1.4.1.3375.2.1.3.2.4.2.1.3]','10415','Blade temperature discovery','bigip.blade.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Containing information of blade temperature of the system','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35665','20','discovery[{#VOLT.INDEX},.1.3.6.1.4.1.3375.2.1.3.2.5.2.1.1]','10415','Blade voltage discovery','bigip.blade.voltage.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table containing information of blade voltage of the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35666','20','discovery[{#CERT.NAME},.1.3.6.1.4.1.3375.2.1.15.1.2.1.1]','10415','Certificate discovery','bigip.cert.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table containing certificate configuration.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35667','20','discovery[{#FAN.INDEX},.1.3.6.1.4.1.3375.2.1.3.2.1.2.1.1]','10415','Chassis fan discovery','bigip.chassis.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table containing information of chassis fan status of the system','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35668','20','discovery[{#POWER.INDEX},.1.3.6.1.4.1.3375.2.1.3.2.2.2.1.1]','10415','Chassis power supply discovery','bigip.chassis.power.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table containing information of chassis power supply status of the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35669','20','discovery[{#TEMP.INDEX},.1.3.6.1.4.1.3375.2.1.3.2.3.2.1.1]','10415','Chassis temperature discovery','bigip.chassis.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table containing information of chassis temperature of the system','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35670','20','discovery[{#HOST.ID},.1.3.6.1.4.1.3375.2.1.7.5.2.1.1,{#CPU.ID},.1.3.6.1.4.1.3375.2.1.7.5.2.1.3]','10415','CPU discovery','bigip.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table containing entries of system CPU usage information for a system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35671','20','discovery[{#CPU.SENSOR.INDEX},.1.3.6.1.4.1.3375.2.1.3.6.2.1.1,{#CPU.SENSOR.SLOT},.1.3.6.1.4.1.3375.2.1.3.6.2.1.5,{#CPU.SENSOR.NAME},.1.3.6.1.4.1.3375.2.1.3.6.2.1.4]','10415','CPU sensor discovery','bigip.cpu.sensor.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table containing information of CPU sensor status on the system.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35672','20','discovery[{#PART.NAME},.1.3.6.1.4.1.3375.2.1.7.3.2.1.1]','10415','File system discovery','bigip.disktable.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table containing entries of system disk usage information.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35673','20','discovery[{#HOST.ID},.1.3.6.1.4.1.3375.2.1.7.4.2.1.1]','10415','Memory discovery','bigip.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Containing system statistics information of the memory usage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35674','20','discovery[{#MODULE.NAME},.1.3.6.1.4.1.3375.2.1.11.1.2.1.1]','10415','Module discovery','bigip.module.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Resource allocation information about modules on the system','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35675','20','discovery[{#IF.NAME},.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.1]','10415','Network interface discovery','bigip.net.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table containing statistic information of the interfaces on the device.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35676','20','discovery[{#NODE.NAME},.1.3.6.1.4.1.3375.2.2.4.2.3.1.20]','10415','Node discovery','bigip.node.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table containing statistic information of node addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35677','20','discovery[{#POOL.NAME},.1.3.6.1.4.1.3375.2.2.5.2.3.1.1]','10415','Pool discovery','bigip.pool.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table containing statistic information of pools.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35678','20','discovery[{#VSERVER.NAME},.1.3.6.1.4.1.3375.2.2.10.2.3.1.1]','10415','Virtual server discovery','bigip.virtual_server.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table containing information of virtual servers.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35679','20','.1.3.6.1.4.1.3375.2.1.3.2.4.2.1.2.{#SNMPINDEX}','10415','F5 BIG-IP: Sensor [{#SLOT.INDEX}:{#TEMP.INDEX}]: Temperature','bigip.blade.temp.value[{#SLOT.INDEX},{#TEMP.INDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
Location: {#TEMP.LOCATION}
The blade temperature (in Celsius) of the indexed sensor on the system.,
This is only supported for the platform where
the sensor data is available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35680','20','.1.3.6.1.4.1.3375.2.1.3.2.5.2.1.3.{#SNMPINDEX}','10415','F5 BIG-IP: Voltage [{#VOLT.INDEX}]: Slot','bigip.blade.voltage.slot[{#VOLT.INDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The chassis slot number, if applicable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35681','20','.1.3.6.1.4.1.3375.2.1.3.2.4.2.1.2.{#SNMPINDEX}','10415','F5 BIG-IP: Voltage [{#VOLT.INDEX}]: Value','bigip.blade.voltage.value[{#VOLT.INDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The blade voltage (in V) of the indexed sensor on the system.,
This is only supported for the platform where
the sensor data is available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35682','20','.1.3.6.1.4.1.3375.2.1.15.1.2.1.5.{#SNMPINDEX}','10415','F5 BIG-IP: Certificate [{#CERT.NAME}]: Expiration date','bigip.cert.expiration.date[{#CERT.NAME}]','1m','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The expiration date of the certificate in unix time.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35683','20','.1.3.6.1.4.1.3375.2.1.3.2.1.2.1.3.{#SNMPINDEX}','10415','F5 BIG-IP: FAN [{#FAN.INDEX}]: Speed','bigip.chassis.fan.speed[{#FAN.INDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The actual speed of the indexed chassis fan on the system.
This is only supported for the platform where the actual
fan speed data is available.
''0'' means fan speed is unavailable while the associated chassis status is good.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35684','20','.1.3.6.1.4.1.3375.2.1.3.2.1.2.1.2.{#SNMPINDEX}','10415','F5 BIG-IP: FAN [{#FAN.INDEX}]: Status','bigip.chassis.fan.status[{#FAN.INDEX}]','1m','7d','365d','0','3','','','','',NULL,'240','','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The status of the indexed chassis fan on the system.,
This is only supported for the platform where
the sensor data is available.
Possible values: 0 - bad, 1 - good, 2 - notpresent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35685','20','.1.3.6.1.4.1.3375.2.1.3.2.2.2.1.2.{#SNMPINDEX}','10415','F5 BIG-IP: Power supply [{#POWER.INDEX}]: Status','bigip.chassis.power.status[{#POWER.INDEX}]','1m','7d','365d','0','3','','','','',NULL,'240','','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The status of the indexed power supply on the system.,
This is only supported for the platform where
the sensor data is available.
Possible values: 0 - bad, 1 - good, 2 - notpresent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35686','20','.1.3.6.1.4.1.3375.2.1.3.2.3.2.1.2.{#SNMPINDEX}','10415','F5 BIG-IP: Sensor [{#TEMP.INDEX}]: Temperature','bigip.chassis.temp.value[{#TEMP.INDEX}]','1m','7d','365d','0','0','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The chassis temperature (in Celsius) of the indexed sensor on the system.,
This is only supported for the platform where
the sensor data is available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35687','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.23.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Idle, avg 1m','bigip.cpu.idle.1m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor doing nothing for the associated host in the last one minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35688','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.17.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Soft IRQ, avg 5s','bigip.cpu.spftirq.5s[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor servicing soft interrupts for the associated host in the last five seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35689','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.28.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: User, avg 5m','bigip.cpu.user.5m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor in user context for the associated host in the last five minutes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35690','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.20.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: User, avg 1m','bigip.cpu.user.1m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor in user context for the associated host in the last one minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35691','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.19.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Usage ratio, avg 5s','bigip.cpu.usageratio.5s[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
This is  average usage ratio of CPU for the associated host in the last five seconds. It is calculated by
(sum of deltas for user, niced, system)/(sum of deltas of user, niced, system, idle, irq, softirq, and iowait),
where each delta is the difference for each stat over the last 5-second interval;
user:sysMultiHostCpuUser5s;
niced:sysMultiHostCpuNiced5s;
stolen:sysMultiHostCpuStolen5s;
system:sysMultiHostCpuSystem5s;
idle:sysMultiHostCpuIdle5s;
irq:sysMultiHostCpuIrq5s;
iowait:sysMultiHostCpuIowait5s','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35692','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.35.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Usage ratio, avg 5m','bigip.cpu.usageratio.5m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
This is  average usage ratio of CPU for the associated host in the last five minutes. It is calculated by
(sum of deltas for user, niced, system)/(sum of deltas of user, niced, system, idle, irq, softirq, and iowait),
where each delta is the difference for each stat over the last 5-second interval;
user:sysMultiHostCpuUser5m;
niced:sysMultiHostCpuNiced5m;
stolen:sysMultiHostCpuStolen5m;
system:sysMultiHostCpuSystem5m;
idle:sysMultiHostCpuIdle5m;
irq:sysMultiHostCpuIrq5m;
iowait:sysMultiHostCpuIowait5m','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35693','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.27.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Usage ratio, avg 1m','bigip.cpu.usageratio.1m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
This is  average usage ratio of CPU for the associated host in the last one minute. It is calculated by
(sum of deltas for user, niced, system)/(sum of deltas of user, niced, system, idle, irq, softirq, and iowait),
where each delta is the difference for each stat over the last 5-second interval;
user:sysMultiHostCpuUser1m;
niced:sysMultiHostCpuNiced1m;
stolen:sysMultiHostCpuStolen1m;
system:sysMultiHostCpuSystem1m;
idle:sysMultiHostCpuIdle1m;
irq:sysMultiHostCpuIrq1m;
iowait:sysMultiHostCpuIowait1m','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35694','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.14.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: System, avg 5s','bigip.cpu.system.5s[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor servicing system calls for the associated host in the last five seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35695','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.30.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: System, avg 5m','bigip.cpu.system.5m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor servicing system calls for the associated host in the last five minutes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35696','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.22.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: System, avg 1m','bigip.cpu.system.1m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor servicing system calls for the associated host in the last one minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35697','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.39.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Stolen, avg 5m','bigip.cpu.stolen.5m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time ''stolen'' from the specified processor for the associated host in the last five minutes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35698','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.37.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Stolen, avg 1s)','bigip.cpu.stolen.1s[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time ''stolen'' from the specified processor for the associated host in the last five seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35699','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.38.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Stolen, avg 1m','bigip.cpu.stolen.1m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time ''stolen'' from the specified processor for the associated host in the last one minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35700','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.33.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Soft IRQ, avg 5m','bigip.cpu.spftirq.5m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor servicing soft interrupts for the associated host in the last five minutes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35701','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.31.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Idle, avg 5m','bigip.cpu.idle.5m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor doing nothing for the associated host in the last five minutes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35702','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.25.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Soft IRQ, avg 1m','bigip.cpu.spftirq.1m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor servicing soft interrupts for the associated host in the last one minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35703','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.13.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Nice, avg 5s','bigip.cpu.nice.5s[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor running niced processes for the associated host in the last five seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35704','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.29.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Nice, avg 5m','bigip.cpu.nice.5m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor running niced processes for the associated host in the last five minutes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35705','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.21.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Nice, avg 1m','bigip.cpu.nice.1m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor running niced processes for the associated host in the last one minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35706','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.16.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: IRQ, avg 5s','bigip.cpu.irq.5s[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor servicing hardware interrupts for the associated host in the last five seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35707','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.32.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: IRQ, avg 5m','bigip.cpu.irq.5m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor servicing hardware interrupts for the associated host in the last five minutes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35708','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.24.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: IRQ, avg 1m','bigip.cpu.irq.1m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor servicing hardware interrupts for the associated host in the last one minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35709','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.18.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: IO wait, avg 5s','bigip.cpu.iowait.5s[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor waiting for external I/O to complete for the associated host in the last five seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35710','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.34.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: IO wait, avg 5m','bigip.cpu.iowait.5m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor waiting for external I/O to complete for the associated host in the last five minutes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35711','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.26.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: IO wait, avg 1m','bigip.cpu.iowait.1m[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor waiting for external I/O to complete for the associated host in the last one minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35712','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.15.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Idle, avg 5s','bigip.cpu.idle.5s[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor doing nothing for the associated host in the last five seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35713','20','.1.3.6.1.4.1.3375.2.1.7.5.2.1.12.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: User, avg 5s','bigip.cpu.user.5s[{#HOST.ID},{#CPU.ID}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The average time spent by the specified processor in user context for the associated host in the last five seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35714','20','.1.3.6.1.4.1.3375.2.1.3.6.2.1.3.{#SNMPINDEX}','10415','F5 BIG-IP: Sensor [{#CPU.SENSOR.SLOT}:{#CPU.SENSOR.INDEX}]: FAN speed','bigip.cpu.sensor.fan[{#CPU.SENSOR.SLOT},{#CPU.SENSOR.INDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
CPU: {#CPU.SENSOR.NAME}
The fan speed (in RPM) of the indexed CPU on the system.,
This is only supported for the platform where
the sensor data is available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35715','20','.1.3.6.1.4.1.3375.2.1.3.6.2.1.4.{#SNMPINDEX}','10415','F5 BIG-IP: Sensor [{#CPU.SENSOR.SLOT}:{#CPU.SENSOR.INDEX}]: Name','bigip.cpu.sensor.name[{#CPU.SENSOR.SLOT},{#CPU.SENSOR.INDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
Identifier for the CPU.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35716','20','.1.3.6.1.4.1.3375.2.1.3.6.2.1.2.{#SNMPINDEX}','10415','F5 BIG-IP: Sensor [{#CPU.SENSOR.SLOT}:{#CPU.SENSOR.INDEX}]: Temperature','bigip.cpu.sensor.temperature[{#CPU.SENSOR.SLOT},{#CPU.SENSOR.INDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
CPU: {#CPU.SENSOR.NAME}
The temperature of the indexed CPU on the system.
This is only supported for the platform where
the sensor data is available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35717','20','.1.3.6.1.4.1.3375.2.1.7.3.2.1.2.{#SNMPINDEX}','10415','F5 BIG-IP: Mount point [{#PART.NAME}]: Block size','bigip.disktable.blocksize[{#PART.NAME}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of bytes in the specified partition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35718','20','.1.3.6.1.4.1.3375.2.1.7.3.2.1.4.{#SNMPINDEX}','10415','F5 BIG-IP: Mount point [{#PART.NAME}]: Free blocks','bigip.disktable.freeblocks[{#PART.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of free blocks in the specified partition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35719','20','.1.3.6.1.4.1.3375.2.1.7.3.2.1.6.{#SNMPINDEX}','10415','F5 BIG-IP: Mount point [{#PART.NAME}]: Free nodes','bigip.disktable.freenodes[{#PART.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of free file nodes in the specified partition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35720','20','.1.3.6.1.4.1.3375.2.1.7.3.2.1.3.{#SNMPINDEX}','10415','F5 BIG-IP: Mount point [{#PART.NAME}]: Total blocks','bigip.disktable.totalblocks[{#PART.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of total blocks in the specified partition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35721','20','.1.3.6.1.4.1.3375.2.1.7.3.2.1.5.{#SNMPINDEX}','10415','F5 BIG-IP: Mount point [{#PART.NAME}]: Total nodes','bigip.disktable.totalnodes[{#PART.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of total file nodes in the specified partition.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35722','20','.1.3.6.1.4.1.3375.2.1.7.4.2.1.7.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}]: Total other non-TMM memory','bigip.memory.total.other[{#HOST.ID}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The total other non-TMM memory in bytes for the specified host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35723','20','.1.3.6.1.4.1.3375.2.1.7.4.2.1.9.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}]: Total swap','bigip.memory.total.swap[{#HOST.ID}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The total swap in bytes for the specified host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35724','20','.1.3.6.1.4.1.3375.2.1.7.4.2.1.2.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}]: Total memory','bigip.memory.total[{#HOST.ID}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The total host memory in bytes for the specified host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35725','20','.1.3.6.1.4.1.3375.2.1.7.4.2.1.8.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}]: Used other non-TMM memory','bigip.memory.used.other[{#HOST.ID}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The other non-TMM memory in bytes currently in use for the specified host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35726','20','.1.3.6.1.4.1.3375.2.1.7.4.2.1.10.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}]: Used swap','bigip.memory.used.swap[{#HOST.ID}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The swap in bytes currently in use for the specified host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35727','20','.1.3.6.1.4.1.3375.2.1.7.4.2.1.3.{#SNMPINDEX}','10415','F5 BIG-IP: Host [{#HOST.ID}]: Used memory','bigip.memory.used[{#HOST.ID}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The host memory in bytes currently in use for the specified host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35728','20','.1.3.6.1.4.1.3375.2.1.11.1.2.1.4.{#SNMPINDEX}','10415','F5 BIG-IP: Module [{#MODULE.NAME}]: CPU ratio','bigip.module.cpu.ratio[{#MODULE.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The ratio of CPU to allocate to this module. Only valid if level is ''custom''','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35729','20','.1.3.6.1.4.1.3375.2.1.11.1.2.1.5.{#SNMPINDEX}','10415','F5 BIG-IP: Module [{#MODULE.NAME}]: Disk ratio','bigip.module.disk.ratio[{#MODULE.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The ratio of available disk space to allocate to this module. Only valid if level is ''custom''','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35730','20','.1.3.6.1.4.1.3375.2.1.11.1.2.1.3.{#SNMPINDEX}','10415','F5 BIG-IP: Module [{#MODULE.NAME}]: Memory ratio','bigip.module.memory.ratio[{#MODULE.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The ratio of available memory to allocate. Only valid if level is ''custom''','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35731','20','.1.3.6.1.4.1.3375.2.1.11.1.2.1.2.{#SNMPINDEX}','10415','F5 BIG-IP: Module [{#MODULE.NAME}]: Provision level','bigip.module.provision.level[{#MODULE.NAME}]','1m','7d','365d','0','3','','','','',NULL,'241','','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The provisioning level indicates how the systems resources
are distributed amongst the modules
Possible values: 1 - none, 2 - minimum, 3 - nominal, 4 - dedicated, 5 - custom.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35732','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.12.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Collisions','bigip.net.collisions[{#IF.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of collisions on the specified interface, incremented by the
number of collisions experienced during transmissions of a frame','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35733','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.3.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Incoming traffic, rate','bigip.net.in.bytes.rate[{#IF.NAME}]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The rate of bytes received on this interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35734','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.10.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Incoming packet drops','bigip.net.in.drops[{#IF.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of packets dropped on ingress for various reasons on the specified interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35735','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.8.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Incoming packet error','bigip.net.in.error[{#IF.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of received packets that are either undersized,
oversized, or have FCS errors by the specified interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35736','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.6.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Incoming multicast packet, rate','bigip.net.in.multicast.rate[{#IF.NAME}]','1m','7d','365d','0','3','','pps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The rate of multicast packets received on this interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35737','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.2.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Incoming packet, rate','bigip.net.in.pkts.rate[{#IF.NAME}]','1m','7d','365d','0','3','','pps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The rate of packets received on this interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35738','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.13.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Incoming QnQ packet, rate','bigip.net.in.qq.rate[{#IF.NAME}]','1m','7d','365d','0','3','','pps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The rate of double tagged packets received on the specified interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35739','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.5.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Outgoing traffic, rate','bigip.net.out.bytes.rate[{#IF.NAME}]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The rate of bytes transmitted out of the specified interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35740','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.11.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Outgoing packet drops','bigip.net.out.drops[{#IF.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of packets aged out or with excessive transmission
delays due to multiple deferrals on the specified interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35741','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.9.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Outgoing packet error','bigip.net.out.error[{#IF.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The number of excessive collisions, incremented for each
frame that experienced 16 collisions during transmission and
was aborted on the specified interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35742','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.7.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Outgoing multicast packet, rate','bigip.net.out.multicast.rate[{#IF.NAME}]','1m','7d','365d','0','3','','pps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The rate of multicast packets transmitted out of the specified interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35743','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.4.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Outgoing packet, rate','bigip.net.out.pkts.rate[{#IF.NAME}]','1m','7d','365d','0','3','','pps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The rate of packets transmitted out of the specified interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35744','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.14.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Outgoing QnQ packet, rate','bigip.net.out.qq.rate[{#IF.NAME}]','1m','7d','365d','0','3','','pps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The rate of double tagged packets transmitted out of the specified interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35745','20','.1.3.6.1.4.1.3375.2.1.2.4.4.3.1.15.{#SNMPINDEX}','10415','F5 BIG-IP: Interface [{#IF.NAME}]: Pause state','bigip.net.pause[{#IF.NAME}]','1m','7d','365d','0','3','','','','',NULL,'242','','','0','','','','','2',NULL,'MIB: F5-BIGIP-SYSTEM-MIB
The pause state of the specified interface.
none - no pause;
txrx - pause all data flow;
tx - pause out going data flow;
rx - pause in coming data flow.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35746','20','.1.3.6.1.4.1.3375.2.2.4.2.3.1.9.{#SNMPINDEX}','10415','F5 BIG-IP: Node [{#NODE.NAME}]: Current connections','bigip.node.net.conn[{#NODE.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The current connections from server-side to the specified node address.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35747','20','.1.3.6.1.4.1.3375.2.2.4.2.3.1.4.{#SNMPINDEX}','10415','F5 BIG-IP: Node [{#NODE.NAME}]: Incoming traffic, rate','bigip.node.net.in.bytes.rate[{#NODE.NAME}]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The rate of bytes received by the specified node address from server-side.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35748','20','.1.3.6.1.4.1.3375.2.2.4.2.3.1.3.{#SNMPINDEX}','10415','F5 BIG-IP: Node [{#NODE.NAME}]: Incoming packet, rate','bigip.node.net.in.pkts.rate[{#NODE.NAME}]','1m','7d','365d','0','3','','pps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The rate of packets received by the specified node address from server-side.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35749','20','.1.3.6.1.4.1.3375.2.2.4.2.3.1.6.{#SNMPINDEX}','10415','F5 BIG-IP: Node [{#NODE.NAME}]: Outgoing traffic, rate','bigip.node.net.out.bytes.rate[{#NODE.NAME}]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The rate of bytes sent to server-side from the specified node address.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35750','20','.1.3.6.1.4.1.3375.2.2.4.2.3.1.5.{#SNMPINDEX}','10415','F5 BIG-IP: Node [{#NODE.NAME}]: Outgoing packet, rate','bigip.node.net.out.pkts.rate[{#NODE.NAME}]','1m','7d','365d','0','3','','pps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The rate of packets sent to server-side from the specified node address.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35751','20','.1.3.6.1.4.1.3375.2.2.4.2.3.1.21.{#SNMPINDEX}','10415','F5 BIG-IP: Node [{#NODE.NAME}]: Current sessions','bigip.node.net.sessions[{#NODE.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The number of current sessions going through the specified node address.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35752','20','.1.3.6.1.4.1.3375.2.2.4.2.3.1.22.{#SNMPINDEX}','10415','F5 BIG-IP: Node [{#NODE.NAME}]: Connections hit a rate limit','bigip.node.overlimit[{#NODE.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The last recorded value for the number of connections to the node address when connections hit a rate limit;
this calculation is only maintained if rate limiting is configured for the node.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35753','20','.1.3.6.1.4.1.3375.2.2.4.2.3.1.23.{#SNMPINDEX}','10415','F5 BIG-IP: Node [{#NODE.NAME}]: Duration of exceeding rate limit','bigip.node.overtime[{#NODE.NAME}]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
Duration of time in seconds the specified node address has exceeded the
configured connection rate limit.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35754','20','.1.3.6.1.4.1.3375.2.2.5.2.3.1.8.{#SNMPINDEX}','10415','F5 BIG-IP: Pool [{#POOL.NAME}]: Current connections','bigip.pool.net.conn[{#POOL.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The current connections from server-side to the specified pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35755','20','.1.3.6.1.4.1.3375.2.2.5.2.3.1.3.{#SNMPINDEX}','10415','F5 BIG-IP: Pool [{#POOL.NAME}]: Incoming traffic, rate','bigip.pool.net.in.bytes.rate[{#POOL.NAME}]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The rate of bytes received by the specified pool from server-side.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35756','20','.1.3.6.1.4.1.3375.2.2.5.2.3.1.2.{#SNMPINDEX}','10415','F5 BIG-IP: Pool [{#POOL.NAME}]: Incoming packet, rate','bigip.pool.net.in.pkts.rate[{#POOL.NAME}]','1m','7d','365d','0','3','','pps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The rate of packets received by the specified pool from server-side.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35757','20','.1.3.6.1.4.1.3375.2.2.5.2.3.1.5.{#SNMPINDEX}','10415','F5 BIG-IP: Pool [{#POOL.NAME}]: Outgoing traffic, rate','bigip.pool.net.out.bytes.rate[{#POOL.NAME}]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The rate of bytes sent to server-side from the specified pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35758','20','.1.3.6.1.4.1.3375.2.2.5.2.3.1.4.{#SNMPINDEX}','10415','F5 BIG-IP: Pool [{#POOL.NAME}]: Outgoing packet, rate','bigip.pool.net.out.pkts.rate[{#POOL.NAME}]','1m','7d','365d','0','3','','pps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The rate of packets sent to server-side from the specified pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35759','20','.1.3.6.1.4.1.3375.2.2.5.2.3.1.31.{#SNMPINDEX}','10415','F5 BIG-IP: Pool [{#POOL.NAME}]: Current sessions','bigip.pool.net.sessions[{#POOL.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The number of current sessions going through the specified pool.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35760','20','.1.3.6.1.4.1.3375.2.2.5.2.3.1.19.{#SNMPINDEX}','10415','F5 BIG-IP: Pool [{#POOL.NAME}]: Age of the oldest queue entry','bigip.pool.queue.age[{#POOL.NAME}]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
Age of the oldest queue entry, max.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35761','20','.1.3.6.1.4.1.3375.2.2.5.2.3.1.18.{#SNMPINDEX}','10415','F5 BIG-IP: Pool [{#POOL.NAME}]: Queue','bigip.pool.queue[{#POOL.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
Number of connections currently in queue, sum.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35762','20','.1.3.6.1.4.1.3375.2.2.10.2.3.1.12.{#SNMPINDEX}','10415','F5 BIG-IP: Virtual sever [{#VSERVER.NAME}]: Current connections','bigip.vserver.net.conn[{#VSERVER.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The current connections from client-side to the specified virtual server.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35763','20','.1.3.6.1.4.1.3375.2.2.10.2.3.1.7.{#SNMPINDEX}','10415','F5 BIG-IP: Virtual sever [{#VSERVER.NAME}]: Incoming traffic, rate','bigip.vserver.net.in.bytes.rate[{#VSERVER.NAME}]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The rate of bytes received by the specified virtual server from client-side.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35764','20','.1.3.6.1.4.1.3375.2.2.10.2.3.1.6.{#SNMPINDEX}','10415','F5 BIG-IP: Virtual sever [{#VSERVER.NAME}]: Incoming packet, rate','bigip.vserver.net.in.pkts.rate[{#VSERVER.NAME}]','1m','7d','365d','0','3','','pps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The rate of packets received by the specified virtual server from client-side.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35765','20','.1.3.6.1.4.1.3375.2.2.10.2.3.1.9.{#SNMPINDEX}','10415','F5 BIG-IP: Virtual sever [{#VSERVER.NAME}]: Outgoing traffic, rate','bigip.vserver.net.out.bytes.rate[{#VSERVER.NAME}]','1m','7d','365d','0','3','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The rate of bytes sent to client-side from the specified virtual server.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35766','20','.1.3.6.1.4.1.3375.2.2.10.2.3.1.8.{#SNMPINDEX}','10415','F5 BIG-IP: Virtual sever [{#VSERVER.NAME}]: Outgoing packet, rate','bigip.vserver.net.out.pkts.rate[{#VSERVER.NAME}]','1m','7d','365d','0','3','','pps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The rate of packets sent to client-side from the specified virtual server.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35767','20','.1.3.6.1.4.1.3375.2.2.10.2.3.1.34.{#SNMPINDEX}','10415','F5 BIG-IP: Virtual sever [{#VSERVER.NAME}]: Connections hit a rate limit','bigip.vserver.overlimit[{#VSERVER.NAME}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The last recorded value for the number of connections to the virtual server when connections hit a rate limit;
this calculation is only maintained if rate limiting is configured for the service.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35768','20','.1.3.6.1.4.1.3375.2.2.10.2.3.1.35.{#SNMPINDEX}','10415','F5 BIG-IP: Virtual sever [{#VSERVER.NAME}]: Duration of exceeding rate limit','bigip.vserver.overtime[{#VSERVER.NAME}]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
Duration of time in seconds the specified virtual server has exceeded the configured connection rate limit.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35769','20','.1.3.6.1.4.1.3375.2.2.10.2.3.1.32.{#SNMPINDEX}','10415','F5 BIG-IP: Virtual sever [{#VSERVER.NAME}]: Usage ratio, avg 1m','bigip.vserver.usage.1m[{#VSERVER.NAME}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The percentage of time Virtual Server was busy over the last 1 minute.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35770','20','.1.3.6.1.4.1.3375.2.2.10.2.3.1.33.{#SNMPINDEX}','10415','F5 BIG-IP: Virtual sever [{#VSERVER.NAME}]: Usage ratio, avg 5m','bigip.vserver.usage.5m[{#VSERVER.NAME}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The percentage of time Virtual Server was busy over the last 5 minutes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35771','20','.1.3.6.1.4.1.3375.2.2.10.2.3.1.31.{#SNMPINDEX}','10415','F5 BIG-IP: Virtual sever [{#VSERVER.NAME}]: Usage ratio, avg 5s','bigip.vserver.usage.5s[{#VSERVER.NAME}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: F5-BIGIP-LOCAL-MIB
The percentage of time Virtual Server was busy over the last 5 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35772','0','','10416','Cert: Get','web.certificate.get[{$CERT.WEBSITE.HOSTNAME},{$CERT.WEBSITE.PORT},{$CERT.WEBSITE.IP}]','15m','0h','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Returns the JSON with attributes of a certificate of the requested site.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35786','15','','10308','HAProxy Frontend {#PXNAME}: Session utilization','haproxy.frontend.sutil[{#PXNAME},{#SVNAME}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("haproxy.frontend.scur[{#PXNAME},{#SVNAME}]") / last("haproxy.frontend.slim[{#PXNAME},{#SVNAME}]") * 100','','0','','','','','2',NULL,'Percentage of sessions used (scur / slim * 100).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35845','15','','10309','HAProxy Frontend {#PXNAME}: Session utilization','haproxy.frontend.sutil[{#PXNAME},{#SVNAME}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last("haproxy.frontend.scur[{#PXNAME},{#SVNAME}]") / last("haproxy.frontend.slim[{#PXNAME},{#SVNAME}]") * 100','','0','','','','','2',NULL,'Percentage of sessions used (scur / slim * 100).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35903','20','.1.3.6.1.2.1.1.4.0','10417','Cisco ASAv: Contact','cisco.asav.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35904','20','.1.3.6.1.2.1.1.6.0','10417','Cisco ASAv: Location','cisco.asav.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35905','20','.1.3.6.1.2.1.1.1.0','10417','Cisco ASAv: System description','cisco.asav.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35906','20','.1.3.6.1.2.1.1.5.0','10417','Cisco ASAv: Host name','cisco.asav.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35907','20','.1.3.6.1.2.1.1.3.0','10417','Cisco ASAv: Uptime','cisco.asav.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35908','5','','10417','Cisco ASAv: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35909','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.109.1.1.1.1.8]','10417','CPU discovery','cisco.asav.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of cpmCPUTotalTable, a table of CPU monitoring entries.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35910','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.48.1.1.1.2]','10417','Memory discovery','cisco.asav.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of ciscoMemoryPoolTable, a table of memory pool monitoring entries.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35911','20','discovery[{#CISCO.IF.NAME}, .1.3.6.1.2.1.31.1.1.1.1,{#CISCO.IF.STATUS.ADMIN},.1.3.6.1.2.1.2.2.1.7,{#CISCO.IF.STATUS.OPER},.1.3.6.1.2.1.2.2.1.8,{#CISCO.IF.DESC},.1.3.6.1.2.1.31.1.1.1.18]','10417','Interface discovery','cisco.asav.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Network interfaces discovery','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35912','20','discovery[{#CISCO.ASAV.PHYS.DESC},.1.3.6.1.2.1.47.1.1.1.1.2,{#CISCO.ASAV.PHYS.CLASS},.1.3.6.1.2.1.47.1.1.1.1.5,{#CISCO.ASAV.PHYS.NAME},.1.3.6.1.2.1.47.1.1.1.1.7]','10417','Physical entry discovery','cisco.asav.physical.entry.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Information about a particular physical entity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35913','20','discovery[{#CISCO.CRAS.USER},.1.3.6.1.4.1.9.9.392.1.3.21.1.1,{#CISCO.CRAS.INDEX},.1.3.6.1.4.1.9.9.392.1.3.21.1.3]','10417','Session discovery','cisco.asav.session.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Remote access session discovery','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35914','20','1.3.6.1.4.1.9.9.109.1.1.1.1.8.{#SNMPINDEX}','10417','Cisco ASAv: CPU [{#SNMPINDEX}] Utilization','cisco.asav.cpu.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-PROCESS-MIB
The overall CPU busy percentage in the last 5 minute
period. This object deprecates the object cpmCPUTotal5min
and increases the value range to (0..100).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35915','20','1.3.6.1.4.1.9.9.48.1.1.1.6.{#SNMPINDEX}','10417','Cisco ASAv: {#SNMPVALUE} Free memory','cisco.asav.memory.free[{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Indicates the number of bytes from the memory pool that are currently unused on the managed device. Note that the sum of ciscoMemoryPoolUsed and ciscoMemoryPoolFree is the total amount of memory in the pool
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35916','20','1.3.6.1.4.1.9.9.48.1.1.1.5.{#SNMPINDEX}','10417','Cisco ASAv: {#SNMPVALUE} Used memory','cisco.asav.memory.used[{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Indicates the number of bytes from the memory pool that are currently in use by applications on the managed device.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35917','15','','10417','Cisco ASAv: {#SNMPVALUE} Memory utilization','cisco.asav.memory.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(cisco.asav.memory.used[{#SNMPINDEX}])/(last(cisco.asav.memory.free[{#SNMPINDEX}])+last(cisco.asav.memory.used[{#SNMPINDEX}]))*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35918','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Administrative status','cisco.asav.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'246','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35919','20','.1.3.6.1.2.1.31.1.1.1.18.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Interface description','cisco.asav.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35920','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Link speed','cisco.asav.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35921','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Incoming broadcast packets','cisco.asav.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35922','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Incoming multicast packets','cisco.asav.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35923','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Incoming traffic','cisco.asav.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35924','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Incoming unicast packets','cisco.asav.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35925','15','','10417','Cisco ASAv: {#CISCO.IF.NAME} Incoming utilization','cisco.asav.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(cisco.asav.net.if.in.traffic[{#SNMPINDEX}]) * (last(cisco.asav.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(cisco.asav.net.if.highspeed[{#SNMPINDEX}]) + (last(cisco.asav.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35926','20','.1.3.6.1.2.1.31.1.1.1.1.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Interface name','cisco.asav.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-PORT-MIB
Descriptive name that identifies this port.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35927','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Operational status','cisco.asav.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'247','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35928','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Outgoing broadcast packets','cisco.asav.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35929','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Outgoing multicast packets','cisco.asav.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35930','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Outgoing traffic','cisco.asav.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35931','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.IF.NAME} Outgoing unicast packets','cisco.asav.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35932','15','','10417','Cisco ASAv: {#CISCO.IF.NAME} Outgoing utilization','cisco.asav.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(cisco.asav.net.if.out.traffic[{#SNMPINDEX}]) * (last(cisco.asav.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(cisco.asav.net.if.highspeed[{#SNMPINDEX}]) + (last(cisco.asav.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35933','20','.1.3.6.1.2.1.47.1.1.1.1.5.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.ASAV.PHYS.NAME} Physical class','cisco.asav.phys.class[{#SNMPINDEX}]','1h','7d','365d','0','3','','','','',NULL,'250','','','0','','','','','2',NULL,'MIB: ENTITY-MIB
An indication of the general hardware type of the physical
entity.
An agent should set this object to the standard enumeration
value that most accurately indicates the general class of
the physical entity, or the primary class if there is more
than one entity.
If no appropriate standard registration identifier exists
for this physical entity, then the value ''other(1)'' is
returned.  If the value is unknown by this agent, then the
value ''unknown(2)'' is returned.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35934','20','.1.3.6.1.2.1.47.1.1.1.1.2.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.ASAV.PHYS.NAME} Physical description','cisco.asav.phys.description[{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB
A textual description of physical entity.  This object
should contain a string that identifies the manufacturer''s
name for the physical entity, and should be set to a
distinct value for each version or model of the physical
entity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35935','20','.1.3.6.1.2.1.47.1.1.1.1.8.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.ASAV.PHYS.NAME} Hardware revision','cisco.asav.phys.hw[{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB
The vendor-specific hardware revision string for the
physical entity.  The preferred value is the hardware
revision identifier actually printed on the component itself
(if present).
Note that if revision information is stored internally in a
non-printable (e.g., binary) format, then the agent must
convert such information to a printable format, in an
implementation-specific manner.
If no specific hardware revision string is associated with
the physical component, or if this information is unknown to
the agent, then this object will contain a zero-length
string.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35936','20','.1.3.6.1.2.1.47.1.1.1.1.12.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.ASAV.PHYS.NAME} Manufacturer name','cisco.asav.phys.mfgname[{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB
The name of the manufacturer of this physical component.
The preferred value is the manufacturer name string actually
printed on the component itself (if present).
Note that comparisons between instances of the
entPhysicalModelName, entPhysicalFirmwareRev,
entPhysicalSoftwareRev, and the entPhysicalSerialNum
objects, are only meaningful amongst entPhysicalEntries with
the same value of entPhysicalMfgName.
If the manufacturer name string associated with the physical
component is unknown to the agent, then this object will
contain a zero-length string.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35937','20','.1.3.6.1.2.1.47.1.1.1.1.13.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.ASAV.PHYS.NAME} Model name','cisco.asav.phys.model[{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB
The vendor-specific model name identifier string associated
with this physical component.  The preferred value is the
customer-visible part number, which may be printed on the
component itself.
If the model name string associated with the physical
component is unknown to the agent, then this object will
contain a zero-length string.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35938','20','.1.3.6.1.2.1.47.1.1.1.1.7.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.ASAV.PHYS.NAME} Physical name','cisco.asav.phys.name[{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB
The textual name of the physical entity.  The value of this
object should be the name of the component as assigned by
the local device and should be suitable for use in commands
entered at the device''s `console''.  This might be a text
name (e.g., `console'') or a simple component number (e.g.,
port or module number, such as `1''), depending on the
physical component naming syntax of the device.
If there is no local name, or if this object is otherwise
not applicable, then this object contains a zero-length
string.
Note that the value of entPhysicalName for two physical
entities will be the same in the event that the console
interface does not distinguish between them, e.g., slot-1
and the card in slot-1.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35939','20','.1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.ASAV.PHYS.NAME} Serial number','cisco.asav.phys.sn[{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB
The vendor-specific serial number string for the physical
entity.  The preferred value is the serial number string
actually printed on the component itself (if present).
On the first instantiation of an physical entity, the value
of entPhysicalSerialNum associated with that entity is set
to the correct vendor-assigned serial number, if this
information is available to the agent.  If a serial number
is unknown or non-existent, the entPhysicalSerialNum will be
set to a zero-length string instead.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35940','20','.1.3.6.1.2.1.47.1.1.1.1.10.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.ASAV.PHYS.NAME} Software revision','cisco.asav.phys.sw[{#SNMPINDEX}]','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB
The vendor-specific software revision string for the
physical entity.
Note that if revision information is stored internally in a
non-printable (e.g., binary) format, then the agent must
convert such information to a printable format, in an
implementation-specific manner.
If no specific software programs are associated with the
physical component, or if this information is unknown to the
agent, then this object will contain a zero-length string.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35941','20','.1.3.6.1.4.1.9.9.392.1.3.21.1.10.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.CRAS.USER} [{#CISCO.CRAS.INDEX}] ISP address','cisco.asav.session.addr.isp[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  CISCO-REMOTE-ACCESS-MONITOR-MIB
The IP address of the peer (client) assigned by the ISP.
This is the address of the client device in the public
network.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35942','20','.1.3.6.1.4.1.9.9.392.1.3.21.1.8.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.CRAS.USER} [{#CISCO.CRAS.INDEX}] Local address','cisco.asav.session.addr.local[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  CISCO-REMOTE-ACCESS-MONITOR-MIB
The IP address assigned to the client of this session
in the private network assigned by the managed entity.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35943','20','.1.3.6.1.4.1.9.9.392.1.3.21.1.14.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.CRAS.USER} [{#CISCO.CRAS.INDEX}] Algorithm validate packets','cisco.asav.session.authen.algorithm[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'244','','','0','','','','','2',NULL,'MIB:  CISCO-REMOTE-ACCESS-MONITOR-MIB
The algorithm used by this remote access session to
to validate packets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35944','20','.1.3.6.1.4.1.9.9.392.1.3.21.1.4.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.CRAS.USER} [{#CISCO.CRAS.INDEX}] Authenticate method','cisco.asav.session.authen.method[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'249','','','0','','','','','2',NULL,'MIB:  CISCO-REMOTE-ACCESS-MONITOR-MIB
The method used to authenticate the user prior to
establishing the session.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35945','20','.1.3.6.1.4.1.9.9.392.1.3.21.1.5.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.CRAS.USER} [{#CISCO.CRAS.INDEX}] Authorize method','cisco.asav.session.author.method[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'249','','','0','','','','','2',NULL,'MIB:  CISCO-REMOTE-ACCESS-MONITOR-MIB
The method used to authorize the user prior to
establishing the session.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35946','20','.1.3.6.1.4.1.9.9.392.1.3.21.1.6.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.CRAS.USER} [{#CISCO.CRAS.INDEX}] Session duration','cisco.asav.session.duration[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  CISCO-REMOTE-ACCESS-MONITOR-MIB
The number of seconds elapsed since this session
was established.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35947','20','.1.3.6.1.4.1.9.9.392.1.3.21.1.13.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.CRAS.USER} [{#CISCO.CRAS.INDEX}] Encryption algorithm','cisco.asav.session.encryption[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'245','','','0','','','','','2',NULL,'MIB:  CISCO-REMOTE-ACCESS-MONITOR-MIB
The algorithm used by this remote access session to
encrypt its payload.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35948','20','.1.3.6.1.4.1.9.9.392.1.3.21.1.35.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.CRAS.USER} [{#CISCO.CRAS.INDEX}] Incoming traffic','cisco.asav.session.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-REMOTE-ACCESS-MONITOR-MIB
The rate of octets received by this Remote
Access Session.
This value is accumulated BEFORE determining whether
or not the packet should be decompressed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35949','20','.1.3.6.1.4.1.9.9.392.1.3.21.1.36.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.CRAS.USER} [{#CISCO.CRAS.INDEX}] Outgoing traffic','cisco.asav.session.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: CISCO-REMOTE-ACCESS-MONITOR-MIB
The rate of octets transmitted by this Remote
Access Session.
This value is accumulated AFTER determining whether
or not the packet should be compressed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35950','20','.1.3.6.1.4.1.9.9.392.1.3.21.1.11.{#SNMPINDEX}','10417','Cisco ASAv: {#CISCO.CRAS.USER} [{#CISCO.CRAS.INDEX}] Session protocol','cisco.asav.session.protocol[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'248','','','0','','','','','2',NULL,'MIB:  CISCO-REMOTE-ACCESS-MONITOR-MIB
The protocol underlying this remote access session.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35951','5','','10418','ZYXEL AAM1212-51 / IES-612: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35952','20','.1.3.6.1.2.1.1.4.0','10418','ZYXEL AAM1212-51 / IES-612: Contact','zyxel.aam1212.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35953','20','.1.3.6.1.4.1.890.1.5.13.1.1.3.1.4.0.0','10418','ZYXEL AAM1212-51 / IES-612: ZyNOS F/W Version','zyxel.aam1212.fwversion','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-IESCOMMON-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35954','20','.1.3.6.1.2.1.1.6.0','10418','ZYXEL AAM1212-51 / IES-612: Location','zyxel.aam1212.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35955','20','.1.3.6.1.2.1.2.2.1.6.1','10418','ZYXEL AAM1212-51 / IES-612: MAC address','zyxel.aam1212.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35956','20','.1.3.6.1.2.1.1.1.0','10418','ZYXEL AAM1212-51 / IES-612: Hardware model name','zyxel.aam1212.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35957','20','.1.3.6.1.2.1.1.5.0','10418','ZYXEL AAM1212-51 / IES-612: Host name','zyxel.aam1212.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35958','20','.1.3.6.1.4.1.890.1.5.13.1.1.2.1.3.0','10418','ZYXEL AAM1212-51 / IES-612: Hardware serial number','zyxel.aam1212.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-IESCOMMON-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35959','20','.1.3.6.1.4.1.890.1.5.13.1.1.3.1.8.0.0','10418','ZYXEL AAM1212-51 / IES-612: Alarm status','zyxel.aam1212.slot.alarm','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-IESCOMMON-MIB
This variable indicates the alarm status of the module.
It is a bit map represented a sum, therefore, it can represent
multiple defects simultaneously. The moduleNoDefect should be set
if and only if no other flag is set.
The various bit positions are:
1   moduleNoDefect
2   moduleOverHeat
3   moduleFanRpmLow
4   moduleVoltageLow
5   moduleThermalSensorFailure
6   modulePullOut
7   powerDC48VAFailure
8   powerDC48VBFailure
9   extAlarmInputTrigger
10   moduleDown
11   mscSwitchOverOK
12   networkTopologyChange
13   macSpoof
14   cpuHigh
15   memoryUsageHigh
16   packetBufferUsageHigh
17   loopguardOccurence','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35960','20','.1.3.6.1.2.1.1.3.0','10418','ZYXEL AAM1212-51 / IES-612: Uptime','zyxel.aam1212.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35961','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.2.2.1.2,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8]','10418','ADSL interface discovery','zyxel.aam1212.net.adsl.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35962','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.2.2.1.2,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8]','10418','Ethernet interface discovery','zyxel.aam1212.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35963','20','discovery[{#ZYXEL.TEMP.ID}, .1.3.6.1.4.1.890.1.5.13.1.2.3.1.1,{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.13.1.2.3.1.5]','10418','Temperature discovery','zyxel.aam1212.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35964','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.13.1.2.2.1.6,{#ZYXEL.VOLT.NOMINAL}, .1.3.6.1.4.1.890.1.5.13.1.2.2.1.5]','10418','Voltage discovery','zyxel.aam1212.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35965','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: Administrative status','zyxel.aam1212.net.adsl.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'166','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35966','20','.1.3.6.1.2.1.10.94.1.1.2.1.5.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: ATUC attenuation','zyxel.aam1212.net.adsl.atuc.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL AAM1212-51 / IES-612, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35967','20','.1.3.6.1.2.1.10.94.1.1.2.1.7.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: ATUC output power','zyxel.aam1212.net.adsl.atuc.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL AAM1212-51 / IES-612, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35968','20','.1.3.6.1.2.1.10.94.1.1.2.1.4.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: ATUC noise margin','zyxel.aam1212.net.adsl.atuc.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL AAM1212-51 / IES-612, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35969','20','.1.3.6.1.2.1.10.94.1.1.3.1.5.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: ATUR attenuation','zyxel.aam1212.net.adsl.atur.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35970','20','.1.3.6.1.2.1.10.94.1.1.3.1.7.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: ATUR output power','zyxel.aam1212.net.adsl.atur.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35971','20','.1.3.6.1.2.1.10.94.1.1.3.1.4.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: ATUR noise margin','zyxel.aam1212.net.adsl.atur.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35972','20','.1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: Incoming traffic','zyxel.aam1212.net.adsl.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35973','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: Interface name','zyxel.aam1212.net.adsl.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35974','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: Operational status','zyxel.aam1212.net.adsl.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'167','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35975','20','.1.3.6.1.2.1.2.2.1.16.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: Outgoing traffic','zyxel.aam1212.net.adsl.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35976','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#ZYXEL.IF.NAME}: Administrative status','zyxel.aam1212.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'166','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35977','20','.1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#ZYXEL.IF.NAME}: Incoming traffic','zyxel.aam1212.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35978','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#ZYXEL.IF.NAME}: Interface name','zyxel.aam1212.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35979','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#ZYXEL.IF.NAME}: Operational status','zyxel.aam1212.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'167','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35980','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Port {#ZYXEL.IF.NAME}: Outgoing traffic','zyxel.aam1212.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35981','20','.1.3.6.1.4.1.890.1.5.13.1.2.3.1.2.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.aam1212.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IESCOMMON-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35982','20','.1.3.6.1.4.1.890.1.5.13.1.2.2.1.2.{#SNMPINDEX}','10418','ZYXEL AAM1212-51 / IES-612: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.aam1212.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IESCOMMON-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35983','5','','10419','ZYXEL ES3500-8PD: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35984','20','.1.3.6.1.2.1.1.4.0','10419','ZYXEL ES3500-8PD: Contact','zyxel.3500_8pd.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35985','20','.1.3.6.1.4.1.890.1.5.8.72.12.7.0','10419','ZYXEL ES3500-8PD: CPU utilization','zyxel.3500_8pd.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35986','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.72.1]','10419','ZYXEL ES3500-8PD: ZyNOS F/W Version','zyxel.3500_8pd.fwversion','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES3500-8PD-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35987','20','.1.3.6.1.2.1.1.6.0','10419','ZYXEL ES3500-8PD: Location','zyxel.3500_8pd.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35988','20','.1.3.6.1.2.1.2.2.1.6.1','10419','ZYXEL ES3500-8PD: MAC address','zyxel.3500_8pd.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35989','20','.1.3.6.1.2.1.1.1.0','10419','ZYXEL ES3500-8PD: Hardware model name','zyxel.3500_8pd.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35990','20','.1.3.6.1.2.1.1.5.0','10419','ZYXEL ES3500-8PD: Host name','zyxel.3500_8pd.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35991','20','.1.3.6.1.4.1.890.1.5.8.72.1.10.0','10419','ZYXEL ES3500-8PD: Hardware serial number','zyxel.3500_8pd.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35992','20','.1.3.6.1.2.1.1.3.0','10419','ZYXEL ES3500-8PD: Uptime','zyxel.3500_8pd.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35993','20','discovery[{#ZYXEL.MEMORY.NAME},.1.3.6.1.4.1.890.1.5.8.72.124.1.1.2]','10419','Memory pool discovery','zyxel.3500_8pd.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35994','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.72.24.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.72.24.1.1.5]','10419','Interface discovery','zyxel.3500_8pd.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35995','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.72.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.72.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.72.117.2.1.8]','10419','SFP with DDM discovery','zyxel.3500_8pd.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35996','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.72.117.1.1.2]','10419','SFP without DDM discovery','zyxel.3500_8pd.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35997','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.72.9.2.1.5]','10419','Temperature discovery','zyxel.3500_8pd.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35998','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.72.9.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.72.9.3.1.5]','10419','Voltage discovery','zyxel.3500_8pd.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35999','20','.1.3.6.1.4.1.890.1.5.8.72.124.1.1.5.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Memory "{#ZYXEL.MEMORY.NAME}" utilization','zyxel.3500_8pd.memory[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Utilization of memory pool in %.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36000','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Administrative status','zyxel.3500_8pd.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'170','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36001','20','.1.3.6.1.4.1.890.1.5.8.72.24.1.1.3.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Interface description','zyxel.3500_8pd.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  ZYXEL-ES3500-8PD-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36002','15','','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3500_8pd.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3500_8pd.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36003','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3500_8pd.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36004','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3500_8pd.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36005','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3500_8pd.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36006','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3500_8pd.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36007','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Operational status','zyxel.3500_8pd.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'171','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36008','20','.1.3.6.1.4.1.890.1.5.8.72.24.1.1.5.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Link type','zyxel.3500_8pd.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'169','','','0','','','','','2',NULL,'MIB:  ZYXEL-ES3500-8PD-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36009','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Interface name','zyxel.3500_8pd.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36010','15','','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Incoming utilization','zyxel.3500_8pd.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3500_8pd.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36011','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3500_8pd.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36012','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Incoming traffic','zyxel.3500_8pd.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36013','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3500_8pd.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36014','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3500_8pd.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36015','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Link speed','zyxel.3500_8pd.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36016','20','.1.3.6.1.4.1.890.1.5.8.72.24.1.1.1.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Speed Duplex','zyxel.3500_8pd.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'168','','','0','','','','','2',NULL,'MIB:  ZYXEL-ES3500-8PD-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36017','20','.1.3.6.1.4.1.890.1.5.8.72.117.2.1.7.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3500_8pd.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36018','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.7.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Date code','zyxel.3500_8pd.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36019','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.4.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Part number','zyxel.3500_8pd.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36020','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.6.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Revision','zyxel.3500_8pd.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36021','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.5.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Serial number','zyxel.3500_8pd.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36022','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.2.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Status','zyxel.3500_8pd.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'172','','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36023','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.8.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Transceiver','zyxel.3500_8pd.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36024','20','.1.3.6.1.4.1.890.1.5.8.72.117.1.1.3.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: SFP {#SNMPINDEX}: Vendor','zyxel.3500_8pd.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36025','20','.1.3.6.1.4.1.890.1.5.8.72.9.2.1.2.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.3500_8pd.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36026','20','.1.3.6.1.4.1.890.1.5.8.72.9.3.1.2.{#SNMPINDEX}','10419','ZYXEL ES3500-8PD: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.3500_8pd.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-ES3500-8PD-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36027','5','','10420','ZYXEL GS-4012F: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36028','20','.1.3.6.1.2.1.1.4.0','10420','ZYXEL GS-4012F: Contact','zyxel.4012f.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36029','20','.1.3.6.1.4.1.890.1.5.8.20.12.7.0','10420','ZYXEL GS-4012F: CPU utilization','zyxel.4012f.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-GS4012F-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36030','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.20.1]','10420','ZYXEL GS-4012F: ZyNOS F/W Version','zyxel.4012f.fwversion','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-GS4012F-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36031','20','.1.3.6.1.2.1.1.6.0','10420','ZYXEL GS-4012F: Location','zyxel.4012f.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36032','20','.1.3.6.1.2.1.2.2.1.6.1','10420','ZYXEL GS-4012F: MAC address','zyxel.4012f.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36033','20','.1.3.6.1.2.1.1.1.0','10420','ZYXEL GS-4012F: Hardware model name','zyxel.4012f.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36034','20','.1.3.6.1.2.1.1.5.0','10420','ZYXEL GS-4012F: Host name','zyxel.4012f.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36035','20','.1.3.6.1.4.1.890.1.5.8.20.1.10.0','10420','ZYXEL GS-4012F: Hardware serial number','zyxel.4012f.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-GS4012F-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36036','20','.1.3.6.1.2.1.1.3.0','10420','ZYXEL GS-4012F: Uptime','zyxel.4012f.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36037','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.20.9.1.1.5]','10420','Fan discovery','zyxel.4012f.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36038','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.20.23.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.20.23.1.1.5]','10420','Interface discovery','zyxel.4012f.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36039','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.20.9.2.1.5]','10420','Temperature discovery','zyxel.4012f.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36040','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.20.9.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.20.9.3.1.5]','10420','Voltage discovery','zyxel.4012f.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36041','20','.1.3.6.1.4.1.890.1.5.8.20.9.1.1.2.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Fan #{#SNMPINDEX}','zyxel.4012f.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-GS4012F-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36042','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Administrative status','zyxel.4012f.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'175','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36043','20','.1.3.6.1.4.1.890.1.5.8.20.23.1.1.3.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Interface description','zyxel.4012f.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-GS4012F-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36044','15','','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Outgoing utilization','zyxel.4012f.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.4012f.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36045','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.4012f.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36046','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Outgoing traffic','zyxel.4012f.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36047','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.4012f.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36048','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.4012f.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36049','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Operational status','zyxel.4012f.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'176','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36050','20','.1.3.6.1.4.1.890.1.5.8.20.23.1.1.5.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Link type','zyxel.4012f.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'174','','','0','','','','','2',NULL,'MIB: ZYXEL-GS4012F-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36051','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Interface name','zyxel.4012f.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36052','15','','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Incoming utilization','zyxel.4012f.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.4012f.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36053','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.4012f.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36054','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Incoming traffic','zyxel.4012f.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36055','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.4012f.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36056','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.4012f.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36057','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Link speed','zyxel.4012f.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36058','20','.1.3.6.1.4.1.890.1.5.8.20.23.1.1.1.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Port {#SNMPINDEX}: Speed Duplex','zyxel.4012f.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'173','','','0','','','','','2',NULL,'MIB: ZYXEL-GS4012F-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36059','20','.1.3.6.1.4.1.890.1.5.8.20.9.2.1.2.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.4012f.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-GS4012F-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36060','20','.1.3.6.1.4.1.890.1.5.8.20.9.3.1.2.{#SNMPINDEX}','10420','ZYXEL GS-4012F: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.4012f.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-GS4012F-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36061','5','','10421','ZYXEL IES-500x: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36062','20','.1.3.6.1.2.1.1.4.0','10421','ZYXEL IES-500x: Contact','zyxel.ies500x.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36063','20','.1.3.6.1.2.1.1.6.0','10421','ZYXEL IES-500x: Location','zyxel.ies500x.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36064','20','.1.3.6.1.2.1.2.2.1.6.1','10421','ZYXEL IES-500x: MAC address','zyxel.ies500x.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36065','20','.1.3.6.1.2.1.1.1.0','10421','ZYXEL IES-500x: Hardware model name','zyxel.ies500x.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36066','20','.1.3.6.1.2.1.1.5.0','10421','ZYXEL IES-500x: Host name','zyxel.ies500x.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36067','20','.1.3.6.1.2.1.1.3.0','10421','ZYXEL IES-500x: Uptime','zyxel.ies500x.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36068','20','discovery[{#ZYXEL.BUFFERHIGHTHRESH}, .1.3.6.1.4.1.890.1.5.13.5.11.3.5.1.4]','10421','Packet buffer discovery','zyxel.ies500x.buffer.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table that contains packet buffer usage information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36069','20','discovery[{#ZYXEL.CPU.THRESH.HIGH}, .1.3.6.1.4.1.890.1.5.13.5.11.3.4.1.4]','10421','CPU discovery','zyxel.ies500x.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table that contains CPU utilization information.
This table is supported by R1.03 and later versions.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36070','20','discovery[{#ZYXEL.FANRPM.THRESH.HIGH}, .1.3.6.1.4.1.890.1.5.13.5.11.3.1.1.7,{#ZYXEL.FANRPM.THRESH.LOW}, .1.3.6.1.4.1.890.1.5.13.5.11.3.1.1.5]','10421','Fan discovery','zyxel.ies500x.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36071','20','discovery[{#ZYXEL.MEMORYHIGHTHRESH},  .1.3.6.1.4.1.890.1.5.13.5.11.3.6.1.4]','10421','Memory discovery','zyxel.ies500x.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table that contains memory usage information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36072','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.31.1.1.1.1,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8,{#ZYXEL.IF.DESC},.1.3.6.1.2.1.31.1.1.1.18]','10421','ADSL interface discovery','zyxel.ies500x.net.adsl.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36073','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.31.1.1.1.1,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8,{#ZYXEL.IF.DESC},.1.3.6.1.2.1.31.1.1.1.18]','10421','Ethernet interface discovery','zyxel.ies500x.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36074','20','discovery[{#ZYXEL.SLOTSTATUS},.1.3.6.1.4.1.890.1.5.13.5.6.3.1.7,{#ZYXEL.SLOT.ID},.1.3.6.1.4.1.890.1.5.13.5.6.3.1.1]','10421','Slot discovery','zyxel.ies500x.slot.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table which contains the slot information in a chassis.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36075','20','discovery[{#ZYXEL.TEMP.THRESH.LOW},.1.3.6.1.4.1.890.1.5.13.5.11.3.3.1.7,{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.13.5.11.3.3.1.5]','10421','Temperature discovery','zyxel.ies500x.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36076','20','discovery[{#ZYXEL.VOLT.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.8,{#ZYXEL.VOLT.THRESH.LOW}, .1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.5]','10421','Voltage discovery','zyxel.ies500x.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36077','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.5.1.2.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Packet buffer utilization','zyxel.ies500x.buffer[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The packet buffer usage in the past 60 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36078','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.4.1.2.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: CPU utilization','zyxel.ies500x.cpu[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The CPU utilization in the past 60 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36079','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.1.1.2.{#SNMPINDEX}','10421','ZYXEL IES-500x: Fan #{#SNMPINDEX}','zyxel.ies500x.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36080','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.6.1.2.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Memory utilization','zyxel.ies500x.memory[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The memory usage in the past 60 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36081','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Administrative status','zyxel.ies500x.net.adsl.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'182','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36082','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming traffic','zyxel.ies500x.net.adsl.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36083','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing traffic','zyxel.ies500x.net.adsl.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36084','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing multicast packages','zyxel.ies500x.net.adsl.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36085','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing broadcast packages','zyxel.ies500x.net.adsl.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36086','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Operational status','zyxel.ies500x.net.adsl.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'183','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36087','20','.1.3.6.1.2.1.31.1.1.1.1.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Interface name','zyxel.ies500x.net.adsl.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36088','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming unicast packages','zyxel.ies500x.net.adsl.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36089','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming multicast packages','zyxel.ies500x.net.adsl.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36090','20','.1.3.6.1.2.1.10.94.1.1.2.1.5.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUC attenuation','zyxel.ies500x.net.adsl.atuc.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES-500x, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36091','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming broadcast packages','zyxel.ies500x.net.adsl.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36092','20','.1.3.6.1.2.1.31.1.1.1.18.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Interface description','zyxel.ies500x.net.adsl.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36093','20','.1.3.6.1.2.1.10.94.1.1.3.1.4.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUR noise margin','zyxel.ies500x.net.adsl.atur.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36094','20','.1.3.6.1.2.1.10.94.1.1.3.1.7.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUR output power','zyxel.ies500x.net.adsl.atur.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36095','20','.1.3.6.1.2.1.10.94.1.1.3.1.5.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUR attenuation','zyxel.ies500x.net.adsl.atur.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36096','20','.1.3.6.1.2.1.10.94.1.1.2.1.4.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUC noise margin','zyxel.ies500x.net.adsl.atuc.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES-500x, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36097','20','.1.3.6.1.2.1.10.94.1.1.2.1.7.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUC output power','zyxel.ies500x.net.adsl.atuc.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES-500x, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36098','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing unicast packages','zyxel.ies500x.net.adsl.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36099','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Administrative status','zyxel.ies500x.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'182','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36100','20','.1.3.6.1.2.1.31.1.1.1.18.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Interface description','zyxel.ies500x.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36101','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Link speed','zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36102','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.ies500x.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36103','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.ies500x.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36104','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Incoming traffic','zyxel.ies500x.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36105','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.ies500x.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36106','15','','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Incoming utilization','zyxel.ies500x.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.ies500x.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]) <> 0) /
( last(zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36107','20','.1.3.6.1.2.1.31.1.1.1.1.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Interface name','zyxel.ies500x.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36108','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Operational status','zyxel.ies500x.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'183','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36109','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.ies500x.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36110','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.ies500x.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36111','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Outgoing traffic','zyxel.ies500x.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36112','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.ies500x.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36113','15','','10421','ZYXEL IES-500x: Port {#SNMPINDEX}: Outgoing utilization','zyxel.ies500x.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.ies500x.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]) <> 0) /
( last(zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.ies500x.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36114','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.8.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Alarm status','zyxel.ies500x.slot.alarm[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
This variable indicates the alarm status of the module.
It is a bit map represented a sum, therefore, it can represent
multiple defects simultaneously. The moduleNoDefect should be set
if and only if no other flag is set.
The various bit positions are:
1   moduleNoDefect
2   moduleOverHeat
3   moduleFanRpmLow
4   moduleVoltageLow
5   moduleThermalSensorFailure
6   modulePullOut
7   powerDC48VAFailure
8   powerDC48VBFailure
9   extAlarmInputTrigger
10   moduleDown
11   mscSwitchOverOK
12   networkTopologyChange
13   macSpoof
14   cpuHigh
15   memoryUsageHigh
16   packetBufferUsageHigh
17   loopguardOccurence','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36115','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.6.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: DSL modem code version','zyxel.ies500x.slot.cv.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The DSL modem code version of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36116','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.3.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Description','zyxel.ies500x.slot.desc[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The descriptions of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36117','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.5.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Driver version','zyxel.ies500x.slot.dv.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The DSL driver of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36118','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.4.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Firmware version','zyxel.ies500x.slot.fw.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The firmware version of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36119','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.10.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Hardware version','zyxel.ies500x.slot.hw.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The hardware version of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36120','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.12.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: MAC address 1','zyxel.ies500x.slot.mac1[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The MAC Address of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36121','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.13.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: MAC address 2','zyxel.ies500x.slot.mac2[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The MAC Address of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36122','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.9.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Serial number','zyxel.ies500x.slot.serial[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The serial number of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36123','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.7.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Status','zyxel.ies500x.slot.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'178','','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The module state of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36124','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.2.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Type','zyxel.ies500x.slot.type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'179','','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
Card type of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36125','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.11.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Uptime','zyxel.ies500x.slot.uptime[{#SNMPINDEX}]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The time (in seconds) since the plug-in card was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36126','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.3.1.2.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.ies500x.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36127','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.2.{#SNMPINDEX}','10421','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.ies500x.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36128','5','','10422','ZYXEL IES-6000: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36129','20','.1.3.6.1.2.1.1.4.0','10422','ZYXEL IES-6000: Contact','zyxel.ies6000.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36130','20','.1.3.6.1.2.1.1.6.0','10422','ZYXEL IES-6000: Location','zyxel.ies6000.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36131','20','.1.3.6.1.2.1.2.2.1.6.1','10422','ZYXEL IES-6000: MAC address','zyxel.ies6000.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36132','20','.1.3.6.1.2.1.1.1.0','10422','ZYXEL IES-6000: Hardware model name','zyxel.ies6000.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36133','20','.1.3.6.1.2.1.1.5.0','10422','ZYXEL IES-6000: Host name','zyxel.ies6000.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36134','20','.1.3.6.1.2.1.1.3.0','10422','ZYXEL IES-6000: Uptime','zyxel.ies6000.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36135','20','discovery[{#ZYXEL.BUFFERHIGHTHRESH}, .1.3.6.1.4.1.890.1.5.13.5.11.3.5.1.4]','10422','Packet buffer discovery','zyxel.ies6000.buffer.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table that contains packet buffer usage information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36136','20','discovery[{#ZYXEL.CPU.THRESH.HIGH}, .1.3.6.1.4.1.890.1.5.13.5.11.3.4.1.4]','10422','CPU discovery','zyxel.ies6000.cpu.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table that contains CPU utilization information.
This table is supported by R1.03 and later versions.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36137','20','discovery[{#ZYXEL.FANRPM.THRESH.HIGH}, .1.3.6.1.4.1.890.1.5.13.5.11.3.1.1.7,{#ZYXEL.FANRPM.THRESH.LOW}, .1.3.6.1.4.1.890.1.5.13.5.11.3.1.1.5]','10422','Fan discovery','zyxel.ies6000.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36138','20','discovery[{#ZYXEL.MEMORYHIGHTHRESH},  .1.3.6.1.4.1.890.1.5.13.5.11.3.6.1.4]','10422','Memory discovery','zyxel.ies6000.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'A table that contains memory usage information.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36139','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.31.1.1.1.1,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8,{#ZYXEL.IF.DESC},.1.3.6.1.2.1.31.1.1.1.18]','10422','ADSL interface discovery','zyxel.ies6000.net.adsl.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36140','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.31.1.1.1.1,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8,{#ZYXEL.IF.DESC},.1.3.6.1.2.1.31.1.1.1.18]','10422','Ethernet interface discovery','zyxel.ies6000.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36141','20','discovery[{#ZYXEL.SLOTSTATUS},.1.3.6.1.4.1.890.1.5.13.5.6.3.1.7,{#ZYXEL.SLOT.ID},.1.3.6.1.4.1.890.1.5.13.5.6.3.1.1]','10422','Slot discovery','zyxel.ies6000.slot.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'The table which contains the slot information in a chassis.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36142','20','discovery[{#ZYXEL.TEMP.THRESH.LOW},.1.3.6.1.4.1.890.1.5.13.5.11.3.3.1.7,{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.13.5.11.3.3.1.5]','10422','Temperature discovery','zyxel.ies6000.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36143','20','discovery[{#ZYXEL.VOLT.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.8,{#ZYXEL.VOLT.THRESH.LOW}, .1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.5]','10422','Voltage discovery','zyxel.ies6000.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36144','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.5.1.2.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Packet buffer utilization','zyxel.ies6000.buffer[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The packet buffer usage in the past 60 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36145','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.4.1.2.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: CPU utilization','zyxel.ies6000.cpu[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The CPU utilization in the past 60 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36146','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.1.1.2.{#SNMPINDEX}','10422','ZYXEL IES-6000: Fan #{#SNMPINDEX}','zyxel.ies6000.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36147','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.6.1.2.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Memory utilization','zyxel.ies6000.memory[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The memory usage in the past 60 seconds.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36148','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Administrative status','zyxel.ies6000.net.adsl.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'188','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36149','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming traffic','zyxel.ies6000.net.adsl.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36150','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing traffic','zyxel.ies6000.net.adsl.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36151','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing multicast packages','zyxel.ies6000.net.adsl.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36152','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing broadcast packages','zyxel.ies6000.net.adsl.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36153','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Operational status','zyxel.ies6000.net.adsl.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'189','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36154','20','.1.3.6.1.2.1.31.1.1.1.1.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Interface name','zyxel.ies6000.net.adsl.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36155','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming unicast packages','zyxel.ies6000.net.adsl.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36156','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming multicast packages','zyxel.ies6000.net.adsl.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36157','20','.1.3.6.1.2.1.10.94.1.1.2.1.5.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUC attenuation','zyxel.ies6000.net.adsl.atuc.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES-6000, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36158','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Incoming broadcast packages','zyxel.ies6000.net.adsl.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36159','20','.1.3.6.1.2.1.31.1.1.1.18.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Interface description','zyxel.ies6000.net.adsl.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36160','20','.1.3.6.1.2.1.10.94.1.1.3.1.4.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUR noise margin','zyxel.ies6000.net.adsl.atur.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36161','20','.1.3.6.1.2.1.10.94.1.1.3.1.7.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUR output power','zyxel.ies6000.net.adsl.atur.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36162','20','.1.3.6.1.2.1.10.94.1.1.3.1.5.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUR attenuation','zyxel.ies6000.net.adsl.atur.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36163','20','.1.3.6.1.2.1.10.94.1.1.2.1.4.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUC noise margin','zyxel.ies6000.net.adsl.atuc.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES-6000, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36164','20','.1.3.6.1.2.1.10.94.1.1.2.1.7.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: ATUC output power','zyxel.ies6000.net.adsl.atuc.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES-6000, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36165','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Outgoing unicast packages','zyxel.ies6000.net.adsl.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36166','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Administrative status','zyxel.ies6000.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'188','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36167','20','.1.3.6.1.2.1.31.1.1.1.18.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Interface description','zyxel.ies6000.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36168','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Link speed','zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36169','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.ies6000.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36170','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.ies6000.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36171','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Incoming traffic','zyxel.ies6000.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36172','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.ies6000.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36173','15','','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Incoming utilization','zyxel.ies6000.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.ies6000.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]) <> 0) /
( last(zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36174','20','.1.3.6.1.2.1.31.1.1.1.1.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Interface name','zyxel.ies6000.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36175','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Operational status','zyxel.ies6000.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'189','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36176','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.ies6000.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36177','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.ies6000.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36178','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Outgoing traffic','zyxel.ies6000.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36179','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.ies6000.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36180','15','','10422','ZYXEL IES-6000: Port {#SNMPINDEX}: Outgoing utilization','zyxel.ies6000.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.ies6000.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]) <> 0) /
( last(zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.ies6000.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36181','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.8.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Alarm status','zyxel.ies6000.slot.alarm[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
This variable indicates the alarm status of the module.
It is a bit map represented a sum, therefore, it can represent
multiple defects simultaneously. The moduleNoDefect should be set
if and only if no other flag is set.
The various bit positions are:
1   moduleNoDefect
2   moduleOverHeat
3   moduleFanRpmLow
4   moduleVoltageLow
5   moduleThermalSensorFailure
6   modulePullOut
7   powerDC48VAFailure
8   powerDC48VBFailure
9   extAlarmInputTrigger
10   moduleDown
11   mscSwitchOverOK
12   networkTopologyChange
13   macSpoof
14   cpuHigh
15   memoryUsageHigh
16   packetBufferUsageHigh
17   loopguardOccurence','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36182','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.6.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: DSL modem code version','zyxel.ies6000.slot.cv.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The DSL modem code version of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36183','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.3.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Description','zyxel.ies6000.slot.desc[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The descriptions of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36184','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.5.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Driver version','zyxel.ies6000.slot.dv.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The DSL driver of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36185','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.4.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Firmware version','zyxel.ies6000.slot.fw.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The firmware version of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36186','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.10.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Hardware version','zyxel.ies6000.slot.hw.ver[{#SNMPINDEX}]','1h','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The hardware version of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36187','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.12.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: MAC address 1','zyxel.ies6000.slot.mac1[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The MAC Address of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36188','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.13.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: MAC address 2','zyxel.ies6000.slot.mac2[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The MAC Address of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36189','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.9.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Serial number','zyxel.ies6000.slot.serial[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The serial number of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36190','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.7.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Status','zyxel.ies6000.slot.status[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'184','','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The module state of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36191','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.2.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Type','zyxel.ies6000.slot.type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'185','','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
Card type of the plug-in card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36192','20','.1.3.6.1.4.1.890.1.5.13.5.6.3.1.11.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Uptime','zyxel.ies6000.slot.uptime[{#SNMPINDEX}]','1m','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The time (in seconds) since the plug-in card was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36193','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.3.1.2.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.ies6000.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36194','20','.1.3.6.1.4.1.890.1.5.13.5.11.3.2.1.2.{#SNMPINDEX}','10422','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.ies6000.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IES5000-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36195','5','','10423','ZYXEL IES1248-51: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36196','20','.1.3.6.1.2.1.1.4.0','10423','ZYXEL IES1248-51: Contact','zyxel.ies1248.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36197','20','.1.3.6.1.4.1.890.1.5.13.1.1.3.1.4.0.0','10423','ZYXEL IES1248-51: ZyNOS F/W Version','zyxel.ies1248.fwversion','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-IESCOMMON-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36198','20','.1.3.6.1.2.1.1.6.0','10423','ZYXEL IES1248-51: Location','zyxel.ies1248.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36199','20','.1.3.6.1.2.1.2.2.1.6.1','10423','ZYXEL IES1248-51: MAC address','zyxel.ies1248.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36200','20','.1.3.6.1.2.1.1.1.0','10423','ZYXEL IES1248-51: Hardware model name','zyxel.ies1248.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36201','20','.1.3.6.1.2.1.1.5.0','10423','ZYXEL IES1248-51: Host name','zyxel.ies1248.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36202','20','.1.3.6.1.4.1.890.1.5.13.1.1.2.1.3.0','10423','ZYXEL IES1248-51: Hardware serial number','zyxel.ies1248.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-IESCOMMON-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36203','20','.1.3.6.1.4.1.890.1.5.13.1.1.3.1.8.0.0','10423','ZYXEL IES1248-51: Alarm status','zyxel.ies1248.slot.alarm','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-IESCOMMON-MIB
This variable indicates the alarm status of the module.
It is a bit map represented a sum, therefore, it can represent
multiple defects simultaneously. The moduleNoDefect should be set
if and only if no other flag is set.
The various bit positions are:
1   moduleNoDefect
2   moduleOverHeat
3   moduleFanRpmLow
4   moduleVoltageLow
5   moduleThermalSensorFailure
6   modulePullOut
7   powerDC48VAFailure
8   powerDC48VBFailure
9   extAlarmInputTrigger
10   moduleDown
11   mscSwitchOverOK
12   networkTopologyChange
13   macSpoof
14   cpuHigh
15   memoryUsageHigh
16   packetBufferUsageHigh
17   loopguardOccurence','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36204','20','.1.3.6.1.2.1.1.3.0','10423','ZYXEL IES1248-51: Uptime','zyxel.ies1248.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36205','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.5.13.1.2.1.1.5]','10423','Fan discovery','zyxel.ies1248.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36206','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.2.2.1.2,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8]','10423','ADSL interface discovery','zyxel.ies1248.net.adsl.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36207','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.2.1.2.2.1.2,{#ZYXEL.IF.LINKSTATUS},.1.3.6.1.2.1.2.2.1.8]','10423','Ethernet interface discovery','zyxel.ies1248.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36208','20','discovery[{#ZYXEL.TEMP.ID}, .1.3.6.1.4.1.890.1.5.13.1.2.3.1.1,{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.13.1.2.3.1.5]','10423','Temperature discovery','zyxel.ies1248.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36209','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.13.1.2.2.1.6,{#ZYXEL.VOLT.NOMINAL}, .1.3.6.1.4.1.890.1.5.13.1.2.2.1.5]','10423','Voltage discovery','zyxel.ies1248.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36210','20','.1.3.6.1.4.1.890.1.5.13.1.2.1.1.2.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Fan #{#SNMPINDEX}','zyxel.ies1248.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IESCOMMON-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36211','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#SNMPINDEX}: Administrative status','zyxel.ies1248.net.adsl.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'193','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36212','20','.1.3.6.1.2.1.10.94.1.1.2.1.5.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#SNMPINDEX}: ATUC attenuation','zyxel.ies1248.net.adsl.atuc.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES1248-51, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36213','20','.1.3.6.1.2.1.10.94.1.1.2.1.7.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#SNMPINDEX}: ATUC output power','zyxel.ies1248.net.adsl.atuc.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES1248-51, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36214','20','.1.3.6.1.2.1.10.94.1.1.2.1.4.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#SNMPINDEX}: ATUC noise margin','zyxel.ies1248.net.adsl.atuc.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atuc fields show data acquired from the ATUC (ADSL Termination Unit – Central), in this case ZYXEL IES1248-51, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36215','20','.1.3.6.1.2.1.10.94.1.1.3.1.5.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#SNMPINDEX}: ATUR attenuation','zyxel.ies1248.net.adsl.atur.atn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured difference in the total power transmitted by
the peer ATU and the total power received by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36216','20','.1.3.6.1.2.1.10.94.1.1.3.1.7.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#SNMPINDEX}: ATUR output power','zyxel.ies1248.net.adsl.atur.outpwr[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Measured total output power transmitted by this ATU. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36217','20','.1.3.6.1.2.1.10.94.1.1.3.1.4.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#SNMPINDEX}: ATUR noise margin','zyxel.ies1248.net.adsl.atur.snrmgn[{#SNMPINDEX}]','1m','7d','365d','0','0','','dB','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ADSL-LINE-MIB
Noise Margin as seen by this ATU with respect to its
received signal in tenth dB. 
The Info Atur fields show data acquired from the ATUR (ADSL Termination Unit – Remote), in this case the subscriber’s ADSL modem or router, during negotiation/provisioning message interchanges.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36218','20','.1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#SNMPINDEX}: Incoming traffic','zyxel.ies1248.net.adsl.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36219','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#SNMPINDEX}: Interface name','zyxel.ies1248.net.adsl.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36220','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#SNMPINDEX}: Operational status','zyxel.ies1248.net.adsl.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'194','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36221','20','.1.3.6.1.2.1.2.2.1.16.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#SNMPINDEX}: Outgoing traffic','zyxel.ies1248.net.adsl.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36222','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#ZYXEL.IF.NAME}: Administrative status','zyxel.ies1248.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'193','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36223','20','.1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#ZYXEL.IF.NAME}: Incoming traffic','zyxel.ies1248.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36224','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#SNMPINDEX}: Interface name','zyxel.ies1248.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36225','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#ZYXEL.IF.NAME}: Operational status','zyxel.ies1248.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'194','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36226','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Port {#ZYXEL.IF.NAME}: Outgoing traffic','zyxel.ies1248.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36227','20','.1.3.6.1.4.1.890.1.5.13.1.2.3.1.2.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.ies1248.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IESCOMMON-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36228','20','.1.3.6.1.4.1.890.1.5.13.1.2.2.1.2.{#SNMPINDEX}','10423','ZYXEL IES1248-51: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.ies1248.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-IESCOMMON-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36229','5','','10424','ZYXEL MES-3528: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36230','20','.1.3.6.1.2.1.1.4.0','10424','ZYXEL MES-3528: Contact','zyxel.3528.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36231','20','.1.3.6.1.4.1.890.1.5.8.51.12.7.0','10424','ZYXEL MES-3528: CPU utilization','zyxel.3528.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3528-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36232','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.51.1]','10424','ZYXEL MES-3528: ZyNOS F/W Version','zyxel.3528.fwversion','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3528-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36233','20','.1.3.6.1.2.1.1.6.0','10424','ZYXEL MES-3528: Location','zyxel.3528.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36234','20','.1.3.6.1.2.1.2.2.1.6.1','10424','ZYXEL MES-3528: MAC address','zyxel.3528.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36235','20','.1.3.6.1.2.1.1.1.0','10424','ZYXEL MES-3528: Hardware model name','zyxel.3528.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36236','20','.1.3.6.1.2.1.1.5.0','10424','ZYXEL MES-3528: Host name','zyxel.3528.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36237','20','.1.3.6.1.4.1.890.1.5.8.51.1.10.0','10424','ZYXEL MES-3528: Hardware serial number','zyxel.3528.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3528-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36238','20','.1.3.6.1.2.1.1.3.0','10424','ZYXEL MES-3528: Uptime','zyxel.3528.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36239','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.51.24.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.51.24.1.1.5]','10424','Interface discovery','zyxel.3528.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36240','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.51.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.51.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.51.117.2.1.8]','10424','SFP with DDM discovery','zyxel.3528.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36241','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.51.117.1.1.2]','10424','SFP without DDM discovery','zyxel.3528.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36242','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Administrative status','zyxel.3528.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'197','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36243','20','.1.3.6.1.4.1.890.1.5.8.51.24.1.1.3.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Interface description','zyxel.3528.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3528-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36244','15','','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3528.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3528.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3528.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3528.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3528.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36245','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3528.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36246','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3528.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36247','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3528.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36248','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3528.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36249','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Operational status','zyxel.3528.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'198','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36250','20','.1.3.6.1.4.1.890.1.5.8.51.24.1.1.5.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Link type','zyxel.3528.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'196','','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3528-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36251','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Interface name','zyxel.3528.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36252','15','','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Incoming utilization','zyxel.3528.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3528.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3528.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3528.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3528.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36253','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3528.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36254','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Incoming traffic','zyxel.3528.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36255','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3528.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36256','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3528.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36257','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Link speed','zyxel.3528.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36258','20','.1.3.6.1.4.1.890.1.5.8.51.24.1.1.1.{#SNMPINDEX}','10424','ZYXEL MES-3528: Port {#SNMPINDEX}: Speed Duplex','zyxel.3528.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'195','','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3528-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36259','20','.1.3.6.1.4.1.890.1.5.8.51.117.2.1.7.{#SNMPINDEX}','10424','ZYXEL MES-3528: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3528.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36260','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.7.{#SNMPINDEX}','10424','ZYXEL MES-3528: SFP {#SNMPINDEX}: Date code','zyxel.3528.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36261','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.4.{#SNMPINDEX}','10424','ZYXEL MES-3528: SFP {#SNMPINDEX}: Part number','zyxel.3528.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36262','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.6.{#SNMPINDEX}','10424','ZYXEL MES-3528: SFP {#SNMPINDEX}: Revision','zyxel.3528.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36263','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.5.{#SNMPINDEX}','10424','ZYXEL MES-3528: SFP {#SNMPINDEX}: Serial number','zyxel.3528.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36264','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.2.{#SNMPINDEX}','10424','ZYXEL MES-3528: SFP {#SNMPINDEX}: Status','zyxel.3528.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'199','','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36265','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.8.{#SNMPINDEX}','10424','ZYXEL MES-3528: SFP {#SNMPINDEX}: Transceiver','zyxel.3528.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36266','20','.1.3.6.1.4.1.890.1.5.8.51.117.1.1.3.{#SNMPINDEX}','10424','ZYXEL MES-3528: SFP {#SNMPINDEX}: Vendor','zyxel.3528.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3528-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36267','5','','10425','ZYXEL MES3500-10: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36268','20','.1.3.6.1.2.1.1.4.0','10425','ZYXEL MES3500-10: Contact','zyxel.3500_10.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36269','20','.1.3.6.1.4.1.890.1.5.8.80.12.7.0','10425','ZYXEL MES3500-10: CPU utilization','zyxel.3500_10.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3500-10-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36270','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.80.1]','10425','ZYXEL MES3500-10: ZyNOS F/W Version','zyxel.3500_10.fwversion','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3500-10-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36271','20','.1.3.6.1.2.1.1.6.0','10425','ZYXEL MES3500-10: Location','zyxel.3500_10.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36272','20','.1.3.6.1.2.1.2.2.1.6.1','10425','ZYXEL MES3500-10: MAC address','zyxel.3500_10.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36273','20','.1.3.6.1.2.1.1.1.0','10425','ZYXEL MES3500-10: Hardware model name','zyxel.3500_10.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36274','20','.1.3.6.1.2.1.1.5.0','10425','ZYXEL MES3500-10: Host name','zyxel.3500_10.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36275','20','.1.3.6.1.4.1.890.1.5.8.80.1.10.0','10425','ZYXEL MES3500-10: Hardware serial number','zyxel.3500_10.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3500-10-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36276','20','.1.3.6.1.2.1.1.3.0','10425','ZYXEL MES3500-10: Uptime','zyxel.3500_10.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36277','20','discovery[{#ZYXEL.MEMORY.NAME},.1.3.6.1.4.1.890.1.5.8.80.124.1.1.2]','10425','Memory pool discovery','zyxel.3500_10.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36278','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.80.24.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.80.24.1.1.5]','10425','Interface discovery','zyxel.3500_10.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36279','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.80.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.80.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.80.117.2.1.8]','10425','SFP with DDM discovery','zyxel.3500_10.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36280','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.80.117.1.1.2]','10425','SFP without DDM discovery','zyxel.3500_10.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36281','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.80.9.2.1.5]','10425','Temperature discovery','zyxel.3500_10.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36282','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.80.9.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.80.9.3.1.5]','10425','Voltage discovery','zyxel.3500_10.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36283','20','.1.3.6.1.4.1.890.1.5.8.80.124.1.1.5.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Memory "{#ZYXEL.MEMORY.NAME}" utilization','zyxel.3500_10.memory[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Utilization of memory pool in %.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36284','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Administrative status','zyxel.3500_10.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'202','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36285','20','.1.3.6.1.4.1.890.1.5.8.80.24.1.1.3.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Interface description','zyxel.3500_10.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3500-10-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36286','15','','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3500_10.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3500_10.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36287','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3500_10.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36288','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3500_10.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36289','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3500_10.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36290','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3500_10.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36291','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Operational status','zyxel.3500_10.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'203','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36292','20','.1.3.6.1.4.1.890.1.5.8.80.24.1.1.5.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Link type','zyxel.3500_10.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'201','','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3500-10-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36293','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Interface name','zyxel.3500_10.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36294','15','','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Incoming utilization','zyxel.3500_10.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3500_10.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36295','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3500_10.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36296','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Incoming traffic','zyxel.3500_10.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36297','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3500_10.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36298','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3500_10.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36299','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Link speed','zyxel.3500_10.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36300','20','.1.3.6.1.4.1.890.1.5.8.80.24.1.1.1.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Port {#SNMPINDEX}: Speed Duplex','zyxel.3500_10.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'200','','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3500-10-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36301','20','.1.3.6.1.4.1.890.1.5.8.80.117.2.1.7.{#SNMPINDEX}','10425','ZYXEL MES3500-10: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3500_10.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36302','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.7.{#SNMPINDEX}','10425','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Date code','zyxel.3500_10.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36303','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.4.{#SNMPINDEX}','10425','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Part number','zyxel.3500_10.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36304','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.6.{#SNMPINDEX}','10425','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Revision','zyxel.3500_10.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36305','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.5.{#SNMPINDEX}','10425','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Serial number','zyxel.3500_10.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36306','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.2.{#SNMPINDEX}','10425','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Status','zyxel.3500_10.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'204','','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36307','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.8.{#SNMPINDEX}','10425','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Transceiver','zyxel.3500_10.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36308','20','.1.3.6.1.4.1.890.1.5.8.80.117.1.1.3.{#SNMPINDEX}','10425','ZYXEL MES3500-10: SFP {#SNMPINDEX}: Vendor','zyxel.3500_10.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36309','20','.1.3.6.1.4.1.890.1.5.8.80.9.2.1.2.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.3500_10.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36310','20','.1.3.6.1.4.1.890.1.5.8.80.9.3.1.2.{#SNMPINDEX}','10425','ZYXEL MES3500-10: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.3500_10.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-10-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36311','5','','10426','ZYXEL MES3500-24: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36312','20','.1.3.6.1.2.1.1.4.0','10426','ZYXEL MES3500-24: Contact','zyxel.3500_24.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36313','20','.1.3.6.1.4.1.890.1.5.8.68.12.7.0','10426','ZYXEL MES3500-24: CPU utilization','zyxel.3500_24.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3500-24-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36314','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.68.1]','10426','ZYXEL MES3500-24: ZyNOS F/W Version','zyxel.3500_24.fwversion','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3500-24-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36315','20','.1.3.6.1.2.1.1.6.0','10426','ZYXEL MES3500-24: Location','zyxel.3500_24.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36316','20','.1.3.6.1.2.1.2.2.1.6.1','10426','ZYXEL MES3500-24: MAC address','zyxel.3500_24.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36317','20','.1.3.6.1.2.1.1.1.0','10426','ZYXEL MES3500-24: Hardware model name','zyxel.3500_24.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36318','20','.1.3.6.1.2.1.1.5.0','10426','ZYXEL MES3500-24: Host name','zyxel.3500_24.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36319','20','.1.3.6.1.4.1.890.1.5.8.68.1.10.0','10426','ZYXEL MES3500-24: Hardware serial number','zyxel.3500_24.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MES3500-24-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36320','20','.1.3.6.1.2.1.1.3.0','10426','ZYXEL MES3500-24: Uptime','zyxel.3500_24.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36321','20','discovery[{#ZYXEL.MEMORY.NAME},.1.3.6.1.4.1.890.1.5.8.68.124.1.1.2]','10426','Memory pool discovery','zyxel.3500_24.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36322','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.68.24.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.68.24.1.1.5]','10426','Interface discovery','zyxel.3500_24.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36323','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.68.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.68.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.68.117.2.1.8]','10426','SFP with DDM discovery','zyxel.3500_24.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36324','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.68.117.1.1.2]','10426','SFP without DDM discovery','zyxel.3500_24.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36325','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.68.9.2.1.5]','10426','Temperature discovery','zyxel.3500_24.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36326','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.68.9.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.68.9.3.1.5]','10426','Voltage discovery','zyxel.3500_24.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36327','20','.1.3.6.1.4.1.890.1.5.8.68.124.1.1.5.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Memory "{#ZYXEL.MEMORY.NAME}" utilization','zyxel.3500_24.memory[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Utilization of memory pool in %.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36328','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Administrative status','zyxel.3500_24.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'207','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36329','20','.1.3.6.1.4.1.890.1.5.8.68.24.1.1.3.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Interface description','zyxel.3500_24.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3500-24-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36330','15','','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3500_24.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3500_24.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36331','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3500_24.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36332','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3500_24.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36333','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3500_24.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36334','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3500_24.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36335','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Operational status','zyxel.3500_24.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'208','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36336','20','.1.3.6.1.4.1.890.1.5.8.68.24.1.1.5.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Link type','zyxel.3500_24.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'206','','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3500-24-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36337','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Interface name','zyxel.3500_24.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36338','15','','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Incoming utilization','zyxel.3500_24.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3500_24.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36339','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3500_24.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36340','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Incoming traffic','zyxel.3500_24.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36341','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3500_24.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36342','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3500_24.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36343','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Link speed','zyxel.3500_24.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36344','20','.1.3.6.1.4.1.890.1.5.8.68.24.1.1.1.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Port {#SNMPINDEX}: Speed Duplex','zyxel.3500_24.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'205','','','0','','','','','2',NULL,'MIB:  ZYXEL-MES3500-24-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36345','20','.1.3.6.1.4.1.890.1.5.8.68.117.2.1.7.{#SNMPINDEX}','10426','ZYXEL MES3500-24: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3500_24.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36346','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.7.{#SNMPINDEX}','10426','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Date code','zyxel.3500_24.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36347','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.4.{#SNMPINDEX}','10426','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Part number','zyxel.3500_24.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36348','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.6.{#SNMPINDEX}','10426','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Revision','zyxel.3500_24.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36349','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.5.{#SNMPINDEX}','10426','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Serial number','zyxel.3500_24.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36350','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.2.{#SNMPINDEX}','10426','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Status','zyxel.3500_24.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'209','','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36351','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.8.{#SNMPINDEX}','10426','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Transceiver','zyxel.3500_24.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36352','20','.1.3.6.1.4.1.890.1.5.8.68.117.1.1.3.{#SNMPINDEX}','10426','ZYXEL MES3500-24: SFP {#SNMPINDEX}: Vendor','zyxel.3500_24.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36353','20','.1.3.6.1.4.1.890.1.5.8.68.9.2.1.2.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.3500_24.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36354','20','.1.3.6.1.4.1.890.1.5.8.68.9.3.1.2.{#SNMPINDEX}','10426','ZYXEL MES3500-24: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.3500_24.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MES3500-24-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36355','5','','10427','ZYXEL MGS-3712: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36356','20','.1.3.6.1.2.1.1.4.0','10427','ZYXEL MGS-3712: Contact','zyxel.3712.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36357','20','.1.3.6.1.4.1.890.1.5.8.47.11.7.0','10427','ZYXEL MGS-3712: CPU utilization','zyxel.3712.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MGS3712F-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36358','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.47.1]','10427','ZYXEL MGS-3712: ZyNOS F/W Version','zyxel.3712.fwversion','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MGS3712F-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36359','20','.1.3.6.1.2.1.1.6.0','10427','ZYXEL MGS-3712: Location','zyxel.3712.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36360','20','.1.3.6.1.2.1.2.2.1.6.1','10427','ZYXEL MGS-3712: MAC address','zyxel.3712.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36361','20','.1.3.6.1.2.1.1.1.0','10427','ZYXEL MGS-3712: Hardware model name','zyxel.3712.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36362','20','.1.3.6.1.2.1.1.5.0','10427','ZYXEL MGS-3712: Host name','zyxel.3712.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36363','20','.1.3.6.1.4.1.890.1.5.8.47.1.10.0','10427','ZYXEL MGS-3712: Hardware serial number','zyxel.3712.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MGS3712F-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36364','20','.1.3.6.1.2.1.1.3.0','10427','ZYXEL MGS-3712: Uptime','zyxel.3712.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36365','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.47.8.1.1.5]','10427','Fan discovery','zyxel.3712.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36366','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.47.22.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.47.22.1.1.5]','10427','Interface discovery','zyxel.3712.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36367','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.47.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.47.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.47.117.2.1.8]','10427','SFP with DDM discovery','zyxel.3712.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36368','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.47.117.1.1.2]','10427','SFP without DDM discovery','zyxel.3712.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36369','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.47.8.2.1.5]','10427','Temperature discovery','zyxel.3712.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36370','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.47.8.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.47.8.3.1.5]','10427','Voltage discovery','zyxel.3712.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36371','20','.1.3.6.1.4.1.890.1.5.8.47.8.1.1.2.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Fan #{#SNMPINDEX}','zyxel.3712.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36372','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Administrative status','zyxel.3712.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'212','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36373','20','.1.3.6.1.4.1.890.1.5.8.47.22.1.1.3.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Interface description','zyxel.3712.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36374','15','','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3712.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3712.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3712.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3712.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3712.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36375','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3712.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36376','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3712.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36377','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3712.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36378','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3712.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36379','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Operational status','zyxel.3712.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'213','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36380','20','.1.3.6.1.4.1.890.1.5.8.47.22.1.1.5.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Link type','zyxel.3712.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'211','','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36381','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Interface name','zyxel.3712.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36382','15','','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Incoming utilization','zyxel.3712.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3712.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3712.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3712.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3712.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36383','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3712.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36384','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Incoming traffic','zyxel.3712.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36385','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3712.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36386','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3712.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36387','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Link speed','zyxel.3712.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36388','20','.1.3.6.1.4.1.890.1.5.8.47.22.1.1.1.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Port {#SNMPINDEX}: Speed Duplex','zyxel.3712.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'210','','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36389','20','.1.3.6.1.4.1.890.1.5.8.47.117.2.1.7.{#SNMPINDEX}','10427','ZYXEL MGS-3712: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3712.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36390','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.7.{#SNMPINDEX}','10427','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Date code','zyxel.3712.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36391','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.4.{#SNMPINDEX}','10427','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Part number','zyxel.3712.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36392','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.6.{#SNMPINDEX}','10427','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Revision','zyxel.3712.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36393','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.5.{#SNMPINDEX}','10427','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Serial number','zyxel.3712.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36394','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.2.{#SNMPINDEX}','10427','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Status','zyxel.3712.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'214','','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36395','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.8.{#SNMPINDEX}','10427','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Transceiver','zyxel.3712.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36396','20','.1.3.6.1.4.1.890.1.5.8.47.117.1.1.3.{#SNMPINDEX}','10427','ZYXEL MGS-3712: SFP {#SNMPINDEX}: Vendor','zyxel.3712.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36397','20','.1.3.6.1.4.1.890.1.5.8.47.8.2.1.2.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.3712.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36398','20','.1.3.6.1.4.1.890.1.5.8.47.8.3.1.2.{#SNMPINDEX}','10427','ZYXEL MGS-3712: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.3712.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36399','5','','10428','ZYXEL MGS-3712F: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36400','20','.1.3.6.1.2.1.1.4.0','10428','ZYXEL MGS-3712F: Contact','zyxel.3712f.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36401','20','.1.3.6.1.4.1.890.1.5.8.48.11.7.0','10428','ZYXEL MGS-3712F: CPU utilization','zyxel.3712f.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MGS3712F-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36402','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.48.1]','10428','ZYXEL MGS-3712F: ZyNOS F/W Version','zyxel.3712f.fwversion','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MGS3712F-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36403','20','.1.3.6.1.2.1.1.6.0','10428','ZYXEL MGS-3712F: Location','zyxel.3712f.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36404','20','.1.3.6.1.2.1.2.2.1.6.1','10428','ZYXEL MGS-3712F: MAC address','zyxel.3712f.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36405','20','.1.3.6.1.2.1.1.1.0','10428','ZYXEL MGS-3712F: Hardware model name','zyxel.3712f.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36406','20','.1.3.6.1.2.1.1.5.0','10428','ZYXEL MGS-3712F: Host name','zyxel.3712f.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36407','20','.1.3.6.1.4.1.890.1.5.8.48.1.10.0','10428','ZYXEL MGS-3712F: Hardware serial number','zyxel.3712f.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-MGS3712F-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36408','20','.1.3.6.1.2.1.1.3.0','10428','ZYXEL MGS-3712F: Uptime','zyxel.3712f.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36409','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.48.8.1.1.5]','10428','Fan discovery','zyxel.3712f.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36410','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.48.22.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.48.22.1.1.5]','10428','Interface discovery','zyxel.3712f.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36411','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.48.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.48.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.48.117.2.1.8]','10428','SFP with DDM discovery','zyxel.3712f.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36412','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.48.117.1.1.2]','10428','SFP without DDM discovery','zyxel.3712f.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36413','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.48.8.2.1.5]','10428','Temperature discovery','zyxel.3712f.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36414','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.48.8.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.48.8.3.1.5]','10428','Voltage discovery','zyxel.3712f.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36415','20','.1.3.6.1.4.1.890.1.5.8.48.8.1.1.2.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Fan #{#SNMPINDEX}','zyxel.3712f.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36416','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Administrative status','zyxel.3712f.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'217','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36417','20','.1.3.6.1.4.1.890.1.5.8.48.22.1.1.3.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Interface description','zyxel.3712f.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36418','15','','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3712f.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3712f.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36419','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3712f.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36420','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3712f.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36421','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3712f.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36422','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3712f.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36423','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Operational status','zyxel.3712f.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'218','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36424','20','.1.3.6.1.4.1.890.1.5.8.48.22.1.1.5.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Link type','zyxel.3712f.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'216','','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36425','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Interface name','zyxel.3712f.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36426','15','','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Incoming utilization','zyxel.3712f.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3712f.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36427','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3712f.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36428','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Incoming traffic','zyxel.3712f.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36429','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3712f.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36430','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3712f.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36431','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Link speed','zyxel.3712f.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36432','20','.1.3.6.1.4.1.890.1.5.8.48.22.1.1.1.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Speed Duplex','zyxel.3712f.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'215','','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36433','20','.1.3.6.1.4.1.890.1.5.8.48.117.2.1.7.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3712f.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36434','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.7.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Date code','zyxel.3712f.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36435','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.4.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Part number','zyxel.3712f.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36436','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.6.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Revision','zyxel.3712f.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36437','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.5.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Serial number','zyxel.3712f.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36438','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.2.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Status','zyxel.3712f.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'219','','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36439','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.8.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Transceiver','zyxel.3712f.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36440','20','.1.3.6.1.4.1.890.1.5.8.48.117.1.1.3.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: SFP {#SNMPINDEX}: Vendor','zyxel.3712f.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36441','20','.1.3.6.1.4.1.890.1.5.8.48.8.2.1.2.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.3712f.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36442','20','.1.3.6.1.4.1.890.1.5.8.48.8.3.1.2.{#SNMPINDEX}','10428','ZYXEL MGS-3712F: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.3712f.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-MGS3712F-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36443','5','','10429','ZYXEL MES3500-24S: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36444','20','.1.3.6.1.2.1.1.4.0','10429','ZYXEL MES3500-24S: Contact','zyxel.3500_24s.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36445','20','.1.3.6.1.4.1.890.1.15.3.2.4.0','10429','ZYXEL MES3500-24S: CPU utilization','zyxel.3500_24s.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36446','20','.1.3.6.1.4.1.890.1.15.3.1.6.0','10429','ZYXEL MES3500-24S: ZyNOS F/W Version','zyxel.3500_24s.fwversion','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36447','20','.1.3.6.1.2.1.1.6.0','10429','ZYXEL MES3500-24S: Location','zyxel.3500_24s.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36448','20','.1.3.6.1.2.1.2.2.1.6.1','10429','ZYXEL MES3500-24S: MAC address','zyxel.3500_24s.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36449','20','.1.3.6.1.4.1.890.1.15.3.2.5.0','10429','ZYXEL MES3500-24S: Memory utilization','zyxel.3500_24s.memusage','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON
Show device memory usage in %.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36450','20','.1.3.6.1.2.1.1.1.0','10429','ZYXEL MES3500-24S: Hardware model name','zyxel.3500_24s.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36451','20','.1.3.6.1.2.1.1.5.0','10429','ZYXEL MES3500-24S: Host name','zyxel.3500_24s.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36452','20','.1.3.6.1.4.1.890.1.15.3.1.12.0','10429','ZYXEL MES3500-24S: Hardware serial number','zyxel.3500_24s.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36453','20','.1.3.6.1.2.1.1.3.0','10429','ZYXEL MES3500-24S: Uptime','zyxel.3500_24s.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36454','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.15.3.26.1.1.1.6,{#ZYXEL.FAN.DESCRIPTION},.1.3.6.1.4.1.890.1.15.3.26.1.1.1.2]','10429','Fan discovery','zyxel.3500_24s.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36455','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.15.3.61.1.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.15.3.61.2.1.1.2]','10429','Interface discovery','zyxel.3500_24s.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36456','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.15.3.84.1.2.1.4,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.15.3.84.1.2.1.5,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.15.3.84.1.2.1.7]','10429','SFP with DDM discovery','zyxel.3500_24s.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36457','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.15.3.84.1.1.1.1]','10429','SFP without DDM discovery','zyxel.3500_24s.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36458','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.15.3.26.1.2.1.6,{#ZYXEL.TEMPDESCRIPTION},.1.3.6.1.4.1.890.1.15.3.26.1.2.1.2]','10429','Temperature discovery','zyxel.3500_24s.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36459','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.15.3.26.1.3.1.7,{#ZYXEL.DESCRIPTION},.1.3.6.1.4.1.890.1.15.3.26.1.3.1.2]','10429','Voltage discovery','zyxel.3500_24s.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36460','20','.1.3.6.1.4.1.890.1.15.3.26.1.1.1.3.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: {#ZYXEL.FAN.DESCRIPTION}','zyxel.3500_24s.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-HW-MONITOR-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36461','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Administrative status','zyxel.3500_24s.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'222','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36462','20','.1.3.6.1.4.1.890.1.15.3.61.1.1.1.3.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Interface description','zyxel.3500_24s.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-PORT-MIB
Descriptive name that identifies this port.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36463','15','','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3500_24s.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3500_24s.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36464','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3500_24s.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36465','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3500_24s.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36466','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3500_24s.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36467','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3500_24s.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36468','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Operational status','zyxel.3500_24s.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'223','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36469','20','.1.3.6.1.4.1.890.1.15.3.61.2.1.1.2.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Link type','zyxel.3500_24s.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'221','','','0','','','','','2',NULL,'MIB: ZYXEL-PORT-MIB
The entry shows the linkUp cable type (copper, fiber, xfp or cx4) for the combo ports.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36470','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Interface name','zyxel.3500_24s.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36471','15','','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Incoming utilization','zyxel.3500_24s.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3500_24s.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36472','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3500_24s.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36473','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Incoming traffic','zyxel.3500_24s.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36474','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3500_24s.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36475','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3500_24s.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36476','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Link speed','zyxel.3500_24s.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36477','20','.1.3.6.1.4.1.890.1.15.3.61.1.1.1.1.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Speed Duplex','zyxel.3500_24s.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'220','','','0','','','','','2',NULL,'MIB: ZYXEL-PORT-MIB
Select The speed and the duplex mode of the Ethernet connection on this port. Selecting Auto 
(auto-negotiation) allows one port to negotiate with a peer port automatically to obtain the 
connection speed and duplex mode that both ends support. When auto-negotiation is turned on, 
a port on the Switch negotiates with the peer automatically to determine the connection speed 
and duplex mode. If the peer port does not support auto-negotiation or turns off this feature, 
the Switch determines the connection speed by detecting the signal on the cable and using half 
duplex mode. Thus requiring you to make sure that the settings of the peer port are the same in 
order to connect.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36478','20','.1.3.6.1.4.1.890.1.15.3.84.1.2.1.6.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3500_24s.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36479','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.6.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Date code','zyxel.3500_24s.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36480','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.3.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Part number','zyxel.3500_24s.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36481','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.5.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Revision','zyxel.3500_24s.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36482','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.4.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Serial number','zyxel.3500_24s.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36483','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.1.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Status','zyxel.3500_24s.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'224','','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module type.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36484','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.7.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Transceiver','zyxel.3500_24s.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36485','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.2.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: SFP {#SNMPINDEX}: Vendor','zyxel.3500_24s.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36486','20','.1.3.6.1.4.1.890.1.15.3.26.1.2.1.3.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Temperature "{#ZYXEL.TEMPDESCRIPTION}"','zyxel.3500_24s.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-HW-MONITOR-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36487','20','.1.3.6.1.4.1.890.1.15.3.26.1.3.1.3.{#SNMPINDEX}','10429','ZYXEL MES3500-24S: Nominal "{#ZYXEL.DESCRIPTION}"','zyxel.3500_24s.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-HW-MONITOR-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36488','5','','10430','ZYXEL MGS3520-28x: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36489','20','.1.3.6.1.2.1.1.4.0','10430','ZYXEL MGS3520-28x: Contact','zyxel.3520_28.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36490','20','.1.3.6.1.4.1.890.1.15.3.2.4.0','10430','ZYXEL MGS3520-28x: CPU utilization','zyxel.3520_28.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36491','20','.1.3.6.1.4.1.890.1.15.3.1.6.0','10430','ZYXEL MGS3520-28x: ZyNOS F/W Version','zyxel.3520_28.fwversion','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36492','20','.1.3.6.1.2.1.1.6.0','10430','ZYXEL MGS3520-28x: Location','zyxel.3520_28.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36493','20','.1.3.6.1.2.1.2.2.1.6.1','10430','ZYXEL MGS3520-28x: MAC address','zyxel.3520_28.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36494','20','.1.3.6.1.4.1.890.1.15.3.2.5.0','10430','ZYXEL MGS3520-28x: Memory utilization','zyxel.3520_28.memusage','1m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON
Show device memory usage in %.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36495','20','.1.3.6.1.2.1.1.1.0','10430','ZYXEL MGS3520-28x: Hardware model name','zyxel.3520_28.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36496','20','.1.3.6.1.2.1.1.5.0','10430','ZYXEL MGS3520-28x: Host name','zyxel.3520_28.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36497','20','.1.3.6.1.4.1.890.1.15.3.1.12.0','10430','ZYXEL MGS3520-28x: Hardware serial number','zyxel.3520_28.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-ES-COMMON
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36498','20','.1.3.6.1.2.1.1.3.0','10430','ZYXEL MGS3520-28x: Uptime','zyxel.3520_28.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36499','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.15.3.26.1.1.1.6,{#ZYXEL.FAN.DESCRIPTION},.1.3.6.1.4.1.890.1.15.3.26.1.1.1.2]','10430','Fan discovery','zyxel.3520_28.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36500','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.15.3.61.1.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.15.3.61.2.1.1.2]','10430','Interface discovery','zyxel.3520_28.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36501','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.15.3.84.1.2.1.4,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.15.3.84.1.2.1.5,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.15.3.84.1.2.1.7]','10430','SFP with DDM discovery','zyxel.3520_28.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36502','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.15.3.84.1.1.1.1]','10430','SFP without DDM discovery','zyxel.3520_28.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36503','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.15.3.26.1.2.1.6,{#ZYXEL.TEMPDESCRIPTION},.1.3.6.1.4.1.890.1.15.3.26.1.2.1.2]','10430','Temperature discovery','zyxel.3520_28.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36504','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.15.3.26.1.3.1.7,{#ZYXEL.DESCRIPTION},.1.3.6.1.4.1.890.1.15.3.26.1.3.1.2]','10430','Voltage discovery','zyxel.3520_28.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36505','20','.1.3.6.1.4.1.890.1.15.3.26.1.1.1.3.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: {#ZYXEL.FAN.DESCRIPTION}','zyxel.3520_28.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-HW-MONITOR-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36506','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Administrative status','zyxel.3520_28.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'227','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36507','20','.1.3.6.1.4.1.890.1.15.3.61.1.1.1.3.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Interface description','zyxel.3520_28.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-PORT-MIB
Descriptive name that identifies this port.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36508','15','','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Outgoing utilization','zyxel.3520_28.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3520_28.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36509','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.3520_28.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36510','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Outgoing traffic','zyxel.3520_28.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36511','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.3520_28.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36512','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.3520_28.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36513','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Operational status','zyxel.3520_28.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'228','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36514','20','.1.3.6.1.4.1.890.1.15.3.61.2.1.1.2.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Link type','zyxel.3520_28.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'226','','','0','','','','','2',NULL,'MIB: ZYXEL-PORT-MIB
The entry shows the linkUp cable type (copper, fiber, xfp or cx4) for the combo ports.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36515','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Interface name','zyxel.3520_28.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36516','15','','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Incoming utilization','zyxel.3520_28.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.3520_28.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36517','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.3520_28.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36518','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Incoming traffic','zyxel.3520_28.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36519','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.3520_28.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36520','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.3520_28.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36521','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Link speed','zyxel.3520_28.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36522','20','.1.3.6.1.4.1.890.1.15.3.61.1.1.1.1.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Speed Duplex','zyxel.3520_28.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'225','','','0','','','','','2',NULL,'MIB: ZYXEL-PORT-MIB
Select The speed and the duplex mode of the Ethernet connection on this port. Selecting Auto 
(auto-negotiation) allows one port to negotiate with a peer port automatically to obtain the 
connection speed and duplex mode that both ends support. When auto-negotiation is turned on, 
a port on the Switch negotiates with the peer automatically to determine the connection speed 
and duplex mode. If the peer port does not support auto-negotiation or turns off this feature, 
the Switch determines the connection speed by detecting the signal on the cable and using half 
duplex mode. Thus requiring you to make sure that the settings of the peer port are the same in 
order to connect.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36523','20','.1.3.6.1.4.1.890.1.15.3.84.1.2.1.6.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.3520_28.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36524','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.6.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Date code','zyxel.3520_28.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36525','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.3.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Part number','zyxel.3520_28.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36526','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.5.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Revision','zyxel.3520_28.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36527','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.4.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Serial number','zyxel.3520_28.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36528','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.1.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Status','zyxel.3520_28.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'229','','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module type.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36529','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.7.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Transceiver','zyxel.3520_28.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36530','20','.1.3.6.1.4.1.890.1.15.3.84.1.1.1.2.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: SFP {#SNMPINDEX}: Vendor','zyxel.3520_28.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-TRANSCEIVER-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36531','20','.1.3.6.1.4.1.890.1.15.3.26.1.2.1.3.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Temperature "{#ZYXEL.TEMPDESCRIPTION}"','zyxel.3520_28.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-HW-MONITOR-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36532','20','.1.3.6.1.4.1.890.1.15.3.26.1.3.1.3.{#SNMPINDEX}','10430','ZYXEL MGS3520-28x: Nominal "{#ZYXEL.DESCRIPTION}"','zyxel.3520_28.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-HW-MONITOR-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36533','5','','10431','ZYXEL XGS-4728F: SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','',NULL,'162','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36534','20','.1.3.6.1.2.1.1.4.0','10431','ZYXEL XGS-4728F: Contact','zyxel.4728f.contact','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The textual identification of the contact person
for this managed node, together with information
on how to contact this person.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36535','20','.1.3.6.1.4.1.890.1.5.8.46.12.7.0','10431','ZYXEL XGS-4728F: CPU utilization','zyxel.4728f.cpuusage','1m','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-XGS4728F-MIB
Show device CPU load in %, it''s the snapshot of CPU load when 
getting the values.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36536','20','discovery[{#SNMP.ARRAY},.1.3.6.1.4.1.890.1.5.8.46.1]','10431','ZYXEL XGS-4728F: ZyNOS F/W Version','zyxel.4728f.fwversion','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-XGS4728F-MIB','17','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36537','20','.1.3.6.1.2.1.1.6.0','10431','ZYXEL XGS-4728F: Location','zyxel.4728f.location','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The physical location of this node (e.g.,
`telephone closet, 3rd floor'').','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36538','20','.1.3.6.1.2.1.2.2.1.6.1','10431','ZYXEL XGS-4728F: MAC address','zyxel.4728f.mac','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: IF-MIB
The interface''s address at the protocol layer
immediately `below'' the network layer in the
protocol stack.  For interfaces which do not have
such an address (e.g., a serial line), this object
should contain an octet string of zero length.','12','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36539','20','.1.3.6.1.2.1.1.1.0','10431','ZYXEL XGS-4728F: Hardware model name','zyxel.4728f.model','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
A textual description of the entity.  This value
should include the full name and version
identification of the system''s hardware type,
software operating-system, and networking
software.  It is mandatory that this only contain
printable ASCII characters.','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36540','20','.1.3.6.1.2.1.1.5.0','10431','ZYXEL XGS-4728F: Host name','zyxel.4728f.name','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
An administratively-assigned name for this
managed node.  By convention, this is the node''s
fully-qualified domain name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36541','20','.1.3.6.1.4.1.890.1.5.8.46.1.10.0','10431','ZYXEL XGS-4728F: Hardware serial number','zyxel.4728f.serialnumber','1h','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: ZYXEL-XGS4728F-MIB
Serial number','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36542','20','.1.3.6.1.2.1.1.3.0','10431','ZYXEL XGS-4728F: Uptime','zyxel.4728f.uptime','30s','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MIB: RFC1213-MIB
The time (in hundredths of a second) since the
network management portion of the system was last
re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36543','20','discovery[{#ZYXEL.FANRPM.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.46.9.1.1.5]','10431','Fan discovery','zyxel.4728f.fan.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in fanRpmTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36544','20','discovery[{#ZYXEL.MEMORY.NAME},.1.3.6.1.4.1.890.1.5.8.46.124.1.1.2]','10431','Memory pool discovery','zyxel.4728f.memory.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36545','20','discovery[{#ZYXEL.IF.NAME},.1.3.6.1.4.1.890.1.5.8.46.23.1.1.3,{#ZYXEL.IF.LINKUPTYPE},.1.3.6.1.4.1.890.1.5.8.46.23.1.1.5]','10431','Interface discovery','zyxel.4728f.net.if.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36546','20','discovery[{#ZYXEL.SFP.WARN.MAX},.1.3.6.1.4.1.890.1.5.8.46.117.2.1.5,{#ZYXEL.SFP.WARN.MIN},.1.3.6.1.4.1.890.1.5.8.46.117.2.1.6,{#ZYXEL.SFP.DESCRIPTION},.1.3.6.1.4.1.890.1.5.8.46.117.2.1.8]','10431','SFP with DDM discovery','zyxel.4728f.sfp.ddm.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP DDM module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36547','20','discovery[{#ZYXEL.SFP.STATUS},.1.3.6.1.4.1.890.1.5.8.46.117.1.1.2]','10431','SFP without DDM discovery','zyxel.4728f.sfp.discovery','12h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'SFP module discovery.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36548','20','discovery[{#ZYXEL.TEMP.THRESH.HIGH},.1.3.6.1.4.1.890.1.5.8.46.9.2.1.5]','10431','Temperature discovery','zyxel.4728f.temp.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in tempTable.
Index of temperature unit. 1:MAC, 2:CPU, 3:PHY','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36549','20','discovery[{#ZYXEL.VOLT.THRESH.LOW},.1.3.6.1.4.1.890.1.5.8.46.9.3.1.6,{#ZYXEL.VOLT.NOMINAL},.1.3.6.1.4.1.890.1.5.8.46.9.3.1.5]','10431','Voltage discovery','zyxel.4728f.volt.discovery','1h','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'An entry in voltageTable.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36550','20','.1.3.6.1.4.1.890.1.5.8.46.9.1.1.2.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Fan #{#SNMPINDEX}','zyxel.4728f.fan[{#SNMPINDEX}]','1m','7d','365d','0','3','','!rpm','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Current speed in Revolutions Per Minute (RPM) on the fan.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36551','20','.1.3.6.1.4.1.890.1.5.8.46.124.1.1.5.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Memory "{#ZYXEL.MEMORY.NAME}" utilization','zyxel.4728f.memory[{#SNMPINDEX}]','1m','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Utilization of memory pool in %.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36552','20','.1.3.6.1.2.1.2.2.1.7.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Administrative status','zyxel.4728f.net.if.adminstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'232','','','0','','','','','2',NULL,'MIB: IF-MIB
The desired state of the interface.  The
testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36553','20','.1.3.6.1.4.1.890.1.5.8.46.23.1.1.3.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Interface description','zyxel.4728f.net.if.name[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB:  ZYXEL-XGS4728F-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36554','15','','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Outgoing utilization','zyxel.4728f.net.if.out.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.4728f.net.if.out.traffic[{#SNMPINDEX}]) * (last(zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36555','20','.1.3.6.1.2.1.31.1.1.1.11.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Outgoing unicast packages','zyxel.4728f.net.if.out.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were not addressed to a
multicast or broadcast address at this sub-layer, including
those that were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36556','20','.1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Outgoing traffic','zyxel.4728f.net.if.out.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the
interface, including framing characters.  This object is a
64-bit version of ifOutOctets.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36557','20','.1.3.6.1.2.1.31.1.1.1.12.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Outgoing multicast packages','zyxel.4728f.net.if.out.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
multicast address at this sub-layer, including those that
were discarded or not sent.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36558','20','.1.3.6.1.2.1.31.1.1.1.13.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Outgoing broadcast packages','zyxel.4728f.net.if.out.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of packets that higher-level protocols
requested be transmitted, and which were addressed to a
broadcast address at this sub-layer, including those that
were discarded or not sent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36559','20','.1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Operational status','zyxel.4728f.net.if.operstatus[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'233','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
The testing(3) state indicates that no operational
packets can be passed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36560','20','.1.3.6.1.4.1.890.1.5.8.46.23.1.1.5.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Link type','zyxel.4728f.net.if.link_type[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'231','','','0','','','','','2',NULL,'MIB:  ZYXEL-XGS4728F-MIB
Physical connection type','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36561','20','.1.3.6.1.2.1.2.2.1.2.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Interface name','zyxel.4728f.net.if.descr[{#SNMPINDEX}]','1m','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
A textual string containing information about the interface','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36562','15','','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Incoming utilization','zyxel.4728f.net.if.in.util[{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','',NULL,NULL,'last(zyxel.4728f.net.if.in.traffic[{#SNMPINDEX}]) * (last(zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]) <> 0) / 
( last(zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]) + (last(zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]) = 0) ) * 100','','0','','','','','2',NULL,'Interface utilization percentage','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36563','20','.1.3.6.1.2.1.31.1.1.1.7.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Incoming unicast packages','zyxel.4728f.net.if.in.ucastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were not addressed to a multicast
or broadcast address at this sub-layer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36564','20','.1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Incoming traffic','zyxel.4728f.net.if.in.traffic[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,
including framing characters.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36565','20','.1.3.6.1.2.1.31.1.1.1.8.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Incoming multicast packages','zyxel.4728f.net.if.in.multicastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a multicast
address at this sub-layer.  For a MAC layer protocol, this
includes both Group and Functional addresses.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36566','20','.1.3.6.1.2.1.31.1.1.1.9.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Incoming broadcast packages','zyxel.4728f.net.if.in.broadcastpkts[{#SNMPINDEX}]','1m','7d','365d','0','3','','packets/s','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of packets, delivered by this sub-layer to a
higher (sub-)layer, which were addressed to a broadcast
address at this sub-layer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36567','20','.1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Link speed','zyxel.4728f.net.if.highspeed[{#SNMPINDEX}]','1m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36568','20','.1.3.6.1.4.1.890.1.5.8.46.23.1.1.1.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Speed Duplex','zyxel.4728f.net.if.speed_duplex[{#SNMPINDEX}]','1m','7d','365d','0','3','','','','',NULL,'230','','','0','','','','','2',NULL,'MIB:  ZYXEL-XGS4728F-MIB
Transmission mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36569','20','.1.3.6.1.4.1.890.1.5.8.46.117.2.1.7.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','zyxel.4728f.sfp.ddm[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','0','','!{#ZYXEL.SFP.UNIT}','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Transceiver module DDM data ({#ZYXEL.SFP.DESCRIPTION}).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36570','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.7.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Date code','zyxel.4728f.sfp.datecode[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Transceiver module vendor''s manufacturing date code.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36571','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.4.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Part number','zyxel.4728f.sfp.part[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36572','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.6.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Revision','zyxel.4728f.sfp.revision[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Revision level for part number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36573','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.5.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Serial number','zyxel.4728f.sfp.serialnumber[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Serial number provided by transceiver module vendor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36574','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.2.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Status','zyxel.4728f.sfp.status[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','365d','0','3','','','','',NULL,'234','','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Transceiver module status.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36575','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.8.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Transceiver','zyxel.4728f.sfp.transceiver[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Transceiver module type names.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36576','20','.1.3.6.1.4.1.890.1.5.8.46.117.1.1.3.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: SFP {#SNMPINDEX}: Vendor','zyxel.4728f.sfp.vendor[{#SNMPINDEX}]','{$ZYXEL.LLD.SFP.UPDATE}','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
Transceiver module vendor name.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36577','20','.1.3.6.1.4.1.890.1.5.8.46.9.2.1.2.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Temperature "{#ZYXEL.TEMP.ID}"','zyxel.4728f.temp[{#SNMPINDEX}]','1m','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
The current temperature measured at this sensor','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36578','20','.1.3.6.1.4.1.890.1.5.8.46.9.3.1.2.{#SNMPINDEX}','10431','ZYXEL XGS-4728F: Nominal "{#ZYXEL.VOLT.NOMINAL}"','zyxel.4728f.volt[{#SNMPINDEX}]','1m','7d','365d','0','0','','V','','',NULL,NULL,'','','0','','','','','2',NULL,'MIB: ZYXEL-XGS4728F-MIB
The current voltage reading.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36579','0','','10291','Network interfaces WMI get','wmi.getall[root\cimv2,"select Name,Description,NetConnectionID,Speed,AdapterTypeId,NetConnectionStatus,GUID from win32_networkadapter where PhysicalAdapter=True and NetConnectionStatus>0"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Raw data of win32_networkadapter.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36583','0','','10291','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in["{#IFGUID}",dropped]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of incoming packets dropped on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36584','0','','10291','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in["{#IFGUID}",errors]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of incoming packets with errors on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36585','0','','10291','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in["{#IFGUID}"]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Incoming traffic on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36586','0','','10291','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out["{#IFGUID}",dropped]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of outgoing packets dropped on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36587','0','','10291','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out["{#IFGUID}",errors]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of outgoing packets with errors on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36588','0','','10291','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out["{#IFGUID}"]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Outgoing traffic on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36601','7','','10298','Network interfaces WMI get','wmi.getall[root\cimv2,"select Name,Description,NetConnectionID,Speed,AdapterTypeId,NetConnectionStatus,GUID from win32_networkadapter where PhysicalAdapter=True and NetConnectionStatus>0"]','1m','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Raw data of win32_networkadapter.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36605','7','','10298','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in["{#IFGUID}",dropped]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of incoming packets dropped on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36606','7','','10298','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in["{#IFGUID}",errors]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of incoming packets with errors on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36607','7','','10298','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in["{#IFGUID}"]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Incoming traffic on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36608','7','','10298','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out["{#IFGUID}",dropped]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of outgoing packets dropped on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36609','7','','10298','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out["{#IFGUID}",errors]','3m','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of outgoing packets with errors on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36610','7','','10298','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out["{#IFGUID}"]','3m','7d','365d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Outgoing traffic on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28306','18','','10254','Temperature discovery','temp.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'ENTITY-SENSORS-MIB::EntitySensorDataType discovery with celsius filter','0','30d','1','','28305','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28307','18','','10254','Fan discovery','fan.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'ENTITY-SENSORS-MIB::EntitySensorDataType discovery with rpm filter','0','30d','2','','28305','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28542','18','','10261','Remote Zabbix server: History index cache, % used','wcache.index.pused','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache. Percentage of used history index buffer.
History index cache is used to index values stored in history cache.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28543','18','','10261','Remote Zabbix server: Configuration cache, % used','rcache.buffer.pused','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Availability statistics of Zabbix configuration cache. Percentage of used buffer','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28544','18','','10261','Remote Zabbix server: Value cache, % used','vcache.buffer.pused','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Availability statistics of Zabbix value cache. Percentage of used buffer','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28545','18','','10261','Remote Zabbix server: Value cache hits','vcache.cache.hits','0','1w','365d','0','0','','vps','','',NULL,NULL,'','','0','','','','','0',NULL,'Effectiveness statistics of Zabbix value cache. Number of cache hits (history values taken from the cache)','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28546','18','','10261','Remote Zabbix server: Value cache misses','vcache.cache.misses','0','1w','365d','0','0','','vps','','',NULL,NULL,'','','0','','','','','0',NULL,'Effectiveness statistics of Zabbix value cache. Number of cache misses (history values taken from the database)','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28547','18','','10261','Remote Zabbix server: Value cache operating mode','vcache.cache.mode','0','1w','365d','0','3','','','','',NULL,'15','','','0','','','','','0',NULL,'Value cache operating mode','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28548','18','','10261','Remote Zabbix server: VMware cache, % used','vmware.buffer.pused','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Availability statistics of Zabbix vmware cache. Percentage of used buffer','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28549','18','','10261','Remote Zabbix server: History write cache, % used','wcache.history.pused','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache. Percentage of used history buffer.
History cache is used to store item values. A high number indicates performance problems on the database side.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28550','18','','10261','Remote Zabbix server: Number of processed values per second','wcache.values','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Total number of values processed by Zabbix server or Zabbix proxy, except unsupported items.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28551','18','','10261','Remote Zabbix server: Trend write cache, % used','wcache.trend.pused','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache. Percentage of used trend buffer.
Trend cache stores aggregate for the current hour for all items that receive data.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28552','18','','10261','Remote Zabbix server: Utilization of unreachable poller data collector processes, in %','process.unreachable_poller.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time unreachable poller processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28553','18','','10261','Remote Zabbix server: Number of processed numeric (float) values per second','wcache.values.float','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed float values.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28554','18','','10261','Remote Zabbix server: Number of processed log values per second','wcache.values.log','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed log values.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28555','18','','10261','Remote Zabbix server: Number of processed not supported values per second','wcache.values.not_supported','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of times item processing resulted in item becoming unsupported or keeping that state.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28556','18','','10261','Remote Zabbix server: Number of processed character values per second','wcache.values.str','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed character/string values.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28557','18','','10261','Remote Zabbix server: Number of processed text values per second','wcache.values.text','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed text values.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28558','18','','10261','Remote Zabbix server: Number of processed numeric (unsigned) values per second','wcache.values.uint','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed numeric (unsigned) values.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28559','18','','10261','Remote Zabbix server: Utilization of vmware data collector processes, in %','process.vmware_collector.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time vmware collector processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28560','18','','10261','Remote Zabbix server: Preprocessing queue','preprocessing_queue','0','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of values enqueued in the preprocessing queue.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28561','18','','10261','Remote Zabbix server: Utilization of alerter internal processes, in %','process.alerter.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time alerter processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28562','18','','10261','Remote Zabbix server: Utilization of ipmi manager internal processes, in %','process.ipmi_manager.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time ipmi manager processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28563','18','','10261','Remote Zabbix server: Utilization of alert manager internal processes, in %','process.alert_manager.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time alert manager processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28564','18','','10261','Remote Zabbix server: Utilization of configuration syncer internal processes, in %','process.configuration_syncer.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time configuration syncer processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28565','18','','10261','Remote Zabbix server: Utilization of discoverer data collector processes, in %','process.discoverer.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time discoverer processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28566','18','','10261','Remote Zabbix server: Utilization of escalator internal processes, in %','process.escalator.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time escalator processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28567','18','','10261','Remote Zabbix server: Utilization of history syncer internal processes, in %','process.history_syncer.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time history syncer processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28568','18','','10261','Remote Zabbix server: Utilization of housekeeper internal processes, in %','process.housekeeper.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time housekeeper processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28569','18','','10261','Remote Zabbix server: Utilization of http poller data collector processes, in %','process.http_poller.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time http poller processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28570','18','','10261','Remote Zabbix server: Utilization of icmp pinger data collector processes, in %','process.icmp_pinger.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time icmp pinger processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28571','18','','10261','Remote Zabbix server: Utilization of ipmi poller data collector processes, in %','process.ipmi_poller.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time ipmi poller processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28572','18','','10261','Remote Zabbix server: Utilization of timer internal processes, in %','process.timer.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time timer processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28573','18','','10261','Remote Zabbix server: Utilization of java poller data collector processes, in %','process.java_poller.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time java poller processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28574','18','','10261','Remote Zabbix server: Utilization of poller data collector processes, in %','process.poller.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time poller processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28575','18','','10261','Remote Zabbix server: Utilization of preprocessing manager internal processes, in %','process.preprocessing_manager.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time preprocessing manager processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28576','18','','10261','Remote Zabbix server: Utilization of preprocessing worker internal processes, in %','process.preprocessing_worker.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time preprocessing worker processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28577','18','','10261','Remote Zabbix server: Utilization of proxy poller data collector processes, in %','process.proxy_poller.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time proxy poller processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28578','18','','10261','Remote Zabbix server: Utilization of self-monitoring internal processes, in %','process.self-monitoring.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time self-monitoring processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28579','18','','10261','Remote Zabbix server: Utilization of snmp trapper data collector processes, in %','process.snmp_trapper.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time snmp trapper processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28580','18','','10261','Remote Zabbix server: Utilization of task manager internal processes, in %','process.task_manager.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time task manager processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28581','18','','10261','Remote Zabbix server: Utilization of trapper data collector processes, in %','process.trapper.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time trapper processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28582','18','','10261','Remote Zabbix server: Utilization of LLD manager internal processes, in %','process.lld_manager.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time lld manager processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28583','18','','10261','Remote Zabbix server: Utilization of LLD worker internal processes, in %','process.lld_worker.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time lld worker processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28584','18','','10261','Remote Zabbix server: LLD queue','lld_queue','0','1w','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of values enqueued in the low-level discovery processing queue.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28588','18','','10262','Utilization of vmware data collector processes, in %','process.vmware_collector.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28589','18','','10262','Number of processed numeric (unsigned) values per second','wcache.values.uint','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28590','18','','10262','Number of processed text values per second','wcache.values.text','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28591','18','','10262','Number of processed character values per second','wcache.values.str','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28592','18','','10262','Number of processed not supported values per second','wcache.values.not_supported','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28593','18','','10262','Number of processed log values per second','wcache.values.log','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28594','18','','10262','Number of processed numeric (float) values per second','wcache.values.float','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28595','18','','10262','Number of processed values per second','wcache.values','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28596','18','','10262','History index cache, % used','wcache.index.pused','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28597','18','','10262','History write cache, % used','wcache.history.pused','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28598','18','','10262','VMware cache, % used','vmware.buffer.pused','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28599','18','','10262','Configuration cache, % used','rcache.buffer.pused','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28600','18','','10262','Utilization of configuration syncer internal processes, in %','process.configuration_syncer.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28601','18','','10262','Utilization of data sender internal processes, in %','process.data_sender.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28602','18','','10262','Utilization of trapper data collector processes, in %','process.trapper.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28603','18','','10262','Utilization of task manager internal processes, in %','process.task_manager.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28604','18','','10262','Utilization of snmp trapper data collector processes, in %','process.snmp_trapper.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28605','18','','10262','Utilization of self-monitoring internal processes, in %','process.self-monitoring.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28606','18','','10262','Utilization of poller data collector processes, in %','process.poller.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28607','18','','10262','Utilization of java poller data collector processes, in %','process.java_poller.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28608','18','','10262','Utilization of ipmi poller data collector processes, in %','process.ipmi_poller.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28609','18','','10262','Utilization of ipmi manager internal processes, in %','process.ipmi_manager.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28610','18','','10262','Utilization of icmp pinger data collector processes, in %','process.icmp_pinger.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28611','18','','10262','Utilization of http poller data collector processes, in %','process.http_poller.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28612','18','','10262','Utilization of housekeeper internal processes, in %','process.housekeeper.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28613','18','','10262','Utilization of history syncer internal processes, in %','process.history_syncer.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28614','18','','10262','Utilization of heartbeat sender internal processes, in %','process.heartbeat_sender.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28615','18','','10262','Utilization of discoverer data collector processes, in %','process.discoverer.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28616','18','','10262','Utilization of unreachable poller data collector processes, in %','process.unreachable_poller.avg.busy','0','1w','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28688','18','','10263','Transactions: Max idle transaction time','pgsql.transactions.idle','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Current max idle transaction time','0','30d','0','','28683','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28689','18','','10263','Transactions: Max active transaction time','pgsql.transactions.active','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Current max active transaction time','0','30d','0','','28683','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28690','18','','10263','Transactions: Max prepared transaction time','pgsql.transactions.prepared','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Current max prepared transaction time','0','30d','0','','28683','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28691','18','','10263','Transactions: Max waiting transaction time','pgsql.transactions.waiting','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Current max waiting transaction time','0','30d','0','','28683','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28692','18','','10263','WAL: Segments count','pgsql.wal.count','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of WAL segments','0','30d','0','','28686','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28693','18','','10263','Bgwriter: Buffers allocated per second','pgsql.bgwriter.buffers_alloc.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of buffers allocated','0','30d','0','','28682','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28694','18','','10263','Bgwriter: Buffers written directly by a backend per second','pgsql.bgwriter.buffers_backend.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of buffers written directly by a backend','0','30d','0','','28682','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28695','18','','10263','Bgwriter: Checkpoint write time','pgsql.bgwriter.checkpoint_write_time','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Total amount of time that has been spent in the portion of checkpoint processing where files are written to disk, in milliseconds','0','30d','0','','28682','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28696','18','','10263','Bgwriter: Buffers backend fsync per second','pgsql.bgwriter.buffers_backend_fsync.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times a backend had to execute its own fsync call (normally the background writer handles those even when the backend does its own write)','0','30d','0','','28682','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28697','18','','10263','Bgwriter: Buffers written during checkpoints per second','pgsql.bgwriter.buffers_checkpoint.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of buffers written during checkpoints','0','30d','0','','28682','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28698','18','','10263','Bgwriter: Buffers written by the background writer per second','pgsql.bgwriter.buffers_clean.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of buffers written by the background writer','0','30d','0','','28682','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28699','18','','10263','Bgwriter: Requested checkpoints per second','pgsql.bgwriter.checkpoints_req.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of requested checkpoints that have been performed','0','30d','0','','28682','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28700','18','','10263','Bgwriter: Scheduled checkpoints per second','pgsql.bgwriter.checkpoints_timed.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of scheduled checkpoints that have been performed','0','30d','0','','28682','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28701','18','','10263','Bgwriter: Checkpoint sync time','pgsql.bgwriter.checkpoint_sync_time','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Total amount of time that has been spent in the portion of checkpoint processing where files are synchronized to disk','0','30d','0','','28682','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28702','18','','10263','Bgwriter: Max written per second','pgsql.bgwriter.maxwritten_clean.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times the background writer stopped a cleaning scan because it had written too many buffers','0','30d','0','','28682','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28703','18','','10263','Connections sum: Waiting','pgsql.connections.sum.waiting','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of waiting connections
https://www.postgresql.org/docs/current/monitoring-stats.html#WAIT-EVENT-TABLE','0','30d','0','','28671','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28704','18','','10263','Connections sum: Active','pgsql.connections.sum.active','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections executing a query','0','30d','0','','28671','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28705','18','','10263','Connections sum: Idle','pgsql.connections.sum.idle','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections waiting for a new client command','0','30d','0','','28671','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28706','18','','10263','Connections sum: Idle in transaction','pgsql.connections.sum.idle_in_transaction','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections in a transaction state, but not executing a query','0','30d','0','','28671','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28707','18','','10263','Connections sum: Prepared','pgsql.connections.sum.prepared','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of prepared transactions
https://www.postgresql.org/docs/current/sql-prepare-transaction.html','0','30d','0','','28671','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28708','18','','10263','Connections sum: Total','pgsql.connections.sum.total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections','0','30d','0','','28671','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28709','18','','10263','Connections sum: Total %','pgsql.connections.sum.total_pct','0','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections in percentage','0','30d','0','','28671','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28710','18','','10263','WAL: Bytes written','pgsql.wal.write','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'WAL write in bytes','0','30d','0','','28686','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28715','18','','10263','DB {#DBNAME}: Detected conflicts per second','pgsql.dbstat.conflicts.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of queries canceled due to conflicts with recovery in this database','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28716','18','','10263','DB {#DBNAME}: Locks total','pgsql.locks.total["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of locks in the database','0','30d','0','','28672','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28717','18','','10263','DB {#DBNAME}: Sequential scans per second','pgsql.scans.seq.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of sequential scans in the database','0','30d','0','','28714','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28718','18','','10263','DB {#DBNAME}: Index scans per second','pgsql.scans.idx.rate["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of index scans in the database','0','30d','0','','28714','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28719','18','','10263','DB {#DBNAME}: Queries sum transaction time','pgsql.queries.tx.time_sum["{#DBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Sum transaction query time','0','30d','0','','28675','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28720','18','','10263','DB {#DBNAME}: Queries max transaction time','pgsql.queries.tx.time_max["{#DBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Max transaction query time','0','30d','0','','28675','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28721','18','','10263','DB {#DBNAME}: Queries slow transaction count','pgsql.queries.tx.slow_count["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Slow transaction query count','0','30d','0','','28675','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28722','18','','10263','DB {#DBNAME}: Queries sum query time','pgsql.queries.query.time_sum["{#DBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Sum query time','0','30d','0','','28675','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28723','18','','10263','DB {#DBNAME}: Queries max query time','pgsql.queries.query.time_max["{#DBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Max query time','0','30d','0','','28675','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28724','18','','10263','DB {#DBNAME}: Queries slow query count','pgsql.queries.query.slow_count["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Slow query count','0','30d','0','','28675','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28725','18','','10263','DB {#DBNAME}: Queries sum maintenance time','pgsql.queries.mro.time_sum["{#DBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Sum maintenance query time','0','30d','0','','28675','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28726','18','','10263','DB {#DBNAME}: Queries max maintenance time','pgsql.queries.mro.time_max["{#DBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Max maintenance query time','0','30d','0','','28675','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28727','18','','10263','DB {#DBNAME}: Queries slow maintenance count','pgsql.queries.mro.slow_count["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Slow maintenance query count','0','30d','0','','28675','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28728','18','','10263','DB {#DBNAME}: Disk blocks read per second','pgsql.dbstat.blks_read.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of disk blocks read in this database','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28729','18','','10263','DB {#DBNAME}: Detected deadlocks per second','pgsql.dbstat.deadlocks.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of detected deadlocks in this database','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28730','18','','10263','DB {#DBNAME}: Blocks hit per second','pgsql.dbstat.blks_hit.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of times disk blocks were found already in the buffer cache, so that a read was not necessary','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28731','18','','10263','DB {#DBNAME}: Frozen XID before avtovacuum %','pgsql.frozenxid.prc_before_av["{#DBNAME}"]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'reventing Transaction ID Wraparound Failures
https://www.postgresql.org/docs/current/routine-vacuuming.html#VACUUM-FOR-WRAPAROUND','0','30d','0','','28713','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28732','18','','10263','DB {#DBNAME}: Rollbacks per second','pgsql.dbstat.xact_rollback.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of transactions in this database that have been rolled back','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28733','18','','10263','DB {#DBNAME}: Commits per second','pgsql.dbstat.xact_commit.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of transactions in this database that have been committed','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28734','18','','10263','DB {#DBNAME}: Tuples updated per second','pgsql.dbstat.tup_updated.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of rows updated by queries in this database','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28735','18','','10263','DB {#DBNAME}: Tuples returned per second','pgsql.dbstat.tup_returned.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of rows updated by queries in this database','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28736','18','','10263','DB {#DBNAME}: Tuples inserted per second','pgsql.dbstat.tup_inserted.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of rows inserted by queries in this database','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28737','18','','10263','DB {#DBNAME}: Tuples fetched per second','pgsql.dbstat.tup_fetched.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of rows fetched by queries in this database','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28738','18','','10263','DB {#DBNAME}: Tuples deleted per second','pgsql.dbstat.tup_deleted.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of rows deleted by queries in this database','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28739','18','','10263','DB {#DBNAME}: Temp_files created per second','pgsql.dbstat.temp_files.rate["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of temporary files created by queries in this database','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28740','18','','10263','DB {#DBNAME}: Temp_bytes written per second','pgsql.dbstat.temp_bytes.rate["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total amount of data written to temporary files by queries in this database','0','30d','0','','28687','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28741','18','','10263','DB {#DBNAME}: Frozen XID before stop %','pgsql.frozenxid.prc_before_stop["{#DBNAME}"]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Preventing Transaction ID Wraparound Failures
https://www.postgresql.org/docs/current/routine-vacuuming.html#VACUUM-FOR-WRAPAROUND','0','30d','0','','28713','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28778','18','','10265','Apache: Workers starting up','apache.workers.starting','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in starting state','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28779','18','','10265','Apache: Workers slot with no current process','apache.workers.slot','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of slots with no current process','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28780','18','','10265','Apache: Workers sending reply','apache.workers.sending','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in sending state','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28781','18','','10265','Apache: Workers reading request','apache.workers.reading','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in reading state','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28782','18','','10265','Apache: Workers logging','apache.workers.logging','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in logging state','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28783','18','','10265','Apache: Workers keepalive (read)','apache.workers.keepalive','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in keepalive state','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28784','18','','10265','Apache: Workers idle cleanup','apache.workers.cleanup','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in cleanup state','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28785','18','','10265','Apache: Workers finishing','apache.workers.finishing','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in finishing state','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28786','18','','10265','Apache: Workers closing connection','apache.workers.closing','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in closing state','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28787','18','','10265','Apache: Workers DNS lookup','apache.workers.dnslookup','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in dnslookup state','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28788','18','','10265','Apache: Total workers idle','apache.workers_total.idle','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of idle worker threads/processes','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28789','18','','10265','Apache: Total workers busy','apache.workers_total.busy','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of busy worker threads/processes','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28790','18','','10265','Apache: Version','apache.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Service version','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28791','18','','10265','Apache: Uptime','apache.uptime','0','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'Service uptime in seconds','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28792','18','','10265','Apache: Total requests','apache.requests','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'A total number of accesses','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28793','18','','10265','Apache: Requests per second','apache.requests.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Calculated as change rate for ''Total requests'' stat.
ReqPerSec is not used, as it counts average since last Apache server start.','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28794','18','','10265','Apache: Bytes per second','apache.bytes.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Calculated as change rate for ''Total bytes'' stat.
BytesPerSec is not used, as it counts average since last Apache server start.','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28795','18','','10265','Apache: Total bytes','apache.bytes','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total bytes served','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28796','18','','10265','Apache: Workers waiting for connection','apache.workers.waiting','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in waiting state','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28797','18','','10265','Event MPM discovery','apache.mpm.event.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Additional metrics if event MPM is used
https://httpd.apache.org/docs/current/mod/event.html','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28798','18','','10265','Apache: Connections async closing','apache.connections[async_closing{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of async connections in closing state (only applicable to event MPM)','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28799','18','','10265','Apache: Connections async keep alive','apache.connections[async_keep_alive{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of async connections in keep-alive state (only applicable to event MPM)','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28800','18','','10265','Apache: Connections async writing','apache.connections[async_writing{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of async connections in writing state (only applicable to event MPM)','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28801','18','','10265','Apache: Connections total','apache.connections[total{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of total connections','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28802','18','','10265','Apache: Bytes per request','apache.bytes[per_request{#SINGLETON}]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Average number of client requests per second','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28803','18','','10265','Apache: Number of async processes','apache.process[num{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of async processes','0','30d','0','','28775','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28811','18','','10266','Nginx: Connections waiting','nginx.connections.waiting','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of idle client connections waiting for a request.','0','30d','0','','28804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28812','18','','10266','Nginx: Connections writing','nginx.connections.writing','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of connections where nginx is writing the response back to the client.','0','30d','0','','28804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28813','18','','10266','Nginx: Connections active','nginx.connections.active','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of active client connections including Waiting connections.','0','30d','0','','28804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28814','18','','10266','Nginx: Connections reading','nginx.connections.reading','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of connections where nginx is reading the request header.','0','30d','0','','28804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28815','18','','10266','Nginx: Connections handled per second','nginx.connections.handled.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of handled connections. Generally, the parameter value is the same as accepts unless some resource limits have been reached (for example, the worker_connections limit).','0','30d','0','','28804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28816','18','','10266','Nginx: Connections dropped per second','nginx.connections.dropped.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of dropped client connections.','0','30d','0','','28804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28817','18','','10266','Nginx: Connections accepted per second','nginx.connections.accepted.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of accepted client connections.','0','30d','0','','28804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28818','18','','10266','Nginx: Requests per second','nginx.requests.total.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of client requests.','0','30d','0','','28804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28819','18','','10266','Nginx: Requests total','nginx.requests.total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of client requests.','0','30d','0','','28804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28820','18','','10266','Nginx: Version','nginx.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28824','18','','10267','Nginx: Requests total','nginx.requests.total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of client requests.','0','30d','0','','28821','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28825','18','','10267','Nginx: Requests per second','nginx.requests.total.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of client requests.','0','30d','0','','28821','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28826','18','','10267','Nginx: Connections accepted per second','nginx.connections.accepted.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of accepted client connections.','0','30d','0','','28821','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28827','18','','10267','Nginx: Connections dropped per second','nginx.connections.dropped.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of dropped client connections.','0','30d','0','','28821','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28828','18','','10267','Nginx: Connections handled per second','nginx.connections.handled.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of handled connections. Generally, the parameter value is the same as accepts unless some resource limits have been reached (for example, the worker_connections limit).','0','30d','0','','28821','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28829','18','','10267','Nginx: Connections active','nginx.connections.active','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of active client connections including Waiting connections.','0','30d','0','','28821','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28830','18','','10267','Nginx: Connections reading','nginx.connections.reading','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of connections where nginx is reading the request header.','0','30d','0','','28821','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28831','18','','10267','Nginx: Connections waiting','nginx.connections.waiting','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of idle client connections waiting for a request.','0','30d','0','','28821','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28832','18','','10267','Nginx: Connections writing','nginx.connections.writing','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of connections where nginx is writing the response back to the client.','0','30d','0','','28821','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28833','18','','10267','Nginx: Version','nginx.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','28821','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28914','18','','10170','Performance: InnoDB buffer pool reads','mysql.innodb_buffer_pool_reads','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of logical reads that InnoDB could not satisfy from the buffer pool, and had to read directly from disk.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28915','18','','10170','Performance: InnoDB buffer pool read requests','mysql.innodb_buffer_pool_read_requests','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of logical read requests.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28916','18','','10170','Performance: InnoDB row lock time','mysql.innodb_row_lock_time','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'The total time spent in acquiring row locks for InnoDB tables, in milliseconds.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28917','18','','10170','Performance: InnoDB row lock time max','mysql.innodb_row_lock_time_max','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'The maximum time to acquire a row lock for InnoDB tables, in milliseconds.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28918','18','','10170','Performance: InnoDB row lock waits','mysql.innodb_row_lock_waits','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of times operations on InnoDB tables had to wait for a row lock.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28919','18','','10170','Connections: Max used connections','mysql.max_used_connections','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The maximum number of connections that have been in use simultaneously since the server started.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28920','18','','10170','Throughput: Questions per second','mysql.questions.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of statements executed by the server. This includes only statements sent to the server by clients and not statements executed within stored programs, unlike the Queries variable.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28921','18','','10170','Throughput: Queries per second','mysql.queries.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of statements executed by the server. This variable includes statements executed within stored programs, unlike the Questions variable.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28922','18','','10170','Performance: Slow queries per second','mysql.slow_queries.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of queries that have taken more than long_query_time seconds.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28923','18','','10170','Connections: Threads cached','mysql.threads_cached','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of threads in the thread cache.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28924','18','','10170','Connections: Threads connected','mysql.threads_connected','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of currently open connections.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28925','18','','10170','Connections: Threads created','mysql.threads_created','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. The cache miss rate can be calculated as Threads_created/Connections.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28926','18','','10170','Connections: Threads running','mysql.threads_running','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of threads that are not sleeping.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28927','18','','10170','Info: Uptime','mysql.uptime','0','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of seconds that the server has been up.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28928','18','','10170','Performance: InnoDB buffer pool pages total','mysql.innodb_buffer_pool_pages_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total size of the InnoDB buffer pool, in pages.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28929','18','','10170','Connections: Aborted clients per second','mysql.aborted_clients.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of connections that were aborted because the client died without closing the connection properly.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28930','18','','10170','Performance: InnoDB buffer pool pages free','mysql.innodb_buffer_pool_pages_free','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total size of the InnoDB buffer pool, in pages.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28931','18','','10170','Connections: Connections per second','mysql.connections.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of connection attempts (successful or not) to the MySQL server.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28932','18','','10170','Throughput: Bytes received','mysql.bytes_received.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of bytes received from all clients.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28933','18','','10170','Throughput: Bytes sent','mysql.bytes_sent.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of bytes sent to all clients.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28934','18','','10170','Throughput: Command Delete per second','mysql.com_delete.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_delete counter variable indicates the number of times the delete statement has been executed.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28935','18','','10170','Throughput: Command Insert per second','mysql.com_insert.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_insert counter variable indicates the number of times the insert statement has been executed.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28936','18','','10170','Throughput: Command Select per second','mysql.com_select.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_select counter variable indicates the number of times the select statement has been executed.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28937','18','','10170','Throughput: Command Update per second','mysql.com_update.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_update counter variable indicates the number of times the update statement has been executed.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28938','18','','10170','Connections: Connection errors accept per second','mysql.connection_errors_accept.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors that occurred during calls to accept() on the listening port.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28939','18','','10170','Connections: Aborted connections per second','mysql.aborted_connects.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of failed attempts to connect to the MySQL server.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28940','18','','10170','Connections: Connection errors internal per second','mysql.connection_errors_internal.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of refused connections due to internal server errors, for example out of memory errors, or failed thread starts.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28941','18','','10170','Connections: Connection errors max connections per second','mysql.connection_errors_max_connections.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of refused connections due to the max_connections limit being reached.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28942','18','','10170','Connections: Connection errors peer address per second','mysql.connection_errors_peer_address.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors while searching for the connecting client IP address.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28943','18','','10170','Connections: Connection errors select per second','mysql.connection_errors_select.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors during calls to select() or poll() on the listening port. The client would not necessarily have been rejected in these cases.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28944','18','','10170','Connections: Connection errors tcpwrap per second','mysql.connection_errors_tcpwrap.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections the libwrap library refused.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28945','18','','10170','Performance: Created tmp tables on disk','mysql.created_tmp_disk_tables','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of internal on-disk temporary tables created by the server while executing statements.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28946','18','','10170','Performance: Created tmp files on disk','mysql.created_tmp_files','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'How many temporary files mysqld has created.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28947','18','','10170','Performance: Created tmp tables on memory','mysql.created_tmp_tables','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of internal temporary tables created by the server while executing statements.','0','30d','0','','28913','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28952','18','','10170','Replication: Seconds Behind Master {#MASTERHOST}','mysql.seconds_behind_master["{#MASTERHOST}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of seconds that the slave SQL thread is behind processing the master binary log. A high number (or an increasing one) can indicate that the slave is unable to handle events from the master in a timely fashion.','0','30d','0','','28951','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28953','18','','10170','Replication: Slave IO Running {#MASTERHOST}','mysql.slave_io_running["{#MASTERHOST}"]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Whether the I/O thread for reading the master''s binary log is running. Normally, you want this to be Yes unless you have not yet started replication or have explicitly stopped it with STOP SLAVE.','0','30d','0','','28951','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28954','18','','10170','Replication: Slave SQL Running {#MASTERHOST}','mysql.slave_sql_running["{#MASTERHOST}"]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Whether the SQL thread for executing events in the relay log is running. As with the I/O thread, this should normally be Yes.','0','30d','0','','28951','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29009','18','','10270','CPU discovery','cpu.discovery[snmp]','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'This discovery will create set of per core CPU metrics from UCD-SNMP-MIB, using {#CPU.COUNT} in preprocessing. That''s the only reason why LLD is used.','0','30d','0','','28990','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29048','18','','10270','CPU utilization','system.cpu.util[snmp,{#SNMPINDEX}]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'CPU utilization in %','0','30d','0','','29017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29198','18','','10272','CPU utilization','system.cpu.util','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'CPU utilization in %','0','30d','0','','29099','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29347','18','','10278','CPU utilization','system.cpu.util','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'CPU utilization in %','0','30d','0','','29285','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29398','18','','10285','System local time','system.localtime[node_exporter]','0','7d','365d','0','0','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'System local time of the host.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29399','18','','10285','CPU steal time','system.cpu.steal[node_exporter]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of CPU ''stolen'' from this virtual machine by the hypervisor for other tasks (such as running another virtual machine).','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29400','18','','10285','Free swap space','system.swap.free[node_exporter]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in bytes.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29401','18','','10285','Total swap space','system.swap.total[node_exporter]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The total space of swap volume/file in bytes.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29402','18','','10285','Available memory','vm.memory.available[node_exporter]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Available memory, in Linux, available = free + buffers + cache. On other platforms calculation may vary. See also: https://www.zabbix.com/documentation/5.0/manual/appendix/items/vm.memory.size_params','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29403','18','','10285','Total memory','vm.memory.total[node_exporter]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total memory in Bytes','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29404','18','','10285','System boot time','system.boottime[node_exporter]','0','7d','365d','0','0','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29405','18','','10285','Context switches per second','system.cpu.switches[node_exporter]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29406','18','','10285','Interrupts per second','system.cpu.intr[node_exporter]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29407','18','','10285','CPU guest nice time','system.cpu.guest_nice[node_exporter]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Time spent running a niced guest (virtual CPU for guest operating systems under the control of the Linux kernel)','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29408','18','','10285','CPU guest time','system.cpu.guest[node_exporter]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Guest  time (time  spent  running  a  virtual  CPU  for  a  guest  operating  system)','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29409','18','','10285','CPU interrupt time','system.cpu.interrupt[node_exporter]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of time the CPU has been servicing hardware interrupts.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29410','18','','10285','CPU iowait time','system.cpu.iowait[node_exporter]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Amount of time the CPU has been waiting for I/O to complete.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29411','18','','10285','CPU nice time','system.cpu.nice[node_exporter]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that have been niced.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29412','18','','10285','CPU softirq time','system.cpu.softirq[node_exporter]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of time the CPU has been servicing software interrupts.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29413','18','','10285','CPU user time','system.cpu.user[node_exporter]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that are not niced.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29414','18','','10285','System name','system.name[node_exporter]','0','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29415','18','','10285','Version of node_exporter running','agent.version[node_exporter]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29416','18','','10285','CPU idle time','system.cpu.idle[node_exporter]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent doing nothing.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29417','18','','10285','Number of CPUs','system.cpu.num[node_exporter]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29418','18','','10285','Load average (15m avg)','system.cpu.load.avg15[node_exporter]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29419','18','','10285','Load average (5m avg)','system.cpu.load.avg5[node_exporter]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29420','18','','10285','Load average (1m avg)','system.cpu.load.avg1[node_exporter]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29421','18','','10285','System uptime','system.uptime[node_exporter]','0','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'System uptime in ''N days, hh:mm:ss'' format.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29422','18','','10285','Operating system architecture','system.sw.arch[node_exporter]','0','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Operating system architecture of the host.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29423','18','','10285','Number of open file descriptors','fd.open[node_exporter]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29424','18','','10285','Maximum number of open file descriptors','kernel.maxfiles[node_exporter]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29425','18','','10285','System description','system.descr[node_exporter]','0','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Labeled system information as provided by the uname system call.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29426','18','','10285','CPU system time','system.cpu.system[node_exporter]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running the kernel and its processes.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29429','18','','10285','Network interface discovery','net.if.discovery[node_exporter]','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of network interfaces. Requires node_exporter v0.18 and up.','0','30d','1','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29430','18','','10285','Mounted filesystem discovery','vfs.fs.discovery[node_exporter]','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types.','0','30d','1','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29431','18','','10285','Block devices discovery','vfs.dev.discovery[node_exporter]','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29436','18','','10285','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[node_exporter,"{#IFNAME}"]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29437','18','','10285','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[node_exporter,"{#IFNAME}"]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29438','18','','10285','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[node_exporter"{#IFNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29439','18','','10285','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[node_exporter,"{#IFNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29440','18','','10285','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[node_exporter,"{#IFNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29441','18','','10285','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[node_exporter,"{#IFNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29442','18','','10285','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[node_exporter,"{#IFNAME}"]','0','7d','0d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Sets value to 0 if metric is missing in node_exporter output.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29443','18','','10285','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[node_exporter,"{#IFNAME}"]','0','7d','0d','0','3','','','','',NULL,'78','','','0','','','','','2',NULL,'node_network_protocol_type protocol_type value of /sys/class/net/<iface>.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29444','18','','10285','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[node_exporter,"{#IFNAME}"]','0','7d','0','0','3','','','','',NULL,'20','','','0','','','','','2',NULL,'Indicates the interface RFC2863 operational state as a string.
Possible values are:"unknown", "notpresent", "down", "lowerlayerdown", "testing","dormant", "up".
Reference: https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-class-net','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29445','18','','10285','{#FSNAME}: Free space','vfs.fs.free[node_exporter,"{#FSNAME}"]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29446','18','','10285','{#FSNAME}: Total space','vfs.fs.total[node_exporter,"{#FSNAME}"]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total space in Bytes','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29447','18','','10285','{#FSNAME}: Free inodes in %','vfs.fs.inode.pfree[node_exporter,"{#FSNAME}"]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29448','18','','10285','{#DEVNAME}: Disk read rate','vfs.dev.read.rate[node_exporter,"{#DEVNAME}"]','0','7d','365d','0','0','','!r/s','','',NULL,NULL,'','','0','','','','','2',NULL,'r/s. The number (after merges) of read requests completed per second for the device.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29449','18','','10285','{#DEVNAME}: Disk write rate','vfs.dev.write.rate[node_exporter,"{#DEVNAME}"]','0','7d','365d','0','0','','!w/s','','',NULL,NULL,'','','0','','','','','2',NULL,'w/s. The number (after merges) of write requests completed per second for the device.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29450','18','','10285','{#DEVNAME}: Disk read time (rate)','vfs.dev.read.time.rate[node_exporter,"{#DEVNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of total read time counter. Used in r_await calculation','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29451','18','','10285','{#DEVNAME}: Disk write time (rate)','vfs.dev.write.time.rate[node_exporter,"{#DEVNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of total write time counter. Used in w_await calculation','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29452','18','','10285','{#DEVNAME}: Disk average queue size (avgqu-sz)','vfs.dev.queue_size[node_exporter,"{#DEVNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Current average disk queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29453','18','','10285','{#DEVNAME}: Disk utilization','vfs.dev.util[node_exporter,"{#DEVNAME}"]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'This item is the percentage of elapsed time that the selected disk drive was busy servicing read or writes requests.','0','30d','0','','29395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29687','18','','10301','RabbitMQ: Memory used','rabbitmq.node.mem_used','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory used in bytes','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29688','18','','10301','RabbitMQ: Disk free alarm','rabbitmq.node.disk_free_alarm','0','7d','365d','0','3','','','','',NULL,'83','','','0','','','','','0',NULL,'Does the node have disk alarm','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29691','18','','10301','RabbitMQ: Used file descriptors','rabbitmq.node.fd_used','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Used file descriptors','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29692','18','','10301','RabbitMQ: Uptime','rabbitmq.node.uptime','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Uptime in milliseconds','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29693','18','','10301','RabbitMQ: Memory alarm','rabbitmq.node.mem_alarm','0','7d','365d','0','3','','','','',NULL,'83','','','0','','','','','0',NULL,'Does the host has memory alarm','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29694','18','','10301','RabbitMQ: Memory limit','rabbitmq.node.mem_limit','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory usage high watermark in bytes','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29695','18','','10301','RabbitMQ: Is running','rabbitmq.node.running','0','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'Is the node running or not','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29696','18','','10301','RabbitMQ: Number of network partitions','rabbitmq.node.partitions','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of network partitions this node is seeing','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29697','18','','10301','RabbitMQ: Sockets available','rabbitmq.node.sockets_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'File descriptors available for use as sockets','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29698','18','','10301','RabbitMQ: Free disk space','rabbitmq.node.disk_free','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current free disk space','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29699','18','','10301','RabbitMQ: Runtime run queue','rabbitmq.node.run_queue','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Average number of Erlang processes waiting to run','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29700','18','','10301','RabbitMQ: Disk free limit','rabbitmq.node.disk_free_limit','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Disk free space limit in bytes','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29701','18','','10301','RabbitMQ: Sockets used','rabbitmq.node.sockets_used','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of file descriptors used as sockets','0','30d','0','','29654','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29703','18','','10301','Queues discovery','rabbitmq.queues.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Individual queue metrics','0','30d','1','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29720','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages','rabbitmq.queue.messages["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of the total messages in the queue','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29721','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered','rabbitmq.queue.messages.deliver["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages delivered in acknowledgement mode to consumers','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29722','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages redelivered','rabbitmq.queue.messages.redeliver["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29723','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages published per second','rabbitmq.queue.messages.publish.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of messages published','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29724','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages published','rabbitmq.queue.messages.publish["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29725','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered per second','rabbitmq.queue.messages.deliver_get.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of the sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29726','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered','rabbitmq.queue.messages.deliver_get["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29727','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered per second','rabbitmq.queue.messages.deliver.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages delivered in acknowledgement mode to consumers','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29728','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages acknowledged per second','rabbitmq.queue.messages.ack.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number per second of messages delivered to clients and acknowledged','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29729','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages per second','rabbitmq.queue.messages.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count per second of the total messages in the queue','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29730','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages acknowledged','rabbitmq.queue.messages.ack["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages delivered to clients and acknowledged','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29731','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages unacknowledged per second','rabbitmq.queue.messages_unacknowledged.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number per second of messages delivered to clients but not yet acknowledged','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29732','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages unacknowledged','rabbitmq.queue.messages_unacknowledged["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages delivered to clients but not yet acknowledged','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29733','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages ready per second','rabbitmq.queue.messages_ready.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number per second of messages ready to be delivered to clients','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29734','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages ready','rabbitmq.queue.messages_ready["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages ready to be delivered to clients','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29735','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Memory','rabbitmq.queue.memory["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Bytes of memory consumed by the Erlang process associated with the queue, including stack, heap and internal structures','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29736','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Consumers','rabbitmq.queue.consumers["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of consumers','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29737','18','','10301','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages redelivered per second','rabbitmq.queue.messages.redeliver.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','29661','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29746','18','','10302','RabbitMQ: Messages returned redeliver','rabbitmq.overview.messages.redeliver','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29747','18','','10302','RabbitMQ: Messages returned unroutable per second','rabbitmq.overview.messages.return_unroutable.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages returned to publisher as unroutable per second','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29748','18','','10302','RabbitMQ: Messages returned unroutable','rabbitmq.overview.messages.return_unroutable','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages returned to publisher as unroutable','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29749','18','','10302','RabbitMQ: Messages publish_out per second','rabbitmq.overview.messages.publish_out.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages published from this overview into queues per second,0,rabbitmq,total msgs pub out rate','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29750','18','','10302','RabbitMQ: Messages publish_out','rabbitmq.overview.messages.publish_out','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages published from this overview into queues','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29751','18','','10302','RabbitMQ: Messages publish_in per second','rabbitmq.overview.messages.publish_in.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages published from channels into this overview per sec','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29752','18','','10302','RabbitMQ: Messages publish_in','rabbitmq.overview.messages.publish_in','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages published from channels into this overview','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29753','18','','10302','RabbitMQ: Messages published per second','rabbitmq.overview.messages.publish.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages published per second','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29754','18','','10302','RabbitMQ: Messages published','rabbitmq.overview.messages.publish','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages published','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29755','18','','10302','RabbitMQ: Messages delivered per second','rabbitmq.overview.messages.deliver_get.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate per second of the sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29756','18','','10302','RabbitMQ: Messages delivered','rabbitmq.overview.messages.deliver_get','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29757','18','','10302','RabbitMQ: Messages confirmed per second','rabbitmq.overview.messages.confirm.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages confirmed per second','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29758','18','','10302','RabbitMQ: Messages confirmed','rabbitmq.overview.messages.confirm','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages confirmed','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29759','18','','10302','RabbitMQ: Messages acknowledged per second','rabbitmq.overview.messages.ack.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages delivered to clients and acknowledged per second','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29760','18','','10302','RabbitMQ: Messages acknowledged','rabbitmq.overview.messages.ack','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of messages delivered to clients and acknowledged','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29761','18','','10302','RabbitMQ: Messages unacknowledged','rabbitmq.overview.queue_totals.messages.unacknowledged','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of unacknowledged messages','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29762','18','','10302','RabbitMQ: Messages ready for delivery','rabbitmq.overview.queue_totals.messages.ready','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of messages ready for deliver','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29763','18','','10302','RabbitMQ: Messages total','rabbitmq.overview.queue_totals.messages','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of messages (ready plus unacknowledged)','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29764','18','','10302','RabbitMQ: Exchanges total','rabbitmq.overview.object_totals.exchanges','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of exchanges','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29765','18','','10302','RabbitMQ: Consumers total','rabbitmq.overview.object_totals.consumers','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of consumers','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29766','18','','10302','RabbitMQ: Queues total','rabbitmq.overview.object_totals.queues','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of queues','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29767','18','','10302','RabbitMQ: Channels total','rabbitmq.overview.object_totals.channels','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of channels','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29768','18','','10302','RabbitMQ: Connections total','rabbitmq.overview.object_totals.connections','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29769','18','','10302','RabbitMQ: Messages returned redeliver per second','rabbitmq.overview.messages.redeliver.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of subset of messages in deliver_get which had the redelivered flag set per second','0','30d','0','','29738','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29771','18','','10303','RabbitMQ: Number of network partitions','rabbitmq.node.partitions','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of network partitions this node is seeing','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29772','18','','10303','RabbitMQ: Uptime','rabbitmq.node.uptime','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Uptime in milliseconds','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29773','18','','10303','RabbitMQ: Disk free alarm','rabbitmq.node.disk_free_alarm','0','7d','365d','0','3','','','','',NULL,'83','','','0','','','','','0',NULL,'Does the node have disk alarm','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29774','18','','10303','RabbitMQ: Memory alarm','rabbitmq.node.mem_alarm','0','7d','365d','0','3','','','','',NULL,'83','','','0','','','','','0',NULL,'Does the host has memory alarm','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29775','18','','10303','RabbitMQ: Is running','rabbitmq.node.running','0','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'Is the node running or not','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29776','18','','10303','RabbitMQ: Sockets used','rabbitmq.node.sockets_used','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of file descriptors used as sockets','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29777','18','','10303','RabbitMQ: Sockets available','rabbitmq.node.sockets_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'File descriptors available for use as sockets','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29779','18','','10303','RabbitMQ: Runtime run queue','rabbitmq.node.run_queue','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Average number of Erlang processes waiting to run','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29780','18','','10303','RabbitMQ: Memory used','rabbitmq.node.mem_used','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory used in bytes','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29781','18','','10303','RabbitMQ: Disk free limit','rabbitmq.node.disk_free_limit','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Disk free space limit in bytes','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29782','18','','10303','RabbitMQ: Free disk space','rabbitmq.node.disk_free','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current free disk space','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29783','18','','10303','RabbitMQ: Used file descriptors','rabbitmq.node.fd_used','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Used file descriptors','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29784','18','','10303','RabbitMQ: Memory limit','rabbitmq.node.mem_limit','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory usage high watermark in bytes','0','30d','0','','29741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29785','18','','10302','Exchanges discovery','rabbitmq.exchanges.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Individual exchange metrics','0','30d','1','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29786','18','','10303','Queues discovery','rabbitmq.queues.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Individual queue metrics','0','30d','1','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29787','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages acknowledged','rabbitmq.exchange.messages.ack["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages delivered to clients and acknowledged','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29788','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages acknowledged per second','rabbitmq.exchange.messages.ack.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages delivered to clients and acknowledged per second','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29789','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages confirmed','rabbitmq.exchange.messages.confirm["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages confirmed','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29790','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages confirmed per second','rabbitmq.exchange.messages.confirm.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages confirmed per second','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29791','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages delivered','rabbitmq.exchange.messages.deliver_get["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29792','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages delivered per second','rabbitmq.exchange.messages.deliver_get.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of the sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29793','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages published','rabbitmq.exchange.messages.publish["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29794','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages published per second','rabbitmq.exchange.messages.publish.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages published per second','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29795','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_in','rabbitmq.exchange.messages.publish_in["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published from channels into this overview','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29796','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_in per second','rabbitmq.exchange.messages.publish_in.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages published from channels into this overview per sec','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29797','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_out','rabbitmq.exchange.messages.publish_out["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published from this overview into queues','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29798','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_out per second','rabbitmq.exchange.messages.publish_out.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages published from this overview into queues per second,0,rabbitmq,total msgs pub out rate','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29799','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages returned unroutable','rabbitmq.exchange.messages.return_unroutable["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages returned to publisher as unroutable','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29800','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages returned unroutable per second','rabbitmq.exchange.messages.return_unroutable.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages returned to publisher as unroutable per second','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29801','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages redelivered','rabbitmq.exchange.messages.redeliver["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29802','18','','10302','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages redelivered per second','rabbitmq.exchange.messages.redeliver.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of subset of messages in deliver_get which had the redelivered flag set per second','0','30d','0','','29739','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29803','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages','rabbitmq.queue.messages["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of the total messages in the queue','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29804','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered','rabbitmq.queue.messages.deliver["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages delivered in acknowledgement mode to consumers','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29805','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages redelivered','rabbitmq.queue.messages.redeliver["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29806','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages published per second','rabbitmq.queue.messages.publish.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of messages published','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29807','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages published','rabbitmq.queue.messages.publish["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29808','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered per second','rabbitmq.queue.messages.deliver_get.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of the sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29809','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered','rabbitmq.queue.messages.deliver_get["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29810','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered per second','rabbitmq.queue.messages.deliver.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages delivered in acknowledgement mode to consumers','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29811','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages acknowledged per second','rabbitmq.queue.messages.ack.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number per second of messages delivered to clients and acknowledged','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29812','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages per second','rabbitmq.queue.messages.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count per second of the total messages in the queue','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29813','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages acknowledged','rabbitmq.queue.messages.ack["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages delivered to clients and acknowledged','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29814','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages unacknowledged per second','rabbitmq.queue.messages_unacknowledged.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number per second of messages delivered to clients but not yet acknowledged','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29815','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages unacknowledged','rabbitmq.queue.messages_unacknowledged["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages delivered to clients but not yet acknowledged','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29816','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages ready per second','rabbitmq.queue.messages_ready.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number per second of messages ready to be delivered to clients','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29817','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages ready','rabbitmq.queue.messages_ready["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages ready to be delivered to clients','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29818','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Memory','rabbitmq.queue.memory["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Bytes of memory consumed by the Erlang process associated with the queue, including stack, heap and internal structures','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29819','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Consumers','rabbitmq.queue.consumers["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of consumers','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29820','18','','10303','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages redelivered per second','rabbitmq.queue.messages.redeliver.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','29745','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29821','18','','10261','Remote Zabbix server: Utilization of alert syncer internal processes, in %','process.alert_syncer.avg.busy','0','1w','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average percentage of time alert syncer processes have been busy in the last minute','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30000','18','','10300','RabbitMQ: Messages returned redeliver','rabbitmq.overview.messages.redeliver','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30001','18','','10300','RabbitMQ: Messages returned unroutable per second','rabbitmq.overview.messages.return_unroutable.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages returned to publisher as unroutable per second','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30002','18','','10300','RabbitMQ: Messages returned unroutable','rabbitmq.overview.messages.return_unroutable','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages returned to publisher as unroutable','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30003','18','','10300','RabbitMQ: Messages publish_out per second','rabbitmq.overview.messages.publish_out.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages published from this overview into queues per second,0,rabbitmq,total msgs pub out rate','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30004','18','','10300','RabbitMQ: Messages publish_out','rabbitmq.overview.messages.publish_out','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages published from this overview into queues','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30005','18','','10300','RabbitMQ: Messages publish_in per second','rabbitmq.overview.messages.publish_in.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages published from channels into this overview per sec','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30006','18','','10300','RabbitMQ: Messages publish_in','rabbitmq.overview.messages.publish_in','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages published from channels into this overview','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30007','18','','10300','RabbitMQ: Messages published per second','rabbitmq.overview.messages.publish.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages published per second','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30008','18','','10300','RabbitMQ: Messages published','rabbitmq.overview.messages.publish','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages published','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30009','18','','10300','RabbitMQ: Messages delivered per second','rabbitmq.overview.messages.deliver_get.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate per second of the sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30010','18','','10300','RabbitMQ: Messages delivered','rabbitmq.overview.messages.deliver_get','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30011','18','','10300','RabbitMQ: Messages confirmed per second','rabbitmq.overview.messages.confirm.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages confirmed per second','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30012','18','','10300','RabbitMQ: Messages confirmed','rabbitmq.overview.messages.confirm','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages confirmed','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30013','18','','10300','RabbitMQ: Messages acknowledged per second','rabbitmq.overview.messages.ack.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages delivered to clients and acknowledged per second','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30014','18','','10300','RabbitMQ: Messages acknowledged','rabbitmq.overview.messages.ack','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of messages delivered to clients and acknowledged','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30015','18','','10300','RabbitMQ: Messages unacknowledged','rabbitmq.overview.queue_totals.messages.unacknowledged','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of unacknowledged messages','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30016','18','','10300','RabbitMQ: Messages ready for delivery','rabbitmq.overview.queue_totals.messages.ready','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of messages ready for deliver','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30017','18','','10300','RabbitMQ: Messages total','rabbitmq.overview.queue_totals.messages','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of messages (ready plus unacknowledged)','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30018','18','','10300','RabbitMQ: Exchanges total','rabbitmq.overview.object_totals.exchanges','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of exchanges','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30019','18','','10300','RabbitMQ: Consumers total','rabbitmq.overview.object_totals.consumers','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of consumers','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30020','18','','10300','RabbitMQ: Queues total','rabbitmq.overview.object_totals.queues','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of queues','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30021','18','','10300','RabbitMQ: Channels total','rabbitmq.overview.object_totals.channels','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of channels','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30022','18','','10300','RabbitMQ: Connections total','rabbitmq.overview.object_totals.connections','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30023','18','','10300','RabbitMQ: Messages returned redeliver per second','rabbitmq.overview.messages.redeliver.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of subset of messages in deliver_get which had the redelivered flag set per second','0','30d','0','','29998','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30024','18','','10301','RabbitMQ: Management plugin version','rabbitmq.node.overview.management_version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of the management plugin in use','0','30d','0','','29653','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30025','18','','10301','RabbitMQ: RabbitMQ version','rabbitmq.node.overview.rabbitmq_version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of RabbitMQ on the node which processed this request','0','30d','0','','29653','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30026','18','','10300','Exchanges discovery','rabbitmq.exchanges.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Individual exchange metrics','0','30d','1','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30027','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages acknowledged','rabbitmq.exchange.messages.ack["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages delivered to clients and acknowledged','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30028','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages acknowledged per second','rabbitmq.exchange.messages.ack.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages delivered to clients and acknowledged per second','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30029','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages confirmed','rabbitmq.exchange.messages.confirm["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages confirmed','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30030','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages confirmed per second','rabbitmq.exchange.messages.confirm.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages confirmed per second','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30031','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages delivered','rabbitmq.exchange.messages.deliver_get["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30032','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages delivered per second','rabbitmq.exchange.messages.deliver_get.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of the sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30033','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages published','rabbitmq.exchange.messages.publish["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30034','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages published per second','rabbitmq.exchange.messages.publish.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages published per second','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30035','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_in','rabbitmq.exchange.messages.publish_in["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published from channels into this overview','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30036','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_in per second','rabbitmq.exchange.messages.publish_in.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages published from channels into this overview per sec','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30037','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_out','rabbitmq.exchange.messages.publish_out["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published from this overview into queues','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30038','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_out per second','rabbitmq.exchange.messages.publish_out.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages published from this overview into queues per second,0,rabbitmq,total msgs pub out rate','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30039','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages returned unroutable','rabbitmq.exchange.messages.return_unroutable["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages returned to publisher as unroutable','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30040','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages returned unroutable per second','rabbitmq.exchange.messages.return_unroutable.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages returned to publisher as unroutable per second','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30041','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages redelivered','rabbitmq.exchange.messages.redeliver["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30042','18','','10300','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages redelivered per second','rabbitmq.exchange.messages.redeliver.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of subset of messages in deliver_get which had the redelivered flag set per second','0','30d','0','','29999','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30044','18','','10303','RabbitMQ: Management plugin version','rabbitmq.node.overview.management_version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of the management plugin in use','0','30d','0','','30043','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30045','18','','10303','RabbitMQ: RabbitMQ version','rabbitmq.node.overview.rabbitmq_version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of RabbitMQ on the node which processed this request','0','30d','0','','30043','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30191','18','','10308','HAProxy: Uptime','haproxy.uptime','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30190','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30192','18','','10308','HAProxy: Version','haproxy.version','0','90d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30190','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30234','18','','10309','HAProxy: Uptime','haproxy.uptime','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30231','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30235','18','','10309','HAProxy: Version','haproxy.version','0','90d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30231','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30277','18','','10310','Redis: Blocked clients','redis.clients.blocked','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of connections waiting on a blocking call','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30278','18','','10310','Redis: TCP port','redis.server.tcp_port','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'TCP/IP listen port','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30279','18','','10310','Redis: Expired keys','redis.stats.expired_keys','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of key expiration events','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30280','18','','10310','Redis: Evicted keys','redis.stats.evicted_keys','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of evicted keys due to maxmemory limit','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30281','18','','10310','Redis: Uptime','redis.server.uptime','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of seconds since Redis server start','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30282','18','','10310','Redis: Redis mode','redis.server.redis_mode','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The server''s mode ("standalone", "sentinel" or "cluster")','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30283','18','','10310','Redis: Redis version','redis.server.redis_version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of the Redis server','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30284','18','','10310','Redis: Instantaneous operations per sec','redis.stats.instantaneous_ops.rate','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of commands processed per second','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30285','18','','10310','Redis: Process id','redis.server.process_id','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'PID of the server process','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30286','18','','10310','Redis: Replication role','redis.replication.role','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Value is "master" if the instance is replica of no one, or "slave" if the instance is a replica of some master instance. Note that a replica can be master of another replica (chained replication).','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30287','18','','10310','Redis: Replication backlog size','redis.replication.repl_backlog_size','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total size in bytes of the replication backlog buffer','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30288','18','','10310','Redis: Replication backlog history length','redis.replication.repl_backlog_histlen','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Amount of data in the backlog sync buffer','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30289','18','','10310','Redis: Instantaneous input bytes per second','redis.stats.instantaneous_input.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The network''s read rate per second in KB/sec','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30290','18','','10310','Redis: Keyspace hits','redis.stats.keyspace_hits','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of successful lookup of keys in the main dictionary','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30291','18','','10310','Redis: Instantaneous output bytes per second','redis.stats.instantaneous_output.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The network''s write rate per second in KB/sec','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30292','18','','10310','Redis: Replication backlog active','redis.replication.repl_backlog_active','0','7d','365d','0','3','','','','',NULL,'90','','','0','','','','','0',NULL,'Flag indicating replication backlog is active','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30293','18','','10310','Redis: Keyspace misses','redis.stats.keyspace_misses','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of failed lookup of keys in the main dictionary','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30294','18','','10310','Redis: Latest fork usec','redis.stats.latest_fork_usec','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Duration of the latest fork operation in microseconds','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30295','18','','10310','Redis: Migrate cached sockets','redis.stats.migrate_cached_sockets','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of sockets open for MIGRATE purposes','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30296','18','','10310','Redis: Pubsub channels','redis.stats.pubsub_channels','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Global number of pub/sub channels with client subscriptions','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30297','18','','10310','Redis: Pubsub patterns','redis.stats.pubsub_patterns','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Global number of pub/sub pattern with client subscriptions','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30298','18','','10310','Redis: Rejected connections','redis.stats.rejected_connections','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections rejected because of maxclients limit','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30299','18','','10310','Redis: Sync full','redis.stats.sync_full','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of full resyncs with replicas','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30300','18','','10310','Redis: Sync partial err','redis.stats.sync_partial_err','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of denied partial resync requests','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30301','18','','10310','Redis: Sync partial ok','redis.stats.sync_partial_ok','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of accepted partial resync requests','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30302','18','','10310','Redis: Total commands processed','redis.stats.total_commands_processed','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of commands processed by the server','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30303','18','','10310','Redis: Total connections received','redis.stats.total_connections_received','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections accepted by the server','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30304','18','','10310','Redis: Total net input bytes','redis.stats.total_net_input_bytes','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of bytes read from the network','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30305','18','','10310','Redis: Replication backlog first byte offset','redis.replication.repl_backlog_first_byte_offset','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The master offset of the replication backlog buffer','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30306','18','','10310','Redis: Connected slaves','redis.replication.connected_slaves','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connected slaves','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30307','18','','10310','Redis: Master replication offset','redis.replication.master_repl_offset','0','7d','365d','0','3','','B','','',NULL,'91','','','0','','','','','0',NULL,'Replication offset reported by the master','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30308','18','','10310','Redis: Memory used RSS','redis.memory.used_memory_rss','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of bytes that Redis allocated as seen by the operating system','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30309','18','','10310','Redis: Max input buffer','redis.clients.max_input_buffer','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The biggest input buffer among current client connections','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30310','18','','10310','Redis: Max output buffer','redis.clients.max_output_buffer','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The biggest output buffer among current client connections','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30311','18','','10310','Redis: Cluster enabled','redis.cluster.enabled','0','7d','365d','0','3','','','','',NULL,'90','','','0','','','','','0',NULL,'Indicate Redis cluster is enabled','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30312','18','','10310','Redis: Max clients','redis.config.maxclients','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Max number of connected clients at the same time.
Once the limit is reached Redis will close all the new connections sending an error "max number of clients reached".','0','30d','0','','30275','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30313','18','','10310','Redis: CPU sys','redis.cpu.sys','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'System CPU consumed by the Redis server','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30314','18','','10310','Redis: CPU sys children','redis.cpu.sys_children','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'System CPU consumed by the background processes','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30315','18','','10310','Redis: CPU user','redis.cpu.user','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'User CPU consumed by the Redis server','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30316','18','','10310','Redis: CPU user children','redis.cpu.user_children','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'User CPU consumed by the background processes','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30317','18','','10310','Redis: Memory fragmentation ratio','redis.memory.fragmentation_ratio','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'This ratio is an indication of memory mapping efficiency:
  — Value over 1.0 indicate that memory fragmentation is very likely. Consider restarting the Redis server so the operating system can recover fragmented memory, especially with a ratio over 1.5.
  — Value under 1.0 indicate that Redis likely has insufficient memory available. Consider optimizing memory usage or adding more RAM.

Note: If your peak memory usage is much higher than your current memory usage, the memory fragmentation ratio may be unreliable.

https://redis.io/topics/memory-optimization','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30318','18','','10310','Redis: Memory used','redis.memory.used_memory','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of bytes allocated by Redis using its allocator','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30319','18','','10310','Redis: Memory used Lua','redis.memory.used_memory_lua','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Amount of memory used by the Lua engine','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30320','18','','10310','Redis: Memory used peak','redis.memory.used_memory_peak','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Peak memory consumed by Redis (in bytes)','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30321','18','','10310','Redis: AOF current rewrite time sec','redis.persistence.aof_current_rewrite_time_sec','0','7d','365d','0','0','','s','','',NULL,'92','','','0','','','','','0',NULL,'Duration of the on-going AOF rewrite operation if any','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30322','18','','10310','Redis: Connected clients','redis.clients.connected','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of connected clients','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30323','18','','10310','Redis: AOF enabled','redis.persistence.aof_enabled','0','7d','365d','0','3','','','','',NULL,'90','','','0','','','','','0',NULL,'Flag indicating AOF logging is activated','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30324','18','','10310','Redis: AOF last bgrewrite status','redis.persistence.aof_last_bgrewrite_status','0','7d','365d','0','3','','','','',NULL,'89','','','0','','','','','0',NULL,'Status of the last AOF rewrite operation','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30325','18','','10310','Redis: AOF last rewrite time sec','redis.persistence.aof_last_rewrite_time_sec','0','7d','365d','0','0','','s','','',NULL,'92','','','0','','','','','0',NULL,'Duration of the last AOF rewrite','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30326','18','','10310','Redis: AOF last write status','redis.persistence.aof_last_write_status','0','7d','365d','0','3','','','','',NULL,'89','','','0','','','','','0',NULL,'Status of the last write operation to the AOF','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30327','18','','10310','Redis: AOF rewrite in progress','redis.persistence.aof_rewrite_in_progress','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Flag indicating a AOF rewrite operation is on-going','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30328','18','','10310','Redis: AOF rewrite scheduled','redis.persistence.aof_rewrite_scheduled','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Flag indicating an AOF rewrite operation will be scheduled once the on-going RDB save is complete','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30329','18','','10310','Redis: Dump loading','redis.persistence.loading','0','7d','365d','0','3','','','','',NULL,'90','','','0','','','','','0',NULL,'Flag indicating if the load of a dump file is on-going','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30330','18','','10310','Redis: RDB bgsave in progress','redis.persistence.rdb_bgsave_in_progress','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"1" if bgsave is in progress and "0" otherwise','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30331','18','','10310','Redis: RDB changes since last save','redis.persistence.rdb_changes_since_last_save','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of changes since the last background save','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30332','18','','10310','Redis: RDB current bgsave time sec','redis.persistence.rdb_current_bgsave_time_sec','0','7d','365d','0','0','','s','','',NULL,'92','','','0','','','','','0',NULL,'Duration of the on-going RDB save operation if any','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30333','18','','10310','Redis: RDB last bgsave status','redis.persistence.rdb_last_bgsave_status','0','7d','365d','0','3','','','','',NULL,'89','','','0','','','','','0',NULL,'Status of the last RDB save operation','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30334','18','','10310','Redis: RDB last bgsave time sec','redis.persistence.rdb_last_bgsave_time_sec','0','7d','365d','0','0','','s','','',NULL,'92','','','0','','','','','0',NULL,'Duration of the last bg_save operation','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30335','18','','10310','Redis: RDB last save time','redis.persistence.rdb_last_save_time','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Epoch-based timestamp of last successful RDB save','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30336','18','','10310','Redis: Total net output bytes','redis.stats.total_net_output_bytes','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of bytes written to the network','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30338','18','','10310','Keyspace discovery','redis.keyspace.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Individual keyspace metrics','0','30d','1','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30339','18','','10310','Version 4+ metrics discovery','redis.metrics.v4.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Additional metrics for versions 4+','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30340','18','','10310','Version 5+ metrics discovery','redis.metrics.v5.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Additional metrics for versions 5+','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30341','18','','10310','AOF metrics discovery','redis.persistence.aof.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If AOF is activated, additional metrics will be added','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30342','18','','10310','Replication metrics discovery','redis.replication.master.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If the instance is the master and the slaves are connected, additional metrics are provided','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30343','18','','10310','Slave metrics discovery','redis.replication.slave.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'If the instance is a replica, additional metrics are provided','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30348','18','','10310','DB {#DB}: Average TTL','redis.db.avg_ttl["{#DB}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Average TTL','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30349','18','','10310','DB {#DB}: Expires','redis.db.expires["{#DB}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of keys with an expiration','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30350','18','','10310','DB {#DB}: Keys','redis.db.keys["{#DB}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of keys','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30351','18','','10310','Redis: Active defrag running{#SINGLETON}','redis.memory.active_defrag_running[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Flag indicating if active defragmentation is active','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30352','18','','10310','Redis: RDB last CoW size{#SINGLETON}','redis.persistence.rdb_last_cow_size[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The size in bytes of copy-on-write allocations during the last RDB save operation','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30353','18','','10310','Redis: Expired time cap reached count{#SINGLETON}','redis.stats.expired_time_cap_reached_count[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30354','18','','10310','Redis: Expired stale %{#SINGLETON}','redis.stats.expired_stale_perc[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30355','18','','10310','Redis: Active defrag misses{#SINGLETON}','redis.stats.active_defrag_misses[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of aborted value reallocations started by the active defragmentation process','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30356','18','','10310','Redis: Active defrag key misses{#SINGLETON}','redis.stats.active_defrag_key_misses[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of keys that were skipped by the active defragmentation process','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30357','18','','10310','Redis: Active defrag key hits{#SINGLETON}','redis.stats.active_defrag_key_hits[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of keys that were actively defragmented','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30358','18','','10310','Redis: Active defrag hits{#SINGLETON}','redis.stats.active_defrag_hits[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of value reallocations performed by active the defragmentation process','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30359','18','','10310','Redis: Executable path{#SINGLETON}','redis.server.executable[{#SINGLETON}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The path to the server''s executable','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30360','18','','10310','Redis: Replication second offset{#SINGLETON}','redis.replication.second_repl_offset[{#SINGLETON}]','0','7d','365d','0','0','','B','','',NULL,'91','','','0','','','','','2',NULL,'Offset up to which replication IDs are accepted','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30361','18','','10310','Redis: AOF last CoW size{#SINGLETON}','redis.persistence.aof_last_cow_size[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The size in bytes of copy-on-write allocations during the last AOF rewrite operation','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30362','18','','10310','Redis: Lazyfree pending objects{#SINGLETON}','redis.memory.lazyfree_pending_objects[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of objects waiting to be freed (as a result of calling UNLINK, or FLUSHDB and FLUSHALL with the ASYNC option)','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30363','18','','10310','Redis: Memory used startup{#SINGLETON}','redis.memory.used_memory_startup[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Initial amount of memory consumed by Redis at startup in bytes','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30364','18','','10310','Redis: Memory used peak %{#SINGLETON}','redis.memory.used_memory_peak_perc[{#SINGLETON}]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'The percentage of used_memory_peak out of used_memory','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30365','18','','10310','Redis: Memory used overhead{#SINGLETON}','redis.memory.used_memory_overhead[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The sum in bytes of all overheads that the server allocated for managing its internal data structures','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30366','18','','10310','Redis: Memory used dataset{#SINGLETON}','redis.memory.used_memory_dataset[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The size in bytes of the dataset','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30367','18','','10310','Redis: Memory used dataset %{#SINGLETON}','redis.memory.used_memory_dataset_perc[{#SINGLETON}]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'The percentage of used_memory_dataset out of the net memory usage (used_memory minus used_memory_startup)','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30368','18','','10310','Redis: Total system memory{#SINGLETON}','redis.memory.total_system_memory[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The total amount of memory that the Redis host has','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30369','18','','10310','Redis: Max memory{#SINGLETON}','redis.memory.maxmemory[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Maximum amount of memory allocated to the Redisdb system','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30370','18','','10310','Redis: Max memory policy{#SINGLETON}','redis.memory.maxmemory_policy[{#SINGLETON}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The value of the maxmemory-policy configuration directive','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30371','18','','10310','Redis: Slave expires tracked keys{#SINGLETON}','redis.stats.slave_expires_tracked_keys[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of keys tracked for expiry purposes (applicable only to writable replicas)','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30372','18','','10310','Redis: Allocator active{#SINGLETON}','redis.memory.allocator_active[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30373','18','','10310','Redis: Memory clients normal{#SINGLETON}','redis.memory.mem_clients_normal[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30374','18','','10310','Redis: Memory RSS overhead ratio{#SINGLETON}','redis.memory.rss_overhead_ratio[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30375','18','','10310','Redis: Memory RSS overhead bytes{#SINGLETON}','redis.memory.rss_overhead_bytes[{#SINGLETON}]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30376','18','','10310','Redis: Memory replication backlog{#SINGLETON}','redis.memory.replication_backlog[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30377','18','','10310','Redis: Memory number of cached scripts{#SINGLETON}','redis.memory.number_of_cached_scripts[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30378','18','','10310','Redis: Memory not counted for evict{#SINGLETON}','redis.memory.not_counted_for_evict[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30379','18','','10310','Redis: Memory clients slaves{#SINGLETON}','redis.memory.mem_clients_slaves[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30380','18','','10310','Redis: Memory AOF buffer{#SINGLETON}','redis.memory.mem_aof_buffer[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Size of the AOF buffer','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30381','18','','10310','Redis: Allocator allocated{#SINGLETON}','redis.memory.allocator_allocated[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30382','18','','10310','Redis: Memory fragmentation bytes{#SINGLETON}','redis.memory.fragmentation_bytes[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30383','18','','10310','Redis: Allocator RSS ratio{#SINGLETON}','redis.memory.allocator_rss_ratio[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30384','18','','10310','Redis: Allocator RSS bytes{#SINGLETON}','redis.memory.allocator_rss_bytes[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30385','18','','10310','Redis: Allocator resident{#SINGLETON}','redis.memory.allocator_resident[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30386','18','','10310','Redis: Allocator fragmentation ratio{#SINGLETON}','redis.memory.allocator_frag_ratio[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30387','18','','10310','Redis: Allocator fragmentation bytes{#SINGLETON}','redis.memory.allocator_frag_bytes[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30388','18','','10310','Redis: Memory used scripts{#SINGLETON}','redis.memory.used_memory_scripts[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30389','18','','10310','Redis: AOF base size{#SINGLETON}','redis.persistence.aof_base_size[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'AOF file size on latest startup or rewrite','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30390','18','','10310','Redis: AOF buffer length{#SINGLETON}','redis.persistence.aof_buffer_length[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Size of the AOF buffer','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30391','18','','10310','Redis: AOF current size{#SINGLETON}','redis.persistence.aof_current_size[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'AOF current file size','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30392','18','','10310','Redis: AOF delayed fsync{#SINGLETON}','redis.persistence.aof_delayed_fsync[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Delayed fsync counter','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30393','18','','10310','Redis: AOF pending background I/O fsync{#SINGLETON}','redis.persistence.aof_pending_bio_fsync[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of fsync pending jobs in background I/O queue','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30394','18','','10310','Redis: AOF pending rewrite{#SINGLETON}','redis.persistence.aof_pending_rewrite[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,'90','','','0','','','','','2',NULL,'Flag indicating an AOF rewrite operation will','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30395','18','','10310','Redis: AOF rewrite buffer length{#SINGLETON}','redis.persistence.aof_rewrite_buffer_length[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Size of the AOF rewrite buffer','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30396','18','','10310','Redis slave {#SLAVE_IP}:{#SLAVE_PORT}: Replication lag in bytes','redis.replication.lag_bytes["{#SLAVE_IP}:{#SLAVE_PORT}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Replication lag in bytes','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30397','18','','10310','Redis: Master host{#SINGLETON}','redis.replication.master_host[{#SINGLETON}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Host or IP address of the master','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30398','18','','10310','Redis: Master last I/O seconds ago{#SINGLETON}','redis.replication.master_last_io_seconds_ago[{#SINGLETON}]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of seconds since the last interaction with master','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30399','18','','10310','Redis: Master link status{#SINGLETON}','redis.replication.master_link_status[{#SINGLETON}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Status of the link (up/down)','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30400','18','','10310','Redis: Master port{#SINGLETON}','redis.replication.master_port[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Master listening TCP port','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30401','18','','10310','Redis: Master sync in progress{#SINGLETON}','redis.replication.master_sync_in_progress[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Indicate the master is syncing to the replica','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30402','18','','10310','Redis: Slave priority{#SINGLETON}','redis.replication.slave_priority[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The priority of the instance as a candidate for failover','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30403','18','','10310','Redis: Slave priority{#SINGLETON}','redis.replication.slave_read_only[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Flag indicating if the replica is read-only','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30404','18','','10310','Redis: Slave replication offset{#SINGLETON}','redis.replication.slave_repl_offset[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The replication offset of the replica instance','0','30d','0','','30276','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30436','18','','10316','MySQL: InnoDB buffer pool reads','mysql.innodb_buffer_pool_reads','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of logical reads that InnoDB could not satisfy from the buffer pool, and had to read directly from the disk.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30437','18','','10316','MySQL: InnoDB buffer pool reads per second','mysql.innodb_buffer_pool_reads.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of logical reads per second that InnoDB could not satisfy from the buffer pool, and had to read directly from the disk.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30438','18','','10316','MySQL: InnoDB row lock time','mysql.innodb_row_lock_time','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'The total time spent in acquiring row locks for InnoDB tables, in milliseconds.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30439','18','','10316','MySQL: InnoDB row lock time max','mysql.innodb_row_lock_time_max','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'The maximum time to acquire a row lock for InnoDB tables, in milliseconds.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30440','18','','10316','MySQL: InnoDB row lock waits','mysql.innodb_row_lock_waits','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times operations on InnoDB tables had to wait for a row lock.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30441','18','','10316','MySQL: Max used connections','mysql.max_used_connections','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The maximum number of connections that have been in use simultaneously since the server start.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30442','18','','10316','MySQL: Queries per second','mysql.queries.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of statements executed by the server. This variable includes statements executed within stored programs, unlike the Questions variable.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30443','18','','10316','MySQL: InnoDB buffer pool read requests','mysql.innodb_buffer_pool_read_requests','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of logical read requests.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30444','18','','10316','MySQL: Questions per second','mysql.questions.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of statements executed by the server. This includes only statements sent to the server by clients and not statements executed within stored programs, unlike the Queries variable.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30445','18','','10316','MySQL: Slow queries per second','mysql.slow_queries.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of queries that have taken more than long_query_time seconds.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30446','18','','10316','MySQL: Threads cached','mysql.threads_cached','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of threads in the thread cache.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30447','18','','10316','MySQL: Threads connected','mysql.threads_connected','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of currently open connections.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30449','18','','10316','MySQL: Threads running','mysql.threads_running','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of threads which are not sleeping.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30450','18','','10316','MySQL: Uptime','mysql.uptime','0','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of seconds that the server has been up.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30451','18','','10316','MySQL: InnoDB buffer pool read requests per second','mysql.innodb_buffer_pool_read_requests.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of logical read requests per second.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30452','18','','10316','MySQL: InnoDB buffer pool pages total','mysql.innodb_buffer_pool_pages_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total size of the InnoDB buffer pool, in pages.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30453','18','','10316','MySQL: Bytes received','mysql.bytes_received.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of bytes received from all clients.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30454','18','','10316','MySQL: Connection errors max connections per second','mysql.connection_errors_max_connections.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of refused connections due to the max_connections limit being reached.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30455','18','','10316','MySQL: Bytes sent','mysql.bytes_sent.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of bytes sent to all clients.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30456','18','','10316','MySQL: Command Delete per second','mysql.com_delete.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_delete counter variable indicates the number of times the delete statement has been executed.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30457','18','','10316','MySQL: Command Insert per second','mysql.com_insert.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_insert counter variable indicates the number of times the insert statement has been executed.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30458','18','','10316','MySQL: Command Select per second','mysql.com_select.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_select counter variable indicates the number of times the select statement has been executed.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30459','18','','10316','MySQL: Command Update per second','mysql.com_update.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_update counter variable indicates the number of times the update statement has been executed.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30460','18','','10316','MySQL: Connection errors accept per second','mysql.connection_errors_accept.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors that occurred during calls to accept() on the listening port.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30461','18','','10316','MySQL: Connection errors internal per second','mysql.connection_errors_internal.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of refused connections due to internal server errors, for example, out of memory errors, or failed thread starts.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30462','18','','10316','MySQL: Connection errors peer address per second','mysql.connection_errors_peer_address.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors while searching for the connecting client IP address.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30463','18','','10316','MySQL: InnoDB buffer pool pages free','mysql.innodb_buffer_pool_pages_free','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total size of the InnoDB buffer pool, in pages.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30464','18','','10316','MySQL: Connection errors select per second','mysql.connection_errors_select.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors during calls to select() or poll() on the listening port. The client would not necessarily have been rejected in these cases.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30465','18','','10316','MySQL: Connection errors tcpwrap per second','mysql.connection_errors_tcpwrap.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections the libwrap library has refused.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30466','18','','10316','MySQL: Connections per second','mysql.connections.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connection attempts (successful or not) to the MySQL server.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30470','18','','10316','MySQL: Aborted connections per second','mysql.aborted_connects.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of failed attempts to connect to the MySQL server.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30471','18','','10316','MySQL: Aborted clients per second','mysql.aborted_clients.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections that were aborted because the client died without closing the connection properly.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30476','18','','10316','MySQL: Replication Seconds Behind Master {#MASTERHOST}','mysql.seconds_behind_master["{#MASTERHOST}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of seconds that the slave SQL thread is behind processing the master binary log.
A high number (or an increasing one) can indicate that the slave is unable to handle events
from the master in a timely fashion.','0','30d','0','','30475','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30477','18','','10316','MySQL: Replication Slave IO Running {#MASTERHOST}','mysql.slave_io_running["{#MASTERHOST}"]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Whether the I/O thread for reading the master''s binary log is running. 
Normally, you want this to be Yes unless you have not yet started replication or have 
explicitly stopped it with STOP SLAVE.','0','30d','0','','30475','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30478','18','','10316','MySQL: Replication Slave SQL Running {#MASTERHOST}','mysql.slave_sql_running["{#MASTERHOST}"]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Whether the SQL thread for executing events in the relay log is running. 
As with the I/O thread, this should normally be Yes.','0','30d','0','','30475','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30484','18','','10317','MySQL: InnoDB row lock waits','mysql.innodb_row_lock_waits','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times operations on InnoDB tables had to wait for a row lock.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30485','18','','10317','MySQL: InnoDB buffer pool read requests','mysql.innodb_buffer_pool_read_requests','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of logical read requests.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30486','18','','10317','MySQL: InnoDB buffer pool read requests per second','mysql.innodb_buffer_pool_read_requests.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of logical read requests per second.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30487','18','','10317','MySQL: InnoDB buffer pool reads','mysql.innodb_buffer_pool_reads','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of logical reads that InnoDB could not satisfy from the buffer pool, and had to read directly from the disk.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30488','18','','10317','MySQL: InnoDB buffer pool reads per second','mysql.innodb_buffer_pool_reads.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of logical reads per second that InnoDB could not satisfy from the buffer pool, and had to read directly from the disk.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30489','18','','10317','MySQL: InnoDB row lock time','mysql.innodb_row_lock_time','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'The total time spent in acquiring row locks for InnoDB tables, in milliseconds.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30490','18','','10317','MySQL: InnoDB row lock time max','mysql.innodb_row_lock_time_max','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'The maximum time to acquire a row lock for InnoDB tables, in milliseconds.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30491','18','','10317','MySQL: Queries per second','mysql.queries.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of statements executed by the server. This variable includes statements executed within stored programs, unlike the Questions variable.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30492','18','','10317','MySQL: Max used connections','mysql.max_used_connections','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The maximum number of connections that have been in use simultaneously since the server start.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30493','18','','10317','MySQL: InnoDB buffer pool pages free','mysql.innodb_buffer_pool_pages_free','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total size of the InnoDB buffer pool, in pages.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30494','18','','10317','MySQL: Questions per second','mysql.questions.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of statements executed by the server. This includes only statements sent to the server by clients and not statements executed within stored programs, unlike the Queries variable.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30495','18','','10317','MySQL: Slow queries per second','mysql.slow_queries.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of queries that have taken more than long_query_time seconds.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30496','18','','10317','MySQL: Threads cached','mysql.threads_cached','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of threads in the thread cache.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30497','18','','10317','MySQL: Threads connected','mysql.threads_connected','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of currently open connections.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30499','18','','10317','MySQL: Threads running','mysql.threads_running','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of threads which are not sleeping.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30500','18','','10317','MySQL: InnoDB buffer pool pages total','mysql.innodb_buffer_pool_pages_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total size of the InnoDB buffer pool, in pages.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30503','18','','10317','MySQL: Command Select per second','mysql.com_select.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_select counter variable indicates the number of times the select statement has been executed.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30504','18','','10317','MySQL: Aborted clients per second','mysql.aborted_clients.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections that were aborted because the client died without closing the connection properly.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30505','18','','10317','MySQL: Aborted connections per second','mysql.aborted_connects.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of failed attempts to connect to the MySQL server.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30506','18','','10317','MySQL: Bytes received','mysql.bytes_received.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of bytes received from all clients.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30507','18','','10317','MySQL: Bytes sent','mysql.bytes_sent.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of bytes sent to all clients.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30508','18','','10317','MySQL: Command Delete per second','mysql.com_delete.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_delete counter variable indicates the number of times the delete statement has been executed.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30509','18','','10317','MySQL: Command Insert per second','mysql.com_insert.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_insert counter variable indicates the number of times the insert statement has been executed.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30510','18','','10317','MySQL: Command Update per second','mysql.com_update.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_update counter variable indicates the number of times the update statement has been executed.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30512','18','','10317','MySQL: Connection errors accept per second','mysql.connection_errors_accept.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors that occurred during calls to accept() on the listening port.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30513','18','','10317','MySQL: Connection errors internal per second','mysql.connection_errors_internal.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of refused connections due to internal server errors, for example, out of memory errors, or failed thread starts.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30514','18','','10317','MySQL: Connection errors max connections per second','mysql.connection_errors_max_connections.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of refused connections due to the max_connections limit being reached.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30515','18','','10317','MySQL: Connection errors peer address per second','mysql.connection_errors_peer_address.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors while searching for the connecting client IP address.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30516','18','','10317','MySQL: Connection errors select per second','mysql.connection_errors_select.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors during calls to select() or poll() on the listening port. The client would not necessarily have been rejected in these cases.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30517','18','','10317','MySQL: Connection errors tcpwrap per second','mysql.connection_errors_tcpwrap.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections the libwrap library has refused.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30518','18','','10317','MySQL: Connections per second','mysql.connections.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connection attempts (successful or not) to the MySQL server.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30519','18','','10317','MySQL: Uptime','mysql.uptime','0','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of seconds that the server has been up.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30524','18','','10317','MySQL: Replication Seconds Behind Master {#MASTER_HOST}','mysql.seconds_behind_master["{#MASTER_HOST}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The amount of seconds the slave SQL thread has been behind processing the master binary log.
A high number (or an increasing one) can indicate that the slave is unable to handle events
from the master in a timely fashion.','0','30d','0','','30523','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30525','18','','10317','MySQL: Replication Slave IO Running {#MASTER_HOST}','mysql.slave_io_running["{#MASTER_HOST}"]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Whether the I/O thread for reading the master''s binary log is running. 
Normally, you want this to be Yes unless you have not yet started a replication or have 
explicitly stopped it with STOP SLAVE.','0','30d','0','','30523','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30526','18','','10317','MySQL: Replication Slave SQL Running {#MASTER_HOST}','mysql.slave_sql_running["{#MASTER_HOST}"]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Whether the SQL thread for executing events in the relay log is running. 
As with the I/O thread, this should normally be Yes.','0','30d','0','','30523','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30532','18','','10318','Docker: Architecture','docker.architecture','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30533','18','','10318','Docker: Live restore enabled','docker.live_restore.enabled','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30534','18','','10318','Docker: Logging driver','docker.logging_driver','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30535','18','','10318','Docker: Memory limit enabled','docker.mem_limit.enabled','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30536','18','','10318','Docker: Memory total','docker.mem.total','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30537','18','','10318','Docker: Name','docker.name','0','1h','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30538','18','','10318','Docker: NCPU','docker.ncpu','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30539','18','','10318','Docker: Nfd','docker.nfd','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of used File Descriptors','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30540','18','','10318','Docker: NEvents listener','docker.nevents_listener','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30541','18','','10318','Docker: Kernel version','docker.kernel_version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30542','18','','10318','Docker: OomKill disabled','docker.oomkill.disabled','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30543','18','','10318','Docker: Operating system','docker.operating_system','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30544','18','','10318','Docker: OS type','docker.os_type','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30545','18','','10318','Docker: Pids limit enabled','docker.pids_limit.enabled','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30546','18','','10318','Docker: Docker root dir','docker.root_dir','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30547','18','','10318','Docker: Server version','docker.server_version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30548','18','','10318','Docker: Swap limit enabled','docker.swap_limit.enabled','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30549','18','','10318','Docker: Layers size','docker.layers_size','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30527','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30550','18','','10318','Docker: IPv4 Forwarding enabled','docker.ipv4_forwarding.enabled','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30551','18','','10318','Docker: Kernel memory enabled','docker.kernel_mem.enabled','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30552','18','','10318','Docker: CPU Set enabled','docker.cpu_set.enabled','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','0',NULL,'https://docs.docker.com/config/containers/resource_constraints/#configure-the-default-cfs-scheduler','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30553','18','','10318','Docker: Containers size','docker.containers_size','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30527','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30554','18','','10318','Docker: Containers paused','docker.containers.paused','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of containers paused on this host','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30555','18','','10318','Docker: Containers running','docker.containers.running','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of containers running on this host','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30556','18','','10318','Docker: Containers stopped','docker.containers.stopped','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of containers stopped on this host','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30557','18','','10318','Docker: Containers total','docker.containers.total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of containers on this host','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30558','18','','10318','Docker: CPU CFS Period enabled','docker.cpu_cfs_period.enabled','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','0',NULL,'https://docs.docker.com/config/containers/resource_constraints/#configure-the-default-cfs-scheduler','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30559','18','','10318','Docker: CPU CFS Quota enabled','docker.cpu_cfs_quota.enabled','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','0',NULL,'https://docs.docker.com/config/containers/resource_constraints/#configure-the-default-cfs-scheduler','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30560','18','','10318','Docker: CPU Shares enabled','docker.cpu_shares.enabled','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','0',NULL,'https://docs.docker.com/config/containers/resource_constraints/#configure-the-default-cfs-scheduler','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30561','18','','10318','Docker: Kernel memory TCP enabled','docker.kernel_mem_tcp.enabled','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30562','18','','10318','Docker: Debug enabled','docker.debug.enabled','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30563','18','','10318','Docker: Default runtime','docker.default_runtime','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30564','18','','10318','Docker: Storage driver','docker.driver','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Docker storage driver 
 https://docs.docker.com/storage/storagedriver/','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30565','18','','10318','Docker: Goroutines','docker.goroutines','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of goroutines','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30566','18','','10318','Docker: Images size','docker.images_size','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30527','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30567','18','','10318','Docker: Images available','docker.images.top_level','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of top-level images','0','30d','0','','30531','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30568','18','','10318','Docker: Images total','docker.images.total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of images with intermediate image layers','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30569','18','','10318','Docker: Cgroup driver','docker.cgroup_driver','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30529','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30570','18','','10318','Docker: Volumes size','docker.volumes_size','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30527','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30575','18','','10318','Container {#NAME}: Online CPUs','docker.container_stats.online_cpus["{#NAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30576','18','','10318','Container {#NAME}: Memory commit bytes','docker.container_stats.memory.commit_bytes["{#NAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30577','18','','10318','Container {#NAME}: Memory commit peak bytes','docker.container_stats.memory.commit_peak_bytes["{#NAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30578','18','','10318','Container {#NAME}: Memory maximum usage','docker.container_stats.memory.max_usage["{#NAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30579','18','','10318','Container {#NAME}: Memory private working set','docker.container_stats.memory.private_working_set["{#NAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30580','18','','10318','Container {#NAME}: Memory usage','docker.container_stats.memory.usage["{#NAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30581','18','','10318','Container {#NAME}: Created','docker.container_info.created["{#NAME}"]','0','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30582','18','','10318','Container {#NAME}: CPU total usage per second','docker.container_stats.cpu_usage.total.rate["{#NAME}"]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30583','18','','10318','Container {#NAME}: Networks bytes received per second','docker.networks.rx_bytes["{#NAME}"]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30584','18','','10318','Container {#NAME}: Networks incoming packets dropped per second','docker.networks.rx_dropped["{#NAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30585','18','','10318','Container {#NAME}: Networks errors received per second','docker.networks.rx_errors["{#NAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30586','18','','10318','Container {#NAME}: Networks packets received per second','docker.networks.rx_packets["{#NAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30587','18','','10318','Container {#NAME}: Networks bytes sent per second','docker.networks.tx_bytes["{#NAME}"]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30588','18','','10318','Container {#NAME}: Networks outgoing packets dropped per second','docker.networks.tx_dropped["{#NAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30589','18','','10318','Container {#NAME}: Networks errors sent per second','docker.networks.tx_errors["{#NAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30590','18','','10318','Container {#NAME}: CPU usermode usage per second','docker.container_stats.cpu_usage.user.rate["{#NAME}"]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30591','18','','10318','Container {#NAME}: Throttling periods','docker.container_stats.cpu_usage.throttling_periods["{#NAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of periods with throttling active','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30592','18','','10318','Container {#NAME}: Finished at','docker.container_info.finished["{#NAME}"]','0','7d','365d','0','0','','unixtime','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30593','18','','10318','Container {#NAME}: OOMKilled','docker.container_info.state.oomkilled["{#NAME}"]','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30594','18','','10318','Container {#NAME}: Image','docker.container_info.image["{#NAME}"]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30528','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30595','18','','10318','Container {#NAME}: Restart count','docker.container_info.restart_count["{#NAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30596','18','','10318','Container {#NAME}: Started at','docker.container_info.started["{#NAME}"]','0','7d','365d','0','0','','unixtime','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30597','18','','10318','Container {#NAME}: Dead','docker.container_info.state.dead["{#NAME}"]','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30598','18','','10318','Container {#NAME}: Error','docker.container_info.state.error["{#NAME}"]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30599','18','','10318','Container {#NAME}: Exit code','docker.container_info.state.exitcode["{#NAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30600','18','','10318','Container {#NAME}: Paused','docker.container_info.state.paused["{#NAME}"]','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30601','18','','10318','Container {#NAME}: Throttled time','docker.container_stats.cpu_usage.throttled_time["{#NAME}"]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Aggregate time the container was throttled for in nanoseconds','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30602','18','','10318','Container {#NAME}: Pid','docker.container_info.state.pid["{#NAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30603','18','','10318','Container {#NAME}: Restarting','docker.container_info.state.restarting["{#NAME}"]','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30604','18','','10318','Container {#NAME}: Running','docker.container_info.state.running["{#NAME}"]','0','7d','365d','0','3','','','','',NULL,'93','','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30605','18','','10318','Container {#NAME}: Status','docker.container_info.state.status["{#NAME}"]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30574','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30606','18','','10318','Container {#NAME}: CPU kernelmode usage per second','docker.container_stats.cpu_usage.kernel.rate["{#NAME}"]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30607','18','','10318','Container {#NAME}: Throttled periods','docker.container_stats.cpu_usage.throttled_periods["{#NAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of periods when the container hits its throttling limit','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30608','18','','10318','Container {#NAME}: Networks packets sent per second','docker.networks.tx_packets["{#NAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30573','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30609','18','','10318','Image {#NAME}: Created','docker.image.created["{#ID}"]','0','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30531','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30610','18','','10318','Image {#NAME}: Size','docker.image.size["{#ID}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30531','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30613','18','','10319','Memcached: Commands: FLUSH per second','memcached.commands.flush.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The flush_all command invalidates all items in the database. This operation incurs a performance penalty and shouldn’t take place in production, so check your debug scripts.','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30614','18','','10319','Memcached: Bytes used','memcached.stats.bytes','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current number of bytes used to store items.','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30615','18','','10319','Memcached: Uptime','memcached.uptime','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of seconds since Memcached server start','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30616','18','','10319','Memcached: New items per second','memcached.stats.total_items.rate','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of new items stored per second.','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30617','18','','10319','Memcached: Threads','memcached.stats.threads','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of worker threads requested','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30618','18','','10319','Memcached: Misses per second','memcached.stats.misses.rate','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of missed GET requests (items requested but not found) per second.','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30619','18','','10319','Memcached: Hits per second','memcached.stats.hits.rate','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of successful GET requests (items requested and found) per second.','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30620','18','','10319','Memcached: Evictions per second','memcached.stats.evictions.rate','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"An eviction is when an item that still has time to live is removed from the cache because a brand new item needs to be allocated.
The item is selected with a pseudo-LRU mechanism.
A high number of evictions coupled with a low hit rate means your application is setting a large number of keys that are never used again."','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30621','18','','10319','Memcached: Current number of items stored','memcached.stats.curr_items','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Current number of items stored by this instance.','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30622','18','','10319','Memcached: Written bytes per second','memcached.stats.bytes_written.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The network''s read rate per second in B/sec','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30623','18','','10319','Memcached: Read bytes per second','memcached.stats.bytes_read.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The network''s read rate per second in B/sec','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30624','18','','10319','Memcached: Process id','memcached.process_id','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'PID of the server process','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30625','18','','10319','Memcached: Commands: GET per second','memcached.commands.get.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of GET requests received by server per second.','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30626','18','','10319','Memcached: CPU user','memcached.cpu.user','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'User CPU consumed by the Memcached server','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30627','18','','10319','Memcached: CPU sys','memcached.cpu.sys','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'System CPU consumed by the Memcached server','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30628','18','','10319','Memcached: Throttled connections','memcached.connections.throttled.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times a client connection was throttled. When sending GETs in batch mode and the connection contains too many requests (limited by -R parameter) the connection might be throttled to prevent starvation.','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30629','18','','10319','Memcached: Connection structures','memcached.connections.structures','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of  connection structures allocated by the server','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30630','18','','10319','Memcached: New connections per second','memcached.connections.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections opened per second','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30631','18','','10319','Memcached: Queued connections per second','memcached.connections.queued.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times that memcached has hit its connections limit and disabled its listener','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30632','18','','10319','Memcached: Max connections','memcached.connections.max','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Max number of concurrent connections','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30633','18','','10319','Memcached: Open connections','memcached.connections.current','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of clients presently connected','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30634','18','','10319','Memcached: Maximum number of bytes','memcached.config.limit_maxbytes','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum number of bytes allowed in cache. You can adjust this setting via a config file or the command line while starting your Memcached server.','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30635','18','','10319','Memcached: Commands: SET per second','memcached.commands.set.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of SET requests received by server per second.','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30636','18','','10319','Memcached: Memcached version','memcached.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of the Memcached server','0','30d','0','','30612','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30642','18','','10320','MySQL: InnoDB buffer pool reads','mysql.innodb_buffer_pool_reads','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of logical reads that InnoDB could not satisfy from the buffer pool, and had to read directly from the disk.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30643','18','','10320','MySQL: InnoDB buffer pool reads per second','mysql.innodb_buffer_pool_reads.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of logical reads per second that InnoDB could not satisfy from the buffer pool, and had to read directly from the disk.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30644','18','','10320','MySQL: InnoDB row lock time','mysql.innodb_row_lock_time','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'The total time spent in acquiring row locks for InnoDB tables, in milliseconds.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30645','18','','10320','MySQL: InnoDB row lock time max','mysql.innodb_row_lock_time_max','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'The maximum time to acquire a row lock for InnoDB tables, in milliseconds.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30646','18','','10320','MySQL: InnoDB row lock waits','mysql.innodb_row_lock_waits','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times operations on InnoDB tables had to wait for a row lock.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30647','18','','10320','MySQL: Max used connections','mysql.max_used_connections','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The maximum number of connections that have been in use simultaneously since the server start.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30648','18','','10320','MySQL: Queries per second','mysql.queries.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of statements executed by the server. This variable includes statements executed within stored programs, unlike the Questions variable.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30649','18','','10320','MySQL: InnoDB buffer pool read requests','mysql.innodb_buffer_pool_read_requests','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of logical read requests.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30650','18','','10320','MySQL: Questions per second','mysql.questions.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of statements executed by the server. This includes only statements sent to the server by clients and not statements executed within stored programs, unlike the Queries variable.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30651','18','','10320','MySQL: Slow queries per second','mysql.slow_queries.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of queries that have taken more than long_query_time seconds.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30652','18','','10320','MySQL: Threads cached','mysql.threads_cached','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of threads in the thread cache.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30653','18','','10320','MySQL: Threads connected','mysql.threads_connected','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of currently open connections.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30655','18','','10320','MySQL: Threads running','mysql.threads_running','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of threads which are not sleeping.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30656','18','','10320','MySQL: Uptime','mysql.uptime','0','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of seconds that the server has been up.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30657','18','','10320','MySQL: InnoDB buffer pool read requests per second','mysql.innodb_buffer_pool_read_requests.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of logical read requests per second.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30658','18','','10320','MySQL: InnoDB buffer pool pages total','mysql.innodb_buffer_pool_pages_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total size of the InnoDB buffer pool, in pages.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30659','18','','10320','MySQL: Bytes received','mysql.bytes_received.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of bytes received from all clients.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30660','18','','10320','MySQL: Connection errors max connections per second','mysql.connection_errors_max_connections.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of refused connections due to the max_connections limit being reached.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30661','18','','10320','MySQL: Bytes sent','mysql.bytes_sent.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of bytes sent to all clients.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30662','18','','10320','MySQL: Command Delete per second','mysql.com_delete.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_delete counter variable indicates the number of times the delete statement has been executed.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30663','18','','10320','MySQL: Command Insert per second','mysql.com_insert.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_insert counter variable indicates the number of times the insert statement has been executed.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30664','18','','10320','MySQL: Command Select per second','mysql.com_select.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_select counter variable indicates the number of times the select statement has been executed.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30665','18','','10320','MySQL: Command Update per second','mysql.com_update.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Com_update counter variable indicates the number of times the update statement has been executed.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30666','18','','10320','MySQL: Connection errors accept per second','mysql.connection_errors_accept.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors that occurred during calls to accept() on the listening port.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30667','18','','10320','MySQL: Connection errors internal per second','mysql.connection_errors_internal.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of refused connections due to internal server errors, for example, out of memory errors, or failed thread starts.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30668','18','','10320','MySQL: Connection errors peer address per second','mysql.connection_errors_peer_address.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors while searching for the connecting client IP address.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30669','18','','10320','MySQL: InnoDB buffer pool pages free','mysql.innodb_buffer_pool_pages_free','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total size of the InnoDB buffer pool, in pages.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30670','18','','10320','MySQL: Connection errors select per second','mysql.connection_errors_select.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors during calls to select() or poll() on the listening port. The client would not necessarily have been rejected in these cases.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30671','18','','10320','MySQL: Connection errors tcpwrap per second','mysql.connection_errors_tcpwrap.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections the libwrap library has refused.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30672','18','','10320','MySQL: Connections per second','mysql.connections.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connection attempts (successful or not) to the MySQL server.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30676','18','','10320','MySQL: Aborted connections per second','mysql.aborted_connects.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of failed attempts to connect to the MySQL server.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30677','18','','10320','MySQL: Aborted clients per second','mysql.aborted_clients.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections that were aborted because the client died without closing the connection properly.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30682','18','','10320','MySQL: Replication Seconds Behind Master {#MASTER_HOST}','mysql.replication.seconds_behind_master["{#MASTER_HOST}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of seconds that the slave SQL thread is behind processing the master binary log.
A high number (or an increasing one) can indicate that the slave is unable to handle events
from the master in a timely fashion.','0','30d','0','','30681','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30683','18','','10320','MySQL: Replication Slave IO Running {#MASTER_HOST}','mysql.replication.slave_io_running["{#MASTER_HOST}"]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Whether the I/O thread for reading the master''s binary log is running. 
Normally, you want this to be Yes unless you have not yet started a replication or have 
explicitly stopped it with STOP SLAVE.','0','30d','0','','30681','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30684','18','','10320','MySQL: Replication Slave SQL Running {#MASTER_HOST}','mysql.replication.slave_sql_running["{#MASTER_HOST}"]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Whether the SQL thread for executing events in the relay log is running. 
As with the I/O thread, this should normally be Yes.','0','30d','0','','30681','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30686','18','','10321','Discrete sensors discovery','ipmi.discrete.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the discrete IPMI sensors.','0','30d','1','','30685','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30687','18','','10321','Threshold sensors discovery','ipmi.sensors.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of the threshold IPMI sensors.','0','30d','1','','30685','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30688','18','','10321','IPMI: {#SENSOR_ID}','ipmi.state_text[{#SENSOR_ID}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'It is a state of the discrete IPMI sensor.','0','30d','0','','30685','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30689','18','','10321','IPMI: {#SENSOR_ID}, {#SENSOR_UNIT}','ipmi.value[{#SENSOR_ID}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'It is a state of the threshold IPMI sensor.','0','30d','0','','30685','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30695','18','','10322','ES: Number of non-deleted documents','es.indices.docs.count','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of non-deleted documents across all primary shards assigned to the selected nodes.
This number is based on the documents in Lucene segments and may include the documents from nested fields.','0','30d','0','','30691','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30696','18','','10322','ES: Cluster uptime','es.nodes.jvm.max_uptime[{#ES.NODE}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Uptime duration in seconds since JVM has last started.','0','30d','0','','30691','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30697','18','','10322','ES: Total size of all file stores','es.nodes.fs.total_in_bytes','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The total size in bytes of all file stores across all selected nodes.','0','30d','0','','30691','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30698','18','','10322','ES: Total available size to JVM in all file stores','es.nodes.fs.available_in_bytes','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of bytes available to JVM in the file stores across all selected nodes.
Depending on OS or process-level restrictions, this number may be less than nodes.fs.free_in_byes. 
This is the actual amount of free disk space the selected Elasticsearch nodes can use.','0','30d','0','','30691','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30699','18','','10322','ES: Nodes with the master role','es.nodes.count.master','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of selected nodes with the master role.','0','30d','0','','30691','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30700','18','','10322','ES: Nodes with the ingest role','es.nodes.count.ingest','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of selected nodes with the ingest role.','0','30d','0','','30691','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30701','18','','10322','ES: Nodes with the data role','es.nodes.count.data','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of selected nodes with the data role.','0','30d','0','','30691','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30702','18','','10322','ES: Delayed unassigned shards','es.cluster.delayed_unassigned_shards','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of shards whose allocation has been delayed by the timeout settings.','0','30d','0','','30694','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30703','18','','10322','ES: Indices with shards assigned to nodes','es.indices.count','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of indices with shards assigned to the selected nodes.','0','30d','0','','30691','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30704','18','','10322','ES: Task max waiting in queue','es.cluster.task_max_waiting_in_queue','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'The time expressed in seconds since the earliest initiated task is waiting for being performed.','0','30d','0','','30694','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30705','18','','10322','ES: Cluster health status','es.cluster.status','0','7d','365d','0','3','','','','',NULL,'94','','','0','','','','','0',NULL,'Health status of the cluster, based on the state of its primary and replica shards. Statuses are:
green
All shards are assigned.
yellow
All primary shards are assigned, but one or more replica shards are unassigned. If a node in the cluster fails, some data could be unavailable until that node is repaired.
red
One or more primary shards are unassigned, so some data is unavailable. This can occur briefly during cluster startup as primary shards are assigned.','0','30d','0','','30694','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30706','18','','10322','ES: Number of relocating shards','es.cluster.relocating_shards','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of shards that are under relocation.','0','30d','0','','30694','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30707','18','','10322','ES: Number of pending tasks','es.cluster.number_of_pending_tasks','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of cluster-level changes that have not yet been executed.','0','30d','0','','30694','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30708','18','','10322','ES: Number of nodes','es.cluster.number_of_nodes','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of nodes within the cluster.','0','30d','0','','30694','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30709','18','','10322','ES: Number of data nodes','es.cluster.number_of_data_nodes','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of nodes that are dedicated to data nodes.','0','30d','0','','30694','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30710','18','','10322','ES: Number of initializing shards','es.cluster.initializing_shards','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of shards that are under initialization.','0','30d','0','','30694','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30711','18','','10322','ES: Inactive shards percentage','es.cluster.inactive_shards_percent_as_number','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The ratio of inactive shards in the cluster expressed as a percentage.','0','30d','0','','30694','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30712','18','','10322','ES: Number of unassigned shards','es.cluster.unassigned_shards','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of shards that are not allocated.','0','30d','0','','30694','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30718','18','','10322','ES {#ES.NODE}: Refresh thread pool active threads','es.node.thread_pool.refresh.active[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of active threads in the refresh thread pool.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30719','18','','10322','ES {#ES.NODE}: Total number of query','es.node.indices.search.query_total[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of query operations.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30720','18','','10322','ES {#ES.NODE}: Rate of queries','es.node.indices.search.query.rate[{#ES.NODE}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of query operations per second.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30721','18','','10322','ES {#ES.NODE}: Amount of JVM heap committed','es.node.jvm.mem.heap_committed_in_bytes[{#ES.NODE}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The amount of memory, in bytes, available for use by the heap.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30722','18','','10322','ES {#ES.NODE}: Maximum JVM memory available for use','es.node.jvm.mem.heap_max_in_bytes[{#ES.NODE}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The maximum amount of memory, in bytes, available for use by the heap.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30723','18','','10322','ES {#ES.NODE}: Amount of JVM heap currently in use','es.node.jvm.mem.heap_used_in_bytes[{#ES.NODE}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The memory, in bytes, currently in use by the heap.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30724','18','','10322','ES {#ES.NODE}: Percent of JVM heap currently in use','es.node.jvm.mem.heap_used_percent[{#ES.NODE}]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'The percentage of memory currently in use by the heap.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30725','18','','10322','ES {#ES.NODE}: Node uptime','es.node.jvm.uptime[{#ES.NODE}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'JVM uptime in seconds.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30726','18','','10322','ES {#ES.NODE}: Total available size','es.node.fs.total.available_in_bytes[{#ES.NODE}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of bytes available to this Java virtual machine on all file stores. 
Depending on OS or process level restrictions, this might appear less than fs.total.free_in_bytes. 
This is the actual amount of free disk space the Elasticsearch node can utilize.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30727','18','','10322','ES {#ES.NODE}: Refresh thread pool executor tasks completed','es.node.thread_pool.refresh.completed.rate[{#ES.NODE}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of tasks completed by the refresh thread pool executor.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30728','18','','10322','ES {#ES.NODE}: Time spent performing query','es.node.indices.search.query_time[{#ES.NODE}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Time in seconds spent performing query operations for the last measuring span.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30729','18','','10322','ES {#ES.NODE}: Refresh thread pool executor tasks rejected','es.node.thread_pool.refresh.rejected.rate[{#ES.NODE}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of tasks rejected by the refresh thread pool executor.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30730','18','','10322','ES {#ES.NODE}: Search thread pool active threads','es.node.thread_pool.search.active[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of active threads in the search thread pool.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30731','18','','10322','ES {#ES.NODE}: Search thread pool executor tasks completed','es.node.thread_pool.search.completed.rate[{#ES.NODE}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of tasks completed by the search thread pool executor.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30732','18','','10322','ES {#ES.NODE}: Search thread pool tasks in queue','es.node.thread_pool.search.queue[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of tasks in queue for the search thread pool.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30733','18','','10322','ES {#ES.NODE}: Search thread pool executor tasks rejected','es.node.thread_pool.search.rejected.rate[{#ES.NODE}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of tasks rejected by the search thread pool executor.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30734','18','','10322','ES {#ES.NODE}: Write thread pool active threads','es.node.thread_pool.write.active[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of active threads in the write thread pool.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30735','18','','10322','ES {#ES.NODE}: Write thread pool executor tasks completed','es.node.thread_pool.write.completed.rate[{#ES.NODE}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of tasks completed by the write thread pool executor.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30736','18','','10322','ES {#ES.NODE}: Write thread pool tasks in queue','es.node.thread_pool.write.queue[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of tasks in queue for the write thread pool.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30737','18','','10322','ES {#ES.NODE}: Refresh thread pool tasks in queue','es.node.thread_pool.refresh.queue[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of tasks in queue for the refresh thread pool.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30738','18','','10322','ES {#ES.NODE}: Current query operations','es.node.indices.search.query_current[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of query operations currently running.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30739','18','','10322','ES {#ES.NODE}: Total time spent performing query','es.node.indices.search.query_time_in_millis[{#ES.NODE}]','0','7d','365d','0','3','','ms','','',NULL,NULL,'','','0','','','','','2',NULL,'Time in milliseconds spent performing query operations.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30740','18','','10322','ES {#ES.NODE}: Time spent throttling operations','es.node.indices.indexing.throttle_time[{#ES.NODE}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Time in seconds spent throttling operations for the last measuring span.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30741','18','','10322','ES {#ES.NODE}: Number of open HTTP connections','es.node.http.current_open[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of currently open HTTP connections for the node.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30742','18','','10322','ES {#ES.NODE}: Rate of HTTP connections opened','es.node.http.opened.rate[{#ES.NODE}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of HTTP connections opened for the node per second.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30743','18','','10322','ES {#ES.NODE}: Total time spent on flushing indices to disk','es.node.indices.flush.total_time_in_millis[{#ES.NODE}]','0','7d','365d','0','3','','ms','','',NULL,NULL,'','','0','','','','','2',NULL,'Total time in milliseconds spent performing flush operations.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30744','18','','10322','ES {#ES.NODE}: Total number of index flushes to disk','es.node.indices.flush.total[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of flush operations.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30745','18','','10322','ES {#ES.NODE}: Current indexing operations','es.node.indices.indexing.index_current[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of indexing operations currently running.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30746','18','','10322','ES {#ES.NODE}: Total time spent performing indexing','es.node.indices.indexing.index_time_in_millis[{#ES.NODE}]','0','7d','365d','0','3','','ms','','',NULL,NULL,'','','0','','','','','2',NULL,'Total time in milliseconds spent performing indexing operations.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30747','18','','10322','ES {#ES.NODE}: Total number of indexing','es.node.indices.indexing.index_total[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of indexing operations.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30748','18','','10322','ES {#ES.NODE}: Time spent throttling merge operations','es.node.indices.merges.total_throttled_time[{#ES.NODE}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Time in seconds spent throttling merge operations for the last measuring span.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30749','18','','10322','ES {#ES.NODE}: Total size','es.node.fs.total.total_in_bytes[{#ES.NODE}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total size (in bytes) of all file stores.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30750','18','','10322','ES {#ES.NODE}: Time spent throttling recovery operations','es.node.indices.recovery.throttle_time[{#ES.NODE}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Time in seconds spent throttling recovery operations for the last measuring span.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30751','18','','10322','ES {#ES.NODE}: Rate of index refreshes','es.node.indices.refresh.rate[{#ES.NODE}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of refresh operations per second.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30752','18','','10322','ES {#ES.NODE}: Time spent performing refresh','es.node.indices.refresh.time[{#ES.NODE}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Time in seconds spent performing refresh operations for the last measuring span.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30753','18','','10322','ES {#ES.NODE}: Current fetch operations','es.node.indices.search.fetch_current[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of fetch operations currently running.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30754','18','','10322','ES {#ES.NODE}: Total time spent performing fetch','es.node.indices.search.fetch_time_in_millis[{#ES.NODE}]','0','7d','365d','0','3','','ms','','',NULL,NULL,'','','0','','','','','2',NULL,'Time in milliseconds spent performing fetch operations.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30755','18','','10322','ES {#ES.NODE}: Time spent performing fetch','es.node.indices.search.fetch_time[{#ES.NODE}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Time in seconds spent performing fetch operations for the last measuring span.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30756','18','','10322','ES {#ES.NODE}: Total number of fetch','es.node.indices.search.fetch_total[{#ES.NODE}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of fetch operations.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30757','18','','10322','ES {#ES.NODE}: Rate of fetch','es.node.indices.search.fetch.rate[{#ES.NODE}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of fetch operations per second.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30758','18','','10322','ES {#ES.NODE}: Write thread pool executor tasks rejected','es.node.thread_pool.write.rejected.rate[{#ES.NODE}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of tasks rejected by the write thread pool executor.','0','30d','0','','30693','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30831','18','','10323','ClickHouse: Write syscalls in fly','clickhouse.write','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of write (write, pwrite, io_getevents, etc.) syscalls in fly','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30832','18','','10323','ClickHouse: Total replication tasks in queue','clickhouse.replicas.sum.queue.size','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','30824','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30833','18','','10323','ClickHouse: New queries per second','clickhouse.query.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of queries to be interpreted and potentially executed. Does not include queries that failed to parse or were rejected due to AST size limits, quota limits or limits on the number of simultaneously running queries. May include internal queries initiated by ClickHouse itself. Does not count subqueries.','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30834','18','','10323','ClickHouse: Read syscalls in fly','clickhouse.read','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of read (read, pread, io_getevents, etc.) syscalls in fly','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30835','18','','10323','ClickHouse: Read bytes per second','clickhouse.read_bytes.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'"Number of bytes (the number of bytes before decompression) read from compressed sources (files, network)."','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30836','18','','10323','ClickHouse: ZooKeeper wait time','clickhouse.zookeper.wait.time','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Time spent in waiting for ZooKeeper operations.','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30837','18','','10323','ClickHouse: Replication lag across all tables','clickhouse.replicas.max.absolute.delay','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum replica queue delay relative to current time','0','30d','0','','30824','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30838','18','','10323','ClickHouse: Total number read-only Replicas','clickhouse.replicas.readonly.total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"Number of Replicated tables that are currently in readonly state 
due to re-initialization after ZooKeeper session loss 
or due to startup without ZooKeeper configured."','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30839','18','','10323','ClickHouse: Revision','clickhouse.revision','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Revision of the server.','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30840','18','','10323','ClickHouse: ZooKeeper exceptions per second','clickhouse.zookeper.exeptions.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of ZooKeeper exceptions that does not belong to user/hardware exceptions.','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30841','18','','10323','ClickHouse: New SELECT queries per second','clickhouse.select_query.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of SELECT queries to be interpreted and potentially executed. Does not include queries that failed to parse or were rejected due to AST size limits, quota limits or limits on the number of simultaneously running queries. May include internal queries initiated by ClickHouse itself. Does not count subqueries.','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30842','18','','10323','ClickHouse: ZooKeeper user exceptions per second','clickhouse.zookeper.user_exeptions.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of ZooKeeper exceptions caused by no znodes, bad version, node exists, node empty and no children for ephemeral.','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30843','18','','10323','ClickHouse: ZooKeeper sessions','clickhouse.zookeper.session','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of sessions (connections) to ZooKeeper. Should be no more than one.','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30844','18','','10323','ClickHouse: ZooKeeper requests','clickhouse.zookeper.request','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of requests to ZooKeeper in progress.','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30845','18','','10323','ClickHouse: ZooKeeper hardware exceptions per second','clickhouse.zookeper.hw_exeptions.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of ZooKeeper exceptions caused by session moved/expired, connection loss, marshalling error, operation timed out and invalid zhandle state.','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30846','18','','10323','ClickHouse: Uptime','clickhouse.uptime','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of seconds since ClickHouse server start','0','30d','0','','30824','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30847','18','','10323','ClickHouse: Current running queries','clickhouse.query.current','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of executing queries','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30848','18','','10323','ClickHouse: Current distribute connections','clickhouse.connections.distribute','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections to remote servers sending data that was INSERTed into Distributed tables.','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30849','18','','10323','ClickHouse: Current HTTP connections','clickhouse.connections.http','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections to HTTP server.','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30850','18','','10323','ClickHouse: Allocated bytes','clickhouse.jemalloc.allocated','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'"Total number of bytes allocated by the application."','0','30d','0','','30824','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30851','18','','10323','ClickHouse: Current Interserver connections','clickhouse.connections.interserver','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections from other replicas to fetch parts.','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30852','18','','10323','ClickHouse: Current MySQL connections','clickhouse.connections.mysql','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections to MySQL server.','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30853','18','','10323','ClickHouse: Current TCP connections','clickhouse.connections.tcp','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connections to TCP server (clients with native interface).','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30854','18','','10323','ClickHouse: Current distributed files to insert','clickhouse.distributed.files','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of pending files to process for asynchronous insertion into Distributed tables. Number of files for every shard is summed.','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30855','18','','10323','ClickHouse: Distributed connection fail with retry per second','clickhouse.distributed.files.fail.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"Connection failures after all retries in replicated DB connection pool"','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30856','18','','10323','ClickHouse: Distributed connection fail with retry per second','clickhouse.distributed.files.retry.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Connection retries in replicated DB connection pool','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30857','18','','10323','ClickHouse: New INSERT queries per second','clickhouse.insert_query.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of INSERT queries to be interpreted and potentially executed. Does not include queries that failed to parse or were rejected due to AST size limits, quota limits or limits on the number of simultaneously running queries. May include internal queries initiated by ClickHouse itself. Does not count subqueries.','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30858','18','','10323','ClickHouse: Delayed insert queries','clickhouse.insert.delay','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"Number of INSERT queries that are throttled due to high number of active data parts for partition in a MergeTree table."','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30859','18','','10323','ClickHouse: Inserted bytes per second','clickhouse.inserted_bytes.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of uncompressed bytes inserted in all tables.','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30860','18','','10323','ClickHouse: Inserted rows per second','clickhouse.inserted_rows.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of rows inserted in all tables.','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30861','18','','10323','ClickHouse: Mapped memory','clickhouse.jemalloc.mapped','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'"Total number of bytes in active extents mapped by the allocator."','0','30d','0','','30824','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30862','18','','10323','ClickHouse: Network errors per second','clickhouse.network.error.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Network errors (timeouts and connection failures) during query execution, background pool tasks and DNS cache update.','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30863','18','','10323','ClickHouse: Resident memory','clickhouse.jemalloc.resident','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'"Maximum number of bytes in physically resident data pages mapped by the allocator, 
comprising all pages dedicated to allocator metadata, pages backing active allocations, 
and unused dirty pages."','0','30d','0','','30824','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30864','18','','10323','ClickHouse: Max count of parts per partition across all tables','clickhouse.max.part.count.for.partition','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"Clickhouse MergeTree table engine split each INSERT query to partitions (PARTITION BY expression) and add one or more PARTS per INSERT inside each partition, 
after that background merge process run."','0','30d','0','','30824','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30865','18','','10323','ClickHouse: Memory used for queries','clickhouse.memory.tracking','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'"Total amount of memory (bytes) allocated in currently executing queries."','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30866','18','','10323','ClickHouse: Memory used for background merges','clickhouse.memory.tracking.background','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'"Total amount of memory (bytes) allocated in background processing pool (that is dedicated for background merges, mutations and fetches).
 Note that this value may include a drift when the memory was allocated in a context of background processing pool and freed in other context or vice-versa. This happens naturally due to caches for tables indexes and doesn''t indicate memory leaks."','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30867','18','','10323','ClickHouse: Memory used for background moves','clickhouse.memory.tracking.background.moves','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'"Total amount of memory (bytes) allocated in background processing pool (that is dedicated for background moves). Note that this value may include a drift when the memory was allocated in a context of background processing pool and freed in other context or vice-versa.
 This happens naturally due to caches for tables indexes and doesn''t indicate memory leaks."','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30868','18','','10323','ClickHouse: Memory used for merges','clickhouse.memory.tracking.merges','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'"Total amount of memory (bytes) allocated for background merges. Included in MemoryTrackingInBackgroundProcessingPool. Note that this value may include a drift when the memory was allocated in a context of background processing pool and freed in other context or vice-versa. 
This happens naturally due to caches for tables indexes and doesn''t indicate memory leaks."','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30869','18','','10323','ClickHouse: Memory used for background schedule pool','clickhouse.memory.tracking.schedule.pool','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'"Total amount of memory (bytes) allocated in background schedule pool (that is dedicated for bookkeeping tasks of Replicated tables)."','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30870','18','','10323','ClickHouse: Uncompressed bytes merged per second','clickhouse.merge_bytes.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Uncompressed bytes that were read for background merges','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30871','18','','10323','ClickHouse: Merged rows per second','clickhouse.merge_rows.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rows read for background merges.','0','30d','0','','30825','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30872','18','','10323','ClickHouse: Current running merges','clickhouse.merge.current','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of executing background merges','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30873','18','','10323','ClickHouse: ZooKeeper watches','clickhouse.zookeper.watch','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of watches (e.g., event subscriptions) in ZooKeeperr.','0','30d','0','','30826','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30874','18','','10323','Dictionaries','clickhouse.dictionaries.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Info about dictionaries','0','30d','1','','30830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30875','18','','10323','Replicas','clickhouse.replicas.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Info about replicas','0','30d','1','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30876','18','','10323','Tables','clickhouse.tables.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Info about tables','0','30d','1','','30828','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30877','18','','10323','ClickHouse: Dictionary {#NAME}: Bytes allocated','clickhouse.dictionary.bytes_allocated["{#NAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The amount of RAM the dictionary uses.','0','30d','0','','30830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30878','18','','10323','ClickHouse: Dictionary {#NAME}: Element count','clickhouse.dictionary.element_count["{#NAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of items stored in the dictionary.','0','30d','0','','30830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30879','18','','10323','ClickHouse: Dictionary {#NAME}: Load factor','clickhouse.dictionary.load_factor["{#NAME}"]','0','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'The percentage filled in the dictionary (for a hashed dictionary, the percentage filled in the hash table).','0','30d','0','','30830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30880','18','','10323','ClickHouse: {#DB}.{#TABLE}: Active replicas','clickhouse.replica.active_replicas["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of replicas of this table that have a session in ZooKeeper (i.e., the number of functioning replicas). (Have a non-zero value only where there is an active session with ZooKeeper).','0','30d','0','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30881','18','','10323','ClickHouse: {#DB}.{#TABLE}: Replica future parts','clickhouse.replica.future_parts["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of data parts that will appear as the result of INSERTs or merges that haven’t been done yet.','0','30d','0','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30882','18','','10323','ClickHouse: {#DB}.{#TABLE}: Replica queue inserts size','clickhouse.replica.inserts_in_queue["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of inserts of blocks of data that need to be made.','0','30d','0','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30883','18','','10323','ClickHouse: {#DB}.{#TABLE}: Replica readonly','clickhouse.replica.is_readonly["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,'95','','','0','','','','','2',NULL,'Whether the replica is in read-only mode.
This mode is turned on if the config doesn’t have sections with ZooKeeper, if an unknown error occurred when reinitializing sessions in ZooKeeper, and during session reinitialization in ZooKeeper.','0','30d','0','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30884','18','','10323','ClickHouse: {#DB}.{#TABLE}: Replica session expired','clickhouse.replica.is_session_expired["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,'95','','','0','','','','','2',NULL,'True if the ZooKeeper session expired','0','30d','0','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30885','18','','10323','ClickHouse: {#DB}.{#TABLE}: Replica lag','clickhouse.replica.lag["{#DB}.{#TABLE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Difference between log_max_index and log_pointer','0','30d','0','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30886','18','','10323','ClickHouse: {#DB}.{#TABLE}: Replica log max index','clickhouse.replica.log_max_index["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Maximum entry number in the log of general activity. (Have a non-zero value only where there is an active session with ZooKeeper).','0','30d','0','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30887','18','','10323','ClickHouse: {#DB}.{#TABLE}: Replica log pointer','clickhouse.replica.log_pointer["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Maximum entry number in the log of general activity that the replica copied to its execution queue, plus one. (Have a non-zero value only where there is an active session with ZooKeeper).','0','30d','0','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30888','18','','10323','ClickHouse: {#DB}.{#TABLE}: Replica queue merges size','clickhouse.replica.merges_in_queue["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of merges waiting to be made.','0','30d','0','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30889','18','','10323','ClickHouse: {#DB}.{#TABLE}: Replica parts to check','clickhouse.replica.parts_to_check["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of data parts in the queue for verification. A part is put in the verification queue if there is suspicion that it might be damaged.','0','30d','0','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30890','18','','10323','ClickHouse: {#DB}.{#TABLE}: Replica queue size','clickhouse.replica.queue_size["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Size of the queue for operations waiting to be performed.','0','30d','0','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30891','18','','10323','ClickHouse: {#DB}.{#TABLE}: Total replicas','clickhouse.replica.total_replicas["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of known replicas of this table. (Have a non-zero value only where there is an active session with ZooKeeper).','0','30d','0','','30823','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30892','18','','10323','ClickHouse: {#DB}: Bytes','clickhouse.db.bytes["{#DB}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Database size in bytes.','0','30d','0','','30828','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30893','18','','10323','ClickHouse: {#DB}.{#TABLE}: Bytes','clickhouse.table.bytes["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Table size in bytes. Database: {#DB}, table: {#TABLE}','0','30d','0','','30828','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30894','18','','10323','ClickHouse: {#DB}.{#TABLE}: Parts','clickhouse.table.parts["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of parts of the table. Database: {#DB}, table: {#TABLE}','0','30d','0','','30828','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30895','18','','10323','ClickHouse: {#DB}.{#TABLE}: Rows','clickhouse.table.rows["{#DB}.{#TABLE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of rows in the table. Database: {#DB}, table: {#TABLE}','0','30d','0','','30828','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30897','18','','10264','Apache: Workers reading request','apache.workers.reading','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in reading state','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30898','18','','10264','Apache: Workers waiting for connection','apache.workers.waiting','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in waiting state','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30899','18','','10264','Apache: Workers starting up','apache.workers.starting','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in starting state','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30900','18','','10264','Apache: Workers slot with no current process','apache.workers.slot','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of slots with no current process','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30901','18','','10264','Apache: Workers sending reply','apache.workers.sending','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in sending state','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30902','18','','10264','Apache: Total bytes','apache.bytes','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total bytes served','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30903','18','','10264','Apache: Bytes per second','apache.bytes.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Calculated as change rate for ''Total bytes'' stat.
BytesPerSec is not used, as it counts average since last Apache server start.','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30904','18','','10264','Apache: Workers keepalive (read)','apache.workers.keepalive','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in keepalive state','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30905','18','','10264','Apache: Workers finishing','apache.workers.finishing','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in finishing state','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30906','18','','10264','Apache: Workers DNS lookup','apache.workers.dnslookup','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in dnslookup state','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30907','18','','10264','Apache: Workers closing connection','apache.workers.closing','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in closing state','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30908','18','','10264','Apache: Workers idle cleanup','apache.workers.cleanup','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in cleanup state','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30909','18','','10264','Apache: Total workers idle','apache.workers_total.idle','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of idle worker threads/processes','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30910','18','','10264','Apache: Total workers busy','apache.workers_total.busy','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of busy worker threads/processes','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30911','18','','10264','Apache: Version','apache.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Service version','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30912','18','','10264','Apache: Uptime','apache.uptime','0','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'Service uptime in seconds','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30913','18','','10264','Apache: Requests per second','apache.requests.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Calculated as change rate for ''Total requests'' stat.
ReqPerSec is not used, as it counts average since last Apache server start.','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30914','18','','10264','Apache: Total requests','apache.requests','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'A total number of accesses','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30915','18','','10264','Apache: Workers logging','apache.workers.logging','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of workers in logging state','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30916','18','','10264','Event MPM discovery','apache.mpm.event.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Additional metrics if event MPM is used
https://httpd.apache.org/docs/current/mod/event.html','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30917','18','','10264','Apache: Bytes per request','apache.bytes[per_request{#SINGLETON}]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Average number of client requests per second','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30918','18','','10264','Apache: Connections async closing','apache.connections[async_closing{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of async connections in closing state (only applicable to event MPM)','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30919','18','','10264','Apache: Connections async keep alive','apache.connections[async_keep_alive{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of async connections in keep-alive state (only applicable to event MPM)','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30920','18','','10264','Apache: Connections async writing','apache.connections[async_writing{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of async connections in writing state (only applicable to event MPM)','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30921','18','','10264','Apache: Connections total','apache.connections[total{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of total connections','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30922','18','','10264','Apache: Number of async processes','apache.process[num{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of async processes','0','30d','0','','30896','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30927','18','','10324','Etcd: Open file descriptors','etcd.open.fds','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of open file descriptors.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30928','18','','10324','Etcd: Proposals applied per second','etcd.proposals.applied.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of consensus proposals applied.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30929','18','','10324','Etcd: Proposals committed per second','etcd.proposals.committed.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of consensus proposals committed.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30930','18','','10324','Etcd: Proposals failed per second','etcd.proposals.failed.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of failed proposals seen.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30931','18','','10324','Etcd: Proposals pending','etcd.proposals.pending','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of pending proposals to commit.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30932','18','','10324','Etcd: PUT per second','etcd.put.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of puts seen by this member per second.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30933','18','','10324','Etcd: Range per second','etcd.range.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of ranges seen by this member per second.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30934','18','','10324','Etcd: Reads per second','etcd.reads.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of reads action by (get/getRecursive), local to this member.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30935','18','','10324','Etcd: Client gRPC received bytes per second','etcd.network.grpc.received.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of bytes received from grpc clients per second','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30936','18','','10324','Etcd: Resident memory','etcd.res.bytes','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Resident memory size in bytes.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30937','18','','10324','Etcd: Server version','etcd.server.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of the Etcd server.','0','30d','0','','30926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30938','18','','10324','Etcd: Transaction per second','etcd.txn.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of transactions seen by this member per second.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30939','18','','10324','Etcd: Uptime','etcd.uptime','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Etcd server uptime.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30940','18','','10324','Etcd: Virtual memory','etcd.virtual.bytes','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Virtual memory size in bytes.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30941','18','','10324','Etcd: Writes per second','etcd.writes.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of writes (e.g. set/compareAndDelete) seen by this member.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30942','18','','10324','Etcd: Client gRPC sent bytes per second','etcd.network.grpc.sent.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of bytes sent from grpc clients per second','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30943','18','','10324','Etcd: Cluster version','etcd.cluster.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of the Etcd cluster.','0','30d','0','','30926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30944','18','','10324','Etcd: Maximum open file descriptors','etcd.max.fds','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Maximum number of open file descriptors.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30945','18','','10324','Etcd: Server has a leader','etcd.has.leader','0','7d','365d','0','3','','','','',NULL,'97','','','0','','','','','0',NULL,'Whether or not a leader exists. 1 is existence, 0 is not.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30946','18','','10324','Etcd: DB size','etcd.db.size','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total size of the underlying database.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30947','18','','10324','Etcd: Deletes per second','etcd.delete.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of deletes seen by this member per second.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30948','18','','10324','Etcd: Pending events','etcd.events.sent.rate','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of pending events to be sent.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30949','18','','10324','Etcd: RPCs received per second','etcd.grpc.received.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of RPC stream messages received on the server.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30950','18','','10324','Etcd: RPCs sent per second','etcd.grpc.sent.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of gRPC stream messages sent by the server.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30951','18','','10324','Etcd: RPCs started per second','etcd.grpc.started.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of RPCs started on the server.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30952','18','','10324','Etcd: HTTP 4XX','etcd.http.requests.4xx.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of handle failures of requests (non-watches), by method (GET/PUT etc.), and code 4XX.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30953','18','','10324','Etcd: CPU','etcd.cpu.util','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Total user and system CPU time spent in seconds.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30954','18','','10324','Etcd: HTTP 5XX','etcd.http.requests.5xx.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of handle failures of requests (non-watches), by method (GET/PUT etc.), and code 5XX.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30955','18','','10324','Etcd: HTTP requests received','etcd.http.requests.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of requests received into the system (successfully parsed and authd).','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30956','18','','10324','Etcd: Server is a leader','etcd.is.leader','0','7d','365d','0','3','','','','',NULL,'97','','','0','','','','','0',NULL,'Whether or not this member is a leader. 1 if is, 0 otherwise.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30957','18','','10324','Etcd: Keys compacted per second','etcd.keys.compacted.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of DB keys compacted per second.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30958','18','','10324','Etcd: Keys expired per second','etcd.keys.expired.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of expired keys per second.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30959','18','','10324','Etcd: Keys total','etcd.keys.total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of keys.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30960','18','','10324','Etcd: Leader changes','etcd.leader.changes','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The the number of leader changes the member has seen since its start.','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30961','18','','10324','gRPC codes discovery','etcd.grpc_code.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30962','18','','10324','Peers discovery','etcd.peer.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30963','18','','10324','Etcd: RPCs completed with code {#GRPC.CODE}','etcd.grpc.handled.rate[{#GRPC.CODE}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of RPCs completed on the server with grpc_code {#GRPC.CODE}','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30964','18','','10324','Etcd: Etcd peer {#ETCD.PEER}: Bytes received','etcd.bytes.received.rate[{#ETCD.PEER}]','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of bytes received from peer with ID {#ETCD.PEER}','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30965','18','','10324','Etcd: Etcd peer {#ETCD.PEER}: Bytes sent','etcd.bytes.sent.rate[{#ETCD.PEER}]','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of bytes sent to peer with ID {#ETCD.PEER}','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30966','18','','10324','Etcd: Etcd peer {#ETCD.PEER}: Receive failures failures','etcd.received.fail.rate[{#ETCD.PEER}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of receive failures from the peer with ID {#ETCD.PEER}','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30967','18','','10324','Etcd: Etcd peer {#ETCD.PEER}: Send failures','etcd.sent.fail.rate[{#ETCD.PEER}]','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of send failures from peer with ID {#ETCD.PEER}','0','30d','0','','30925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31052','18','','10262','Version','version','0','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of Zabbix proxy.','0','30d','0','','28585','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31053','18','','10261','Remote Zabbix server: Version','version','0','1w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of Zabbix server.','0','30d','0','','28539','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31059','18','','10327','MSSQL: Average latch wait time base','mssql.average_latch_wait_time_base','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'For internal use only.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31060','18','','10327','MSSQL: Table lock escalations per second','mssql.table_lock_escalations.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times locks on a table were escalated to the TABLE or HoBT granularity.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31061','18','','10327','MSSQL: Memory grants pending','mssql.memory_grants_pending','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Specifies the total number of processes waiting for a workspace memory grant.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31062','18','','10327','MSSQL: Total lock requests per second that have deadlocks','mssql.number_deadlocks_sec.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of lock requests per second that resulted in a deadlock.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31063','18','','10327','MSSQL: Errors per second (DB offline errors)','mssql.offline_errors_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors per second.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31064','18','','10327','MSSQL: Page life expectancy','mssql.page_life_expectancy','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates the number of seconds a page will stay in the buffer pool without references.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31065','18','','10327','MSSQL: Page lookups per second','mssql.page_lookups_sec.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates the number of requests per second to find a page in the buffer pool.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31066','18','','10327','MSSQL: Page reads per second','mssql.page_reads_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates the number of physical database page reads that are issued per second. This statistic displays the total number of physical page reads across all databases. Because physical I/O is expensive, you may be able to minimize the cost, either by using a larger data cache, intelligent indexes, and more efficient queries, or by changing the database design.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31067','18','','10327','MSSQL: Page splits per second','mssql.page_splits_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of page splits per second that occur as the result of overflowing index pages.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31068','18','','10327','MSSQL: Page writes per second','mssql.page_writes_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates the number of physical database page writes that are issued per second.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31069','18','','10327','MSSQL: Number of blocked processes','mssql.processes_blocked','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of currently blocked processes.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31070','18','','10327','MSSQL: Read-ahead pages per second','mssql.readahead_pages_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates the number of pages read per second in anticipation of use.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31071','18','','10327','MSSQL: Safe auto-params per second','mssql.safe_autoparams_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of safe auto-parameterization attempts per second. Safe refers to a determination that a cached execution plan can be shared between different similar-looking Transact-SQL statements. SQL Server makes many auto-parameterization attempts some of which turn out to be safe and others fail. Note that auto-parameterizations are also known as simple parameterizations in the newer versions of SQL Server. This does not include forced parameterizations.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31072','18','','10327','MSSQL: SQL compilations per second','mssql.sql_compilations_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of SQL compilations per second. Indicates the number of times the compile code path is entered. Includes compiles caused by statement-level recompilations in SQL Server. After SQL Server user activity is stable, this value reaches a steady state.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31073','18','','10327','MSSQL: SQL re-compilations per second','mssql.sql_recompilations_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of statement recompiles per second. Counts the number of times statement recompiles are triggered. Generally, you want the recompiles to be low.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31074','18','','10327','MSSQL: Target pages','mssql.target_pages','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The optimal number of pages in the buffer pool.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31075','18','','10327','MSSQL: Maximum workspace memory','mssql.maximum_workspace_memory','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates the maximum amount of memory available for executing processes, such as hash, sort, bulk copy, and index creation operations.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31076','18','','10327','MSSQL: Target server memory','mssql.target_server_memory','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates the ideal amount of memory the server can consume.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31077','18','','10327','MSSQL: Total latch wait Time','mssql.total_latch_wait_time','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Total latch wait time (in milliseconds) for latch requests in the last second. This value should stay stable compared to the number of latch waits per second.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31078','18','','10327','MSSQL: Total server memory','mssql.total_server_memory','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Specifies the amount of memory the server has committed using the memory manager.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31079','18','','10327','MSSQL: Total transactions number','mssql.transactions','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of currently active transactions of all types.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31080','18','','10327','MSSQL: Total transactions per second','mssql.transactions_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of transactions started for all databases per second.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31081','18','','10327','MSSQL: Unsafe auto-params per second','mssql.unsafe_autoparams_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of unsafe auto-parameterization attempts per second. For example, the query has some characteristics that prevent the cached plan from being shared. These are designated as unsafe. This does not count the number of forced parameterizations.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31082','18','','10327','MSSQL: Uptime','mssql.uptime','0','2w','0d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'MS SQL Server uptime in ''N days, hh:mm:ss'' format.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31083','18','','10327','MSSQL: Number users connected','mssql.user_connections','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of users connected to MS SQL Server.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31084','18','','10327','MSSQL: Errors per second (User errors)','mssql.user_errors_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors per second.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31085','18','','10327','MSSQL: Version','mssql.version','0','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'MS SQL Server version.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31086','18','','10327','MSSQL: Work files created per second','mssql.workfiles_created_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of work files created per second. For example, work files can be used to store temporary results for hash joins and hash aggregates.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31087','18','','10327','MSSQL: Work tables created per second','mssql.worktables_created_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of work tables created per second. For example, work tables can be used to store temporary results for query spool, lob variables, XML variables, and cursors.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31088','18','','10327','MSSQL: Worktables from cache ratio','mssql.worktables_from_cache_ratio','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Percentage of work tables created where the initial two pages of the work table were not allocated but were immediately available from the work table cache.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31089','18','','10327','MSSQL: Memory grants outstanding','mssql.memory_grants_outstanding','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Specifies the total number of processes that have successfully acquired a workspace memory grant.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31090','18','','10327','MSSQL: Logouts per second','mssql.logouts_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of logout operations started per second. Any value over 2 may indicate insufcient connection pooling.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31091','18','','10327','MSSQL: Average latch wait time raw','mssql.average_latch_wait_time_raw','0','7d','365d','0','3','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Average latch wait time (in milliseconds) for latch requests that had to wait.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31092','18','','10327','MSSQL: Forwarded records per second','mssql.forwarded_records_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of records per second fetched through forwarded record pointers.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31093','18','','10327','MSSQL: Total average wait time base','mssql.average_wait_time_base','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'For internal use only.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31094','18','','10327','MSSQL: Total average wait time raw','mssql.average_wait_time_raw','0','7d','365d','0','3','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Average amount of wait time (in milliseconds) for each lock request that resulted in a wait. Information for all locks.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31095','18','','10327','MSSQL: Batch requests per second','mssql.batch_requests_sec.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of Transact-SQL command batches received per second. This statistic is affected by all constraints (such as I/O, number of users, cache size, complexity of requests, and so on). High batch requests mean good throughput.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31096','18','','10327','MSSQL: Buffer cache hit ratio','mssql.buffer_cache_hit_ratio','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates the percentage of pages found in the buffer cache without having to read from disk. The ratio is the total number of cache hits divided by the total number of cache lookups over the last few thousand page accesses. After a long period of time, the ratio changes very little. Since reading from the cache is much less expensive than reading from the disk, a higher value is preferred for this item. To increase the buffer cache hit ratio, consider increasing the amount of memory available to SQL Server or using the buffer pool extension feature.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31097','18','','10327','MSSQL: Cache hit ratio','mssql.cache_hit_ratio','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Ratio between cache hits and lookups.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31098','18','','10327','MSSQL: Cache object counts','mssql.cache_object_counts','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of cache objects in the cache.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31099','18','','10327','MSSQL: Cache objects in use','mssql.cache_objects_in_use','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of cache objects in use.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31100','18','','10327','MSSQL: Cache pages','mssql.cache_pages','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of 8-kilobyte (KB) pages used by cache objects.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31101','18','','10327','MSSQL: Checkpoint pages per second','mssql.checkpoint_pages_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates the number of pages flushed to disk per second by a checkpoint or other operation which required all dirty pages to be flushed.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31102','18','','10327','MSSQL: Total data file size','mssql.data_files_size','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total size of all data files.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31103','18','','10327','MSSQL: Database pages','mssql.database_pages','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates the number of pages in the buffer pool with database content.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31104','18','','10327','MSSQL: Total errors per second','mssql.errors_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors per second.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31105','18','','10327','MSSQL: Failed auto-params per second','mssql.failed_autoparams_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of failed auto-parameterization attempts per second. This number should be small. Note that auto-parameterizations are also known as simple parameterizations in the newer versions of SQL Server.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31106','18','','10327','MSSQL: Free list stalls per second','mssql.free_list_stalls_sec.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates the number of requests per second that had to wait for a free page.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31107','18','','10327','MSSQL: Logins per second','mssql.logins_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of logins started per second. This does not include pooled connections. Any value over 2 may indicate insufcient connection pooling.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31108','18','','10327','MSSQL: Full scans per second','mssql.full_scans_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of unrestricted full scans per second. These can be either base-table or full-index scans. Values greater than 1 or 2 indicate that there are table / Index page scans. If that is combined with high CPU, this counter requires further investigation, otherwise, if the full scans are on small tables, it can be ignored.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31109','18','','10327','MSSQL: Granted Workspace Memory','mssql.granted_workspace_memory','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Specifies the total amount of memory currently granted to executing processes, such as hash, sort, bulk copy, and index creation operations.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31110','18','','10327','MSSQL: Index searches per second','mssql.index_searches_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of index searches per second. These are used to start a range scan, reposition a range scan, revalidate a scan point, fetch a single index record, and search down the index to locate where to insert a new row.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31111','18','','10327','MSSQL: Errors per second (Info errors)','mssql.info_errors_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors per second.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31112','18','','10327','MSSQL: Errors per second (Kill connection errors)','mssql.kill_connection_errors_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of errors per second.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31113','18','','10327','MSSQL: Latch waits per second','mssql.latch_waits_sec.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of latch requests that could not be granted immediately. Latches are lightweight means of holding a very transient server resource, such as an address in memory.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31114','18','','10327','MSSQL: Lazy writes per second','mssql.lazy_writes_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates the number of buffers written per second by the buffer manager''s lazy writer. The lazy writer is a system process that flushes out batches of dirty, aged buffers (buffers that contain changes that must be written back to disk before the buffer can be reused for a different page) and makes them available to user processes. The lazy writer eliminates the need to perform frequent checkpoints in order to create available buffers.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31115','18','','10327','MSSQL: Total lock requests per second','mssql.lock_requests_sec.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of new locks and lock conversions per second requested from the lock manager.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31116','18','','10327','MSSQL: Total lock requests per second that timed out','mssql.lock_timeouts_sec.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of timed out lock requests per second, including requests for NOWAIT locks.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31117','18','','10327','MSSQL: Lock wait time','mssql.lock_wait_time','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Average of total wait time (in milliseconds) for locks in the last second.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31118','18','','10327','MSSQL: Total lock requests per second that required waiting','mssql.lock_waits_sec.rate','0','7d','365d','0','0','','rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of lock requests per second that required the caller to wait.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31119','18','','10327','MSSQL: Total log file size','mssql.log_files_size','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total size of all the transaction log files.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31120','18','','10327','MSSQL: Auto-param attempts per second','mssql.autoparam_attempts_sec.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of auto-parameterization attempts per second. The total should be the sum of the failed, safe, and unsafe auto-parameterizations. Auto-parameterization occurs when an instance of SQL Server tries to parameterize a Transact-SQL request by replacing some literals with parameters to me reuse of the resulting cached execution plan across multiple similar-looking requests possible. Note that auto-parameterizations are also known as simple parameterizations in the newer versions of SQL Server. This counter does not include forced parameterizations.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31121','18','','10327','MSSQL: Total log file used size','mssql.log_files_used_size','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The cumulative used size of all the log files in the database.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31133','18','','10327','MSSQL AG ''{#GROUP_NAME}'': Primary replica recovery health','mssql.primary_recovery_health["{#GROUP_NAME}"]','0','7d','365d','0','3','','','','',NULL,'103','','','0','','','','','2',NULL,'Indicates the recovery health of the primary replica:
0 = In progress
1 = Online
2 = Unavailable','0','30d','0','','31128','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31134','18','','10327','MSSQL AG ''{#GROUP_NAME}'': Primary replica name','mssql.primary_replica["{#GROUP_NAME}"]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Name of the server instance that is hosting the current primary replica.','0','30d','0','','31128','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31135','18','','10327','MSSQL AG ''{#GROUP_NAME}'': Secondary replica recovery health','mssql.secondary_recovery_health["{#GROUP_NAME}"]','0','7d','365d','0','3','','','','',NULL,'103','','','0','','','','','2',NULL,'Indicates the recovery health of a secondary replica replica:
0 = In progress
1 = Online
2 = Unavailable','0','30d','0','','31128','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31136','18','','10327','MSSQL AG ''{#GROUP_NAME}'': Synchronization health','mssql.synchronization_health["{#GROUP_NAME}"]','0','7d','365d','0','3','','','','',NULL,'106','','','0','','','','','2',NULL,'Reflects a rollup of the synchronization_health of all availability replicas in the availability group:
0: Not healthy. None of the availability replicas have a healthy synchronization.
1: Partially healthy. The synchronization of some, but not all, availability replicas is healthy.
2: Healthy. The synchronization of every availability replica is healthy.','0','30d','0','','31128','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31137','18','','10327','MSSQL DB ''{#DBNAME}'': Active transactions','mssql.db.active_transactions["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of active transactions for the database.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31138','18','','10327','MSSQL DB ''{#DBNAME}'': Data file size','mssql.db.data_files_size["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Cumulative size of all the data files in the database including any automatic growth. Monitoring this counter is useful, for example, for determining the correct size of tempdb.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31139','18','','10327','MSSQL DB ''{#DBNAME}'': Log bytes flushed per second','mssql.db.log_bytes_flushed_sec.rate["{#DBNAME}"]','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of log bytes flushed per second. Useful for determining trends and utilization of the transaction log.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31140','18','','10327','MSSQL DB ''{#DBNAME}'': Log file size','mssql.db.log_files_size["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Cumulative size of all the transaction log files in the database.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31141','18','','10327','MSSQL DB ''{#DBNAME}'': Log file used size','mssql.db.log_files_used_size["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Cumulative used size of all the log files in the database.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31142','18','','10327','MSSQL DB ''{#DBNAME}'': Log flush wait time','mssql.db.log_flush_wait_time["{#DBNAME}"]','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','2',NULL,'Total wait time (in milliseconds) to flush the log. On an AlwaysOn secondary database, this value indicates the wait time for log records to be hardened to disk.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31143','18','','10327','MSSQL DB ''{#DBNAME}'': Log flush waits per second','mssql.db.log_flush_waits_sec.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of commits per second waiting for the log flush.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31144','18','','10327','MSSQL DB ''{#DBNAME}'': Log flushes per second','mssql.db.log_flushes_sec.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of log flushes per second.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31145','18','','10327','MSSQL DB ''{#DBNAME}'': Log growths','mssql.db.log_growths["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of times the transaction log for the database has been expanded.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31146','18','','10327','MSSQL DB ''{#DBNAME}'': Log shrinks','mssql.db.log_shrinks["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of times the transaction log for the database has been shrunk.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31147','18','','10327','MSSQL DB ''{#DBNAME}'': Log truncations','mssql.db.log_truncations["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of times the transaction log has been shrunk.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31148','18','','10327','MSSQL DB ''{#DBNAME}'': Percent log used','mssql.db.percent_log_used["{#DBNAME}"]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Percentage of space in the log that is in use.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31149','18','','10327','MSSQL DB ''{#DBNAME}'': State','mssql.db.state["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,'99','','','0','','','','','2',NULL,'0 = ONLINE
1 = RESTORING
2 = RECOVERING | SQL Server 2008 and later
3 = RECOVERY_PENDING | SQL Server 2008 and later
4 = SUSPECT
5 = EMERGENCY | SQL Server 2008 and later
6 = OFFLINE | SQL Server 2008 and later
7 = COPYING | Azure SQL Database Active Geo-Replication
10 = OFFLINE_SECONDARY | Azure SQL Database Active Geo-Replication','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31150','18','','10327','MSSQL DB ''{#DBNAME}'': Transactions per second','mssql.db.transactions_sec.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of transactions started for the database per second.','0','30d','0','','31055','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31151','18','','10327','MSSQL AG ''{#GROUP_NAME}'' Local DB ''{#DBNAME}'': Suspended','mssql.local_db.is_suspended["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Database state:
0 = Resumed
1 = Suspended','0','30d','0','','31129','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31152','18','','10327','MSSQL AG ''{#GROUP_NAME}'' Local DB ''{#DBNAME}'': State','mssql.local_db.state["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,'99','','','0','','','','','2',NULL,'0 = Online
1 = Restoring
2 = Recovering
3 = Recovery pending
4 = Suspect
5 = Emergency
6 = Offline','0','30d','0','','31129','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31153','18','','10327','MSSQL AG ''{#GROUP_NAME}'' Local DB ''{#DBNAME}'': Synchronization health','mssql.local_db.synchronization_health["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,'106','','','0','','','','','2',NULL,'Reflects the intersection of the synchronization state of a database that is joined to the availability group on the availability replica and the availability mode of the availability replica (synchronous-commit or asynchronous-commit mode):
0 = Not healthy. The synchronization_state of the database is 0 (NOT SYNCHRONIZING).
1 = Partially healthy. A database on a synchronous-commit availability replica is considered 
partially healthy if synchronization_state is 1 (SYNCHRONIZING).
2 = Healthy. A database on an synchronous-commit availability replica is considered healthy if synchronization_state is 2 (SYNCHRONIZED), and a database on an asynchronous-commit availability replica is considered healthy if synchronization_state is 1 (SYNCHRONIZING).','0','30d','0','','31129','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31154','18','','10327','MSSQL Mirroring ''{#DBNAME}'': Role sequence','mssql.mirroring.role_sequence["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of times that mirroring partners have switched the principal and mirror roles due to a failover or forced service.','0','30d','0','','31130','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31155','18','','10327','MSSQL Mirroring ''{#DBNAME}'': Role','mssql.mirroring.role["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,'109','','','0','','','','','2',NULL,'Current role of the local database plays in the database mirroring session.
1 = Principal
2 = Mirror','0','30d','0','','31130','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31156','18','','10327','MSSQL Mirroring ''{#DBNAME}'': Safety level','mssql.mirroring.safety_level["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,'110','','','0','','','','','2',NULL,'Safety setting for updates on the mirror database:
0 = Unknown state
1 = Off [asynchronous]
2 = Full [synchronous]','0','30d','0','','31130','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31157','18','','10327','MSSQL Mirroring ''{#DBNAME}'': State','mssql.mirroring.state["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,'108','','','0','','','','','2',NULL,'State of the mirror database and of the database mirroring session.
0 = Suspended
1 = Disconnected from the other partner
2 = Synchronizing
3 = Pending Failover
4 = Synchronized
5 = The partners are not synchronized. Failover is not possible now.
6 = The partners are synchronized. Failover is potentially possible. For information about the requirements for the failover, see Database Mirroring Operating Modes.','0','30d','0','','31130','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31158','18','','10327','MSSQL Mirroring ''{#DBNAME}'': Witness state','mssql.mirroring.witness_state["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,'111','','','0','','','','','2',NULL,'State of the witness in the database mirroring session of the database:
0 = Unknown
1 = Connected
2 = Disconnected','0','30d','0','','31130','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31161','18','','10327','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': Connected state','mssql.replica.connected_state["{#GROUP_NAME}_{#REPLICA_NAME}"]','0','7d','365d','0','3','','','','',NULL,'100','','','0','','','','','2',NULL,'Whether a secondary replica is currently connected to the primary replica:
0 : Disconnected. The response of an availability replica to the DISCONNECTED state depends on its role:
On the primary replica, if a secondary replica is disconnected, its secondary databases are marked as NOT SYNCHRONIZED on the primary replica, which waits for the secondary to reconnect;
On a secondary replica, upon detecting that it is disconnected, the secondary replica attempts to reconnect to the primary replica.
1 : Connected. Each primary replica tracks the connection state for every secondary replica in the same availability group. Secondary replicas track the connection state of only the primary replica.','0','30d','0','','31132','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31162','18','','10327','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': Is local','mssql.replica.is_local["{#GROUP_NAME}_{#REPLICA_NAME}"]','0','7d','365d','0','3','','','','',NULL,'107','','','0','','','','','2',NULL,'Whether the replica is local:
0 = Indicates a remote secondary replica in an availability group whose primary replica is hosted by the local server instance. This value occurs only on the primary replica location.
1 = Indicates a local replica. On secondary replicas, this is the only available value for the availability group to which the replica belongs.','0','30d','0','','31132','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31163','18','','10327','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': Join state','mssql.replica.join_state["{#GROUP_NAME}_{#REPLICA_NAME}"]','0','7d','365d','0','3','','','','',NULL,'101','','','0','','','','','2',NULL,'0 = Not joined
1 = Joined, standalone instance
2 = Joined, failover cluster instance','0','30d','0','','31132','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31164','18','','10327','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': Operational state','mssql.replica.operational_state["{#GROUP_NAME}_{#REPLICA_NAME}"]','0','7d','365d','0','3','','','','',NULL,'102','','','0','','','','','2',NULL,'Current operational state of the replica:
0 = Pending failover
1 = Pending
2 = Online
3 = Offline
4 = Failed
5 = Failed, no quorum
6 = Not local','0','30d','0','','31132','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31165','18','','10327','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': Recovery health','mssql.replica.recovery_health["{#GROUP_NAME}_{#REPLICA_NAME}"]','0','7d','365d','0','3','','','','',NULL,'103','','','0','','','','','2',NULL,'Rollup of the database_state column of the sys.dm_hadr_database_replica_states dynamic management view:
0 : In progress. At least one joined database has a database state other than ONLINE 
(database_state is not 0).
1 : Online. All the joined databases have a database state of ONLINE (database_state is 0).','0','30d','0','','31132','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31166','18','','10327','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': Role','mssql.replica.role["{#GROUP_NAME}_{#REPLICA_NAME}"]','0','7d','365d','0','3','','','','',NULL,'104','','','0','','','','','2',NULL,'Current Always On availability groups role of a local replica or a connected remote replica:
0 = Resolving
1 = Primary
2 = Secondary','0','30d','0','','31132','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31167','18','','10327','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': Sync health','mssql.replica.synchronization_health["{#GROUP_NAME}_{#REPLICA_NAME}"]','0','7d','365d','0','3','','','','',NULL,'106','','','0','','','','','2',NULL,'Reflects a rollup of the database synchronization state (synchronization_state)of all joined availability databases (also known as replicas) and the availability mode of the replica (synchronous-commit or asynchronous-commit mode). The rollup will reflect the least healthy accumulated state of the databases on the replica:
0 : Not healthy. At least one joined database is in the NOT SYNCHRONIZING state.
1 : Partially healthy. Some replicas are not in the target synchronization state: synchronous-commit replicas should be synchronized, and asynchronous-commit replicas should be synchronizing.
2 : Healthy. All replicas are in the target synchronization state: synchronous-commit replicas are synchronized, and asynchronous-commit replicas are synchronizing.','0','30d','0','','31132','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31168','18','','10316','MySQL: Threads created per second','mysql.threads_created.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. The cache miss rate can be calculated as Threads_created/Connections.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31169','18','','10316','MySQL: Created tmp tables on disk per second','mysql.created_tmp_disk_tables.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of internal on-disk temporary tables created by the server while executing statements.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31170','18','','10316','MySQL: Created tmp files on disk per second','mysql.created_tmp_files.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'How many temporary files mysqld has created.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31171','18','','10316','MySQL: Created tmp tables on memory per second','mysql.created_tmp_tables.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of internal temporary tables created by the server while executing statements.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31172','18','','10320','MySQL: Threads created per second','mysql.threads_created.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. The cache miss rate can be calculated as Threads_created/Connections.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31173','18','','10320','MySQL: Created tmp tables on disk per second','mysql.created_tmp_disk_tables.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of internal on-disk temporary tables created by the server while executing statements.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31174','18','','10320','MySQL: Created tmp files on disk per second','mysql.created_tmp_files.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'How many temporary files mysqld has created.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31175','18','','10320','MySQL: Created tmp tables on memory per second','mysql.created_tmp_tables.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of internal temporary tables created by the server while executing statements.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31176','18','','10317','MySQL: Threads created per second','mysql.threads_created.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. The cache miss rate can be calculated as Threads_created/Connections.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31177','18','','10317','MySQL: Created tmp tables on disk per second','mysql.created_tmp_disk_tables.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of internal on-disk temporary tables created by the server while executing statements.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31178','18','','10317','MySQL: Created tmp tables on memory per second','mysql.created_tmp_tables.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of internal temporary tables created by the server while executing statements.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31179','18','','10317','MySQL: Created tmp files on disk per second','mysql.created_tmp_files.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'How many temporary files mysqld has created.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31197','18','','10328','Dbstat: Rows fetched','pgsql.dbstat.sum.tup_fetched.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of rows fetched by queries','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31198','18','','10328','Dbstat: Backends connected','pgsql.dbstat.sum.numbackends','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of connected backends','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31199','18','','10328','Dbstat: Deadlocks','pgsql.dbstat.sum.deadlocks.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of deadlocks detected','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31200','18','','10328','Dbstat: Number temp bytes','pgsql.dbstat.sum.temp_bytes.rate','0','7d','365d','0','0','','b','','',NULL,NULL,'','','0','','','','','0',NULL,'Total amount of data written to temporary files by queries','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31201','18','','10328','Dbstat: Number temp bytes','pgsql.dbstat.sum.temp_files.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of temporary files created by queries','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31202','18','','10328','Dbstat: Rows deleted','pgsql.dbstat.sum.tup_deleted.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of rows deleted by queries','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31203','18','','10328','Archive: Count of archive files','pgsql.archive.count_archived_files','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect all metrics from pg_stat_activity
https://www.postgresql.org/docs/current/monitoring-stats.html#PG-STAT-ARCHIVER-VIEW','0','30d','0','','31195','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31204','18','','10328','Dbstat: Rows inserted','pgsql.dbstat.sum.tup_inserted.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of rows inserted by queries','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31205','18','','10328','Dbstat: Rows returned','pgsql.dbstat.sum.tup_returned.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of rows returned by queries','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31206','18','','10328','Dbstat: Rows updated','pgsql.dbstat.sum.tup_updated.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of rows updated by queries','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31207','18','','10328','Dbstat: Committed transactions','pgsql.dbstat.sum.xact_commit.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of transactions that have been committed','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31208','18','','10328','Dbstat: Roll backed transactions','pgsql.dbstat.sum.xact_rollback.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of transactions that have been rolled back','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31209','18','','10328','Dbstat: Checksum failures','pgsql.dbstat.sum.checksum_failures.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of data page checksum failures detected (or on a shared object), or NULL if data checksums are not enabled. This metric included in PostgreSQL 12','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31210','18','','10328','WAL: Segments count','pgsql.wal.count','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of WAL segments','0','30d','0','','31196','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31211','18','','10328','Dbstat: Conflicts','pgsql.dbstat.sum.conflicts.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of queries canceled due to conflicts with recovery.  (Conflicts occur only on standby servers; see pg_stat_database_conflicts for details.)','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31212','18','','10328','Dbstat: Blocks write time','pgsql.dbstat.sum.blk_write_time','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Time spent writing data file blocks by backends, in milliseconds','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31213','18','','10328','Dbstat: Disk blocks read','pgsql.dbstat.sum.blks_read.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of disk blocks read','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31215','18','','10328','Archive: Count of attempts to archive files','pgsql.archive.failed_trying_to_archive','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Collect all metrics from pg_stat_activity
https://www.postgresql.org/docs/current/monitoring-stats.html#PG-STAT-ARCHIVER-VIEW','0','30d','0','','31195','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31216','18','','10328','Archive: Count of files need to archive','pgsql.archive.size_files_to_archive','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Size of files to archive','0','30d','0','','31195','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31217','18','','10328','Bgwriter: Buffers allocated','pgsql.bgwriter.buffers_alloc.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of buffers allocated','0','30d','0','','31180','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31218','18','','10328','Bgwriter: Times a backend execute its own fsync','pgsql.bgwriter.buffers_backend_fsync.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times a backend had to execute its own fsync call (normally the background writer handles those even when the backend does its own write)','0','30d','0','','31180','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31219','18','','10328','Bgwriter: Buffers written directly by a backend','pgsql.bgwriter.buffers_backend.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of buffers written directly by a backend','0','30d','0','','31180','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31220','18','','10328','Checkpoint: Buffers checkpoints written','pgsql.bgwriter.buffers_checkpoint.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of buffers written during checkpoints','0','30d','0','','31180','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31221','18','','10328','Checkpoint: Buffers background written','pgsql.bgwriter.buffers_clean.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of buffers written by the background writer','0','30d','0','','31180','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31222','18','','10328','Checkpoint: Checkpoint write time','pgsql.bgwriter.checkpoint_write_time.rate','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Total amount of time that has been spent in the portion of checkpoint processing where files are written to disk, in milliseconds','0','30d','0','','31180','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31223','18','','10328','Checkpoint: Requested','pgsql.bgwriter.checkpoints_req.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of requested checkpoints that have been performed','0','30d','0','','31180','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31224','18','','10328','Checkpoint: By timeout','pgsql.bgwriter.checkpoints_timed.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of scheduled checkpoints that have been performed','0','30d','0','','31180','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31225','18','','10328','Bgwriter: Number of bgwriter stopped','pgsql.bgwriter.maxwritten_clean.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times the background writer stopped a cleaning scan because it had written too many buffers','0','30d','0','','31180','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31226','18','','10328','Connections sum: Active','pgsql.connections.active','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections executing a query','0','30d','0','','31182','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31227','18','','10328','Dbstat: Hit blocks read','pgsql.dbstat.sum.blks_hit.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times disk blocks were found already in the buffer cache','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31228','18','','10328','Connections sum: Disabled','pgsql.connections.disabled','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of disabled connections','0','30d','0','','31182','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31229','18','','10328','Connections sum: Fastpath function call','pgsql.connections.fastpath_function_call','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections executing a fast-path function','0','30d','0','','31182','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31230','18','','10328','Connections sum: Idle','pgsql.connections.idle','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections waiting for a new client command','0','30d','0','','31182','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31231','18','','10328','Connections sum: Idle in transaction','pgsql.connections.idle_in_transaction','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections in a transaction state, but not executing a query','0','30d','0','','31182','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31232','18','','10328','Connections sum: Idle in transaction (aborted)','pgsql.connections.idle_in_transaction_aborted','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections in a transaction state, but not executing a query and one of the statements in the transaction caused an error.','0','30d','0','','31182','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31233','18','','10328','Connections sum: Prepared','pgsql.connections.prepared','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of prepared transactions
https://www.postgresql.org/docs/current/sql-prepare-transaction.html','0','30d','0','','31182','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31234','18','','10328','Connections sum: Total','pgsql.connections.total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections','0','30d','0','','31182','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31235','18','','10328','Connections sum: Total %','pgsql.connections.total_pct','0','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections in percentage','0','30d','0','','31182','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31236','18','','10328','Connections sum: Waiting','pgsql.connections.waiting','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of waiting connections
https://www.postgresql.org/docs/current/monitoring-stats.html#WAIT-EVENT-TABLE','0','30d','0','','31182','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31237','18','','10328','Dbstat: Blocks read time','pgsql.dbstat.sum.blk_read_time','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Time spent reading data file blocks by backends, in milliseconds','0','30d','0','','31183','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31238','18','','10328','Archive: Count of files in archive_status need to archive','pgsql.archive.count_files_to_archive','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','31195','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31239','18','','10328','WAL: Bytes written','pgsql.wal.write','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'WAL write in bytes','0','30d','0','','31196','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31244','18','','10328','DB {#DBNAME}: Tuples returned per second','pgsql.dbstat.tup_returned.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of rows returned by queries in this database','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31245','18','','10328','DB {#DBNAME}: Num of shareupdateexclusive locks','pgsql.locks.shareupdateexclusive["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of shareupdateexclusive locks for each database','0','30d','0','','31186','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31246','18','','10328','DB {#DBNAME}: Num of sharerowexclusive locks','pgsql.locks.sharerowexclusive["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of total sharerowexclusive for each database','0','30d','0','','31186','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31247','18','','10328','DB {#DBNAME}: Num of share locks','pgsql.locks.share["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of share locks for each database','0','30d','0','','31186','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31248','18','','10328','DB {#DBNAME}: Num of rowshare locks','pgsql.locks.rowshare["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of rowshare locks for each database','0','30d','0','','31186','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31249','18','','10328','DB {#DBNAME}: Num of rowexclusive locks','pgsql.locks.rowexclusive["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of rowexclusive locks for each database','0','30d','0','','31186','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31250','18','','10328','DB {#DBNAME}: Num of exclusive locks','pgsql.locks.exclusive["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of exclusive locks for each database','0','30d','0','','31186','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31251','18','','10328','DB {#DBNAME}: Num of accessshare locks','pgsql.locks.accessshare["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of accessshare locks for each database','0','30d','0','','31186','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31252','18','','10328','DB {#DBNAME}: Num of accessexclusive locks','pgsql.locks.accessexclusive["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of accessexclusive locks for each database','0','30d','0','','31186','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31253','18','','10328','DB {#DBNAME}: Rollbacks per second','pgsql.dbstat.xact_rollback.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of transactions in this database that have been rolled back','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31254','18','','10328','DB {#DBNAME}: Commits per second','pgsql.dbstat.xact_commit.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of transactions in this database that have been committed','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31255','18','','10328','DB {#DBNAME}: Tuples updated per second','pgsql.dbstat.tup_updated.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of rows updated by queries in this database','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31256','18','','10328','DB {#DBNAME}: Tuples fetched per second','pgsql.dbstat.tup_fetched.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of rows fetched by queries in this database','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31257','18','','10328','DB {#DBNAME}: Tuples inserted per second','pgsql.dbstat.tup_inserted.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of rows inserted by queries in this database','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31258','18','','10328','DB {#DBNAME}: Tuples deleted per second','pgsql.dbstat.tup_deleted.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of rows deleted by queries in this database','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31259','18','','10328','DB {#DBNAME}: Temp_files created per second','pgsql.dbstat.temp_files.rate["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of temporary files created by queries in this database','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31260','18','','10328','DB {#DBNAME}: Temp_bytes written per second','pgsql.dbstat.temp_bytes.rate["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total amount of data written to temporary files by queries in this database','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31261','18','','10328','DB {#DBNAME}: Backends connected','pgsql.dbstat.numbackends["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of backends currently connected to this database','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31262','18','','10328','DB {#DBNAME}: Detected deadlocks per second','pgsql.dbstat.deadlocks.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of detected deadlocks in this database','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31263','18','','10328','DB {#DBNAME}: Detected conflicts per second','pgsql.dbstat.conflicts.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of queries canceled due to conflicts with recovery in this database','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31264','18','','10328','DB {#DBNAME}: Checksum failures','pgsql.dbstat.checksum_failures.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of data page checksum failures detected in this database','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31265','18','','10328','DB {#DBNAME}: Disk blocks read per second','pgsql.dbstat.blks_read.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of disk blocks read in this database','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31266','18','','10328','DB {#DBNAME}: Blocks hit per second','pgsql.dbstat.blks_hit.rate["{#DBNAME}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of times disk blocks were found already in the buffer cache, so that a read was not necessary','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31267','18','','10328','DB {#DBNAME}: Disk blocks read per second','pgsql.dbstat.blk_write_time.rate["{#DBNAME}"]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Time spent writing data file blocks by backends, in milliseconds','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31268','18','','10328','DB {#DBNAME}: Disk blocks read per second','pgsql.dbstat.blk_read_time.rate["{#DBNAME}"]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Time spent reading data file blocks by backends, in milliseconds','0','30d','0','','31185','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31269','18','','10328','DB {#DBNAME}: Num of total locks','pgsql.locks.total["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of total locks for each database','0','30d','0','','31186','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31270','18','','10274','Memory utilization','vm.memory.utilization','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory used percentage is calculated as (100-pavailable)','0','30d','0','','29103','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31285','18','','10275','{#DEVNAME}: Disk average queue size (avgqu-sz)','vfs.dev.queue_size[{#DEVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Current average disk queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','','31278','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31286','18','','10275','{#DEVNAME}: Disk read rate','vfs.dev.read.rate[{#DEVNAME}]','0','7d','365d','0','0','','!r/s','','',NULL,NULL,'','','0','','','','','2',NULL,'r/s. The number (after merges) of read requests completed per second for the device.','0','30d','0','','31278','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31287','18','','10275','{#DEVNAME}: Disk read time (rate)','vfs.dev.read.time.rate[{#DEVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of total read time counter. Used in r_await calculation','0','30d','0','','31278','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31288','18','','10275','{#DEVNAME}: Disk utilization','vfs.dev.util[{#DEVNAME}]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'This item is the percentage of elapsed time that the selected disk drive was busy servicing read or writes requests.','0','30d','0','','31278','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31289','18','','10275','{#DEVNAME}: Disk write rate','vfs.dev.write.rate[{#DEVNAME}]','0','7d','365d','0','0','','!w/s','','',NULL,NULL,'','','0','','','','','2',NULL,'w/s. The number (after merges) of write requests completed per second for the device.','0','30d','0','','31278','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31290','18','','10275','{#DEVNAME}: Disk write time (rate)','vfs.dev.write.time.rate[{#DEVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of total write time counter. Used in w_await calculation','0','30d','0','','31278','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31303','18','','10280','Memory utilization','vm.memory.utilization','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory used percentage is calculated as (100-pavailable)','0','30d','0','','29289','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31313','18','','10281','{#DEVNAME}: Disk average queue size (avgqu-sz)','vfs.dev.queue_size[{#DEVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Current average disk queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','','31309','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31314','18','','10281','{#DEVNAME}: Disk read rate','vfs.dev.read.rate[{#DEVNAME}]','0','7d','365d','0','0','','!r/s','','',NULL,NULL,'','','0','','','','','2',NULL,'r/s. The number (after merges) of read requests completed per second for the device.','0','30d','0','','31309','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31315','18','','10281','{#DEVNAME}: Disk read time (rate)','vfs.dev.read.time.rate[{#DEVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of total read time counter. Used in r_await calculation','0','30d','0','','31309','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31316','18','','10281','{#DEVNAME}: Disk utilization','vfs.dev.util[{#DEVNAME}]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'This item is the percentage of elapsed time that the selected disk drive was busy servicing read or writes requests.','0','30d','0','','31309','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31317','18','','10281','{#DEVNAME}: Disk write rate','vfs.dev.write.rate[{#DEVNAME}]','0','7d','365d','0','0','','!w/s','','',NULL,NULL,'','','0','','','','','2',NULL,'w/s. The number (after merges) of write requests completed per second for the device.','0','30d','0','','31309','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31318','18','','10281','{#DEVNAME}: Disk write time (rate)','vfs.dev.write.time.rate[{#DEVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of total write time counter. Used in w_await calculation','0','30d','0','','31309','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31331','18','','10287','Free swap space in %','system.swap.pfree','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in percent.','0','30d','0','','31326','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31349','18','','10294','Free swap space in %','system.swap.pfree','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in percent.','0','30d','0','','31344','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31646','18','','10333','Oracle: Active user sessions','oracle.session_active_user','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of active user sessions.','0','30d','0','','31643','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31647','18','','10333','Oracle: Rows per sort','oracle.rows_per_sort','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The average number of rows per sort for all types of sorts performed.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31648','18','','10333','Oracle: Active background sessions','oracle.session_active_background','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of active background sessions.','0','30d','0','','31643','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31649','18','','10333','Oracle: Sessions concurrency','oracle.session_concurrency_rate','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The percentage of concurrency. Concurrency is a DB behaviour when different transactions request to change the same resource - in case of modifying data transactions sequentially block temporarily the right to change data, the rest of the transactions are waiting for access. In the case when access for resource is locked for a long time, then the concurrency grows (like the transaction queue) and this often has an extremely negative impact on performance. A high contention value does not indicate the root cause of the problem, but is a signal to search for it.','0','30d','0','','31643','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31650','18','','10333','Oracle: Session count','oracle.session_count','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Session count.','0','30d','0','','31643','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31651','18','','10333','Oracle: Inactive user sessions','oracle.session_inactive_user','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of inactive user sessions.','0','30d','0','','31643','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31652','18','','10333','Oracle: SQL service response time','oracle.service_response_time','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'SQL service response time in seconds.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31653','18','','10333','Oracle: Sessions limit','oracle.session_limit','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'User and system sessions.','0','30d','0','','31638','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31654','18','','10333','Oracle: Sessions lock rate','oracle.session_lock_rate','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The percentage of locked sessions. Locks are mechanisms that prevent destructive interaction between transactions accessing the same resource—either user objects such as tables and rows or system objects not visible to users, such as shared data structures in memory and data dictionary rows.','0','30d','0','','31643','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31655','18','','10333','Oracle: Processes limit','oracle.processes_limit','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Max user processes.','0','30d','0','','31638','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31656','18','','10333','Oracle: Active parallel sessions','oracle.active_parallel_sessions','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of active parallel sessions.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31657','18','','10333','Oracle: Sessions locked over {$ORACLE.SESSION.LOCK.MAX.TIME}s','oracle.session_long_time_locked','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of the prolongely locked sessions. (You can change maximum session lock duration in seconds for query by {$ORACLE.SESSION.LOCK.MAX.TIME} macro. Default 600 sec)','0','30d','0','','31643','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31658','18','','10333','Oracle: SGA, buffer cache','oracle.sga_buffer_cache','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The size of the cache of standard blocks.','0','30d','0','','31633','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31659','18','','10333','Oracle: SGA, fixed','oracle.sga_fixed','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The fixed SGA is an internal housekeeping area.','0','30d','0','','31633','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31660','18','','10333','Oracle: SGA, java pool','oracle.sga_java_pool','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory is allocated from the java pool.','0','30d','0','','31633','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31661','18','','10333','Oracle: SGA, log buffer','oracle.sga_log_buffer','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of bytes allocated for the redo log buffer.','0','30d','0','','31633','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31662','18','','10333','Oracle: SGA, shared pool','oracle.sga_shared_pool','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory is allocated from the shared pool.','0','30d','0','','31633','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31663','18','','10333','Oracle: Shared pool free %','oracle.shared_pool_free','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Shared pool free memory percent. Free/Total','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31664','18','','10333','Oracle: Total sorts per user call','oracle.sorts_per_user_call','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total sorts per user call.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31665','18','','10333','Oracle: Temp space used','oracle.temp_space_used','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Temp space used.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31666','18','','10333','Oracle: PGA, Total allocated','oracle.total_pga_allocated','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current amount of PGA memory allocated by the instance. The Oracle Database attempts to keep this number below the value of the PGA_AGGREGATE_TARGET initialization parameter. However, it is possible for the PGA allocated to exceed that value by a small percentage and for a short period of time when the work area workload is increasing very rapidly or when PGA_AGGREGATE_TARGET is set to a small value.','0','30d','0','','31639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31667','18','','10333','Oracle: PGA, Total freeable','oracle.total_pga_freeable','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of bytes of PGA memory in all processes that could be freed back to the operating system.','0','30d','0','','31639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31668','18','','10333','Oracle: PGA, Total inuse','oracle.total_pga_used','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Indicates how much PGA memory is currently consumed by work areas. This number can be used to determine how much memory is consumed by other consumers of the PGA memory (for example, PL/SQL or Java).','0','30d','0','','31639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31669','18','','10333','Oracle: Uptime','oracle.uptime','0','7d','0d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Oracle instance uptime in seconds.','0','30d','0','','31637','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31670','18','','10333','Oracle: User rollbacks per second','oracle.user_rollbacks_rate','0','7d','365d','0','0','','Rps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of times that users manually issue the ROLLBACK statement or an error occurred during a user''s transactions.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31671','18','','10333','Oracle: SGA, large pool','oracle.sga_large_pool','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory is allocated from the large pool.','0','30d','0','','31633','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31672','18','','10333','Oracle: Physical reads bytes per second','oracle.physical_read_bytes_rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Read bytes per second.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31673','18','','10333','Oracle: Physical writes per second','oracle.physical_writes_rate','0','7d','365d','0','0','','Rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Writes per second.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31674','18','','10333','Oracle: FRA, Space reclaimable','oracle.fra_space_reclaimable','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total amount of disk space (in bytes) that can be created by deleting obsolete, redundant, and other low priority files from the fast recovery area.','0','30d','0','','31631','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31675','18','','10333','Oracle: Average active sessions','oracle.active_sessions','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The average active sessions at a point in time. It is the number of sessions that are either working or waiting.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31676','18','','10333','Oracle: Archiver state','oracle.archiver_state','0','7d','365d','0','3','','','','',NULL,'116','','','0','','','','','0',NULL,'Automatic archiving status.','0','30d','0','','31637','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31677','18','','10333','Oracle: Buffer cache hit ratio','oracle.buffer_cache_hit_ratio','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Ratio of buffer cache hits. (LogRead - PhyRead)/LogRead','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31678','18','','10333','Oracle: Global cache blocks corrupted','oracle.cache_blocks_corrupt','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of blocks that encountered a corruption or checksum failure during interconnect.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31679','18','','10333','Oracle: Global cache blocks lost','oracle.cache_blocks_lost','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of global cache blocks lost','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31680','18','','10333','Oracle: Cursor cache hit ratio','oracle.cursor_cache_hit_ratio','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Ratio of cursor cache hits. CursorCacheHit/SoftParse','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31681','18','','10333','Oracle: Database CPU time ratio','oracle.database_cpu_time_ratio','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Calculated by dividing the total CPU used by the database by the Oracle time model statistic DB time.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31682','18','','10333','Oracle: Database wait time ratio','oracle.database_wait_time_ratio','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Wait time: the time that the server process spends waiting for available shared resources (to be released by other server processes) such as latches, locks, data buffers, and so on','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31683','18','','10333','Oracle: Datafiles limit','oracle.db_files_limit','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Max allowable number of  datafile.','0','30d','0','','31638','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31684','18','','10333','Oracle: Disk sort per second','oracle.disk_sorts','0','7d','365d','0','0','','Rps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of sorts going to disk per second','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31685','18','','10333','Oracle: Enqueue timeouts per second','oracle.enqueue_timeouts_rate','0','7d','365d','0','0','','Rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Enqueue timeouts per second.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31686','18','','10333','Oracle: FRA, Number of files','oracle.fra_number_of_files','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of files in the fast recovery area','0','30d','0','','31631','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31687','18','','10333','Oracle: FRA, Number of restore points','oracle.fra_restore_point','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','31631','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31688','18','','10333','Oracle: FRA, Space limit','oracle.fra_space_limit','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum amount of disk space (in bytes) that the database can use for the fast recovery area.','0','30d','0','','31631','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31689','18','','10333','Oracle: FRA, Used space','oracle.fra_space_used','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Amount of disk space (in bytes) used by fast recovery area files created in current and all previous fast recovery areas.','0','30d','0','','31631','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31690','18','','10333','Oracle: Physical writes bytes per second','oracle.physical_write_bytes_rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Write bytes per second.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31691','18','','10333','Oracle: FRA, Usable space in %','oracle.fra_usable_pct','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','31631','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31692','18','','10333','Oracle: GC CR block received per second','oracle.gc_cr_block_received_rate','0','7d','365d','0','0','','Rps','','',NULL,NULL,'','','0','','','','','0',NULL,'GC CR block received per second.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31693','18','','10333','Oracle: Instance hostname','oracle.instance_hostname','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Name of the host machine.','0','30d','0','','31637','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31694','18','','10333','Oracle: Instance name','oracle.instance_name','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Name of the instance.','0','30d','0','','31637','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31695','18','','10333','Oracle: Instance status','oracle.instance_status','0','7d','365d','0','3','','','','',NULL,'114','','','0','','','','','0',NULL,'Status of the instance.','0','30d','0','','31637','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31696','18','','10333','Oracle: Instance role','oracle.instance.role','0','7d','365d','0','3','','','','',NULL,'115','','','0','','','','','0',NULL,'Indicates whether the instance is an active instance or an inactive secondary instance.','0','30d','0','','31637','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31697','18','','10333','Oracle: Library cache hit ratio','oracle.library_cache_hit_ratio','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Ratio of library cache hits. Hits/Pins','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31698','18','','10333','Oracle: Logons per second','oracle.logons_rate','0','7d','365d','0','0','','Rps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of logon attempts.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31699','18','','10333','Oracle: Long table scans per second','oracle.long_table_scans_rate','0','7d','365d','0','0','','Rps','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of long table scans per second. A table is considered ''long'' if the table is not cached and if its high-water mark is greater than 5 blocks.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31700','18','','10333','Oracle: Memory sorts ratio','oracle.memory_sorts_ratio','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'The percentage of sorts (from ORDER BY clauses or index building) that are done to disk vs in-memory.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31701','18','','10333','Oracle: PGA, Global memory bound','oracle.pga_global_bound','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum size of a work area executed in automatic mode.','0','30d','0','','31639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31702','18','','10333','Oracle: PGA, Aggregate target parameter','oracle.pga_target','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current value of the PGA_AGGREGATE_TARGET initialization parameter. If this parameter is not set, then its value is 0 and automatic management of PGA memory is disabled.','0','30d','0','','31639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31703','18','','10333','Oracle: Active serial sessions','oracle.active_serial_sessions','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of active serial sessions.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31704','18','','10333','Oracle: Physical reads per second','oracle.physical_reads_rate','0','7d','365d','0','0','','Rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Reads per second.','0','30d','0','','31636','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31705','18','','10333','Oracle: Version','oracle.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Oracle Server version.','0','30d','0','','31637','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31711','18','','10333','Archivelog ''{#DEST_NAME}'': Error','oracle.archivelog_error["{#DEST_NAME}"]','0','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Displays the error text','0','30d','0','','31642','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31712','18','','10333','Archivelog ''{#DEST_NAME}'': Last sequence','oracle.archivelog_log_sequence["{#DEST_NAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Identifies the sequence number of the last archived redo log to be archived','0','30d','0','','31642','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31713','18','','10333','Archivelog ''{#DEST_NAME}'': Status','oracle.archivelog_log_status["{#DEST_NAME}"]','0','7d','365d','0','3','','','','',NULL,'118','','','0','','','','','2',NULL,'Identifies the current status of the destination: 1 - ''Valid'', 2 - ''Dederred'',3 - ''Error'', 0 - ''Unknown''','0','30d','0','','31642','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31714','18','','10333','Oracle Database ''{#DBNAME}'': Force logging','oracle.db_force_logging["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,'119','','','0','','','','','2',NULL,'Indicates whether the database is under force logging mode (YES) or not (NO)','0','30d','0','','31644','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31715','18','','10333','Oracle Database ''{#DBNAME}'': Log mode','oracle.db_log_mode["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,'120','','','0','','','','','2',NULL,'Archive log mode, 0 - ''NOARCHIVELOG'', 1 - ''ARCHIVELOG'', 2 - ''MANUAL''','0','30d','0','','31644','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31716','18','','10333','Oracle Database ''{#DBNAME}'': Open status','oracle.db_open_mode["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,'112','','','0','','','','','2',NULL,'1 - ''MOUNTED'', 2 - ''READ WRITE'', 3 - ''READ ONLY'', 4 - ''READ ONLY WITH APPLY'' (A physical standby database is open in real-time query mode)','0','30d','0','','31644','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31717','18','','10333','Oracle Database ''{#DBNAME}'': Role','oracle.db_role["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,'113','','','0','','','','','2',NULL,'Current role of the database, 1 - ''SNAPSHOT STANDBY'', 2 - ''LOGICAL STANDBY'', 3 - ''PHYSICAL STANDBY'', 4 - ''PRIMARY '', 5 -''FAR SYNC''','0','30d','0','','31644','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31718','18','','10333','ASM ''{#DG_NAME}'': Free size','oracle.asm_free_size["{#DG_NAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Free size of ASM disk group.','0','30d','0','','31635','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31719','18','','10333','ASM ''{#DG_NAME}'': Total size','oracle.asm_total_size["{#DG_NAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total size of ASM disk group.','0','30d','0','','31635','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31720','18','','10333','ASM ''{#DG_NAME}'': Free size','oracle.asm_used_pct["{#DG_NAME}"]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Usage percent of ASM disk group.','0','30d','0','','31635','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31721','18','','10333','Oracle Database ''{#DBNAME}'': Open status','oracle.pdb_open_mode["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,'112','','','0','','','','','2',NULL,'1 - ''MOUNTED'', 2 - ''READ WRITE'', 3 - ''READ ONLY'', 4 - ''READ ONLY WITH APPLY'' (A physical standby database is open in real-time query mode)','0','30d','0','','31634','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31722','18','','10333','Oracle TBS ''{#TABLESPACE}'': Tablespace allocated, bytes','oracle.tbs_alloc_bytes["{#TABLESPACE}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Currently allocated bytes for tablespace (sum of the current size of datafiles).','0','30d','0','','31645','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31723','18','','10333','Oracle TBS ''{#TABLESPACE}'': Tablespace free, bytes','oracle.tbs_free_bytes["{#TABLESPACE}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Free bytes of allocated space.','0','30d','0','','31645','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31724','18','','10333','Oracle TBS ''{#TABLESPACE}'': Tablespace MAX size, bytes','oracle.tbs_max_bytes["{#TABLESPACE}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Maximum size of tablespace.','0','30d','0','','31645','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31725','18','','10333','Oracle TBS ''{#TABLESPACE}'': Open status','oracle.tbs_status["{#TABLESPACE}"]','0','7d','365d','0','3','','','','',NULL,'117','','','0','','','','','2',NULL,'Tablespace status. 1 - ''ONLINE'' 2 - ''OFFLINE'' 3- ''READ ONLY''','0','30d','0','','31645','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31726','18','','10333','Oracle TBS ''{#TABLESPACE}'': Tablespace allocated, percent','oracle.tbs_used_pct["{#TABLESPACE}"]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Allocated bytes/Max bytes*100','0','30d','0','','31645','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31805','18','','10334','Ceph: Number of OSDs in state: UP','ceph.num_osd_up','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of online storage daemons in Ceph cluster','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31806','18','','10334','Ceph: Number of Placement Groups in Undersized state','ceph.pg_states.undersized','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in undersized state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31807','18','','10334','Ceph: Number of Placement Groups in Clean state','ceph.pg_states.clean','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in clean state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31808','18','','10334','Ceph: Number of Placement Groups in degraded state','ceph.pg_states.degraded','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in degraded state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31809','18','','10334','Ceph: Number of Placement Groups in inconsistent state','ceph.pg_states.inconsistent','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in inconsistent state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31810','18','','10334','Ceph: Number of Placement Groups in Peering state','ceph.pg_states.peering','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in peering state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31811','18','','10334','Ceph: Number of Placement Groups in recovering state','ceph.pg_states.recovering','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in recovering state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31812','18','','10334','Ceph: Number of Placement Groups in recovery_wait state','ceph.pg_states.recovery_wait','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in recovery_wait state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31813','18','','10334','Ceph: Number of Placement Groups in remapped state','ceph.pg_states.remapped','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in remapped state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31814','18','','10334','Ceph: Number of Placement Groups in Scrubbing state','ceph.pg_states.scrubbing','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in scrubbing state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31815','18','','10334','Ceph: Number of Placement Groups in Unknown state','ceph.pg_states.unknown','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in unknown state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31816','18','','10334','Ceph: Number of Placement Groups in backfill_wait state','ceph.pg_states.backfill_wait','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in backfill_wait state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31817','18','','10334','Ceph: Number of OSDs','ceph.num_osd','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of known storage daemons in Ceph cluster','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31818','18','','10334','Ceph: Ceph Read bandwidth','ceph.rd_bytes.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Global read Bytes per second','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31819','18','','10334','Ceph: Ceph Read operations per sec','ceph.rd_ops.rate','0','7d','365d','0','0','','ops','','',NULL,NULL,'','','0','','','','','0',NULL,'Global read operations per second','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31820','18','','10334','Ceph: Number of Monitors','ceph.num_mon','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of Monitors configured in Ceph cluster','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31821','18','','10334','Ceph: Total bytes available','ceph.total_avail_bytes','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total bytes available in Ceph cluster','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31822','18','','10334','Ceph: Total bytes','ceph.total_bytes','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total (RAW) capacity of Ceph cluster in bytes','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31823','18','','10334','Ceph: Total number of objects','ceph.total_objects','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of objects in Ceph cluster','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31824','18','','10334','Ceph: Total bytes used','ceph.total_used_bytes','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Total bytes used in Ceph cluster','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31825','18','','10334','Ceph: Ceph Write bandwidth','ceph.wr_bytes.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Global write Bytes per second','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31826','18','','10334','Ceph: Number of Placement Groups in Backfilling state','ceph.pg_states.backfilling','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in backfilling state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31827','18','','10334','Ceph: Number of Placement Groups in backfill_toofull state','ceph.pg_states.backfill_toofull','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in backfill_toofull state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31828','18','','10334','Ceph: Number of Placement Groups','ceph.num_pg','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in Ceph cluster','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31829','18','','10334','Ceph: Ceph OSD Apply latency Min','ceph.osd_latency_apply.min','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Minimum apply latency of OSDs','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31830','18','','10334','Ceph: Number of Placement Groups in Temporary state','ceph.num_pg_temp','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in pg_temp state','0','30d','0','','31801','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31831','18','','10334','Ceph: Number of Pools','ceph.num_pools','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of pools in Ceph cluster','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31832','18','','10334','Ceph: Ceph backfill full ratio','ceph.osd_backfillfull_ratio','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Backfill full ratio setting of Ceph cluster as configured on OSDMap','0','30d','0','','31801','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31833','18','','10334','Ceph: Ceph OSD avg fill','ceph.osd_fill.avg','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Average fill of OSDs','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31834','18','','10334','Ceph: Ceph OSD max fill','ceph.osd_fill.max','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Percentage fill of maximum filled OSD','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31835','18','','10334','Ceph: Ceph OSD min fill','ceph.osd_fill.min','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Percentage fill of minimum filled OSD','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31836','18','','10334','Ceph: Ceph full ratio','ceph.osd_full_ratio','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Full ratio setting of Ceph cluster as configured on OSDMap','0','30d','0','','31801','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31837','18','','10334','Ceph: Ceph OSD Apply latency Avg','ceph.osd_latency_apply.avg','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Average apply latency of OSDs','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31838','18','','10334','Ceph: Ceph OSD Apply latency Max','ceph.osd_latency_apply.max','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum apply latency of OSDs','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31839','18','','10334','Ceph: Ceph OSD Commit latency Avg','ceph.osd_latency_commit.avg','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Average commit latency of OSDs','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31840','18','','10334','Ceph: Number of Placement Groups in Active state','ceph.pg_states.active','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of Placement Groups in active state','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31841','18','','10334','Ceph: Ceph OSD Commit latency Max','ceph.osd_latency_commit.max','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum commit latency of OSDs','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31842','18','','10334','Ceph: Ceph OSD Commit latency Min','ceph.osd_latency_commit.min','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Minimum commit latency of OSDs','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31843','18','','10334','Ceph: Ceph nearfull ratio','ceph.osd_nearfull_ratio','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Near full ratio setting of Ceph cluster as configured on OSDMap','0','30d','0','','31801','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31844','18','','10334','Ceph: Ceph OSD avg PGs','ceph.osd_pgs.avg','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Average amount of PGs on OSDs','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31845','18','','10334','Ceph: Ceph OSD max PGs','ceph.osd_pgs.max','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum amount of PGs on OSDs','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31846','18','','10334','Ceph: Ceph OSD min PGs','ceph.osd_pgs.min','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Minimum amount of PGs on OSDs','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31847','18','','10334','Ceph: Number of OSDs in state: IN','ceph.num_osd_in','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of participating storage daemons in Ceph cluster','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31848','18','','10334','Ceph: Minimum Mon release version','ceph.min_mon_release_name','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'min_mon_release_name','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31849','18','','10334','Ceph: Overall cluster status','ceph.overall_status','0','7d','365d','0','3','','','','',NULL,'121','','','0','','','','','0',NULL,'Overall Ceph cluster status, eg 0 - HEALTH_OK, 1 - HEALTH_WARN or 2 - HEALTH_ERR','0','30d','0','','31802','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31850','18','','10334','Ceph: Ceph Write operations per sec','ceph.wr_ops.rate','0','7d','365d','0','0','','ops','','',NULL,NULL,'','','0','','','','','0',NULL,'Global write operations per second','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31853','18','','10334','Ceph: [osd.{#OSDNAME}] OSD fill','ceph.osd[{#OSDNAME},fill]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31854','18','','10334','Ceph: [osd.{#OSDNAME}] OSD in','ceph.osd[{#OSDNAME},in]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','31801','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31855','18','','10334','Ceph: [osd.{#OSDNAME}] OSD latency apply','ceph.osd[{#OSDNAME},latency_apply]','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','2',NULL,'Time taken to flush an update to disks.','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31856','18','','10334','Ceph: [osd.{#OSDNAME}] OSD latency commit','ceph.osd[{#OSDNAME},latency_commit]','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','2',NULL,'Time taken to commit an operation to the journal.','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31857','18','','10334','Ceph: [osd.{#OSDNAME}] OSD PGs','ceph.osd[{#OSDNAME},num_pgs]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','31804','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31858','18','','10334','Ceph: [osd.{#OSDNAME}] OSD up','ceph.osd[{#OSDNAME},up]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','31801','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31875','18','','10335','PHP-FPM: Slow requests','php-fpm.slow_requests','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of requests that exceeded your request_slowlog_timeout value.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31876','18','','10335','PHP-FPM: Version','php-fpm.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Current version PHP. Get from HTTP-Header "X-Powered-By" and may not work if you change default HTTP-headers.','0','30d','0','','31869','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31877','18','','10335','PHP-FPM: Uptime','php-fpm.uptime','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'How long has this pool been running.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31878','18','','10335','PHP-FPM: Start time','php-fpm.start_time','0','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'The time when this pool was started.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31879','18','','10335','PHP-FPM: Accepted connections per second','php-fpm.conn_accepted.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of accepted requests per second.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31880','18','','10335','PHP-FPM: Processes, total','php-fpm.processes_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of server processes currently running.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31881','18','','10335','PHP-FPM: Listen queue','php-fpm.listen_queue','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of connections that have been initiated, but not yet accepted.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31882','18','','10335','PHP-FPM: Processes, idle','php-fpm.processes_idle','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of idle processes.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31883','18','','10335','PHP-FPM: Processes, active','php-fpm.processes_active','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of active processes.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31884','18','','10335','PHP-FPM: Process manager','php-fpm.process_manager','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The method used by the process manager to control the number of child processes for this pool.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31885','18','','10335','PHP-FPM: Ping','php-fpm.ping','0','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','','31869','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31886','18','','10335','PHP-FPM: Pool name','php-fpm.name','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The name of current pool.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31887','18','','10335','PHP-FPM: Max children reached','php-fpm.max_children','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of times that pm.max_children has been reached since the php-fpm pool started','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31888','18','','10335','PHP-FPM: Listen queue, max','php-fpm.listen_queue_max','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The maximum number of requests in the queue of pending connections since this FPM pool has started.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31889','18','','10335','PHP-FPM: Listen queue, len','php-fpm.listen_queue_len','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Size of the socket queue of pending connections.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31890','18','','10335','PHP-FPM: Processes, max active','php-fpm.processes_max_active','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The highest value that ''active processes'' has reached since the php-fpm server started.','0','30d','0','','31868','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31894','18','','10336','PHP-FPM: Accepted connections per second','php-fpm.conn_accepted.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of accepted requests per second.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31895','18','','10336','PHP-FPM: Processes, idle','php-fpm.processes_idle','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of idle processes.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31896','18','','10336','PHP-FPM: Uptime','php-fpm.uptime','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'How long has this pool been running.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31897','18','','10336','PHP-FPM: Start time','php-fpm.start_time','0','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'The time when this pool was started.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31898','18','','10336','PHP-FPM: Slow requests','php-fpm.slow_requests','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of requests that exceeded your request_slowlog_timeout value.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31899','18','','10336','PHP-FPM: Processes, total','php-fpm.processes_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of server processes currently running.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31900','18','','10336','PHP-FPM: Processes, max active','php-fpm.processes_max_active','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The highest value that ''active processes'' has reached since the php-fpm server started.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31901','18','','10336','PHP-FPM: Ping','php-fpm.ping','0','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'','0','30d','0','','31893','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31902','18','','10336','PHP-FPM: Processes, active','php-fpm.processes_active','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of active processes.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31903','18','','10336','PHP-FPM: Process manager','php-fpm.process_manager','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The method used by the process manager to control the number of child processes for this pool.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31904','18','','10336','PHP-FPM: Pool name','php-fpm.name','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The name of current pool.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31905','18','','10336','PHP-FPM: Max children reached','php-fpm.max_children','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of times that pm.max_children has been reached since the php-fpm pool started','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31906','18','','10336','PHP-FPM: Listen queue, max','php-fpm.listen_queue_max','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The maximum number of requests in the queue of pending connections since this FPM pool has started.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31907','18','','10336','PHP-FPM: Listen queue, len','php-fpm.listen_queue_len','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Size of the socket queue of pending connections.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31908','18','','10336','PHP-FPM: Listen queue','php-fpm.listen_queue','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of connections that have been initiated, but not yet accepted.','0','30d','0','','31892','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31909','18','','10336','PHP-FPM: Version','php-fpm.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Current version PHP. Get from HTTP-Header "X-Powered-By" and may not work if you change default HTTP-headers.','0','30d','0','','31893','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32003','18','','10334','Ceph: [{#POOLNAME}] Pool Used','ceph.pool["{#POOLNAME}",bytes_used]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total bytes used in pool.','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32004','18','','10334','Ceph: [{#POOLNAME}] Max available','ceph.pool["{#POOLNAME}",max_avail]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The maximum available space in the given pool.','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32005','18','','10334','Ceph: [{#POOLNAME}] Pool objects','ceph.pool["{#POOLNAME}",objects]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of objects in the pool.','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32006','18','','10334','Ceph: [{#POOLNAME}] Pool Percent Used','ceph.pool["{#POOLNAME}",percent_used]','0','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Percentage of storage used per pool','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32007','18','','10334','Ceph: [{#POOLNAME}] Pool Read bandwidth','ceph.pool["{#POOLNAME}",rd_bytes.rate]','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Per-pool read Bytes/second','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32008','18','','10334','Ceph: [{#POOLNAME}] Pool Read operations','ceph.pool["{#POOLNAME}",rd_ops.rate]','0','7d','365d','0','0','','ops','','',NULL,NULL,'','','0','','','','','2',NULL,'Per-pool read operations/second','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32009','18','','10334','Ceph: [{#POOLNAME}] Pool RAW Used','ceph.pool["{#POOLNAME}",stored_raw]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Bytes used in pool including copies made.','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32010','18','','10334','Ceph: [{#POOLNAME}] Pool Write bandwidth','ceph.pool["{#POOLNAME}",wr_bytes.rate]','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Per-pool write Bytes/second','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32011','18','','10334','Ceph: [{#POOLNAME}] Pool Write operations','ceph.pool["{#POOLNAME}",wr_ops.rate]','0','7d','365d','0','0','','ops','','',NULL,NULL,'','','0','','','','','2',NULL,'Per-pool write operations/second','0','30d','0','','31800','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32020','18','','10339','NameNode: Missing blocks','hadoop.namenode.missing_blocks','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of missing blocks.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32021','18','','10339','ResourceManager: Decommissioned NMs','hadoop.resourcemanager.num_decommissioned_nm','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of Decommissioned NodeManagers.','0','30d','0','','32017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32022','18','','10339','NameNode: Total blocks','hadoop.namenode.blocks_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of blocks tracked by NameNode.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32023','18','','10339','NameNode: Capacity remaining','hadoop.namenode.capacity_remaining','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Available capacity.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32024','18','','10339','NameNode: Corrupt blocks','hadoop.namenode.corrupt_blocks','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of corrupt blocks.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32025','18','','10339','ResourceManager: Uptime','hadoop.resourcemanager.uptime','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','32017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32026','18','','10339','ResourceManager: RPC queue & processing time','hadoop.resourcemanager.rpc_processing_time_avg','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Average time spent on processing RPC requests.','0','30d','0','','32017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32027','18','','10339','ResourceManager: Unhealthy NMs','hadoop.resourcemanager.num_unhealthy_nm','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of Unhealthy NodeManagers.','0','30d','0','','32017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32028','18','','10339','ResourceManager: Shutdown NMs','hadoop.resourcemanager.num_shutdown_nm','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of Shutdown NodeManagers.','0','30d','0','','32017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32029','18','','10339','ResourceManager: Rebooted NMs','hadoop.resourcemanager.num_rebooted_nm','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of Rebooted NodeManagers.','0','30d','0','','32017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32030','18','','10339','ResourceManager: Lost NMs','hadoop.resourcemanager.num_lost_nm','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of Lost NodeManagers.','0','30d','0','','32017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32031','18','','10339','ResourceManager: Decommissioning NMs','hadoop.resourcemanager.num_decommissioning_nm','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of Decommissioning NodeManagers.','0','30d','0','','32017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32032','18','','10339','NameNode: Total files','hadoop.namenode.files_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total count of files tracked by the NameNode.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32033','18','','10339','ResourceManager: Active NMs','hadoop.resourcemanager.num_active_nm','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of Active NodeManagers.','0','30d','0','','32017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32034','18','','10339','NameNode: Dead DataNodes','hadoop.namenode.num_dead_data_nodes','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of dead DataNodes.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32035','18','','10339','NameNode: Failed volumes','hadoop.namenode.volume_failures_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of failed volumes.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32036','18','','10339','NameNode: Blocks allocable','hadoop.namenode.block_capacity','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum number of blocks allocable.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32037','18','','10339','NameNode: Under-replicated blocks','hadoop.namenode.under_replicated_blocks','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of blocks with insufficient replication.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32038','18','','10339','NameNode: Transactions since last checkpoint','hadoop.namenode.transactions_since_last_checkpoint','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of transactions since last checkpoint.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32039','18','','10339','NameNode: Total load','hadoop.namenode.total_load','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of concurrent file accesses (read/write) across all DataNodes.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32040','18','','10339','NameNode: RPC queue & processing time','hadoop.namenode.rpc_processing_time_avg','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Average time spent on processing RPC requests.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32041','18','','10339','NameNode: Percent capacity remaining','hadoop.namenode.percent_remaining','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'Available capacity in percent.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32042','18','','10339','NameNode: Block Pool Renaming','hadoop.namenode.percent_block_pool_used','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32043','18','','10339','NameNode: Stale DataNodes','hadoop.namenode.num_stale_data_nodes','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'DataNodes that do not send a heartbeat within 30 seconds are marked as "stale".','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32044','18','','10339','NameNode: Alive DataNodes','hadoop.namenode.num_live_data_nodes','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of alive DataNodes.','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32045','18','','10339','NameNode: Uptime','hadoop.namenode.uptime','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'','0','30d','0','','32019','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32050','18','','10339','{#HOSTNAME}: Admin state','hadoop.datanode.admin_state[{#HOSTNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Administrative state.','0','30d','0','','32012','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32051','18','','10339','{#HOSTNAME}: Used','hadoop.datanode.dfs_used[{#HOSTNAME}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Used disk space.','0','30d','0','','32048','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32052','18','','10339','{#HOSTNAME}: JVM Garbage collection time','hadoop.datanode.jvm.gc_time[{#HOSTNAME}]','0','7d','365d','0','3','','!ms','','',NULL,NULL,'','','0','','','','','2',NULL,'The JVM garbage collection time in milliseconds.','0','30d','0','','32048','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32053','18','','10339','{#HOSTNAME}: JVM Heap usage','hadoop.datanode.jvm.mem_heap_used[{#HOSTNAME}]','0','7d','365d','0','0','','!MB','','',NULL,NULL,'','','0','','','','','2',NULL,'The JVM heap usage in MBytes.','0','30d','0','','32048','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32054','18','','10339','{#HOSTNAME}: JVM Threads','hadoop.datanode.jvm.threads[{#HOSTNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of JVM threads.','0','30d','0','','32048','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32055','18','','10339','{#HOSTNAME}: Number of failed volumes','hadoop.datanode.numfailedvolumes[{#HOSTNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of failed storage volumes.','0','30d','0','','32048','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32056','18','','10339','{#HOSTNAME}: Oper state','hadoop.datanode.oper_state[{#HOSTNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Operational state.','0','30d','0','','32012','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32057','18','','10339','{#HOSTNAME}: Remaining','hadoop.datanode.remaining[{#HOSTNAME}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Remaining disk space.','0','30d','0','','32048','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32058','18','','10339','{#HOSTNAME}: Uptime','hadoop.datanode.uptime[{#HOSTNAME}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32048','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32059','18','','10339','{#HOSTNAME}: Version','hadoop.datanode.version[{#HOSTNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'DataNode software version.','0','30d','0','','32012','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32060','18','','10339','{#HOSTNAME}: Available memory','hadoop.nodemanager.availablememory[{#HOSTNAME}]','0','7d','365d','0','3','','!MB','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32013','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32061','18','','10339','{#HOSTNAME}: Container launch avg duration','hadoop.nodemanager.container_launch_duration_avg[{#HOSTNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32049','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32062','18','','10339','{#HOSTNAME}: JVM Garbage collection time','hadoop.nodemanager.jvm.gc_time[{#HOSTNAME}]','0','7d','365d','0','3','','!ms','','',NULL,NULL,'','','0','','','','','2',NULL,'The JVM garbage collection time in milliseconds.','0','30d','0','','32049','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32063','18','','10339','{#HOSTNAME}: JVM Heap usage','hadoop.nodemanager.jvm.mem_heap_used[{#HOSTNAME}]','0','7d','365d','0','0','','!MB','','',NULL,NULL,'','','0','','','','','2',NULL,'The JVM heap usage in MBytes.','0','30d','0','','32049','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32064','18','','10339','{#HOSTNAME}: JVM Threads','hadoop.nodemanager.jvm.threads[{#HOSTNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of JVM threads.','0','30d','0','','32049','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32065','18','','10339','{#HOSTNAME}: Number of containers','hadoop.nodemanager.numcontainers[{#HOSTNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32013','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32066','18','','10339','{#HOSTNAME}: RPC queue & processing time','hadoop.nodemanager.rpc_processing_time_avg[{#HOSTNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Average time spent on processing RPC requests.','0','30d','0','','32049','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32067','18','','10339','{#HOSTNAME}: State','hadoop.nodemanager.state[{#HOSTNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'State of the node - valid values are: NEW, RUNNING, UNHEALTHY, DECOMMISSIONING, DECOMMISSIONED, LOST, REBOOTED, SHUTDOWN.','0','30d','0','','32013','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32068','18','','10339','{#HOSTNAME}: Uptime','hadoop.nodemanager.uptime[{#HOSTNAME}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32049','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32069','18','','10339','{#HOSTNAME}: Used memory','hadoop.nodemanager.usedmemory[{#HOSTNAME}]','0','7d','365d','0','3','','!MB','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32013','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32070','18','','10339','{#HOSTNAME}: Version','hadoop.nodemanager.version[{#HOSTNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32013','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32160','18','','10341','Zookeeper: Approximate data size','zookeeper.approximate_data_size','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Data tree size in bytes.The size includes the znode path and its value.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32161','18','','10341','Zookeeper: Outstanding requests','zookeeper.outstanding_requests','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of queued requests when the server is under load and is receiving more sustained requests than it can process.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32162','18','','10341','Zookeeper: Latency, max','zookeeper.max_latency','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'The maximum amount of time it takes for the server to respond to a client request.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32163','18','','10341','Zookeeper: Latency, min','zookeeper.min_latency','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'The minimum amount of time it takes for the server to respond to a client request.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32164','18','','10341','Zookeeper: Alive connections','zookeeper.num_alive_connections','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of active clients connected to a zookeeper server.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32165','18','','10341','Zookeeper: File descriptors, open','zookeeper.open_file_descriptor_count','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of file descriptors that a zookeeper server has open.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32166','18','','10341','Zookeeper: Packets received per sec','zookeeper.packets_received.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of zookeeper packets received by a server per second.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32167','18','','10341','Zookeeper: Looking per sec','zookeeper.looking_count.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of transitions into looking state.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32168','18','','10341','Zookeeper: Packets sent per sec','zookeeper.packets_sent','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of zookeeper packets sent from a server per second.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32169','18','','10341','Zookeeper: Revalidate per sec','zookeeper.revalidate_count.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of revalidations.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32170','18','','10341','Zookeeper: Server mode','zookeeper.server_state','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Mode of the server. In an ensemble, this may either be leader or follower. Otherwise, it is standalone','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32171','18','','10341','Zookeeper: Snap syncs per sec','zookeeper.snap_count.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of snap syncs performed per second','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32172','18','','10341','Zookeeper: Uptime','zookeeper.uptime','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Uptime of Zookeeper server.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32173','18','','10341','Zookeeper: Version','zookeeper.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of Zookeeper server.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32174','18','','10341','Zookeeper: Watch count','zookeeper.watch_count','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of watches currently set on the local ZooKeeper process.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32175','18','','10341','Zookeeper: File descriptors, max','zookeeper.max_file_descriptor_count','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Maximum number of file descriptors that a zookeeper server can open.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32176','18','','10341','Zookeeper: Global sessions','zookeeper.global_sessions','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of global sessions.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32177','18','','10341','Zookeeper: Local sessions','zookeeper.local_sessions','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of local sessions.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32178','18','','10341','Zookeeper: Election time, avg','zookeeper.avg_election_time','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Time between entering and leaving election.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32179','18','','10341','Zookeeper: Ephemeral nodes count','zookeeper.ephemerals_count','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of ephemeral nodes that a zookeeper server has in its data tree.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32180','18','','10341','Zookeeper: Diff syncs per sec','zookeeper.diff_count.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of diff syncs performed per second','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32181','18','','10341','Zookeeper: Revalidate connections per sec','zookeeper.connection_revalidate_count.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate ofconnection revalidations.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32182','18','','10341','Zookeeper: Rejected connections per sec','zookeeper.connection_rejected.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of connection rejected.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32183','18','','10341','Zookeeper: Drop connections per sec','zookeeper.connection_drop_count.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of connection drops.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32184','18','','10341','Zookeeper: Commit per sec','zookeeper.commit_count.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of commits performed per second','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32185','18','','10341','Zookeeper: Snapshot writes','zookeeper.cnt_snapshottime','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of performed snapshot writes.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32186','18','','10341','Zookeeper: Fsync','zookeeper.cnt_fsynctime','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of performed fsyncs.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32187','18','','10341','Zookeeper: Elections','zookeeper.cnt_election_time','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of elections happened.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32188','18','','10341','Zookeeper: Bytes received per sec','zookeeper.bytes_received_count.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of bytes received per second.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32189','18','','10341','Zookeeper: Snapshot write time, avg','zookeeper.avg_snapshottime','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Average time to write a snapshot.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32190','18','','10341','Zookeeper: Latency, avg','zookeeper.avg_latency','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'The average amount of time it takes for the server to respond to a client request.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32191','18','','10341','Zookeeper: Fsync time, avg','zookeeper.avg_fsynctime','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','0',NULL,'Time to fsync transaction log.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32192','18','','10341','Zookeeper: Znode count','zookeeper.znode_count','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of znodes in the ZooKeeper namespace (the data)','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32194','18','','10341','Leader metrics discovery','zookeeper.metrics.leader','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Additional metrics for leader node','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32195','18','','10341','Zookeeper client {#TYPE} [{#CLIENT}]: Latency, avg','zookeeper.avg_latency[{#TYPE},{#CLIENT}]','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','2',NULL,'The average amount of time it takes for the server to respond to a client request.','0','30d','0','','32159','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32196','18','','10341','Zookeeper client {#TYPE} [{#CLIENT}]: Latency, max','zookeeper.max_latency[{#TYPE},{#CLIENT}]','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','2',NULL,'The maximum amount of time it takes for the server to respond to a client request.','0','30d','0','','32159','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32197','18','','10341','Zookeeper client {#TYPE} [{#CLIENT}]: Latency, min','zookeeper.min_latency[{#TYPE},{#CLIENT}]','0','7d','365d','0','0','','ms','','',NULL,NULL,'','','0','','','','','2',NULL,'The minimum amount of time it takes for the server to respond to a client request.','0','30d','0','','32159','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32198','18','','10341','Zookeeper client {#TYPE} [{#CLIENT}]: Outstanding requests','zookeeper.outstanding_requests[{#TYPE},{#CLIENT}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of queued requests when the server is under load and is receiving more sustained requests than it can process.','0','30d','0','','32159','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32199','18','','10341','Zookeeper client {#TYPE} [{#CLIENT}]: Packets received per sec','zookeeper.packets_received[{#TYPE},{#CLIENT}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of packets received.','0','30d','0','','32159','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32200','18','','10341','Zookeeper client {#TYPE} [{#CLIENT}]: Packets sent per sec','zookeeper.packets_sent[{#TYPE},{#CLIENT}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of packets sent.','0','30d','0','','32159','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32201','18','','10341','Zookeeper: Learners{#SINGLETON}','zookeeper.learners[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of learners.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32202','18','','10341','Zookeeper: Pending syncs{#SINGLETON}','zookeeper.pending_syncs[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of pending syncs to carry out to ZooKeeper ensemble followers.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32203','18','','10341','Zookeeper: Quorum size{#SINGLETON}','zookeeper.quorum_size[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32204','18','','10341','Zookeeper: Synced followers{#SINGLETON}','zookeeper.synced_followers[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of synced followers reported when a node server_state is leader.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32205','18','','10341','Zookeeper: Synced non-voting follower{#SINGLETON}','zookeeper.synced_non_voting_followers[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of synced voting followers reported when a node server_state is leader.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32206','18','','10341','Zookeeper: Synced observers{#SINGLETON}','zookeeper.synced_observers[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of synced observers.','0','30d','0','','32158','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32306','18','','10254','Voltage discovery','voltage.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'ENTITY-SENSORS-MIB::EntitySensorDataType discovery with volts filter','0','30d','2','','28305','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32329','18','','10343','Battery voltage discovery','battery.voltage.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for battery voltage triggers','0','30d','0','','32325','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32349','18','','10344','Battery voltage discovery','battery.voltage.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for battery voltage triggers','0','30d','0','','32340','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32372','18','','10345','Battery voltage discovery','battery.voltage.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for battery voltage triggers','0','30d','0','','32368','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32381','18','','10346','Battery voltage discovery','battery.voltage.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for battery voltage triggers','0','30d','0','','32374','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32400','18','','10347','Battery voltage discovery','battery.voltage.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for battery voltage triggers','0','30d','0','','32395','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32419','18','','10348','Battery voltage discovery','battery.voltage.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for battery voltage triggers','0','30d','0','','32414','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32430','18','','10349','Battery voltage discovery','battery.voltage.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for battery voltage triggers','0','30d','0','','32421','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32431','18','','10349','Charge + Diversion mode discovery','controlmode.charge_diversion.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for device in charge and diversion modes','0','1h','0','','32422','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32432','18','','10349','Charge mode discovery','controlmode.charge.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for device in charge mode','0','1h','0','','32422','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32433','18','','10349','Diversion mode discovery','controlmode.diversion.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for device in diversion mode','0','1h','0','','32422','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32434','18','','10349','Load + Diversion mode discovery','controlmode.load_diversion.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for device in load and diversion modes','0','1h','0','','32422','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32435','18','','10349','Load mode discovery','controlmode.load.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery for device in load mode','0','1h','0','','32422','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32547','18','','10316','MySQL: Innodb buffer pool wait free','mysql.innodb_buffer_pool_wait_free','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times InnoDB waited for a free page before reading or creating a page. Normally, writes to the InnoDB buffer pool happen in the background. When no clean pages are available, dirty pages are flushed first in order to free some up. This counts the numbers of wait for this operation to finish. If this value is not small, look at the increasing innodb_buffer_pool_size.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32548','18','','10316','MySQL: Innodb number open files','mysql.innodb_num_open_files','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of open files held by InnoDB. InnoDB only.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32549','18','','10316','MySQL: Innodb log written','mysql.innodb_os_log_written','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of bytes written to the InnoDB log.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32550','18','','10316','MySQL: Open table definitions','mysql.open_table_definitions','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of cached table definitions.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32551','18','','10316','MySQL: Open tables','mysql.open_tables','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of tables that are open.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32552','18','','10316','MySQL: Binlog cache disk use','mysql.binlog_cache_disk_use','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of transactions that used a temporary disk cache because they could not fit in the regular binary log cache, being larger than binlog_cache_size.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32553','18','','10316','MariaDB discovery','mysql.extra_metric.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Additional metrics if MariaDB is used.','0','30d','0','','30431','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32554','18','','10316','MySQL: Binlog commits','mysql.binlog_commits[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of transactions committed to the binary log.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32555','18','','10316','MySQL: Binlog group commits','mysql.binlog_group_commits[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of group commits done to the binary log.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32556','18','','10316','MySQL: Master GTID wait count','mysql.master_gtid_wait_count[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of times MASTER_GTID_WAIT called.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32557','18','','10316','MySQL: Master GTID wait time','mysql.master_gtid_wait_time[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of time spent in MASTER_GTID_WAIT.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32558','18','','10316','MySQL: Master GTID wait timeouts','mysql.master_gtid_wait_timeouts[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of timeouts occurring in MASTER_GTID_WAIT.','0','30d','0','','30433','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32559','18','','10316','MySQL: Replication Slave SQL Running State {#MASTER_HOST}','mysql.slave_sql_running_state["{#MASTER_HOST}"]','0','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'This shows the state of the SQL driver threads.','0','30d','0','','30475','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32561','18','','10320','MySQL: Innodb buffer pool wait free','mysql.innodb_buffer_pool_wait_free','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times InnoDB waited for a free page before reading or creating a page. Normally, writes to the InnoDB buffer pool happen in the background. When no clean pages are available, dirty pages are flushed first in order to free some up. This counts the numbers of wait for this operation to finish. If this value is not small, look at the increasing innodb_buffer_pool_size.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32562','18','','10320','MySQL: Innodb number open files','mysql.innodb_num_open_files','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of open files held by InnoDB. InnoDB only.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32563','18','','10320','MySQL: Innodb log written','mysql.innodb_os_log_written','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of bytes written to the InnoDB log.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32564','18','','10320','MySQL: Open table definitions','mysql.open_table_definitions','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of cached table definitions.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32565','18','','10320','MySQL: Open tables','mysql.open_tables','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of tables that are open.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32566','18','','10320','MySQL: Binlog cache disk use','mysql.binlog_cache_disk_use','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of transactions that used a temporary disk cache because they could not fit in the regular binary log cache, being larger than binlog_cache_size.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32567','18','','10320','MariaDB discovery','mysql.extra_metric.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Additional metrics if MariaDB is used.','0','30d','0','','30637','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32568','18','','10320','MySQL: Binlog commits','mysql.binlog_commits[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of transactions committed to the binary log.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32569','18','','10320','MySQL: Binlog group commits','mysql.binlog_group_commits[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of group commits done to the binary log.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32570','18','','10320','MySQL: Master GTID wait count','mysql.master_gtid_wait_count[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of times MASTER_GTID_WAIT called.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32571','18','','10320','MySQL: Master GTID wait time','mysql.master_gtid_wait_time[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of time spent in MASTER_GTID_WAIT.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32572','18','','10320','MySQL: Master GTID wait timeouts','mysql.master_gtid_wait_timeouts[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of timeouts occurring in MASTER_GTID_WAIT.','0','30d','0','','30639','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32573','18','','10320','MySQL: Replication Slave SQL Running State {#MASTER_HOST}','mysql.replication.slave_sql_running_state["{#MASTER_HOST}"]','0','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'This shows the state of the SQL driver threads.','0','30d','0','','30681','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32575','18','','10317','MySQL: Innodb buffer pool wait free','mysql.innodb_buffer_pool_wait_free','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times InnoDB waited for a free page before reading or creating a page. Normally, writes to the InnoDB buffer pool happen in the background. When no clean pages are available, dirty pages are flushed first in order to free some up. This counts the numbers of wait for this operation to finish. If this value is not small, look at the increasing innodb_buffer_pool_size.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32576','18','','10317','MySQL: Innodb number open files','mysql.innodb_num_open_files','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of open files held by InnoDB. InnoDB only.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32577','18','','10317','MySQL: Innodb log written','mysql.innodb_os_log_written','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of bytes written to the InnoDB log.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32578','18','','10317','MySQL: Open table definitions','mysql.open_table_definitions','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of cached table definitions.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32579','18','','10317','MySQL: Open tables','mysql.open_tables','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of tables that are open.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32580','18','','10317','MySQL: Binlog cache disk use','mysql.binlog_cache_disk_use','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of transactions that used a temporary disk cache because they could not fit in the regular binary log cache, being larger than binlog_cache_size.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32581','18','','10317','MariaDB discovery','mysql.extra_metric.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Additional metrics if MariaDB is used.','0','30d','0','','30480','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32582','18','','10317','MySQL: Replication Slave SQL Running State {#MASTER_HOST}','mysql.slave_sql_running_state["{#MASTER_HOST}"]','0','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'This shows the state of the SQL driver threads.','0','30d','0','','30523','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32583','18','','10317','MySQL: Binlog commits','mysql.binlog_commits[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of transactions committed to the binary log.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32584','18','','10317','MySQL: Binlog group commits','mysql.binlog_group_commits[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of group commits done to the binary log.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32585','18','','10317','MySQL: Master GTID wait count','mysql.master_gtid_wait_count[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of times MASTER_GTID_WAIT called.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32586','18','','10317','MySQL: Master GTID wait time','mysql.master_gtid_wait_time[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of time spent in MASTER_GTID_WAIT.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32587','18','','10317','MySQL: Master GTID wait timeouts','mysql.master_gtid_wait_timeouts[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of timeouts occurring in MASTER_GTID_WAIT.','0','30d','0','','30479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32588','18','','10333','Oracle TBS ''{#TABLESPACE}'': Tablespace used, bytes','oracle.tbs_used_bytes["{#TABLESPACE}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Currently used bytes for tablespace (current size of datafiles-free space).','0','30d','0','','31645','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32589','18','','10333','Oracle TBS ''{#TABLESPACE}'': Tablespace usage, percent','oracle.tbs_used_file_pct["{#TABLESPACE}"]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Used bytes/Allocated bytes*100','0','30d','0','','31645','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32596','18','','10328','Checkpoint: Checkpoint sync time','pgsql.bgwriter.checkpoint_sync_time.rate','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Total amount of time that has been spent in the portion of checkpoint processing where files are synchronized to disk','0','30d','0','','31180','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32598','18','','10328','Application {#APPLICATION}: Replication flush lag','pgsql.replication.process.flush_lag["{#APPLICATION}"]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32595','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32599','18','','10328','Application {#APPLICATION}: Replication replay lag','pgsql.replication.process.replay_lag["{#APPLICATION}"]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32595','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32600','18','','10328','Application {#APPLICATION}: Replication write lag','pgsql.replication.process.write_lag["{#APPLICATION}"]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32595','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32744','18','','10355','SMART [{#NAME}]: ID {#ID} {#ATTRNAME}','smart.disk.error[{#NAME},{#ID}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32745','18','','10355','SMART [{#NAME}]: Critical warning','smart.disk.critical_warning[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'This field indicates critical warnings for the state of the controller.','0','30d','0','','32741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32746','18','','10355','SMART [{#NAME}]: Power on hours','smart.disk.hours[{#NAME}]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of hours in power-on state. The raw value of this attribute shows total count of hours (or minutes, or seconds, depending on manufacturer) in power-on state. "By default, the total expected lifetime of a hard disk in perfect condition is defined as 5 years (running every day and night on all days). This is equal to 1825 days in 24/7 mode or 43800 hours." On some pre-2005 drives, this raw value may advance erratically and/or "wrap around" (reset to zero periodically). https://en.wikipedia.org/wiki/S.M.A.R.T.#Known_ATA_S.M.A.R.T._attributes','0','30d','0','','32741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32747','18','','10355','SMART [{#NAME}]: Media errors','smart.disk.media_errors[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Contains the number of occurrences where the controller detected an unrecovered data integrity error. Errors such as uncorrectable ECC, CRC checksum failure, or LBA tag mismatch are included in this field.','0','30d','0','','32741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32748','18','','10355','SMART [{#NAME}]: Device model','smart.disk.model[{#NAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32749','18','','10355','SMART [{#NAME}]: Percentage used','smart.disk.percentage_used[{#NAME}]','0','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Contains a vendor specific estimate of the percentage of NVM subsystem life used based on the actual usage and the manufacturer’s prediction of NVM life. A value of 100 indicates that the estimated endurance of the NVM in the NVM subsystem has been consumed, but may not indicate an NVM subsystem failure. The value is allowed to exceed 100. Percentages greater than 254 shall be represented as 255. This value shall be updated once per power-on hour (when the controller is not in a sleep state).','0','30d','0','','32741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32750','18','','10355','SMART [{#NAME}]: Serial number','smart.disk.sn[{#NAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32751','18','','10355','SMART [{#NAME}]: Temperature','smart.disk.temperature[{#NAME}]','0','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'Current drive temperature.','0','30d','0','','32741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32752','18','','10355','SMART [{#NAME}]: Self-test passed','smart.disk.test[{#NAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The disk is passed the SMART self-test or not.','0','30d','0','','32741','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32756','18','','10356','SMART [{#NAME}]: ID {#ID} {#ATTRNAME}','smart.disk.error[{#NAME},{#ID}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32753','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32757','18','','10356','SMART [{#NAME}]: Critical warning','smart.disk.critical_warning[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'This field indicates critical warnings for the state of the controller.','0','30d','0','','32753','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32758','18','','10356','SMART [{#NAME}]: Power on hours','smart.disk.hours[{#NAME}]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of hours in power-on state. The raw value of this attribute shows total count of hours (or minutes, or seconds, depending on manufacturer) in power-on state. "By default, the total expected lifetime of a hard disk in perfect condition is defined as 5 years (running every day and night on all days). This is equal to 1825 days in 24/7 mode or 43800 hours." On some pre-2005 drives, this raw value may advance erratically and/or "wrap around" (reset to zero periodically). https://en.wikipedia.org/wiki/S.M.A.R.T.#Known_ATA_S.M.A.R.T._attributes','0','30d','0','','32753','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32759','18','','10356','SMART [{#NAME}]: Media errors','smart.disk.media_errors[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Contains the number of occurrences where the controller detected an unrecovered data integrity error. Errors such as uncorrectable ECC, CRC checksum failure, or LBA tag mismatch are included in this field.','0','30d','0','','32753','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32760','18','','10356','SMART [{#NAME}]: Device model','smart.disk.model[{#NAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32753','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32761','18','','10356','SMART [{#NAME}]: Percentage used','smart.disk.percentage_used[{#NAME}]','0','7d','365d','0','3','','%','','',NULL,NULL,'','','0','','','','','2',NULL,'Contains a vendor specific estimate of the percentage of NVM subsystem life used based on the actual usage and the manufacturer’s prediction of NVM life. A value of 100 indicates that the estimated endurance of the NVM in the NVM subsystem has been consumed, but may not indicate an NVM subsystem failure. The value is allowed to exceed 100. Percentages greater than 254 shall be represented as 255. This value shall be updated once per power-on hour (when the controller is not in a sleep state).','0','30d','0','','32753','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32762','18','','10356','SMART [{#NAME}]: Serial number','smart.disk.sn[{#NAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','32753','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32763','18','','10356','SMART [{#NAME}]: Temperature','smart.disk.temperature[{#NAME}]','0','7d','365d','0','3','','°C','','',NULL,NULL,'','','0','','','','','2',NULL,'Current drive temperature.','0','30d','0','','32753','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32764','18','','10356','SMART [{#NAME}]: Self-test passed','smart.disk.test[{#NAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The disk is passed the SMART self-test or not.','0','30d','0','','32753','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32840','18','','10358','RabbitMQ: Messages returned unroutable','rabbitmq.overview.messages.return_unroutable','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages returned to publisher as unroutable','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32841','18','','10358','RabbitMQ: Messages unacknowledged','rabbitmq.overview.queue_totals.messages.unacknowledged','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of unacknowledged messages','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32842','18','','10358','RabbitMQ: Messages ready for delivery','rabbitmq.overview.queue_totals.messages.ready','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of messages ready for deliver','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32843','18','','10358','RabbitMQ: Messages total','rabbitmq.overview.queue_totals.messages','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of messages (ready plus unacknowledged)','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32844','18','','10358','RabbitMQ: Queues total','rabbitmq.overview.object_totals.queues','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of queues','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32845','18','','10358','RabbitMQ: Exchanges total','rabbitmq.overview.object_totals.exchanges','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of exchanges','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32846','18','','10358','RabbitMQ: Consumers total','rabbitmq.overview.object_totals.consumers','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of consumers','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32847','18','','10358','RabbitMQ: Connections total','rabbitmq.overview.object_totals.connections','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32848','18','','10358','RabbitMQ: Channels total','rabbitmq.overview.object_totals.channels','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of channels','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32849','18','','10358','RabbitMQ: Messages returned unroutable per second','rabbitmq.overview.messages.return_unroutable.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages returned to publisher as unroutable per second','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32850','18','','10358','RabbitMQ: Messages acknowledged','rabbitmq.overview.messages.ack','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of messages delivered to clients and acknowledged','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32851','18','','10358','RabbitMQ: Messages acknowledged per second','rabbitmq.overview.messages.ack.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages delivered to clients and acknowledged per second','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32852','18','','10358','RabbitMQ: Messages returned redeliver','rabbitmq.overview.messages.redeliver','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32853','18','','10358','RabbitMQ: Messages publish_out per second','rabbitmq.overview.messages.publish_out.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages published from this overview into queues per second,0,rabbitmq,total msgs pub out rate','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32854','18','','10358','RabbitMQ: Messages publish_out','rabbitmq.overview.messages.publish_out','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages published from this overview into queues','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32855','18','','10358','RabbitMQ: Messages publish_in per second','rabbitmq.overview.messages.publish_in.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages published from channels into this overview per sec','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32856','18','','10358','RabbitMQ: Messages publish_in','rabbitmq.overview.messages.publish_in','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages published from channels into this overview','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32857','18','','10358','RabbitMQ: Messages published per second','rabbitmq.overview.messages.publish.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages published per second','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32858','18','','10358','RabbitMQ: Messages published','rabbitmq.overview.messages.publish','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages published','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32859','18','','10358','RabbitMQ: Messages delivered per second','rabbitmq.overview.messages.deliver_get.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate per second of the sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32860','18','','10358','RabbitMQ: Messages delivered','rabbitmq.overview.messages.deliver_get','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32861','18','','10358','RabbitMQ: Messages confirmed per second','rabbitmq.overview.messages.confirm.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages confirmed per second','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32862','18','','10358','RabbitMQ: Messages confirmed','rabbitmq.overview.messages.confirm','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages confirmed','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32863','18','','10358','RabbitMQ: Messages returned redeliver per second','rabbitmq.overview.messages.redeliver.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of subset of messages in deliver_get which had the redelivered flag set per second','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32864','18','','10359','RabbitMQ: Is running','rabbitmq.node.running','0','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'Is the node running or not','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32865','18','','10359','RabbitMQ: Uptime','rabbitmq.node.uptime','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Uptime in milliseconds','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32866','18','','10359','RabbitMQ: Sockets used','rabbitmq.node.sockets_used','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of file descriptors used as sockets','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32867','18','','10359','RabbitMQ: Sockets available','rabbitmq.node.sockets_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'File descriptors available for use as sockets','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32868','18','','10359','RabbitMQ: Runtime run queue','rabbitmq.node.run_queue','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Average number of Erlang processes waiting to run','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32869','18','','10359','RabbitMQ: RabbitMQ version','rabbitmq.node.overview.rabbitmq_version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of RabbitMQ on the node which processed this request','0','30d','0','','32833','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32870','18','','10359','RabbitMQ: Number of network partitions','rabbitmq.node.partitions','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of network partitions this node is seeing','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32871','18','','10359','RabbitMQ: Free disk space','rabbitmq.node.disk_free','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current free disk space','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32872','18','','10359','RabbitMQ: Management plugin version','rabbitmq.node.overview.management_version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of the management plugin in use','0','30d','0','','32833','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32873','18','','10359','RabbitMQ: Memory limit','rabbitmq.node.mem_limit','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory usage high watermark in bytes','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32874','18','','10359','RabbitMQ: Memory alarm','rabbitmq.node.mem_alarm','0','7d','365d','0','3','','','','',NULL,'83','','','0','','','','','0',NULL,'Does the host has memory alarm','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32875','18','','10359','RabbitMQ: Used file descriptors','rabbitmq.node.fd_used','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Used file descriptors','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32876','18','','10359','RabbitMQ: Disk free limit','rabbitmq.node.disk_free_limit','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Disk free space limit in bytes','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32877','18','','10359','RabbitMQ: Disk free alarm','rabbitmq.node.disk_free_alarm','0','7d','365d','0','3','','','','',NULL,'83','','','0','','','','','0',NULL,'Does the node have disk alarm','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32878','18','','10359','RabbitMQ: Memory used','rabbitmq.node.mem_used','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory used in bytes','0','30d','0','','32834','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32879','18','','10358','Exchanges discovery','rabbitmq.exchanges.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Individual exchange metrics','0','30d','1','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32880','18','','10358','Health Check 3.8.10+ discovery','rabbitmq.healthcheck.v3810.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Version 3.8.10+ specific metrics','0','30d','0','','32829','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32881','18','','10359','Health Check 3.8.9- discovery','rabbitmq.healthcheck.v389.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Specific metrics up to and including version 3.8.4','0','30d','0','','32833','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32882','18','','10359','Health Check 3.8.10+ discovery','rabbitmq.healthcheck.v3810.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Version 3.8.10+ specific metrics','0','30d','0','','32833','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32883','18','','10359','Queues discovery','rabbitmq.queues.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Individual queue metrics','0','30d','1','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32891','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages acknowledged per second','rabbitmq.exchange.messages.ack.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages delivered to clients and acknowledged per second','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32892','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages acknowledged','rabbitmq.exchange.messages.ack["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages delivered to clients and acknowledged','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32893','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages confirmed per second','rabbitmq.exchange.messages.confirm.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages confirmed per second','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32894','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages confirmed','rabbitmq.exchange.messages.confirm["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages confirmed','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32895','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages delivered per second','rabbitmq.exchange.messages.deliver_get.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of the sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32896','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages delivered','rabbitmq.exchange.messages.deliver_get["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32897','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages published per second','rabbitmq.exchange.messages.publish.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages published per second','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32898','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages published','rabbitmq.exchange.messages.publish["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32899','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_in per second','rabbitmq.exchange.messages.publish_in.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages published from channels into this overview per sec','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32900','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_in','rabbitmq.exchange.messages.publish_in["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published from channels into this overview','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32901','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_out per second','rabbitmq.exchange.messages.publish_out.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages published from this overview into queues per second,0,rabbitmq,total msgs pub out rate','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32902','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_out','rabbitmq.exchange.messages.publish_out["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published from this overview into queues','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32903','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages redelivered per second','rabbitmq.exchange.messages.redeliver.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of subset of messages in deliver_get which had the redelivered flag set per second','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32904','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages redelivered','rabbitmq.exchange.messages.redeliver["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32905','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages returned unroutable per second','rabbitmq.exchange.messages.return_unroutable.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages returned to publisher as unroutable per second','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32906','18','','10358','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages returned unroutable','rabbitmq.exchange.messages.return_unroutable["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages returned to publisher as unroutable','0','30d','0','','32830','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32907','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Consumers','rabbitmq.queue.consumers["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of consumers','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32908','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages per second','rabbitmq.queue.messages.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count per second of the total messages in the queue','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32909','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages unacknowledged per second','rabbitmq.queue.messages_unacknowledged.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number per second of messages delivered to clients but not yet acknowledged','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32910','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages ready','rabbitmq.queue.messages_ready["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages ready to be delivered to clients','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32911','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages ready per second','rabbitmq.queue.messages_ready.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number per second of messages ready to be delivered to clients','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32912','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages','rabbitmq.queue.messages["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of the total messages in the queue','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32913','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages redelivered','rabbitmq.queue.messages.redeliver["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32914','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages redelivered per second','rabbitmq.queue.messages.redeliver.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32915','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages published','rabbitmq.queue.messages.publish["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32916','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Memory','rabbitmq.queue.memory["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Bytes of memory consumed by the Erlang process associated with the queue, including stack, heap and internal structures','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32917','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages published per second','rabbitmq.queue.messages.publish.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of messages published','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32918','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered','rabbitmq.queue.messages.deliver_get["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32919','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered per second','rabbitmq.queue.messages.deliver_get.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of the sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32920','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered','rabbitmq.queue.messages.deliver["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages delivered in acknowledgement mode to consumers','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32921','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered per second','rabbitmq.queue.messages.deliver.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages delivered in acknowledgement mode to consumers','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32922','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages acknowledged','rabbitmq.queue.messages.ack["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages delivered to clients and acknowledged','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32923','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages acknowledged per second','rabbitmq.queue.messages.ack.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number per second of messages delivered to clients and acknowledged','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32924','18','','10359','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages unacknowledged','rabbitmq.queue.messages_unacknowledged["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages delivered to clients but not yet acknowledged','0','30d','0','','32835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32932','18','','10360','RabbitMQ: Messages ready for delivery','rabbitmq.overview.queue_totals.messages.ready','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of messages ready for deliver','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32933','18','','10360','RabbitMQ: Messages total','rabbitmq.overview.queue_totals.messages','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of messages (ready plus unacknowledged)','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32934','18','','10360','RabbitMQ: Queues total','rabbitmq.overview.object_totals.queues','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of queues','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32935','18','','10360','RabbitMQ: Exchanges total','rabbitmq.overview.object_totals.exchanges','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of exchanges','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32936','18','','10360','RabbitMQ: Consumers total','rabbitmq.overview.object_totals.consumers','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of consumers','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32937','18','','10360','RabbitMQ: Connections total','rabbitmq.overview.object_totals.connections','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of connections','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32938','18','','10360','RabbitMQ: Channels total','rabbitmq.overview.object_totals.channels','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Total number of channels','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32939','18','','10360','RabbitMQ: Messages returned unroutable per second','rabbitmq.overview.messages.return_unroutable.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages returned to publisher as unroutable per second','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32940','18','','10360','RabbitMQ: Messages returned unroutable','rabbitmq.overview.messages.return_unroutable','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages returned to publisher as unroutable','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32941','18','','10360','RabbitMQ: Messages returned redeliver per second','rabbitmq.overview.messages.redeliver.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of subset of messages in deliver_get which had the redelivered flag set per second','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32942','18','','10360','RabbitMQ: Messages returned redeliver','rabbitmq.overview.messages.redeliver','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32943','18','','10360','RabbitMQ: Messages publish_out per second','rabbitmq.overview.messages.publish_out.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages published from this overview into queues per second,0,rabbitmq,total msgs pub out rate','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32944','18','','10360','RabbitMQ: Messages publish_out','rabbitmq.overview.messages.publish_out','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages published from this overview into queues','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32945','18','','10360','RabbitMQ: Messages publish_in per second','rabbitmq.overview.messages.publish_in.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages published from channels into this overview per sec','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32946','18','','10360','RabbitMQ: Messages publish_in','rabbitmq.overview.messages.publish_in','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages published from channels into this overview','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32947','18','','10360','RabbitMQ: Messages published per second','rabbitmq.overview.messages.publish.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages published per second','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32948','18','','10360','RabbitMQ: Messages published','rabbitmq.overview.messages.publish','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages published','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32949','18','','10360','RabbitMQ: Messages delivered per second','rabbitmq.overview.messages.deliver_get.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate per second of the sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32950','18','','10360','RabbitMQ: Messages delivered','rabbitmq.overview.messages.deliver_get','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32951','18','','10360','RabbitMQ: Messages confirmed per second','rabbitmq.overview.messages.confirm.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages confirmed per second','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32952','18','','10360','RabbitMQ: Messages confirmed','rabbitmq.overview.messages.confirm','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Count of messages confirmed','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32953','18','','10360','RabbitMQ: Messages acknowledged per second','rabbitmq.overview.messages.ack.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of messages delivered to clients and acknowledged per second','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32954','18','','10360','RabbitMQ: Messages acknowledged','rabbitmq.overview.messages.ack','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of messages delivered to clients and acknowledged','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32955','18','','10360','RabbitMQ: Messages unacknowledged','rabbitmq.overview.queue_totals.messages.unacknowledged','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of unacknowledged messages','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32956','18','','10361','RabbitMQ: RabbitMQ version','rabbitmq.node.overview.rabbitmq_version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of RabbitMQ on the node which processed this request','0','30d','0','','32929','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32957','18','','10361','RabbitMQ: Sockets used','rabbitmq.node.sockets_used','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of file descriptors used as sockets','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32958','18','','10361','RabbitMQ: Sockets available','rabbitmq.node.sockets_total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'File descriptors available for use as sockets','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32959','18','','10361','RabbitMQ: Runtime run queue','rabbitmq.node.run_queue','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Average number of Erlang processes waiting to run','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32960','18','','10361','RabbitMQ: Is running','rabbitmq.node.running','0','7d','365d','0','3','','','','',NULL,'1','','','0','','','','','0',NULL,'Is the node running or not','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32961','18','','10361','RabbitMQ: Number of network partitions','rabbitmq.node.partitions','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of network partitions this node is seeing','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32962','18','','10361','RabbitMQ: Memory limit','rabbitmq.node.mem_limit','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory usage high watermark in bytes','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32963','18','','10361','RabbitMQ: Management plugin version','rabbitmq.node.overview.management_version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of the management plugin in use','0','30d','0','','32929','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32964','18','','10361','RabbitMQ: Memory used','rabbitmq.node.mem_used','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Memory used in bytes','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32965','18','','10361','RabbitMQ: Memory alarm','rabbitmq.node.mem_alarm','0','7d','365d','0','3','','','','',NULL,'83','','','0','','','','','0',NULL,'Does the host has memory alarm','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32966','18','','10361','RabbitMQ: Used file descriptors','rabbitmq.node.fd_used','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Used file descriptors','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32967','18','','10361','RabbitMQ: Disk free limit','rabbitmq.node.disk_free_limit','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Disk free space limit in bytes','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32968','18','','10361','RabbitMQ: Disk free alarm','rabbitmq.node.disk_free_alarm','0','7d','365d','0','3','','','','',NULL,'83','','','0','','','','','0',NULL,'Does the node have disk alarm','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32969','18','','10361','RabbitMQ: Free disk space','rabbitmq.node.disk_free','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Current free disk space','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32970','18','','10361','RabbitMQ: Uptime','rabbitmq.node.uptime','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Uptime in milliseconds','0','30d','0','','32928','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32971','18','','10360','Exchanges discovery','rabbitmq.exchanges.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Individual exchange metrics','0','30d','1','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32972','18','','10360','Health Check 3.8.10+ discovery','rabbitmq.healthcheck.v3810.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Version 3.8.10+ specific metrics','0','30d','0','','32926','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32973','18','','10361','Health Check 3.8.9- discovery','rabbitmq.healthcheck.v389.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Specific metrics up to and including version 3.8.4','0','30d','0','','32929','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32974','18','','10361','Health Check 3.8.10+ discovery','rabbitmq.healthcheck.v3810.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Version 3.8.10+ specific metrics','0','30d','0','','32929','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32975','18','','10361','Queues discovery','rabbitmq.queues.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Individual queue metrics','0','30d','1','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32983','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages acknowledged per second','rabbitmq.exchange.messages.ack.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages delivered to clients and acknowledged per second','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32984','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages acknowledged','rabbitmq.exchange.messages.ack["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages delivered to clients and acknowledged','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32985','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages confirmed per second','rabbitmq.exchange.messages.confirm.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages confirmed per second','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32986','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages confirmed','rabbitmq.exchange.messages.confirm["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages confirmed','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32987','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages delivered per second','rabbitmq.exchange.messages.deliver_get.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of the sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32988','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages delivered','rabbitmq.exchange.messages.deliver_get["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32989','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages published per second','rabbitmq.exchange.messages.publish.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages published per second','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32990','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages published','rabbitmq.exchange.messages.publish["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32991','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_in per second','rabbitmq.exchange.messages.publish_in.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages published from channels into this overview per sec','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32992','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_in','rabbitmq.exchange.messages.publish_in["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published from channels into this overview','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32993','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_out per second','rabbitmq.exchange.messages.publish_out.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages published from this overview into queues per second,0,rabbitmq,total msgs pub out rate','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32994','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages publish_out','rabbitmq.exchange.messages.publish_out["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published from this overview into queues','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32995','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages redelivered per second','rabbitmq.exchange.messages.redeliver.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of subset of messages in deliver_get which had the redelivered flag set per second','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32996','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages redelivered','rabbitmq.exchange.messages.redeliver["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32997','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages returned unroutable per second','rabbitmq.exchange.messages.return_unroutable.rate["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate of messages returned to publisher as unroutable per second','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32998','18','','10360','RabbitMQ: Exchange {#VHOST}/{#EXCHANGE}/{#TYPE}: Messages returned unroutable','rabbitmq.exchange.messages.return_unroutable["{#VHOST}/{#EXCHANGE}/{#TYPE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages returned to publisher as unroutable','0','30d','0','','32925','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32999','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Consumers','rabbitmq.queue.consumers["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of consumers','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33000','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages per second','rabbitmq.queue.messages.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count per second of the total messages in the queue','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33001','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages unacknowledged per second','rabbitmq.queue.messages_unacknowledged.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number per second of messages delivered to clients but not yet acknowledged','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33002','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages ready','rabbitmq.queue.messages_ready["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages ready to be delivered to clients','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33003','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages ready per second','rabbitmq.queue.messages_ready.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number per second of messages ready to be delivered to clients','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33004','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages','rabbitmq.queue.messages["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of the total messages in the queue','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33005','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages redelivered','rabbitmq.queue.messages.redeliver["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33006','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages redelivered per second','rabbitmq.queue.messages.redeliver.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of subset of messages in deliver_get which had the redelivered flag set','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33007','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages published','rabbitmq.queue.messages.publish["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages published','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33008','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Memory','rabbitmq.queue.memory["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Bytes of memory consumed by the Erlang process associated with the queue, including stack, heap and internal structures','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33009','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages published per second','rabbitmq.queue.messages.publish.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of messages published','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33010','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered','rabbitmq.queue.messages.deliver_get["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33011','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered per second','rabbitmq.queue.messages.deliver_get.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Rate per second of the sum of messages delivered in acknowledgement mode to consumers, in no-acknowledgement mode to consumers, in acknowledgement mode in response to basic.get, and in no-acknowledgement mode in response to basic.get','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33012','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered','rabbitmq.queue.messages.deliver["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages delivered in acknowledgement mode to consumers','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33013','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages delivered per second','rabbitmq.queue.messages.deliver.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Count of messages delivered in acknowledgement mode to consumers','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33014','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages acknowledged','rabbitmq.queue.messages.ack["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages delivered to clients and acknowledged','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33015','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages acknowledged per second','rabbitmq.queue.messages.ack.rate["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number per second of messages delivered to clients and acknowledged','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33016','18','','10361','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages unacknowledged','rabbitmq.queue.messages_unacknowledged["{#VHOST}/{#QUEUE}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of messages delivered to clients but not yet acknowledged','0','30d','0','','32930','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33022','18','','10362','MongoDB: Document: deleted, rate','mongod.document.deleted.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of documents deleted per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33023','18','','10362','MongoDB: Requests, rate','mongodb.network.numRequests.rate','0','7d','365d','0','0','','!Rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of distinct requests that the server has received per second','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33024','18','','10362','MongoDB: Memory: mapped with journal','mongodb.mem.mapped_with_journal','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'The amount of mapped memory, including the memory used for journaling.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33025','18','','10362','MongoDB: Memory: resident','mongodb.mem.resident','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Amount of memory currently used by the database process.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33026','18','','10362','MongoDB: Memory: virtual','mongodb.mem.virtual','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Amount of virtual memory used by the mongod process.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33027','18','','10362','MongoDB: Cursor: open no timeout','mongodb.metrics.cursor.open.no_timeout','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of open cursors with the option DBQuery.Option.noTimeout set to prevent timeout after a period of inactivity.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33028','18','','10362','MongoDB: Bytes in, rate','mongodb.network.bytes_in.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of bytes that the server has received over network connections initiated by clients or other mongod/mongos instances per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33029','18','','10362','MongoDB: Bytes out, rate','mongodb.network.bytes_out.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of bytes that the server has sent over network connections initiated by clients or other mongod/mongos instances per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33030','18','','10362','MongoDB: Operations: delete, rate','mongodb.opcounters.delete.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of delete operations the mongod instance per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33031','18','','10362','MongoDB: Operations: command, rate','mongodb.opcounters.command.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of commands issued to the database the mongod instance per second.
Counts all commands except the write commands: insert, update, and delete.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33032','18','','10362','MongoDB: Architecture','mongodb.mem.bits','0','7d','365d','0','3','','bit','','',NULL,NULL,'','','0','','','','','0',NULL,'A number, either 64 or 32, that indicates whether the MongoDB instance is compiled for 64-bit or 32-bit architecture.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33033','18','','10362','MongoDB: Operations: getmore, rate','mongodb.opcounters.getmore.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of “getmore” operations since the mongod instance per second. This counter can be high even if the query count is low. 
Secondary nodes send getMore operations as part of the replication process.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33034','18','','10362','MongoDB: Operations: insert, rate','mongodb.opcounters.insert.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of insert operations received since the mongod instance per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33035','18','','10362','MongoDB: Operations: query, rate','mongodb.opcounters.query.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of queries received the mongod instance per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33036','18','','10362','MongoDB: Operations: update, rate','mongodb.opcounters.update.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of update operations the mongod instance per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33037','18','','10362','MongoDB: Uptime','mongodb.uptime','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of seconds that the mongod process has been active.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33038','18','','10362','MongoDB: Memory: mapped','mongodb.mem.mapped','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Amount of mapped memory by the database.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33039','18','','10362','MongoDB: Cursor: timed out, rate','mongodb.cursor.timed_out.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of cursors that time out, per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33040','18','','10362','MongoDB: Document: inserted, rate','mongod.document.inserted.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of documents inserted per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33041','18','','10362','MongoDB: Asserts: user, rate','mongodb.asserts.user.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of “user asserts” that have occurred per second.
These are errors that user may generate, such as out of disk space or duplicate key.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33042','18','','10362','MongoDB: Document: returned, rate','mongod.document.returned.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of documents returned by queries per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33043','18','','10362','MongoDB: Document: updated, rate','mongod.document.updated.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of documents updated per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33044','18','','10362','MongoDB: Active clients: readers','mongodb.active_clients.readers','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of the active client connections performing read operations.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33045','18','','10362','MongoDB: Active clients: total','mongodb.active_clients.total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of internal client connections to the database including system threads as well as queued readers and writers.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33046','18','','10362','MongoDB: Active clients: writers','mongodb.active_clients.writers','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of active client connections performing write operations.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33047','18','','10362','MongoDB: Asserts: message, rate','mongodb.asserts.msg.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of message assertions raised per second.
Check the log file for more information about these messages.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33048','18','','10362','MongoDB: Asserts: regular, rate','mongodb.asserts.regular.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of regular assertions raised per second.
Check the log file for more information about these messages.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33049','18','','10362','MongoDB: Asserts: rollovers, rate','mongodb.asserts.rollovers.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of times that the rollover counters roll over per second.
The counters rollover to zero every 2^30 assertions.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33050','18','','10362','MongoDB: Asserts: warning, rate','mongodb.asserts.warning.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of warnings raised per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33051','18','','10362','MongoDB: Cursor: open total','mongodb.cursor.open.total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of cursors that MongoDB is maintaining for clients.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33052','18','','10362','MongoDB: Connections, active','mongodb.connections.active','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of active client connections to the server.
Active client connections refers to client connections that currently have operations in progress.
Available starting in  4.0.7, 0 for older versions.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33053','18','','10362','MongoDB: Connections, available','mongodb.connections.available','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of unused incoming connections available.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33054','18','','10362','MongoDB: Connections, current','mongodb.connections.current','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of incoming connections from clients to the database server.
This number includes the current shell session','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33055','18','','10362','MongoDB: New connections, rate','mongodb.connections.rate','0','7d','365d','0','0','','Rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Rate of all incoming connections created to the server.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33056','18','','10362','MongoDB: Current queue: readers','mongodb.current_queue.readers','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of operations that are currently queued and waiting for the read lock.
A consistently small read-queue, particularly of shorter operations, should cause no concern.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33057','18','','10362','MongoDB: Current queue: total','mongodb.current_queue.total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of operations queued waiting for the lock.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33058','18','','10362','MongoDB: Current queue: writers','mongodb.current_queue.writers','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of operations that are currently queued and waiting for the write lock. 
 A consistently small write-queue, particularly of shorter operations, is no cause for concern.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33059','18','','10362','MongoDB: Cursor: open pinned','mongodb.cursor.open.pinned','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of pinned open cursors.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33060','18','','10362','MongoDB: MongoDB version','mongodb.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of the MongoDB server.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33063','18','','10362','Replication discovery','mongodb.rs.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Collect metrics by Zabbix agent if it exists','0','30d','0','','33018','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33064','18','','10362','WiredTiger metrics','mongodb.wired_tiger.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Collect metrics of WiredTiger Storage Engine if it exists','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33067','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Objects, avg size','mongodb.collection.avg_obj_size["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The size of the average object in the collection in bytes.','0','30d','0','','33065','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33068','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: remove, ms/s','mongodb.collection.ops.remove.ms["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) the mongod has spent to operations.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33069','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Write lock, ms/s','mongodb.collection.write_lock.ms["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) the mongod has spent to operations.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33070','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Storage size','mongodb.collection.storage_size["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total storage space allocated to this collection for document storage.','0','30d','0','','33065','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33071','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Size','mongodb.collection.size["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The total size in bytes of the data in the collection plus the size of every indexes on the mongodb.collection.','0','30d','0','','33065','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33072','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Read lock, rate','mongodb.collection.read_lock.rate["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of operations per second.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33073','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Read lock, ms/s','mongodb.collection.read_lock.ms["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) the mongod has spent to operations.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33074','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: update, rate','mongodb.collection.ops.update.rate["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of operations per second.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33075','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: update, ms/s','mongodb.collection.ops.update.ms["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) the mongod has spent to operations.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33076','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: total, rate','mongodb.collection.ops.total.rate["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of operations per second.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33077','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: total, ms/s','mongodb.collection.ops.total.ms["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) the mongod has spent to operations.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33078','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: remove, rate','mongodb.collection.ops.remove.rate["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of operations per second.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33079','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: queries, rate','mongodb.collection.ops.queries.rate["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of operations per second.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33080','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Capped','mongodb.collection.capped["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','3','','','','',NULL,'153','','','0','','','','','2',NULL,'Whether or not the collection is capped.','0','30d','0','','33065','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33081','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: queries, ms/s','mongodb.collection.ops.queries.ms["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) the mongod has spent to operations.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33082','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: insert, rate','mongodb.collection.ops.insert.rate["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of operations per second.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33083','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: insert, ms/s','mongodb.collection.ops.insert.ms["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) the mongod has spent to operations.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33084','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: getmore, rate','mongodb.collection.ops.getmore.rate["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of operations per second.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33085','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: getmore, ms/s','mongodb.collection.ops.getmore.ms["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) the mongod has spent to operations.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33086','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: commands, rate','mongodb.collection.ops.commands.rate["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of operations per second.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33087','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Operations: commands, ms/s','mongodb.collection.ops.commands.ms["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) the mongod has spent to operations.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33088','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Indexes','mongodb.collection.nindexes["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of indices on the collection.','0','30d','0','','33065','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33089','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Capped: max size','mongodb.collection.max_size["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Maximum size of a capped collection in bytes.','0','30d','0','','33065','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33090','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Capped: max number','mongodb.collection.max_number["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Maximum number of documents that may be present in a capped collection.','0','30d','0','','33065','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33091','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Objects, count','mongodb.collection.count["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of objects in the collection.','0','30d','0','','33065','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33092','18','','10362','MongoDB {#DBNAME}.{#COLLECTION}: Write lock, rate','mongodb.collection.write_lock.rate["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of operations per second.','0','30d','0','','33021','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33093','18','','10362','MongoDB {#DBNAME}: Collections','mongodb.db.collections["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Contains a count of the number of collections in that database.','0','30d','0','','33066','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33094','18','','10362','MongoDB {#DBNAME}: Size, data','mongodb.db.data_size["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total size of the data held in this database including the padding factor.','0','30d','0','','33066','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33095','18','','10362','MongoDB {#DBNAME}: Extents','mongodb.db.extents["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Contains a count of the number of extents in the database across all collections.','0','30d','0','','33066','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33096','18','','10362','MongoDB {#DBNAME}: Size, file','mongodb.db.file_size["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total size of the data held in this database including the padding factor (only available with the mmapv1 storage engine).','0','30d','0','','33066','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33097','18','','10362','MongoDB {#DBNAME}: Size, index','mongodb.db.index_size["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total size of all indexes created on this database.','0','30d','0','','33066','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33098','18','','10362','MongoDB {#DBNAME}: Objects, count','mongodb.db.objects["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of objects (documents) in the database across all collections.','0','30d','0','','33066','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33099','18','','10362','MongoDB {#DBNAME}: Objects, avg size','mongodb.db.size["{#DBNAME}"]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The average size of each document in bytes.','0','30d','0','','33066','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33100','18','','10362','MongoDB {#DBNAME}: Size, storage','mongodb.db.storage_size["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total amount of space allocated to collections in this database for document storage.','0','30d','0','','33066','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33101','18','','10362','MongoDB: Apply batches, ms/s','mongodb.rs.apply.batches.ms.rate[{#RS_NAME}]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) the mongod has spent applying operations from the oplog.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33102','18','','10362','MongoDB: Network readers created, rate','mongodb.rs.network.readers.rate[{#RS_NAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of oplog query processes created per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33103','18','','10362','MongoDB: Number of unhealthy replicas','mongodb.rs.unhealthy_count[{#RS_NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of replicated nodes with member health value  = 0.','0','30d','0','','33018','3s','','','','200','1','0','','0','0','0','0','0','0','1');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33104','18','','10362','MongoDB: Number of replicas','mongodb.rs.total_nodes[{#RS_NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of replucated nodes in current ReplicaSet.','0','30d','0','','33018','3s','','','','200','1','0','','0','0','0','0','0','0','1');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33105','18','','10362','MongoDB: Node state','mongodb.rs.state[{#RS_NAME}]','0','7d','365d','0','3','','','','',NULL,'154','','','0','','','','','2',NULL,'An integer between 0 and 10 that represents the replica state of the current member.','0','30d','0','','33018','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33106','18','','10362','MongoDB: Preload indexes, rate','mongodb.rs.preload.indexes.rate[{#RS_NAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of index entries loaded by members before updating documents as part of the pre-fetch stage of replication.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33107','18','','10362','MongoDB: Preload indexes, ms/s','mongodb.rs.preload.indexes.ms.rate[{#RS_NAME}]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) spent loading documents as part of the pre-fetch stage of replication.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33108','18','','10362','MongoDB: Preload docs, rate','mongodb.rs.preload.docs.rate[{#RS_NAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of documents loaded per second during the pre-fetch stage of replication.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33109','18','','10362','MongoDB: Preload docs, ms/s','mongodb.rs.preload.docs.ms.rate[{#RS_NAME}]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) spent loading documents as part of the pre-fetch stage of replication.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33110','18','','10362','MongoDB {#RS_NAME}: Oplog time diff','mongodb.rs.oplog.timediff[{#RS_NAME}]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Oplog window: difference between the first and last operation in the oplog. Only present if there are entries in the oplog.','0','30d','0','','33020','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33111','18','','10362','MongoDB: Network ops, rate','mongodb.rs.network.ops.rate[{#RS_NAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of operations read from the replication source per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33112','18','','10362','MongoDB: Apply batches, rate','mongodb.rs.apply.batches.rate[{#RS_NAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of batches applied across all databases per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33113','18','','10362','MongoDB: Network getmores, rate','mongodb.rs.network.getmores.rate[{#RS_NAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of getmore operations per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33114','18','','10362','MongoDB: Network getmores, ms/s','mongodb.rs.network.getmores.ms.rate[{#RS_NAME}]','0','7d','365d','0','0','','ms/s','','',NULL,NULL,'','','0','','','','','2',NULL,'Fraction of time (ms/s) required to collect data from getmore operations.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33115','18','','10362','MongoDB: Network bytes, rate','mongodb.rs.network.bytes.rate[{#RS_NAME}]','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Amount of data read from the replication sync source per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33116','18','','10362','MongoDB: Replication lag','mongodb.rs.lag[{#RS_NAME}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Delay between a write operation on the primary and its copy to a secondary.','0','30d','0','','33018','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33117','18','','10362','MongoDB: Buffer, size','mongodb.rs.buffer.size[{#RS_NAME}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Current size of the contents of the oplog buffer.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33118','18','','10362','MongoDB: Buffer, max size','mongodb.rs.buffer.max_size[{#RS_NAME}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Maximum size of the buffer.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33119','18','','10362','MongoDB: Buffer','mongodb.rs.buffer.count[{#RS_NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of operations in the oplog buffer.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33120','18','','10362','MongoDB: Apply ops, rate','mongodb.rs.apply.rate[{#RS_NAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of oplog operations applied per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33121','18','','10362','MongoDB: Unhealthy replicas','mongodb.rs.unhealthy[{#RS_NAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The replicated nodes in current ReplicaSet with member health value  = 0.','0','30d','0','','33018','3s','','','','200','1','0','','0','0','0','0','0','0','1');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33122','18','','10362','MongoDB: WiredTiger cache: bytes','mongodb.wired_tiger.cache.bytes_in_cache[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Size of the data currently in cache.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33123','18','','10362','MongoDB: WiredTiger cache: tracked dirty bytes in the cache','mongodb.wired_tiger.cache.tracked_dirty_bytes[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Size of the dirty data in the cache.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33124','18','','10362','MongoDB: WiredTiger concurrent transactions: write, out','mongodb.wired_tiger.concurrent_transactions.write.out[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of write tickets (concurrent transactions) in use.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33125','18','','10362','MongoDB: WiredTiger concurrent transactions: write, available','mongodb.wired_tiger.concurrent_transactions.write.available[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of available write tickets (concurrent transactions) remaining.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33126','18','','10362','MongoDB: WiredTiger concurrent transactions: read, total tickets','mongodb.wired_tiger.concurrent_transactions.read.totalTickets[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of read tickets (concurrent transactions) available.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33127','18','','10362','MongoDB: WiredTiger concurrent transactions: read, out','mongodb.wired_tiger.concurrent_transactions.read.out[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of read tickets (concurrent transactions) in use.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33128','18','','10362','MongoDB: WiredTiger concurrent transactions: read, available','mongodb.wired_tiger.concurrent_transactions.read.available[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of available read tickets (concurrent transactions) remaining.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33129','18','','10362','MongoDB: WiredTiger cache: unmodified pages evicted','mongodb.wired_tiger.cache.unmodified_pages_evicted[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of pages, that were not modified, evicted from the cache.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33130','18','','10362','MongoDB: WiredTiger cache: in-memory page splits','mongodb.wired_tiger.cache.splits[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'In-memory page splits.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33131','18','','10362','MongoDB: WiredTiger cache: max page size at eviction','mongodb.wired_tiger.cache.max_page_size_eviction[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Maximum page size at eviction.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33132','18','','10362','MongoDB: WiredTiger cache: pages written from cache','mongodb.wired_tiger.cache.pages_written[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of pages writtent from the cache.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33133','18','','10362','MongoDB: WiredTiger cache: pages read into cache','mongodb.wired_tiger.cache.pages_read[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of pages read into the cache.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33134','18','','10362','MongoDB: WiredTiger cache: pages held in cache','mongodb.wired_tiger.cache.pages_in_cache[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of pages currently held in the cache.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33135','18','','10362','MongoDB: WiredTiger cache: pages evicted by application threads, rate','mongodb.wired_tiger.cache.pages_evicted_threads.rate[{#SINGLETON}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of page evicted by application threads per second.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33136','18','','10362','MongoDB: WiredTiger cache: modified pages evicted','mongodb.wired_tiger.cache.modified_pages_evicted[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of pages, that have been modified, evicted from the cache.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33137','18','','10362','MongoDB: WiredTiger cache: bytes, max','mongodb.wired_tiger.cache.maximum_bytes_configured[{#SINGLETON}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Maximum cache size.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33138','18','','10362','MongoDB: WiredTiger concurrent transactions: write, total tickets','mongodb.wired_tiger.concurrent_transactions.write.totalTickets[{#SINGLETON}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of write tickets (concurrent transactions) available.','0','30d','0','','33017','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33144','18','','10363','MongoDB cluster: Operations: command','mongodb.opcounters.command.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"The number of commands issued to the database per second.
Counts all commands except the write commands: insert, update, and delete."','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33145','18','','10363','MongoDB cluster: Bytes in, rate','mongodb.network.bytes_in.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of bytes that the server has received over network connections initiated by clients or other mongod/mongos instances per second.','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33146','18','','10363','MongoDB cluster: Bytes out, rate','mongodb.network.bytes_out.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of bytes that the server has sent over network connections initiated by clients or other mongod/mongos instances per second.','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33147','18','','10363','MongoDB cluster: Requests, rate','mongodb.network.numRequests.rate','0','7d','365d','0','0','','!Rps','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of distinct requests that the server has received per second','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33148','18','','10363','MongoDB cluster: Operations: getmore, rate','mongodb.opcounters.getmore.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"The number of “getmore” operations the mongos per second. This counter can be high even if the query count is low.
Secondary nodes send getMore operations as part of the replication process."','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33149','18','','10363','MongoDB cluster: Operations: delete','mongodb.opcounters.delete.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"The number of delete operations the mongos instance per second."','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33150','18','','10363','MongoDB cluster: Memory: virtual','mongodb.mem.virtual','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Amount of virtual memory used by the mongos process.','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33151','18','','10363','MongoDB cluster: Operations: insert, rate','mongodb.opcounters.insert.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"The number of insert operations received the mongos instance per second."','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33152','18','','10363','MongoDB cluster: Operations: query, rate','mongodb.opcounters.query.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"The number of queries received the mongos instance per second."','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33153','18','','10363','MongoDB cluster: Operations: update, rate','mongodb.opcounters.update.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"The number of update operations the mongos instance per second."','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33154','18','','10363','MongoDB cluster: Uptime','mongodb.uptime','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of seconds since Mongos server start','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33155','18','','10363','MongoDB cluster: Cursor: open no timeout','mongodb.metrics.cursor.open.no_timeout','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of open cursors with the option DBQuery.Option.noTimeout set to prevent timeout after a period of inactivity.','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33156','18','','10363','MongoDB cluster: Architecture','mongodb.mem.bits','0','7d','365d','0','3','','bit','','',NULL,NULL,'','','0','','','','','0',NULL,'A number, either 64 or 32, that indicates whether the MongoDB instance is compiled for 64-bit or 32-bit architecture.','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33157','18','','10363','MongoDB cluster: Memory: resident','mongodb.mem.resident','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','0',NULL,'Amount of memory currently used by the database process.','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33158','18','','10363','MongoDB cluster: Connection pool: available','mongodb.connection_pool.available','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of available outgoing connections from the current mongos instance to other members of the sharded cluster.','0','30d','0','','33142','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33159','18','','10363','MongoDB cluster: Last seen configserver','mongodb.last_seen_config_server','0','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'The latest optime of the CSRS primary that the mongos has seen.','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33160','18','','10363','MongoDB cluster: Cursor: timed out, rate','mongodb.cursor.timed_out.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of cursors that time out, per second.','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33161','18','','10363','MongoDB cluster: Cursor: open total','mongodb.cursor.open.total','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of cursors that MongoDB is maintaining for clients.','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33162','18','','10363','MongoDB cluster: Cursor: open pinned','mongodb.cursor.open.pinned','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of pinned open cursors.','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33163','18','','10363','MongoDB cluster: New connections, rate','mongodb.connections.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"Rate of all incoming connections created to the server."','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33164','18','','10363','MongoDB cluster: Connections, current','mongodb.connections.current','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"The number of incoming connections from clients to the database server. 
This number includes the current shell session"','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33165','18','','10363','MongoDB cluster: Connections, available','mongodb.connections.available','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"The number of unused incoming connections available."','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33166','18','','10363','MongoDB cluster: Connections, active','mongodb.connections.active','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'"The number of active client connections to the server. 
Active client connections refers to client connections that currently have operations in progress.
Available starting in  4.0.7, 0 for older versions."','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33167','18','','10363','MongoDB cluster: Connection pool: scoped','mongodb.connection_pool.scoped','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Number of active and stored outgoing scoped synchronous connections from the current mongos instance to other members of the sharded cluster.','0','30d','0','','33142','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33168','18','','10363','MongoDB cluster: Connection pool: refreshing','mongodb.connection_pool.refreshing','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Reports the total number of outgoing connections from the current mongos instance to other members of the sharded cluster that are currently being refreshed.','0','30d','0','','33142','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33169','18','','10363','MongoDB cluster: Connection pool: in use','mongodb.connection_pool.in_use','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Reports the total number of outgoing connections from the current mongos instance to other members of the sharded cluster set that are currently in use.','0','30d','0','','33142','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33170','18','','10363','MongoDB cluster: Connection pool: created, rate','mongodb.connection_pool.created.rate','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of outgoing connections created per second by the current mongos instance to other members of the sharded cluster.','0','30d','0','','33142','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33171','18','','10363','MongoDB cluster: Connection pool: client connections','mongodb.connection_pool.client','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of active and stored outgoing synchronous connections from the current mongos instance to other members of the sharded cluster.','0','30d','0','','33142','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33172','18','','10363','MongoDB cluster: Mongos version','mongodb.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of the Mongos server','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33179','18','','10363','MongoDB {#DBNAME}.{#COLLECTION}: Objects, avg size','mongodb.collection.avg_obj_size["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The size of the average object in the collection in bytes.','0','30d','0','','33177','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33180','18','','10363','MongoDB {#DBNAME}.{#COLLECTION}: Capped','mongodb.collection.capped["{#DBNAME}","{#COLLECTION}"]','0','7d','0','0','1','','','','',NULL,'153','','','0','','','','','2',NULL,'Whether or not the collection is capped.','0','30d','0','','33177','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33181','18','','10363','MongoDB {#DBNAME}.{#COLLECTION}: Objects, count','mongodb.collection.count["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of objects in the collection.','0','30d','0','','33177','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33182','18','','10363','MongoDB {#DBNAME}.{#COLLECTION}: Capped, max size','mongodb.collection.max_size["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Maximum size of a capped collection in bytes.','0','30d','0','','33177','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33183','18','','10363','MongoDB {#DBNAME}.{#COLLECTION}: Capped, max number','mongodb.collection.max["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Maximum number of documents in a capped collection.','0','30d','0','','33177','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33184','18','','10363','MongoDB {#DBNAME}.{#COLLECTION}: Indexes','mongodb.collection.nindexes["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total number of indices on the collection.','0','30d','0','','33177','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33185','18','','10363','MongoDB {#DBNAME}.{#COLLECTION}: Size','mongodb.collection.size["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The total size in bytes of the data in the collection plus the size of every indexes on the mongodb.collection.','0','30d','0','','33177','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33186','18','','10363','MongoDB {#DBNAME}.{#COLLECTION}: Storage size','mongodb.collection.storage_size["{#DBNAME}","{#COLLECTION}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total storage space allocated to this collection for document storage.','0','30d','0','','33177','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33187','18','','10363','MongoDB {#DBNAME}: Size, data','mongodb.db.data_size["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total size of the data held in this database including the padding factor.','0','30d','0','','33178','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33188','18','','10363','MongoDB {#DBNAME}: Extents','mongodb.db.extents["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Contains a count of the number of extents in the database across all collections.','0','30d','0','','33178','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33189','18','','10363','MongoDB {#DBNAME}: Size, file','mongodb.db.file_size["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total size of the data held in this database including the padding factor (only available with the mmapv1 storage engine).','0','30d','0','','33178','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33190','18','','10363','MongoDB {#DBNAME}: Size, index','mongodb.db.index_size["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total size of all indexes created on this database.','0','30d','0','','33178','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33191','18','','10363','MongoDB {#DBNAME}: Objects, count','mongodb.db.objects["{#DBNAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of objects (documents) in the database across all collections.','0','30d','0','','33178','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33192','18','','10363','MongoDB {#DBNAME}: Objects, avg size','mongodb.db.size["{#DBNAME}"]','0','7d','365d','0','0','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The average size of each document in bytes.','0','30d','0','','33178','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33193','18','','10363','MongoDB {#DBNAME}: Size, storage','mongodb.db.storage_size["{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total amount of space allocated to collections in this database for document storage.','0','30d','0','','33178','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33195','18','','10327','MSSQL AG ''{#GROUP_NAME}'' Non-Local DB ''*{#REPLICA_NAME}*{#DBNAME}'': Log queue size','mssql.non-local_db.log_send_queue_size["{#GROUP_NAME}*{#REPLICA_NAME}*{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Amount of the log records of the primary database that has not been sent to the secondary databases.','0','30d','0','','33194','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33196','18','','10327','MSSQL AG ''{#GROUP_NAME}'' Non-Local DB ''*{#REPLICA_NAME}*{#DBNAME}'': Redo log queue size','mssql.non-local_db.redo_queue_size["{#GROUP_NAME}*{#REPLICA_NAME}*{#DBNAME}"]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Amount of log records in the log files of the secondary replica that has not yet been redone.','0','30d','0','','33194','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33493','18','','10372','Cluster status','netapp.cluster.status','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The status of the cluster: ok, error, partial_no_data, partial_no_response, partial_other_error, negative_delta, backfilled_data, inconsistent_delta_time, inconsistent_old_data.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33494','18','','10372','Cluster location','netapp.cluster.location','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The location of the cluster.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33495','18','','10372','Cluster name','netapp.cluster.name','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The name of the cluster.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33496','18','','10372','Cluster IOPS raw, other','netapp.cluster.statistics.iops_raw.other','0','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of I/O operations observed at the storage object. Performance metric for other I/O operations. Other I/O operations can be metadata operations, such as directory lookups and so on.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33497','18','','10372','Cluster IOPS raw, read','netapp.cluster.statistics.iops_raw.read','0','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of I/O operations observed at the storage object. Performance metric for read I/O operations.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33498','18','','10372','Cluster IOPS raw, total','netapp.cluster.statistics.iops_raw.total','0','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of I/O operations observed at the storage object. Performance metric aggregated over all types of I/O operations.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33499','18','','10372','Cluster IOPS raw, write','netapp.cluster.statistics.iops_raw.write','0','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of I/O operations observed at the storage object. Performance metric for write I/O operations.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33500','18','','10372','Cluster IOPS, other rate','netapp.cluster.statistics.iops.other.rate','0','7d','365d','0','0','','!iops','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of I/O operations observed at the storage object. Performance metric for other I/O operations. Other I/O operations can be metadata operations, such as directory lookups and so on.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33501','18','','10372','Cluster software version','netapp.cluster.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'This returns the cluster version information. When the cluster has more than one node, the cluster version is equivalent to the lowest of generation, major, and minor versions on all nodes.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33502','18','','10372','Cluster latency raw, read','netapp.cluster.statistics.latency_raw.read','0','7d','365d','0','3','','!mcs','','',NULL,NULL,'','','0','','','','','0',NULL,'The raw latency in microseconds observed at the storage object. This can be divided by the raw IOPS value to calculate the average latency per I/O operation. Performance metric for read I/O operations.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33503','18','','10372','Cluster latency raw, total','netapp.cluster.statistics.latency_raw.total','0','7d','365d','0','3','','!mcs','','',NULL,NULL,'','','0','','','','','0',NULL,'The raw latency in microseconds observed at the storage object. This can be divided by the raw IOPS value to calculate the average latency per I/O operation. Performance metric aggregated over all types of I/O operations.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33504','18','','10372','Cluster throughput, total rate','netapp.cluster.statistics.throughput.total.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Throughput bytes observed at the storage object. Performance metric aggregated over all types of I/O operations.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33505','18','','10372','Cluster throughput, read rate','netapp.cluster.statistics.throughput.read.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Throughput bytes observed at the storage object. Performance metric for read I/O operations.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33506','18','','10372','Cluster throughput, other rate','netapp.cluster.statistics.throughput.other.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Throughput bytes observed at the storage object. Performance metric for other I/O operations. Other I/O operations can be metadata operations, such as directory lookups and so on.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33507','18','','10372','Cluster IOPS, read rate','netapp.cluster.statistics.iops.read.rate','0','7d','365d','0','0','','!iops','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of I/O operations observed at the storage object. Performance metric for read I/O operations.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33508','18','','10372','Cluster IOPS, total rate','netapp.cluster.statistics.iops.total.rate','0','7d','365d','0','0','','!iops','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of I/O operations observed at the storage object. Performance metric aggregated over all types of I/O operations.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33509','18','','10372','Cluster IOPS, write rate','netapp.cluster.statistics.iops.write.rate','0','7d','365d','0','0','','!iops','','',NULL,NULL,'','','0','','','','','0',NULL,'The number of I/O operations observed at the storage object. Performance metric for write I/O operations.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33510','18','','10372','Cluster latency raw, other','netapp.cluster.statistics.latency_raw.other','0','7d','365d','0','3','','!mcs','','',NULL,NULL,'','','0','','','','','0',NULL,'The raw latency in microseconds observed at the storage object. This can be divided by the raw IOPS value to calculate the average latency per I/O operation. Performance metric for other I/O operations. Other I/O operations can be metadata operations, such as directory lookups and so on.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33511','18','','10372','Cluster latency raw, write','netapp.cluster.statistics.latency_raw.write','0','7d','365d','0','3','','!mcs','','',NULL,NULL,'','','0','','','','','0',NULL,'The raw latency in microseconds observed at the storage object. This can be divided by the raw IOPS value to calculate the average latency per I/O operation. Performance metric for write I/O operations.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33512','18','','10372','Cluster throughput, write rate','netapp.cluster.statistics.throughput.write.rate','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','0',NULL,'Throughput bytes observed at the storage object. Performance metric for write I/O operations.','0','30d','0','','33490','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33515','18','','10372','FRUs discovery','netapp.frus.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','0','','33486','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33526','18','','10372','{#ID}: State','netapp.chassis.state[{#ID}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The chassis state: ok, error.','0','30d','0','','33479','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33527','18','','10372','{#DISKNAME}: State','netapp.disk.state[{#NODENAME},{#DISKNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The state of the disk. Possible values: broken, copy, maintenance, partner, pending, present, reconstructing, removed, spare, unfail, zeroing','0','30d','0','','33487','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33528','18','','10372','{#FRUID}: State','netapp.chassis.fru.state[{#CHASSISID},{#FRUID}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The FRU state: ok, error.','0','30d','0','','33486','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33529','18','','10372','{#LUNNAME}: Space size','netapp.lun.space.size[{#SVMNAME},{#LUNNAME}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The total provisioned size of the LUN.','0','30d','0','','33485','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33530','18','','10372','{#LUNNAME}: Space used','netapp.lun.space.used[{#SVMNAME},{#LUNNAME}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The amount of space consumed by the main data stream of the LUN.','0','30d','0','','33485','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33531','18','','10372','{#LUNNAME}: Container state','netapp.lun.status.container_state[{#SVMNAME},{#LUNNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The state of the volume and aggregate that contain the LUN: online, aggregate_offline, volume_offline. LUNs are only available when their containers are available.','0','30d','0','','33485','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33532','18','','10372','{#LUNNAME}: State','netapp.lun.status.state[{#SVMNAME},{#LUNNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The state of the LUN. Normal states for a LUN are online and offline. Other states indicate errors. Possible values: foreign_lun_error, nvfail, offline, online, space_error.','0','30d','0','','33485','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33533','18','','10372','{#NODENAME}: Software version','netapp.node.version[{#NODENAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'This returns the cluster version information. When the cluster has more than one node, the cluster version is equivalent to the lowest of generation, major, and minor versions on all nodes.','0','30d','0','','33484','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33534','18','','10372','{#NODENAME}: Controller over temperature','netapp.nodes.controller.over_temperature[{#NODENAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Specifies whether the hardware is currently operating outside of its recommended temperature range. The hardware shuts down if the temperature exceeds critical thresholds. Possible values: over, normal','0','30d','0','','33484','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33535','18','','10372','{#NODENAME}: Location','netapp.nodes.location[{#NODENAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The location of the node.','0','30d','0','','33484','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33536','18','','10372','{#NODENAME}: Membership','netapp.nodes.membership[{#NODENAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Possible values:
  available - If a node is available, this means it is detected on the internal cluster network and can be added to the cluster. Nodes that have a membership of “available” are not returned when a GET request is called when the cluster exists. A query on the “membership” property for available must be provided to scan for nodes on the cluster network. Nodes that have a membership of “available” are returned automatically before a cluster is created.
  joining - Joining nodes are in the process of being added to the cluster. The node may be progressing through the steps to become a member or might have failed. The job to add the node or create the cluster provides details on the current progress of the node.
  member - Nodes that are members have successfully joined the cluster.','0','30d','0','','33484','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33537','18','','10372','{#NODENAME}: State','netapp.nodes.state[{#NODENAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'State of the node:
up - Node is up and operational.
booting - Node is booting up.
down - Node has stopped or is dumping core.
taken_over - Node has been taken over by its HA partner and is not yet waiting for giveback.
waiting_for_giveback - Node has been taken over by its HA partner and is waiting for the HA partner to giveback disks.
degraded - Node has one or more critical services offline.
unknown - Node or its HA partner cannot be contacted and there is no information on the node’s state.','0','30d','0','','33484','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33538','18','','10372','{#NODENAME}: Uptime','netapp.nodes.uptime[{#NODENAME}]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The total time, in seconds, that the node has been up.','0','30d','0','','33484','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33539','18','','10372','{#ETHPORTNAME}: State','netapp.port.eth.state[{#NODENAME},{#ETHPORTNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The operational state of the port. Possible values: up, down.','0','30d','0','','33483','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33540','18','','10372','{#FCPORTNAME}: Description','netapp.port.fc.description[{#NODENAME},{#FCPORTNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'A description of the FC port.','0','30d','0','','33482','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33541','18','','10372','{#FCPORTNAME}: State','netapp.port.fc.state[{#NODENAME},{#FCPORTNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The operational state of the FC port. Possible values:
startup - The port is booting up.
link_not_connected - The port has finished initialization, but a link with the fabric is not established.
online - The port is initialized and a link with the fabric has been established.
link_disconnected - The link was present at one point on this port but is currently not established.
offlined_by_user - The port is administratively disabled.
offlined_by_system - The port is set to offline by the system. This happens when the port encounters too many errors.
node_offline - The state information for the port cannot be retrieved. The node is offline or inaccessible.','0','30d','0','','33482','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33542','18','','10372','{#SVMNAME}: Comment','netapp.svm.comment[{#SVMNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The comment for the SVM.','0','30d','0','','33481','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33543','18','','10372','{#SVMNAME}: State','netapp.svm.state[{#SVMNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'SVM state: starting, running, stopping, stopped, deleting.','0','30d','0','','33481','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33544','18','','10372','{#VOLUMENAME}: Comment','netapp.volume.comment[{#VOLUMENAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'A comment for the volume.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33545','18','','10372','{#VOLUMENAME}: Volume latency raw, read','netapp.volume.statistics.latency_raw.read[{#VOLUMENAME}]','0','7d','365d','0','3','','!mcs','','',NULL,NULL,'','','0','','','','','2',NULL,'The raw latency in microseconds observed at the storage object. Performance metric for read I/O operations.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33546','18','','10372','{#VOLUMENAME}: SVM name','netapp.volume.svm_name[{#VOLUMENAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The volume belongs this SVM.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33547','18','','10372','{#VOLUMENAME}: Volume throughput, write rate','netapp.volume.statistics.throughput.write.rate[{#VOLUMENAME}]','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Throughput bytes observed at the storage object. Performance metric for write I/O operations.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33548','18','','10372','{#VOLUMENAME}: Volume throughput, total rate','netapp.volume.statistics.throughput.total.rate[{#VOLUMENAME}]','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Throughput bytes observed at the storage object. Performance metric aggregated over all types of I/O operations.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33549','18','','10372','{#VOLUMENAME}: Volume throughput, read rate','netapp.volume.statistics.throughput.read.rate[{#VOLUMENAME}]','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Throughput bytes observed at the storage object. Performance metric for read I/O operations.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33550','18','','10372','{#VOLUMENAME}: Volume throughput, other rate','netapp.volume.statistics.throughput.other.rate[{#VOLUMENAME}]','0','7d','365d','0','0','','Bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Throughput bytes observed at the storage object. Performance metric for other I/O operations. Other I/O operations can be metadata operations, such as directory lookups and so on.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33551','18','','10372','{#VOLUMENAME}: Volume latency raw, write','netapp.volume.statistics.latency_raw.write[{#VOLUMENAME}]','0','7d','365d','0','3','','!mcs','','',NULL,NULL,'','','0','','','','','2',NULL,'The raw latency in microseconds observed at the storage object. Performance metric for write I/O operations.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33552','18','','10372','{#VOLUMENAME}: Volume latency raw, total','netapp.volume.statistics.latency_raw.total[{#VOLUMENAME}]','0','7d','365d','0','3','','!mcs','','',NULL,NULL,'','','0','','','','','2',NULL,'The raw latency in microseconds observed at the storage object. Performance metric aggregated over all types of I/O operations.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33553','18','','10372','{#VOLUMENAME}: Volume latency raw, other','netapp.volume.statistics.latency_raw.other[{#VOLUMENAME}]','0','7d','365d','0','3','','!mcs','','',NULL,NULL,'','','0','','','','','2',NULL,'The raw latency in microseconds observed at the storage object. Performance metric for other I/O operations. Other I/O operations can be metadata operations, such as directory lookups and so on.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33554','18','','10372','{#VOLUMENAME}: Available size','netapp.volume.space_available[{#VOLUMENAME}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The available space, in bytes.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33555','18','','10372','{#VOLUMENAME}: Volume IOPS, write rate','netapp.volume.statistics.iops.write.rate[{#VOLUMENAME}]','0','7d','365d','0','0','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of I/O operations observed at the storage object. Performance metric for write I/O operations.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33556','18','','10372','{#VOLUMENAME}: Volume IOPS, total rate','netapp.volume.statistics.iops.total.rate[{#VOLUMENAME}]','0','7d','365d','0','0','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of I/O operations observed at the storage object. Performance metric aggregated over all types of I/O operations.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33557','18','','10372','{#VOLUMENAME}: Volume IOPS, read rate','netapp.volume.statistics.iops.read.rate[{#VOLUMENAME}]','0','7d','365d','0','0','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of I/O operations observed at the storage object. Performance metric for read I/O operations.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33558','18','','10372','{#VOLUMENAME}: Volume IOPS, other rate','netapp.volume.statistics.iops.other.rate[{#VOLUMENAME}]','0','7d','365d','0','0','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of I/O operations observed at the storage object. Performance metric for other I/O operations. Other I/O operations can be metadata operations, such as directory lookups and so on.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33559','18','','10372','{#VOLUMENAME}: Volume IOPS raw, write','netapp.volume.statistics.iops_raw.write[{#VOLUMENAME}]','0','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of I/O operations observed at the storage object. Performance metric for write I/O operations.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33560','18','','10372','{#VOLUMENAME}: Volume IOPS raw, total','netapp.volume.statistics.iops_raw.total[{#VOLUMENAME}]','0','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of I/O operations observed at the storage object. Performance metric aggregated over all types of I/O operations.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33561','18','','10372','{#VOLUMENAME}: Volume IOPS raw, read','netapp.volume.statistics.iops_raw.read[{#VOLUMENAME}]','0','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of I/O operations observed at the storage object. Performance metric for read I/O operations.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33562','18','','10372','{#VOLUMENAME}: Volume IOPS raw, other','netapp.volume.statistics.iops_raw.other[{#VOLUMENAME}]','0','7d','365d','0','3','','!iops','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of I/O operations observed at the storage object. Performance metric for other I/O operations. Other I/O operations can be metadata operations, such as directory lookups and so on.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33563','18','','10372','{#VOLUMENAME}: State','netapp.volume.state[{#VOLUMENAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Volume state. A volume can only be brought online if it is offline. Taking a volume offline removes its junction path. The ‘mixed’ state applies to FlexGroup volumes only and cannot be specified as a target state. An ‘error’ state implies that the volume is not in a state to serve data.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33564','18','','10372','{#VOLUMENAME}: Used size','netapp.volume.space_used[{#VOLUMENAME}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'The virtual space used (includes volume reserves) before storage efficiency, in bytes.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33565','18','','10372','{#VOLUMENAME}: Space size','netapp.volume.space_size[{#VOLUMENAME}]','0','7d','365d','0','3','','B','','',NULL,NULL,'','','0','','','','','2',NULL,'Total provisioned size. The default size is equal to the minimum size of 20MB, in bytes.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33566','18','','10372','{#VOLUMENAME}: Type','netapp.volume.type[{#VOLUMENAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Type of the volume.
rw ‐ read-write volume.
dp ‐ data-protection volume.
ls ‐ load-sharing dp volume.','0','30d','0','','33492','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('33567','18','','10363','MongoDB cluster: Configserver heartbeat','mongodb.config_server_heartbeat','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','0',NULL,'Difference between the latest optime of the CSRS primary that the mongos has seen and cluster time.','0','30d','0','','33140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34176','18','','10327','MSSQL DB ''{#DBNAME}'': Last diff backup duration','mssql.backup.diff.duration["{#DBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Duration of the last differential backup.','0','30d','0','','34174','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34177','18','','10327','MSSQL DB ''{#DBNAME}'': Last diff backup (time ago)','mssql.backup.diff["{#DBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The amount of time since the last differential backup.','0','30d','0','','34174','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34178','18','','10327','MSSQL DB ''{#DBNAME}'': Last log backup','mssql.backup.log["{#DBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The amount of time since the last log backup.','0','30d','0','','34174','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34179','18','','10327','MSSQL DB ''{#DBNAME}'': Last log backup duration','mssql.backup.log.duration["{#DBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Duration of the last log backup.','0','30d','0','','34174','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34180','18','','10327','MSSQL DB ''{#DBNAME}'': Last full backup (time ago)','mssql.backup.full["{#DBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'The amount of time since the last full backup.','0','30d','0','','34174','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34181','18','','10327','MSSQL DB ''{#DBNAME}'': Last full backup duration','mssql.backup.full.duration["{#DBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Duration of the last full backup.','0','30d','0','','34174','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34182','18','','10327','MSSQL Job ''{#JOBNAME}'': Last run date-time','mssql.job.lastrundatetime["{#JOBNAME}"]','0','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The last date-time of the job run.','0','30d','0','','34173','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34183','18','','10327','MSSQL Job ''{#JOBNAME}'': Last run status message','mssql.job.lastrunstatusmessage["{#JOBNAME}"]','0','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The informational message about the last run of the job.','0','30d','0','','34173','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34184','18','','10327','MSSQL Job ''{#JOBNAME}'': Next run date-time','mssql.job.nextrundatetime["{#JOBNAME}"]','0','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The next date-time of the job run.','0','30d','0','','34173','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34185','18','','10327','MSSQL Job ''{#JOBNAME}'': Run duration','mssql.job.run_duration["{#JOBNAME}"]','0','7d','365d','0','3','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Duration of the last run job.','0','30d','0','','34173','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34186','18','','10327','MSSQL Job ''{#JOBNAME}'': Run status','mssql.job.runstatus["{#JOBNAME}"]','0','7d','365d','0','3','','','','',NULL,'161','','','0','','','','','2',NULL,'The job status possible values:
0 ⇒ Failed
1 ⇒ Succeeded
2 ⇒ Retry
3 ⇒ Canceled
4 ⇒ Running','0','30d','0','','34173','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34845','18','','10399','Nginx: Connections idle','nginx.connections.idle','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of idle client connections.','0','30d','0','','34835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34846','18','','10399','Nginx: Connections active','nginx.connections.active','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of active client connections.','0','30d','0','','34835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34847','18','','10399','Nginx: SSL session reuses, rate','nginx.ssl.session_reuses.rate','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of session reuses during SSL handshake per second.','0','30d','0','','34838','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34848','18','','10399','Nginx: SSL handshakes, rate','nginx.ssl.handshakes.rate','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of successful SSL handshakes per second.','0','30d','0','','34838','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34849','18','','10399','Nginx: SSL handshakes failed, rate','nginx.ssl.handshakes_failed.rate','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of failed SSL handshakes per second.','0','30d','0','','34838','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34850','18','','10399','Nginx: Connections dropped','nginx.connections.dropped','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of dropped client connections.','0','30d','0','','34835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34851','18','','10399','Nginx: Requests current','nginx.requests.current','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The current number of client requests.','0','30d','0','','34840','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34852','18','','10399','Nginx: Requests total, rate','nginx.requests.total.rate','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of client requests per second.','0','30d','0','','34840','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34853','18','','10399','Nginx: Version','nginx.info.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Version of nginx.','0','30d','0','','34836','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34854','18','','10399','Nginx: Connections accepted, rate','nginx.connections.accepted.rate','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of accepted client connections per second.','0','30d','0','','34835','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34855','18','','10399','Nginx: Generation','nginx.info.generation','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The total number of configuration reloads.','0','30d','0','','34836','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34856','18','','10399','Nginx: Get info error','nginx.info.error','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Nginx error description.','0','30d','0','','34836','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34857','18','','10399','Nginx: Address','nginx.info.address','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The address of the server that accepted status request.','0','30d','0','','34836','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34858','18','','10399','Nginx: Uptime','nginx.info.uptime','0','7d','365d','0','3','','uptime','','',NULL,NULL,'','','0','','','','','0',NULL,'Server uptime.','0','30d','0','','34836','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34859','18','','10399','HTTP location zones discovery','nginx.http.location_zones.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','','34843','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34860','18','','10399','HTTP server zones discovery','nginx.http.server_zones.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','','34844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34861','18','','10399','HTTP upstream peers discovery','nginx.http.upstream.peers.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34862','18','','10399','HTTP upstreams discovery','nginx.http.upstreams.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34863','18','','10399','Resolvers discovery','nginx.resolvers.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','','34839','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34864','18','','10399','Stream server zones discovery','nginx.stream.server_zones.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','','34837','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34865','18','','10399','Stream upstream peers discovery','nginx.stream.upstream.peers.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34866','18','','10399','Stream upstreams discovery','nginx.stream.upstreams.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'','0','30d','1','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34867','18','','10399','Nginx: HTTP location zone [{#NAME}]: Discarded, rate','nginx.http.location_zones.discarded.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of requests completed without sending a response per second.','0','30d','0','','34843','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34868','18','','10399','Nginx: HTTP location zone [{#NAME}]: Received, rate','nginx.http.location_zones.received.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of bytes received from clients per second.','0','30d','0','','34843','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34869','18','','10399','Nginx: HTTP location zone [{#NAME}]: Requests, rate','nginx.http.location_zones.requests.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of client requests received from clients per second.','0','30d','0','','34843','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34870','18','','10399','Nginx: HTTP location zone [{#NAME}]: Responses 1xx, rate','nginx.http.location_zones.responses.1xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “1xx” status codes per second.','0','30d','0','','34843','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34871','18','','10399','Nginx: HTTP location zone [{#NAME}]: Responses 2xx, rate','nginx.http.location_zones.responses.2xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “2xx” status codes per second.','0','30d','0','','34843','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34872','18','','10399','Nginx: HTTP location zone [{#NAME}]: Responses 3xx, rate','nginx.http.location_zones.responses.3xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “3xx” status codes per second.','0','30d','0','','34843','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34873','18','','10399','Nginx: HTTP location zone [{#NAME}]: Responses 4xx, rate','nginx.http.location_zones.responses.4xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “4xx” status codes per second.','0','30d','0','','34843','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34874','18','','10399','Nginx: HTTP location zone [{#NAME}]: Responses 5xx, rate','nginx.http.location_zones.responses.5xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “5xx” status codes per second.','0','30d','0','','34843','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34875','18','','10399','Nginx: HTTP location zone [{#NAME}]: Responses total, rate','nginx.http.location_zones.responses.total.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of responses sent to clients per second.','0','30d','0','','34843','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34876','18','','10399','Nginx: HTTP location zone [{#NAME}]: Sent, rate','nginx.http.location_zones.sent.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of bytes sent to clients per second.','0','30d','0','','34843','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34877','18','','10399','Nginx: HTTP server zone [{#NAME}]: Discarded, rate','nginx.http.server_zones.discarded.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of requests completed without sending a response per second.','0','30d','0','','34844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34878','18','','10399','Nginx: HTTP server zone [{#NAME}]: Processing','nginx.http.server_zones.processing[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of client requests that are currently being processed.','0','30d','0','','34844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34879','18','','10399','Nginx: HTTP server zone [{#NAME}]: Received, rate','nginx.http.server_zones.received.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of bytes received from clients per second.','0','30d','0','','34844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34880','18','','10399','Nginx: HTTP server zone [{#NAME}]: Requests, rate','nginx.http.server_zones.requests.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of client requests received from clients per second.','0','30d','0','','34844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34881','18','','10399','Nginx: HTTP server zone [{#NAME}]: Responses 1xx, rate','nginx.http.server_zones.responses.1xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “1xx” status codes per second.','0','30d','0','','34844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34882','18','','10399','Nginx: HTTP server zone [{#NAME}]: Responses 2xx, rate','nginx.http.server_zones.responses.2xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “2xx” status codes per second.','0','30d','0','','34844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34883','18','','10399','Nginx: HTTP server zone [{#NAME}]: Responses 3xx, rate','nginx.http.server_zones.responses.3xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “3xx” status codes per second.','0','30d','0','','34844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34884','18','','10399','Nginx: HTTP server zone [{#NAME}]: Responses 4xx, rate','nginx.http.server_zones.responses.4xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “4xx” status codes per second.','0','30d','0','','34844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34885','18','','10399','Nginx: HTTP server zone [{#NAME}]: Responses 5xx, rate','nginx.http.server_zones.responses.5xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “5xx” status codes per second.','0','30d','0','','34844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34886','18','','10399','Nginx: HTTP server zone [{#NAME}]: Responses total, rate','nginx.http.server_zones.responses.total.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of responses sent to clients per second.','0','30d','0','','34844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34887','18','','10399','Nginx: HTTP server zone [{#NAME}]: Sent, rate','nginx.http.server_zones.sent.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of bytes sent to clients per second.','0','30d','0','','34844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34888','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Active','nginx.http.upstream.peer.active[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The current number of active connections.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34889','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Responses 2xx, rate','nginx.http.upstream.peer.responses.2xx.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “2xx” status codes per second.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34890','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: State','nginx.http.upstream.peer.state[{#UPSTREAM},{#PEER}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Current state, which may be one of “up”, “draining”, “down”, “unavail”, “checking”, and “unhealthy”.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34891','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Sent, rate','nginx.http.upstream.peer.sent.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of bytes sent to this server per second.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34892','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Responses total, rate','nginx.http.upstream.peer.responses.total.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of responses obtained from this server.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34893','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Responses 5xx, rate','nginx.http.upstream.peer.responses.5xx.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “5xx” status codes per second.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34894','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Responses 4xx, rate','nginx.http.upstream.peer.responses.4xx.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “4xx” status codes per second.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34895','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Responses 3xx, rate','nginx.http.upstream.peer.responses.3xx.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “3xx” status codes per second.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34896','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Responses 1xx, rate','nginx.http.upstream.peer.responses.1xx.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of responses with “1xx” status codes per second.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34897','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Fails, rate','nginx.http.upstream.peer.fails.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of unsuccessful attempts to communicate with the server per second.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34898','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Response time','nginx.http.upstream.peer.response_time.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','!ms','','',NULL,NULL,'','','0','','','','','2',NULL,'The average time to get the full response from the server.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34899','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Requests, rate','nginx.http.upstream.peer.requests.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of client requests forwarded to this server per second.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34900','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Received, rate','nginx.http.upstream.peer.received.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of bytes received from this server per second.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34901','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Health checks, unhealthy','nginx.http.upstream.peer.health_checks.unhealthy[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'How many times the server became unhealthy (state “unhealthy”).','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34902','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Health checks, fails','nginx.http.upstream.peer.health_checks.fails[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of failed health checks.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34903','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Health checks, check','nginx.http.upstream.peer.health_checks.checks[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of health check requests made.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34904','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Header time','nginx.http.upstream.peer.header_time.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','!ms','','',NULL,NULL,'','','0','','','','','2',NULL,'The average time to get the response header from the server.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34905','18','','10399','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Unavail','nginx.http.upstream.peer.unavail.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'How many times the server became unavailable for client requests (state “unavail”) due to the number of unsuccessful attempts reaching the max_fails threshold.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34906','18','','10399','Nginx: HTTP upstream [{#NAME}]: Keepalive','nginx.http.upstreams.keepalive[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The current number of idle keepalive connections.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34907','18','','10399','Nginx: HTTP upstream [{#NAME}]: Zombies','nginx.http.upstreams.zombies[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The current number of servers removed from the group but still processing active client requests.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34908','18','','10399','Nginx: HTTP upstream [{#NAME}]: Zone','nginx.http.upstreams.zone[{#NAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The name of the shared memory zone that keeps the group’s configuration and run-time state.','0','30d','0','','34842','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34909','18','','10399','Nginx: Resolver [{#NAME}]: Requests addr, rate','nginx.resolvers.requests.addr.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of requests to resolve addresses to names per second.','0','30d','0','','34839','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34910','18','','10399','Nginx: Resolver [{#NAME}]: Requests name, rate','nginx.resolvers.requests.name.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of requests to resolve names to addresses per second.','0','30d','0','','34839','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34911','18','','10399','Nginx: Resolver [{#NAME}]: Requests srv, rate','nginx.resolvers.requests.srv.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of requests to resolve SRV records per second.','0','30d','0','','34839','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34912','18','','10399','Nginx: Resolver [{#NAME}]: Responses formerr, rate','nginx.resolvers.responses.formerr.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of FORMERR (Format error) responses per second.','0','30d','0','','34839','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34913','18','','10399','Nginx: Resolver [{#NAME}]: Responses noerror, rate','nginx.resolvers.responses.noerror.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of successful responses per second.','0','30d','0','','34839','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34914','18','','10399','Nginx: Resolver [{#NAME}]: Responses notimp, rate','nginx.resolvers.responses.notimp.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of NOTIMP (Unimplemented) responses per second.','0','30d','0','','34839','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34915','18','','10399','Nginx: Resolver [{#NAME}]: Responses nxdomain, rate','nginx.resolvers.responses.nxdomain.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of NXDOMAIN (Host not found) responses per second.','0','30d','0','','34839','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34916','18','','10399','Nginx: Resolver [{#NAME}]: Responses refused, rate','nginx.resolvers.responses.refused.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of REFUSED (Operation refused) responses per second.','0','30d','0','','34839','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34917','18','','10399','Nginx: Resolver [{#NAME}]: Responses servfail, rate','nginx.resolvers.responses.servfail.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of SERVFAIL (Server failure) responses per second.','0','30d','0','','34839','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34918','18','','10399','Nginx: Resolver [{#NAME}]: Responses timedout, rate','nginx.resolvers.responses.timedout.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of timed out requests per second.','0','30d','0','','34839','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34919','18','','10399','Nginx: Resolver [{#NAME}]: Responses unknown, rate','nginx.resolvers.responses.unknown.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of requests completed with an unknown error per second.','0','30d','0','','34839','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34920','18','','10399','Nginx: Stream server zone [{#NAME}]: Connections, rate','nginx.stream.server_zones.connections.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of connections accepted from clients per second.','0','30d','0','','34837','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34921','18','','10399','Nginx: Stream server zone [{#NAME}]: Discarded, rate','nginx.stream.server_zones.discarded.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of connections completed without creating a session per second.','0','30d','0','','34837','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34922','18','','10399','Nginx: Stream server zone [{#NAME}]: Processing','nginx.stream.server_zones.processing[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of client connections that are currently being processed.','0','30d','0','','34837','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34923','18','','10399','Nginx: Stream server zone [{#NAME}]: Received, rate','nginx.stream.server_zones.received.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of bytes received from clients per second.','0','30d','0','','34837','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34924','18','','10399','Nginx: Stream server zone [{#NAME}]: Sent, rate','nginx.stream.server_zones.sent.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of bytes sent to clients per second.','0','30d','0','','34837','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34925','18','','10399','Nginx: Stream server zone [{#NAME}]: Sessions 2xx, rate','nginx.stream.server_zones.sessions.2xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of sessions completed with status codes “2xx” per second.','0','30d','0','','34837','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34926','18','','10399','Nginx: Stream server zone [{#NAME}]: Sessions 4xx, rate','nginx.stream.server_zones.sessions.4xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of sessions completed with status codes “4xx” per second.','0','30d','0','','34837','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34927','18','','10399','Nginx: Stream server zone [{#NAME}]: Sessions 5xx, rate','nginx.stream.server_zones.sessions.5xx.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of sessions completed with status codes “5xx” per second.','0','30d','0','','34837','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34928','18','','10399','Nginx: Stream server zone [{#NAME}]: Sessions total, rate','nginx.stream.server_zones.sessions.total.rate[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of completed client sessions per second.','0','30d','0','','34837','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34929','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: Active','nginx.stream.upstream.peer.active[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The current number of connections.','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34930','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: Connect time','nginx.stream.upstream.peer.connect_time.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','!ms','','',NULL,NULL,'','','0','','','','','2',NULL,'The average time to connect to the upstream server.','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34931','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: Connections','nginx.stream.upstream.peer.connections.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of client connections forwarded to this server.','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34932','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: Fails, rate','nginx.stream.upstream.peer.fails.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of unsuccessful attempts to communicate with the server per second.','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34933','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: First byte time','nginx.stream.upstream.peer.first_byte_time.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','!ms','','',NULL,NULL,'','','0','','','','','2',NULL,'The average time to receive the first byte of data.','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34934','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: Health checks, check','nginx.stream.upstream.peer.health_checks.checks[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of health check requests made.','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34935','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: Health checks, fails','nginx.stream.upstream.peer.health_checks.fails[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of failed health checks.','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34936','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: Health checks, unhealthy','nginx.stream.upstream.peer.health_checks.unhealthy[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'How many times the server became unhealthy (state “unhealthy”).','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34937','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: Received, rate','nginx.stream.upstream.peer.received.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of bytes received from this server per second.','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34938','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: Response time','nginx.stream.upstream.peer.response_time.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','!ms','','',NULL,NULL,'','','0','','','','','2',NULL,'The average time to receive the last byte of data.','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34939','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: Sent, rate','nginx.stream.upstream.peer.sent.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The total number of bytes sent to this server per second.','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34940','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: State','nginx.stream.upstream.peer.state[{#UPSTREAM},{#PEER}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Current state, which may be one of “up”, “draining”, “down”, “unavail”, “checking”, and “unhealthy”.','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34941','18','','10399','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: Unavail','nginx.stream.upstream.peer.unavail.rate[{#UPSTREAM},{#PEER}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'How many times the server became unavailable for client requests (state “unavail”) due to the number of unsuccessful attempts reaching the max_fails threshold.','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34942','18','','10399','Nginx: Stream upstream [{#NAME}]: Zombies','nginx.stream.upstreams.zombies[{#NAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34943','18','','10399','Nginx: Stream upstream [{#NAME}]: Zone','nginx.stream.upstreams.zone[{#NAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','34841','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35562','18','','10413','{#UNIT.NAME}: Active state','systemd.service.active_state["{#UNIT.NAME}"]','0','7d','365d','0','3','','','','',NULL,'238','','','0','','','','','2',NULL,'State value that reflects whether the unit is currently active or not. The following states are currently defined: "active", "reloading", "inactive", "failed", "activating", and "deactivating".','0','30d','0','','35560','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35563','18','','10413','{#UNIT.NAME}: Load state','systemd.service.load_state["{#UNIT.NAME}"]','0','7d','365d','0','3','','','','',NULL,'237','','','0','','','','','2',NULL,'State value that reflects whether the configuration file of this unit has been loaded. The following states are currently defined: "loaded", "error", and "masked".','0','30d','0','','35560','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35564','18','','10413','{#UNIT.NAME}: Unit file state','systemd.service.unitfile_state["{#UNIT.NAME}"]','0','7d','365d','0','3','','','','',NULL,'239','','','0','','','','','2',NULL,'Encodes the install state of the unit file of FragmentPath. It currently knows the following states: "enabled", "enabled-runtime", "linked", "linked-runtime", "masked", "masked-runtime", "static", "disabled", and "invalid".','0','30d','0','','35560','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35565','18','','10413','{#UNIT.NAME}: Active time','systemd.service.uptime["{#UNIT.NAME}"]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of seconds since unit entered the active state.','0','30d','0','','35560','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35566','18','','10413','{#UNIT.NAME}: Connections accepted per sec','systemd.socket.conn_accepted.rate["{#UNIT.NAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The number of accepted socket connections (NAccepted) per second.','0','30d','0','','35561','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35567','18','','10413','{#UNIT.NAME}: Connections connected','systemd.socket.conn_count["{#UNIT.NAME}"]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The current number of socket connections (NConnections).','0','30d','0','','35561','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35773','18','','10416','Cert: Subject alternative name','cert.alternative_names','0','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The subject alternative name extension allows identities to be bound to the subject of the certificate.  These identities may be included in addition to or in place of the identity in the subject field of the certificate.  Defined options include an Internet electronic mail address, a DNS name, an IP address, and a Uniform Resource Identifier (URI).','0','30d','0','','35772','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35774','18','','10416','Cert: Issuer','cert.issuer','0','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The field identifies the entity that has signed and issued the certificate.','0','30d','0','','35772','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35775','18','','10416','Cert: Last validation status','cert.message','0','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Last check result message.','0','30d','0','','35772','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35776','18','','10416','Cert: Expires on','cert.not_after','0','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'The date on which the certificate validity period ends.','0','30d','0','','35772','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35777','18','','10416','Cert: Valid from','cert.not_before','0','7d','365d','0','3','','unixtime','','',NULL,NULL,'','','0','','','','','0',NULL,'The date on which the certificate validity period begins.','0','30d','0','','35772','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35778','18','','10416','Cert: Public key algorithm','cert.public_key_algorithm','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The digital signature algorithm is used to verify the signature of a certificate.','0','30d','0','','35772','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35779','18','','10416','Cert: Serial number','cert.serial_number','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The serial number is a positive integer assigned by the CA to each certificate. It is unique for each certificate issued by a given CA. Non-conforming CAs may issue certificates with serial numbers that are negative or zero.','0','30d','0','','35772','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35780','18','','10416','Cert: Fingerprint','cert.sha1_fingerprint','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The Certificate Signature (SHA1 Fingerprint or Thumbprint) is the hash of the entire certificate in DER form.','0','30d','0','','35772','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35781','18','','10416','Cert: Signature algorithm','cert.signature_algorithm','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The algorithm identifier for the algorithm used by the CA to sign the certificate.','0','30d','0','','35772','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35782','18','','10416','Cert: Subject','cert.subject','0','7d','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The field identifies the entity associated with the public key stored in the subject public key field.','0','30d','0','','35772','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35783','18','','10416','Cert: Validation result','cert.validation','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The certificate validation result. Possible values: valid/invalid/valid-but-self-signed','0','30d','0','','35772','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35784','18','','10416','Cert: Version','cert.version','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'The version of the encoded certificate.','0','30d','0','','35772','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35785','18','','10308','HAProxy: Get nodes','haproxy.get.nodes','0','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Array for LLD rules.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35787','18','','10308','HAProxy Backend {#PXNAME}: Number of active servers','haproxy.backend.act[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of active servers.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35788','18','','10308','HAProxy Backend {#PXNAME}: Number of responses with codes 5xx per second','haproxy.backend.hrsp_5xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP server errors per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35789','18','','10308','HAProxy Backend {#PXNAME}: Redispatched requests per second','haproxy.backend.wredis.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of times a request was redispatched to a different backend.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35790','18','','10308','HAProxy Backend {#PXNAME}: Weight','haproxy.backend.weight[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total effective weight.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35791','18','','10308','HAProxy Backend {#PXNAME}: Sessions per second','haproxy.backend.stot.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Cumulative number of sessions (end-to-end connections) per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35792','18','','10308','HAProxy Backend {#PXNAME}: Status','haproxy.backend.status[{#PXNAME},{#SVNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Possible values:
UP - The server is reporting as healthy.
DOWN - The server is reporting as unhealthy and unable to receive requests.
NOLB - You''ve added http-check disable-on-404 to the backend and the health checked URL has returned an HTTP 404 response.
MAINT - The server has been disabled or put into maintenance mode.
DRAIN - The server has been put into drain mode.
no check - Health checks are not enabled for this server.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35793','18','','10308','HAProxy Backend {#PXNAME}: Responses time','haproxy.backend.rtime[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Average backend response time (in ms) for the last 1,024 requests','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35794','18','','10308','HAProxy Backend {#PXNAME}: Time in queue','haproxy.backend.qtime[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Average time spent in queue (in ms) for the last 1,024 requests','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35795','18','','10308','HAProxy Backend {#PXNAME}: Unassigned requests','haproxy.backend.qcur[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Current number of requests unassigned in queue.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35796','18','','10308','HAProxy Backend {#PXNAME}: Number of responses with codes 4xx per second','haproxy.backend.hrsp_4xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP client errors per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35797','18','','10308','HAProxy Backend {#PXNAME}: Number of backup servers','haproxy.backend.bck[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of backup servers.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35798','18','','10308','HAProxy Backend {#PXNAME}: Number of responses with codes 3xx per second','haproxy.backend.hrsp_3xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP redirections per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35799','18','','10308','HAProxy Backend {#PXNAME}: Number of responses with codes 2xx per second','haproxy.backend.hrsp_2xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of successful HTTP responses per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35800','18','','10308','HAProxy Backend {#PXNAME}: Number of responses with codes 1xx per second','haproxy.backend.hrsp_1xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of informational HTTP responses per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35801','18','','10308','HAProxy Backend {#PXNAME}: Response errors per second','haproxy.backend.eresp.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of requests whose responses yielded an error','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35802','18','','10308','HAProxy Backend {#PXNAME}: Errors connection per second','haproxy.backend.econ.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of requests that encountered an error attempting to connect to a backend server.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35803','18','','10308','HAProxy Backend {#PXNAME}: Responses denied per second','haproxy.backend.dresp.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Responses denied due to security concerns (ACL-restricted).','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35804','18','','10308','HAProxy Backend {#PXNAME}: Outgoing traffic','haproxy.backend.bout.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bits sent by the backend','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35805','18','','10308','HAProxy Backend {#PXNAME}: Incoming traffic','haproxy.backend.bin.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bits received by the backend','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35806','18','','10308','HAProxy Backend {#PXNAME}: Retried connections per second','haproxy.backend.wretr.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of times a connection was retried.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35807','18','','10308','HAProxy Frontend {#PXNAME}: Incoming traffic','haproxy.frontend.bin.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bits received by the frontend','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35808','18','','10308','HAProxy Frontend {#PXNAME}: Outgoing traffic','haproxy.frontend.bout.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bits sent by the frontend','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35809','18','','10308','HAProxy Frontend {#PXNAME}: Denied requests per second','haproxy.frontend.dreq.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Requests denied due to security concerns (ACL-restricted) per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35810','18','','10308','HAProxy Frontend {#PXNAME}: Request errors per second','haproxy.frontend.ereq.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of request errors per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35811','18','','10308','HAProxy Frontend {#PXNAME}: Number of responses with codes 1xx per second','haproxy.frontend.hrsp_1xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of informational HTTP responses per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35812','18','','10308','HAProxy Frontend {#PXNAME}: Number of responses with codes 2xx per second','haproxy.frontend.hrsp_2xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of successful HTTP responses per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35813','18','','10308','HAProxy Frontend {#PXNAME}: Number of responses with codes 3xx per second','haproxy.frontend.hrsp_3xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP redirections per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35814','18','','10308','HAProxy Frontend {#PXNAME}: Number of responses with codes 4xx per second','haproxy.frontend.hrsp_4xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP client errors per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35815','18','','10308','HAProxy Frontend {#PXNAME}: Number of responses with codes 5xx per second','haproxy.frontend.hrsp_5xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP server errors per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35816','18','','10308','HAProxy Frontend {#PXNAME}: Sessions rate','haproxy.frontend.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of sessions created per second','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35817','18','','10308','HAProxy Frontend {#PXNAME}: Requests rate','haproxy.frontend.req_rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'HTTP requests per second','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35818','18','','10308','HAProxy Frontend {#PXNAME}: Established sessions','haproxy.frontend.scur[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The current number of established sessions.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35819','18','','10308','HAProxy Frontend {#PXNAME}: Session limits','haproxy.frontend.slim[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The most simultaneous sessions that are allowed, as defined by the maxconn setting in the frontend.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35820','18','','10308','HAProxy Frontend {#PXNAME}: Status','haproxy.frontend.status[{#PXNAME},{#SVNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Possible values: OPEN, STOP.
When Status is OPEN, the frontend is operating normally and ready to receive traffic.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35821','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Server is active','haproxy.server.act[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,'243','','','0','','','','','2',NULL,'Shows whether the server is active (marked with a Y) or a backup (marked with a -).','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35822','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Number of responses with codes 5xx per second','haproxy.server.hrsp_5xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP server errors per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35823','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Redispatched requests per second','haproxy.server.wredis.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of times a request was redispatched to a different backend.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35824','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Weight','haproxy.server.weight[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Effective weight.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35825','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Sessions per second','haproxy.server.stot.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Cumulative number of sessions (end-to-end connections) per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35826','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Status','haproxy.server.status[{#PXNAME},{#SVNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35827','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Responses time','haproxy.server.rtime[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Average server response time (in ms) for the last 1,024 requests.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35828','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Time in queue','haproxy.server.qtime[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Average time spent in queue (in ms) for the last 1,024 requests.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35829','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Configured maxqueue','haproxy.server.qlimit[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Configured maxqueue for the server, or nothing in the value is 0 (default, meaning no limit).','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35830','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Unassigned requests','haproxy.server.qcur[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Current number of requests unassigned in queue.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35831','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Server was selected per second','haproxy.server.lbtot.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of times that server was selected.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35832','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Number of responses with codes 4xx per second','haproxy.server.hrsp_4xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP client errors per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35833','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Server is backup','haproxy.server.bck[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,'243','','','0','','','','','2',NULL,'Shows whether the server is a backup (marked with a Y) or active (marked with a -).','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35834','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Number of responses with codes 3xx per second','haproxy.server.hrsp_3xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP redirections per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35835','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Number of responses with codes 2xx per second','haproxy.server.hrsp_2xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of successful HTTP responses per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35836','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Number of responses with codes 1xx per second','haproxy.server.hrsp_1xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of informational HTTP responses per second.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35837','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Response errors per second','haproxy.server.eresp.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of requests whose responses yielded an error.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35838','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Errors connection per second','haproxy.server.econ.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of requests that encountered an error attempting to connect to a backend server.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35839','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Responses denied per second','haproxy.server.dresp.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Responses denied due to security concerns (ACL-restricted).','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35840','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Status of last health check','haproxy.server.check_status[{#PXNAME},{#SVNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Status of last health check, one of:
UNK     -> unknown
INI     -> initializing
SOCKERR -> socket error
L4OK    -> check passed on layer 4, no upper layers testing enabled
L4TOUT  -> layer 1-4 timeout
L4CON   -> layer 1-4 connection problem, for example "Connection refused" (tcp rst) or "No route to host" (icmp)
L6OK    -> check passed on layer 6
L6TOUT  -> layer 6 (SSL) timeout
L6RSP   -> layer 6 invalid response - protocol error
L7OK    -> check passed on layer 7
L7OKC   -> check conditionally passed on layer 7, for example 404 with disable-on-404
L7TOUT  -> layer 7 (HTTP/SMTP) timeout
L7RSP   -> layer 7 invalid response - protocol error
L7STS   -> layer 7 response error, for example HTTP 5xx
Notice: If a check is currently running, the last known status will be reported, prefixed with "* ". e. g. "* L7OK".','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35841','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Outgoing traffic','haproxy.server.bout.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bits sent by the backend','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35842','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Incoming traffic','haproxy.server.bin.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bits received by the backend','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35843','18','','10308','HAProxy {#PXNAME} {#SVNAME}: Retried connections per second','haproxy.server.wretr.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of times a connection was retried.','0','30d','0','','30189','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35844','18','','10309','HAProxy: Get nodes','haproxy.get.nodes','0','0','0','0','4','','','','',NULL,NULL,'','','0','','','','','0',NULL,'Array for LLD rules.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35846','18','','10309','HAProxy Backend {#PXNAME}: Number of active servers','haproxy.backend.act[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of active servers.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35847','18','','10309','HAProxy Backend {#PXNAME}: Number of responses with codes 5xx per second','haproxy.backend.hrsp_5xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP server errors per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35848','18','','10309','HAProxy Backend {#PXNAME}: Redispatched requests per second','haproxy.backend.wredis.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of times a request was redispatched to a different backend.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35849','18','','10309','HAProxy Backend {#PXNAME}: Weight','haproxy.backend.weight[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Total effective weight.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35850','18','','10309','HAProxy Backend {#PXNAME}: Sessions per second','haproxy.backend.stot.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Cumulative number of sessions (end-to-end connections) per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35851','18','','10309','HAProxy Backend {#PXNAME}: Status','haproxy.backend.status[{#PXNAME},{#SVNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Possible values:
UP - The server is reporting as healthy.
DOWN - The server is reporting as unhealthy and unable to receive requests.
NOLB - You''ve added http-check disable-on-404 to the backend and the health checked URL has returned an HTTP 404 response.
MAINT - The server has been disabled or put into maintenance mode.
DRAIN - The server has been put into drain mode.
no check - Health checks are not enabled for this server.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35852','18','','10309','HAProxy Backend {#PXNAME}: Responses time','haproxy.backend.rtime[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Average backend response time (in ms) for the last 1,024 requests','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35853','18','','10309','HAProxy Backend {#PXNAME}: Time in queue','haproxy.backend.qtime[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Average time spent in queue (in ms) for the last 1,024 requests','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35854','18','','10309','HAProxy Backend {#PXNAME}: Unassigned requests','haproxy.backend.qcur[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Current number of requests unassigned in queue.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35855','18','','10309','HAProxy Backend {#PXNAME}: Number of responses with codes 4xx per second','haproxy.backend.hrsp_4xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP client errors per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35856','18','','10309','HAProxy Backend {#PXNAME}: Number of backup servers','haproxy.backend.bck[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of backup servers.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35857','18','','10309','HAProxy Backend {#PXNAME}: Number of responses with codes 3xx per second','haproxy.backend.hrsp_3xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP redirections per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35858','18','','10309','HAProxy Backend {#PXNAME}: Number of responses with codes 2xx per second','haproxy.backend.hrsp_2xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of successful HTTP responses per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35859','18','','10309','HAProxy Backend {#PXNAME}: Number of responses with codes 1xx per second','haproxy.backend.hrsp_1xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of informational HTTP responses per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35860','18','','10309','HAProxy Backend {#PXNAME}: Response errors per second','haproxy.backend.eresp.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of requests whose responses yielded an error','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35861','18','','10309','HAProxy Backend {#PXNAME}: Errors connection per second','haproxy.backend.econ.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of requests that encountered an error attempting to connect to a backend server.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35862','18','','10309','HAProxy Backend {#PXNAME}: Responses denied per second','haproxy.backend.dresp.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Responses denied due to security concerns (ACL-restricted).','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35863','18','','10309','HAProxy Backend {#PXNAME}: Outgoing traffic','haproxy.backend.bout.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bits sent by the backend','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35864','18','','10309','HAProxy Backend {#PXNAME}: Incoming traffic','haproxy.backend.bin.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bits received by the backend','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35865','18','','10309','HAProxy Backend {#PXNAME}: Retried connections per second','haproxy.backend.wretr.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of times a connection was retried.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35866','18','','10309','HAProxy Frontend {#PXNAME}: Incoming traffic','haproxy.frontend.bin.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bits received by the frontend','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35867','18','','10309','HAProxy Frontend {#PXNAME}: Outgoing traffic','haproxy.frontend.bout.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bits sent by the frontend','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35868','18','','10309','HAProxy Frontend {#PXNAME}: Denied requests per second','haproxy.frontend.dreq.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Requests denied due to security concerns (ACL-restricted) per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35869','18','','10309','HAProxy Frontend {#PXNAME}: Request errors per second','haproxy.frontend.ereq.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of request errors per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35870','18','','10309','HAProxy Frontend {#PXNAME}: Number of responses with codes 1xx per second','haproxy.frontend.hrsp_1xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of informational HTTP responses per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35871','18','','10309','HAProxy Frontend {#PXNAME}: Number of responses with codes 2xx per second','haproxy.frontend.hrsp_2xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of successful HTTP responses per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35872','18','','10309','HAProxy Frontend {#PXNAME}: Number of responses with codes 3xx per second','haproxy.frontend.hrsp_3xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP redirections per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35873','18','','10309','HAProxy Frontend {#PXNAME}: Number of responses with codes 4xx per second','haproxy.frontend.hrsp_4xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP client errors per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35874','18','','10309','HAProxy Frontend {#PXNAME}: Number of responses with codes 5xx per second','haproxy.frontend.hrsp_5xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP server errors per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35875','18','','10309','HAProxy Frontend {#PXNAME}: Sessions rate','haproxy.frontend.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of sessions created per second','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35876','18','','10309','HAProxy Frontend {#PXNAME}: Requests rate','haproxy.frontend.req_rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'HTTP requests per second','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35877','18','','10309','HAProxy Frontend {#PXNAME}: Established sessions','haproxy.frontend.scur[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The current number of established sessions.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35878','18','','10309','HAProxy Frontend {#PXNAME}: Session limits','haproxy.frontend.slim[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'The most simultaneous sessions that are allowed, as defined by the maxconn setting in the frontend.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35879','18','','10309','HAProxy Frontend {#PXNAME}: Status','haproxy.frontend.status[{#PXNAME},{#SVNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Possible values: OPEN, STOP.
When Status is OPEN, the frontend is operating normally and ready to receive traffic.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35880','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Server is active','haproxy.server.act[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,'243','','','0','','','','','2',NULL,'Shows whether the server is active (marked with a Y) or a backup (marked with a -).','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35881','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Number of responses with codes 5xx per second','haproxy.server.hrsp_5xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP server errors per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35882','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Redispatched requests per second','haproxy.server.wredis.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of times a request was redispatched to a different backend.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35883','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Weight','haproxy.server.weight[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Effective weight.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35884','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Sessions per second','haproxy.server.stot.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Cumulative number of sessions (end-to-end connections) per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35885','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Status','haproxy.server.status[{#PXNAME},{#SVNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35886','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Responses time','haproxy.server.rtime[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Average server response time (in ms) for the last 1,024 requests.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35887','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Time in queue','haproxy.server.qtime[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','s','','',NULL,NULL,'','','0','','','','','2',NULL,'Average time spent in queue (in ms) for the last 1,024 requests.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35888','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Configured maxqueue','haproxy.server.qlimit[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Configured maxqueue for the server, or nothing in the value is 0 (default, meaning no limit).','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35889','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Unassigned requests','haproxy.server.qcur[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Current number of requests unassigned in queue.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35890','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Server was selected per second','haproxy.server.lbtot.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of times that server was selected.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35891','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Number of responses with codes 4xx per second','haproxy.server.hrsp_4xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP client errors per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35892','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Server is backup','haproxy.server.bck[{#PXNAME},{#SVNAME}]','0','7d','365d','0','3','','','','',NULL,'243','','','0','','','','','2',NULL,'Shows whether the server is a backup (marked with a Y) or active (marked with a -).','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35893','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Number of responses with codes 3xx per second','haproxy.server.hrsp_3xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of HTTP redirections per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35894','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Number of responses with codes 2xx per second','haproxy.server.hrsp_2xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of successful HTTP responses per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35895','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Number of responses with codes 1xx per second','haproxy.server.hrsp_1xx.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of informational HTTP responses per second.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35896','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Response errors per second','haproxy.server.eresp.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of requests whose responses yielded an error.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35897','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Errors connection per second','haproxy.server.econ.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of requests that encountered an error attempting to connect to a backend server.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35898','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Responses denied per second','haproxy.server.dresp.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Responses denied due to security concerns (ACL-restricted).','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35899','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Status of last health check','haproxy.server.check_status[{#PXNAME},{#SVNAME}]','0','7d','0','0','1','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Status of last health check, one of:
UNK     -> unknown
INI     -> initializing
SOCKERR -> socket error
L4OK    -> check passed on layer 4, no upper layers testing enabled
L4TOUT  -> layer 1-4 timeout
L4CON   -> layer 1-4 connection problem, for example "Connection refused" (tcp rst) or "No route to host" (icmp)
L6OK    -> check passed on layer 6
L6TOUT  -> layer 6 (SSL) timeout
L6RSP   -> layer 6 invalid response - protocol error
L7OK    -> check passed on layer 7
L7OKC   -> check conditionally passed on layer 7, for example 404 with disable-on-404
L7TOUT  -> layer 7 (HTTP/SMTP) timeout
L7RSP   -> layer 7 invalid response - protocol error
L7STS   -> layer 7 response error, for example HTTP 5xx
Notice: If a check is currently running, the last known status will be reported, prefixed with "* ". e. g. "* L7OK".','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35900','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Outgoing traffic','haproxy.server.bout.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bits sent by the backend','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35901','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Incoming traffic','haproxy.server.bin.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of bits received by the backend','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('35902','18','','10309','HAProxy {#PXNAME} {#SVNAME}: Retried connections per second','haproxy.server.wretr.rate[{#PXNAME},{#SVNAME}]','0','7d','365d','0','0','','','','',NULL,NULL,'','','0','','','','','2',NULL,'Number of times a connection was retried.','0','30d','0','','30230','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36581','18','','10291','Network interfaces discovery','net.if.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of installed network interfaces.','0','30d','1','','36579','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36595','18','','10291','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed["{#IFGUID}"]','0','7d','0d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Estimated bandwidth of the network interface if any.','0','30d','0','','36579','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36596','18','','10291','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status["{#IFGUID}"]','0','7d','0','0','3','','','','',NULL,'81','','','0','','','','','2',NULL,'The operational status of the network interface.','0','30d','0','','36579','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36597','18','','10291','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type["{#IFGUID}"]','0','7d','0d','0','3','','','','',NULL,'79','','','0','','','','','2',NULL,'The type of the network interface.','0','30d','0','','36579','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36603','18','','10298','Network interfaces discovery','net.if.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery of installed network interfaces.','0','30d','1','','36601','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36617','18','','10298','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed["{#IFGUID}"]','0','7d','0d','0','3','','bps','','',NULL,NULL,'','','0','','','','','2',NULL,'Estimated bandwidth of the network interface if any.','0','30d','0','','36601','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36618','18','','10298','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status["{#IFGUID}"]','0','7d','0','0','3','','','','',NULL,'81','','','0','','','','','2',NULL,'The operational status of the network interface.','0','30d','0','','36601','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36619','18','','10298','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type["{#IFGUID}"]','0','7d','0d','0','3','','','','',NULL,'79','','','0','','','','','2',NULL,'The type of the network interface.','0','30d','0','','36601','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29427','18','','10285','CPU utilization','system.cpu.util[node_exporter]','0','7d','365d','0','0','','%','','',NULL,NULL,'','','0','','','','','0',NULL,'CPU utilization in %','0','30d','0','','29416','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29428','18','','10285','Operating system','system.sw.os[node_exporter]','0','2w','0','0','1','','','','',NULL,NULL,'','','0','','','','','0',NULL,'','5','30d','0','','29425','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30193','18','','10308','Backend discovery','haproxy.backend.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery backends','0','30d','1','','35785','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30194','18','','10308','Frontend discovery','haproxy.frontend.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery frontends','0','30d','1','','35785','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30195','18','','10308','Server discovery','haproxy.server.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery servers','0','30d','1','','35785','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30236','18','','10309','Backend discovery','haproxy.backend.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery backends','0','30d','1','','35844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30237','18','','10309','Frontend discovery','haproxy.frontend.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery frontends','0','30d','1','','35844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30238','18','','10309','Server discovery','haproxy.server.discovery','0','90d','0','0','4','','','','',NULL,NULL,'','','0','','','','','1',NULL,'Discovery servers','0','30d','1','','35844','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10020','0','','10001','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','','22232','10','','','0','','','','','0',NULL,'The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10059','0','','10001','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','','22231',NULL,'','','0','','','','','0',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10073','5','','10084','Zabbix server: Number of processed numeric (float) values per second','zabbix[wcache,values,float]','1m','1w','365d','0','0','','','','','10061',NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed float values.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10074','5','','10084','Zabbix server: Number of processed character values per second','zabbix[wcache,values,str]','1m','1w','365d','0','0','','','','','10062',NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed character/string values.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10075','5','','10084','Zabbix server: Number of processed log values per second','zabbix[wcache,values,log]','1m','1w','365d','0','0','','','','','10063',NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed log values.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10076','5','','10084','Zabbix server: Number of processed numeric (unsigned) values per second','zabbix[wcache,values,uint]','1m','1w','365d','0','0','','','','','10064',NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed numeric (unsigned) values.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10077','5','','10084','Zabbix server: Number of processed text values per second','zabbix[wcache,values,text]','1m','1w','365d','0','0','','','','','10065',NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of processed text values.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('10078','5','','10084','Zabbix server: Number of processed not supported values per second','zabbix[wcache,values,not supported]','1m','1w','365d','0','0','','','','','10066',NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Number of times item processing resulted in item becoming unsupported or keeping that state.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22833','0','','10074','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','','22232','10','','','0','','','','','0',NULL,'The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22834','0','','10074','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','','22231',NULL,'','','0','','','','','0',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22873','0','','10075','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','','22232','10','','','0','','','','','0',NULL,'The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22874','0','','10075','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','','22231',NULL,'','','0','','','','','0',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22913','0','','10076','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','','22232','10','','','0','','','','','0',NULL,'The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22914','0','','10076','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','','22231',NULL,'','','0','','','','','0',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22953','0','','10077','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','','22232','10','','','0','','','','','0',NULL,'The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22954','0','','10077','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','','22231',NULL,'','','0','','','','','0',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22993','0','','10078','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','','22232','10','','','0','','','','','0',NULL,'The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('22994','0','','10078','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','','22231',NULL,'','','0','','','','','0',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23033','0','','10079','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','','22232','10','','','0','','','','','0',NULL,'The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23034','0','','10079','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','','22231',NULL,'','','0','','','','','0',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23160','0','','10081','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','','22232','10','','','0','','','','','0',NULL,'The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23161','0','','10081','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','','22231',NULL,'','','0','','','','','0',NULL,'','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23252','5','','10084','Zabbix server: Utilization of alerter internal processes, in %','zabbix[process,alerter,avg,busy]','1m','1w','365d','0','0','','%','','','22424',NULL,'','','0','','','','','0',NULL,'Average percentage of time alerter processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23253','5','','10084','Zabbix server: Utilization of configuration syncer internal processes, in %','zabbix[process,configuration syncer,avg,busy]','1m','1w','365d','0','0','','%','','','22412',NULL,'','','0','','','','','0',NULL,'Average percentage of time configuration syncer processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23255','5','','10084','Zabbix server: Utilization of discoverer data collector processes, in %','zabbix[process,discoverer,avg,busy]','1m','1w','365d','0','0','','%','','','22430',NULL,'','','0','','','','','0',NULL,'Average percentage of time discoverer processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23256','5','','10084','Zabbix server: Utilization of escalator internal processes, in %','zabbix[process,escalator,avg,busy]','1m','1w','365d','0','0','','%','','','22422',NULL,'','','0','','','','','0',NULL,'Average percentage of time escalator processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23257','5','','10084','Zabbix server: Utilization of history syncer internal processes, in %','zabbix[process,history syncer,avg,busy]','1m','1w','365d','0','0','','%','','','22406',NULL,'','','0','','','','','0',NULL,'Average percentage of time history syncer processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23258','5','','10084','Zabbix server: Utilization of housekeeper internal processes, in %','zabbix[process,housekeeper,avg,busy]','1m','1w','365d','0','0','','%','','','22408',NULL,'','','0','','','','','0',NULL,'Average percentage of time housekeeper processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23259','5','','10084','Zabbix server: Utilization of http poller data collector processes, in %','zabbix[process,http poller,avg,busy]','1m','1w','365d','0','0','','%','','','22402',NULL,'','','0','','','','','0',NULL,'Average percentage of time http poller processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23260','5','','10084','Zabbix server: Utilization of icmp pinger data collector processes, in %','zabbix[process,icmp pinger,avg,busy]','1m','1w','365d','0','0','','%','','','22418',NULL,'','','0','','','','','0',NULL,'Average percentage of time icmp pinger processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23261','5','','10084','Zabbix server: Utilization of ipmi poller data collector processes, in %','zabbix[process,ipmi poller,avg,busy]','1m','1w','365d','0','0','','%','','','22416',NULL,'','','0','','','','','0',NULL,'Average percentage of time ipmi poller processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23262','5','','10084','Zabbix server: Utilization of java poller data collector processes, in %','zabbix[process,java poller,avg,busy]','1m','1w','365d','0','0','','%','','','22689',NULL,'','','0','','','','','0',NULL,'Average percentage of time java poller processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23264','5','','10084','Zabbix server: Utilization of poller data collector processes, in %','zabbix[process,poller,avg,busy]','1m','1w','365d','0','0','','%','','','22399',NULL,'','','0','','','','','0',NULL,'Average percentage of time poller processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23265','5','','10084','Zabbix server: Utilization of proxy poller data collector processes, in %','zabbix[process,proxy poller,avg,busy]','1m','1w','365d','0','0','','%','','','22420',NULL,'','','0','','','','','0',NULL,'Average percentage of time proxy poller processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23266','5','','10084','Zabbix server: Utilization of self-monitoring internal processes, in %','zabbix[process,self-monitoring,avg,busy]','1m','1w','365d','0','0','','%','','','22414',NULL,'','','0','','','','','0',NULL,'Average percentage of time self-monitoring processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23267','5','','10084','Zabbix server: Utilization of snmp trapper data collector processes, in %','zabbix[process,snmp trapper,avg,busy]','1m','1w','365d','0','0','','%','','','23171',NULL,'','','0','','','','','0',NULL,'Average percentage of time snmp trapper processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23268','5','','10084','Zabbix server: Utilization of timer internal processes, in %','zabbix[process,timer,avg,busy]','1m','1w','365d','0','0','','%','','','22426',NULL,'','','0','','','','','0',NULL,'Average percentage of time timer processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23269','5','','10084','Zabbix server: Utilization of trapper data collector processes, in %','zabbix[process,trapper,avg,busy]','1m','1w','365d','0','0','','%','','','22404',NULL,'','','0','','','','','0',NULL,'Average percentage of time trapper processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23270','5','','10084','Zabbix server: Utilization of unreachable poller data collector processes, in %','zabbix[process,unreachable poller,avg,busy]','1m','1w','365d','0','0','','%','','','22400',NULL,'','','0','','','','','0',NULL,'Average percentage of time unreachable poller processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23271','5','','10084','Zabbix server: Queue over 10 minutes','zabbix[queue,10m]','1m','1w','365d','0','3','','','','','22219',NULL,'','','0','','','','','0',NULL,'Number of monitored items in the queue which are delayed at least by 10 minutes','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23272','5','','10084','Zabbix server: Queue','zabbix[queue]','1m','1w','365d','0','3','','','','','23251',NULL,'','','0','','','','','0',NULL,'Number of monitored items in the queue which are delayed at least by 6 seconds','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23273','5','','10084','Zabbix server: Configuration cache, % used','zabbix[rcache,buffer,pused]','1m','1w','365d','0','0','','%','','','22189',NULL,'','','0','','','','','0',NULL,'Availability statistics of Zabbix configuration cache. Percentage of used buffer','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23274','5','','10084','Zabbix server: History write cache, % used','zabbix[wcache,history,pused]','1m','1w','365d','0','0','','%','','','22183',NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache. Percentage of used history buffer.
History cache is used to store item values. A high number indicates performance problems on the database side.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23275','5','','10084','Zabbix server: History index cache, % used','zabbix[wcache,index,pused]','1m','1w','365d','0','0','','%','','','22396',NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache. Percentage of used history index buffer.
History index cache is used to index values stored in history cache.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23276','5','','10084','Zabbix server: Trend write cache, % used','zabbix[wcache,trend,pused]','1m','1w','365d','0','0','','%','','','22185',NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache. Percentage of used trend buffer.
Trend cache stores aggregate for the current hour for all items that receive data.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23277','5','','10084','Zabbix server: Number of processed values per second','zabbix[wcache,values]','1m','1w','365d','0','0','','','','','22187',NULL,'','','0','','','','','0',NULL,'Statistics and availability of Zabbix write cache.
Total number of values processed by Zabbix server or Zabbix proxy, except unsupported items.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23319','0','','10001','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','','23318',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23320','0','','10074','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','','23318',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23321','0','','10075','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','','23318',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23322','0','','10076','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','','23318',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23323','0','','10077','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','','23318',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23324','0','','10078','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','','23318',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23325','0','','10079','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','','23318',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23326','0','','10081','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','','23318',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23328','5','','10084','Zabbix server: Utilization of vmware data collector processes, in %','zabbix[process,vmware collector,avg,busy]','1m','1w','365d','0','0','','%','','','22401',NULL,'','','0','','','','','0',NULL,'Average percentage of time vmware collector processes have been busy in the last minute','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23620','5','','10084','Zabbix server: Value cache, % used','zabbix[vcache,buffer,pused]','1m','1w','365d','0','0','','%','','','22191',NULL,'','','0','','','','','0',NULL,'Availability statistics of Zabbix value cache. Percentage of used buffer','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23625','5','','10084','Zabbix server: Value cache hits','zabbix[vcache,cache,hits]','1m','1w','365d','0','0','','vps','','','22196',NULL,'','','0','','','','','0',NULL,'Effectiveness statistics of Zabbix value cache. Number of cache hits (history values taken from the cache)','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23628','5','','10084','Zabbix server: Value cache misses','zabbix[vcache,cache,misses]','1m','1w','365d','0','0','','vps','','','22199',NULL,'','','0','','','','','0',NULL,'Effectiveness statistics of Zabbix value cache. Number of cache misses (history values taken from the database)','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23635','5','','10084','Zabbix server: VMware cache, % used','zabbix[vmware,buffer,pused]','1m','1w','365d','0','0','','%','','','23634',NULL,'','','0','','','','','0',NULL,'Availability statistics of Zabbix vmware cache. Percentage of used buffer','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23662','5','','10084','Zabbix server: Value cache operating mode','zabbix[vcache,cache,mode]','1m','1w','365d','0','3','','','','','23661','15','','','0','','','','','0',NULL,'Value cache operating mode','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23664','5','','10084','Zabbix server: Utilization of task manager internal processes, in %','zabbix[process,task manager,avg,busy]','1m','1w','365d','0','0','','%','','','23663',NULL,'','','0','','','','','0',NULL,'Average percentage of time task manager processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('25367','5','','10084','Zabbix server: Utilization of ipmi manager internal processes, in %','zabbix[process,ipmi manager,avg,busy]','1m','1w','365d','0','0','','%','','','25366',NULL,'','','0','','','','','0',NULL,'Average percentage of time ipmi manager processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('25371','5','','10084','Zabbix server: Utilization of alert manager internal processes, in %','zabbix[process,alert manager,avg,busy]','1m','1w','365d','0','0','','%','','','25370',NULL,'','','0','','','','','0',NULL,'Average percentage of time alert manager processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('25667','5','','10084','Zabbix server: Utilization of preprocessing manager internal processes, in %','zabbix[process,preprocessing manager,avg,busy]','1m','1w','365d','0','0','','%','','','25665',NULL,'','','0','','','','','0',NULL,'Average percentage of time preprocessing manager processes have been busy in the last minute','0','30','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('25668','5','','10084','Zabbix server: Utilization of preprocessing worker internal processes, in %','zabbix[process,preprocessing worker,avg,busy]','1m','1w','365d','0','0','','%','','','25666',NULL,'','','0','','','','','0',NULL,'Average percentage of time preprocessing worker processes have been busy in the last minute','0','30','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27149','3','','10204','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27067','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27150','3','','10204','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27066',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27151','3','','10204','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27065',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27180','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10207','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27181','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10207','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27182','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10207','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27183','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10207','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27184','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10207','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27185','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10207','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27186','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10207','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27187','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10207','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27188','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10207','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27189','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10207','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27190','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10207','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27191','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10207','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27195','17','','10207','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27199','20','1.3.6.1.2.1.1.5.0','10207','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27202','5','','10207','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27215','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10208','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27216','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10208','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27217','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10208','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27218','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10208','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27219','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10208','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27220','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10208','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27221','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10208','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27222','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10208','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27223','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10208','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27224','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10208','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27228','17','','10208','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27232','20','1.3.6.1.2.1.1.5.0','10208','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27235','5','','10208','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27251','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10210','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27252','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10210','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27253','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10210','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27254','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10210','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27255','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10210','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27256','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10210','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27257','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10210','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27258','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10210','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27259','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10210','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27260','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10210','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27264','17','','10210','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27268','20','1.3.6.1.2.1.1.5.0','10210','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27271','5','','10210','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27272','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10211','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27273','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10211','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27274','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10211','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27275','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10211','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27276','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10211','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27277','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10211','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27278','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10211','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27279','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10211','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27280','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10211','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27281','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10211','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27285','17','','10211','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27289','20','1.3.6.1.2.1.1.5.0','10211','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27292','5','','10211','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27299','20','1.3.6.1.4.1.1991.1.1.2.1.52.0','10210','CPU utilization','system.cpu.util[snAgGblCpuUtil1MinAvg.0]','1m','7d','365d','0','0','','%','','','27294',NULL,'','','0','','','','','0',NULL,'MIB: FOUNDRY-SN-AGENT-MIB
The statistics collection of 1 minute CPU utilization.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27301','20','1.3.6.1.4.1.1991.1.1.2.1.52.0','10211','CPU utilization','system.cpu.util[snAgGblCpuUtil1MinAvg.0]','1m','7d','365d','0','0','','%','','','27294',NULL,'','','0','','','','','0',NULL,'MIB: FOUNDRY-SN-AGENT-MIB
The statistics collection of 1 minute CPU utilization.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27321','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10218','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27322','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10218','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27323','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10218','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27324','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10218','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27325','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10218','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27326','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10218','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27327','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10218','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27328','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10218','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27329','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10218','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27330','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10218','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27331','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10218','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27332','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10218','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27336','17','','10218','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27340','20','1.3.6.1.2.1.1.5.0','10218','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27343','5','','10218','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27368','17','','10220','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27372','20','1.3.6.1.2.1.1.5.0','10220','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27375','5','','10220','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27380','20','1.3.6.1.4.1.9.2.1.58','10220','CPU utilization','system.cpu.util[avgBusy5]','5m','7d','365d','0','0','','%','','','27376',NULL,'','','0','','','','','0',NULL,'MIB: OLD-CISCO-CPU-MIB
5 minute exponentially-decayed moving average of the CPU busy percentage.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15215-collect-cpu-util-snmp.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27382','20','1.3.6.1.2.1.47.1.1.1.1.11.1','10220','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','','27378',NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27383','20','1.3.6.1.2.1.47.1.1.1.1.13.1','10220','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','','27379',NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27385','20','1.3.6.1.2.1.47.1.1.1.1.11.1','10218','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','','27378',NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27386','20','1.3.6.1.2.1.47.1.1.1.1.13.1','10218','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','','27379',NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27397','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.48.1.1.1.2]','10218','Memory Discovery','memory.discovery','1h','90d','0','0','4','','','','','27390',NULL,'','','0','','','','','1',NULL,'Discovery of ciscoMemoryPoolTable, a table of memory pool monitoring entries.
http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27398','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.109.1.1.1.1.5]','10218','CPU Discovery','cpu.discovery','1h','90d','0','0','4','','','','','27391',NULL,'','','0','','','','','1',NULL,'If your IOS device has several CPUs, you must use CISCO-PROCESS-MIB and its object cpmCPUTotal5minRev from the table called cpmCPUTotalTable ,
indexed with cpmCPUTotalIndex .
This table allows CISCO-PROCESS-MIB to keep CPU statistics for different physical entities in the router,
like different CPU chips, group of CPUs, or CPUs in different modules/cards.
In case of a single CPU, cpmCPUTotalTable has only one entry.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27399','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7,{#ENT_SN},1.3.6.1.2.1.47.1.1.1.1.11]','10218','Entity Serial Numbers Discovery','entity_sn.discovery','1h','90d','0','0','4','','','','','27393',NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27400','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.3.1.2]','10218','Temperature Discovery','temperature.discovery','1h','90d','0','0','4','','','','','27394',NULL,'','','0','','','','','1',NULL,'Discovery of ciscoEnvMonTemperatureTable (ciscoEnvMonTemperatureDescr), a table of ambient temperature status
maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27401','20','discovery[{#SENSOR_INFO},1.3.6.1.4.1.9.9.13.1.5.1.2]','10218','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','','27395',NULL,'','','0','','','','','1',NULL,'The table of power supply status maintained by the environmental monitor card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27402','20','discovery[{#SENSOR_INFO},1.3.6.1.4.1.9.9.13.1.4.1.2]','10218','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','','27396',NULL,'','','0','','','','','1',NULL,'The table of fan status maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27409','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.48.1.1.1.2]','10220','Memory Discovery','memory.discovery','1h','90d','0','0','4','','','','','27390',NULL,'','','0','','','','','1',NULL,'Discovery of ciscoMemoryPoolTable, a table of memory pool monitoring entries.
http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27410','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7,{#ENT_SN},1.3.6.1.2.1.47.1.1.1.1.11]','10220','Entity Serial Numbers Discovery','entity_sn.discovery','1h','90d','0','0','4','','','','','27393',NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27411','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.3.1.2]','10220','Temperature Discovery','temperature.discovery','1h','90d','0','0','4','','','','','27394',NULL,'','','0','','','','','1',NULL,'Discovery of ciscoEnvMonTemperatureTable (ciscoEnvMonTemperatureDescr), a table of ambient temperature status
maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27412','20','discovery[{#SENSOR_INFO},1.3.6.1.4.1.9.9.13.1.5.1.2]','10220','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','','27395',NULL,'','','0','','','','','1',NULL,'The table of power supply status maintained by the environmental monitor card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27413','20','discovery[{#SENSOR_INFO},1.3.6.1.4.1.9.9.13.1.4.1.2]','10220','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','','27396',NULL,'','','0','','','','','1',NULL,'The table of fan status maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27425','20','1.3.6.1.4.1.9.9.48.1.1.1.6.{#SNMPINDEX}','10218','{#SNMPVALUE}: Free memory','vm.memory.free[ciscoMemoryPoolFree.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','27415',NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Indicates the number of bytes from the memory pool that are currently unused on the managed device. Note that the sum of ciscoMemoryPoolUsed and ciscoMemoryPoolFree is the total amount of memory in the pool
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27426','20','1.3.6.1.4.1.9.9.48.1.1.1.5.{#SNMPINDEX}','10218','{#SNMPVALUE}: Used memory','vm.memory.used[ciscoMemoryPoolUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','27416',NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Indicates the number of bytes from the memory pool that are currently in use by applications on the managed device.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27427','20','1.3.6.1.4.1.9.9.109.1.1.1.1.8.{#SNMPINDEX}','10218','#{#SNMPINDEX}: CPU utilization','system.cpu.util[cpmCPUTotal5minRev.{#SNMPINDEX}]','5m','7d','365d','0','0','','%','','','27417',NULL,'','','0','','','','','2',NULL,'MIB: CISCO-PROCESS-MIB
The cpmCPUTotal5minRev MIB object provides a more accurate view of the performance of the router over time than the MIB objects cpmCPUTotal1minRev and cpmCPUTotal5secRev . These MIB objects are not accurate because they look at CPU at one minute and five second intervals, respectively. These MIBs enable you to monitor the trends and plan the capacity of your network. The recommended baseline rising threshold for cpmCPUTotal5minRev is 90 percent. Depending on the platform, some routers that run at 90 percent, for example, 2500s, can exhibit performance degradation versus a high-end router, for example, the 7500 series, which can operate fine.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15215-collect-cpu-util-snmp.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27428','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10218','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[entPhysicalSerialNum.{#SNMPINDEX}]','1h','2w','0','0','1','','','','','27419',NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27429','20','1.3.6.1.4.1.9.9.13.1.3.1.6.{#SNMPINDEX}','10218','{#SNMPVALUE}: Temperature status','sensor.temp.status[ciscoEnvMonTemperatureState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','','27420','28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
The current state of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27430','20','1.3.6.1.4.1.9.9.13.1.3.1.3.{#SNMPINDEX}','10218','{#SNMPVALUE}: Temperature','sensor.temp.value[ciscoEnvMonTemperatureValue.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','','27421',NULL,'','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
The current measurement of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27431','20','1.3.6.1.4.1.9.9.13.1.5.1.3.{#SNMPINDEX}','10218','{#SENSOR_INFO}: Power supply status','sensor.psu.status[ciscoEnvMonSupplyState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','','27422','28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27432','20','1.3.6.1.4.1.9.9.13.1.4.1.3.{#SNMPINDEX}','10218','{#SENSOR_INFO}: Fan status','sensor.fan.status[ciscoEnvMonFanState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','','27423','28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27443','20','1.3.6.1.4.1.9.9.48.1.1.1.6.{#SNMPINDEX}','10220','{#SNMPVALUE}: Free memory','vm.memory.free[ciscoMemoryPoolFree.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','27415',NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Indicates the number of bytes from the memory pool that are currently unused on the managed device. Note that the sum of ciscoMemoryPoolUsed and ciscoMemoryPoolFree is the total amount of memory in the pool
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27444','20','1.3.6.1.4.1.9.9.48.1.1.1.5.{#SNMPINDEX}','10220','{#SNMPVALUE}: Used memory','vm.memory.used[ciscoMemoryPoolUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','27416',NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Indicates the number of bytes from the memory pool that are currently in use by applications on the managed device.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27445','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10220','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[entPhysicalSerialNum.{#SNMPINDEX}]','1h','2w','0','0','1','','','','','27419',NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27446','20','1.3.6.1.4.1.9.9.13.1.3.1.6.{#SNMPINDEX}','10220','{#SNMPVALUE}: Temperature status','sensor.temp.status[ciscoEnvMonTemperatureState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','','27420','28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
The current state of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27447','20','1.3.6.1.4.1.9.9.13.1.3.1.3.{#SNMPINDEX}','10220','{#SNMPVALUE}: Temperature','sensor.temp.value[ciscoEnvMonTemperatureValue.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','','27421',NULL,'','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
The current measurement of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27448','20','1.3.6.1.4.1.9.9.13.1.5.1.3.{#SNMPINDEX}','10220','{#SENSOR_INFO}: Power supply status','sensor.psu.status[ciscoEnvMonSupplyState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','','27422','28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27449','20','1.3.6.1.4.1.9.9.13.1.4.1.3.{#SNMPINDEX}','10220','{#SENSOR_INFO}: Fan status','sensor.fan.status[ciscoEnvMonFanState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','','27423','28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27450','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10221','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27451','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10221','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27452','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10221','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27453','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10221','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27454','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10221','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27455','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10221','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27456','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10221','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27457','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10221','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27458','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10221','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27459','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10221','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27460','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10221','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27461','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10221','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27465','17','','10221','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27469','20','1.3.6.1.2.1.1.5.0','10221','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27472','5','','10221','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27486','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10222','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27487','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10222','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27488','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10222','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27489','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10222','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27490','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10222','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27491','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10222','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27492','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10222','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27493','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10222','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27494','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10222','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27495','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10222','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27499','17','','10222','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27503','20','1.3.6.1.2.1.1.5.0','10222','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27506','5','','10222','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27520','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10223','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27521','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10223','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27522','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10223','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27523','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10223','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27524','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10223','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27525','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10223','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27526','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10223','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27527','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10223','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27528','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10223','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27529','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10223','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27530','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10223','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27531','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10223','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27535','17','','10223','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27539','20','1.3.6.1.2.1.1.5.0','10223','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27542','5','','10223','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27556','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10224','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27557','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10224','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27558','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10224','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27559','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10224','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27560','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10224','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27561','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10224','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27562','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10224','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27563','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10224','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27564','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10224','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27565','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10224','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27566','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10224','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27567','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10224','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27571','17','','10224','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27575','20','1.3.6.1.2.1.1.5.0','10224','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27578','5','','10224','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27619','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFNAME},1.3.6.1.2.1.2.2.1.2,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10226','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27078',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27620','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10226','Interface {#IFDESCR}: Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27079',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27621','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10226','Interface {#IFDESCR}: Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27086',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27622','20','1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10226','Interface {#IFDESCR}: Bits received','net.if.in[ifInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27084',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,including framing characters. Discontinuities in the value of this counter can occurat re-initialization of the management system, and atother times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27623','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10226','Interface {#IFDESCR}: Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27082',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27624','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10226','Interface {#IFDESCR}: Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27083',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27625','20','1.3.6.1.2.1.2.2.1.16.{#SNMPINDEX}','10226','Interface {#IFDESCR}: Bits sent','net.if.out[ifOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27085',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. Discontinuities in the value of this counter can occurat re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27626','20','1.3.6.1.2.1.2.2.1.5.{#SNMPINDEX}','10226','Interface {#IFDESCR}: Speed','net.if.speed[ifSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27081',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second.
For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made,
this object should contain the nominal bandwidth.
If the bandwidth of the interface is greater than the maximum value reportable by this object then
this object should report its maximum value (4,294,967,295) and ifHighSpeed must be used to report the interace''s speed.
For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27627','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10226','Interface {#IFDESCR}: Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27087','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27628','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10226','Interface {#IFDESCR}: Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27080','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27629','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10226','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27630','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10226','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27634','17','','10226','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27638','20','1.3.6.1.2.1.1.5.0','10226','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27641','5','','10226','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27642','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10227','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27643','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10227','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27644','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10227','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27645','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10227','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27646','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10227','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27647','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10227','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27648','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10227','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27649','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10227','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27650','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10227','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27651','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10227','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27652','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10227','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27653','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10227','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27657','17','','10227','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27661','20','1.3.6.1.2.1.1.5.0','10227','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27664','5','','10227','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27722','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10229','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27723','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10229','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27724','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10229','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27725','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10229','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27726','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10229','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27727','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10229','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27728','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10229','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27729','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10229','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27730','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10229','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27731','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10229','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27732','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10229','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27733','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10229','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27737','17','','10229','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27741','20','1.3.6.1.2.1.1.5.0','10229','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27744','5','','10229','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27756','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10230','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27757','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10230','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27758','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10230','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27759','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10230','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27760','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10230','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27761','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10230','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27762','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10230','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27763','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10230','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27764','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10230','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27765','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10230','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27769','17','','10230','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27773','20','1.3.6.1.2.1.1.5.0','10230','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27776','5','','10230','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27788','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10231','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27789','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10231','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27790','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10231','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27791','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10231','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27792','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10231','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27793','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10231','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27794','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10231','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27795','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10231','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27796','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10231','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27797','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10231','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27798','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10231','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27799','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10231','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27803','17','','10231','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27807','20','1.3.6.1.2.1.1.5.0','10231','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27810','5','','10231','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27872','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10233','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27873','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27874','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27875','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27876','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27877','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27878','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27879','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27880','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27881','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10233','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27885','17','','10233','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27889','20','1.3.6.1.2.1.1.5.0','10233','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27892','5','','10233','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27909','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10234','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27910','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10234','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27911','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10234','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27912','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10234','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27913','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10234','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27914','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10234','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27915','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10234','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27916','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10234','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27917','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10234','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27918','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10234','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27922','17','','10234','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27926','20','1.3.6.1.2.1.1.5.0','10234','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27929','5','','10234','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27944','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10235','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27945','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10235','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27946','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10235','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27947','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10235','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27948','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10235','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27949','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10235','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27950','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10235','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27951','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10235','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27952','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10235','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27953','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10235','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27954','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10235','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27955','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10235','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27959','17','','10235','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27963','20','1.3.6.1.2.1.1.5.0','10235','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27966','5','','10235','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27976','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFNAME},1.3.6.1.2.1.2.2.1.2,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10236','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27078',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27977','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10236','Interface {#IFDESCR}: Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27079',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27978','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10236','Interface {#IFDESCR}: Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27086',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27979','20','1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10236','Interface {#IFDESCR}: Bits received','net.if.in[ifInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27084',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,including framing characters. Discontinuities in the value of this counter can occurat re-initialization of the management system, and atother times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27980','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10236','Interface {#IFDESCR}: Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27082',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27981','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10236','Interface {#IFDESCR}: Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27083',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27982','20','1.3.6.1.2.1.2.2.1.16.{#SNMPINDEX}','10236','Interface {#IFDESCR}: Bits sent','net.if.out[ifOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27085',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. Discontinuities in the value of this counter can occurat re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27983','20','1.3.6.1.2.1.2.2.1.5.{#SNMPINDEX}','10236','Interface {#IFDESCR}: Speed','net.if.speed[ifSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27081',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second.
For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made,
this object should contain the nominal bandwidth.
If the bandwidth of the interface is greater than the maximum value reportable by this object then
this object should report its maximum value (4,294,967,295) and ifHighSpeed must be used to report the interace''s speed.
For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27984','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10236','Interface {#IFDESCR}: Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27087','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27985','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10236','Interface {#IFDESCR}: Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27080','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27989','17','','10236','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27993','20','1.3.6.1.2.1.1.5.0','10236','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27996','5','','10236','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28005','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFNAME},1.3.6.1.2.1.2.2.1.2,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10237','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27078',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28006','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10237','Interface {#IFDESCR}: Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27079',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28007','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10237','Interface {#IFDESCR}: Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27086',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28008','20','1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10237','Interface {#IFDESCR}: Bits received','net.if.in[ifInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27084',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,including framing characters. Discontinuities in the value of this counter can occurat re-initialization of the management system, and atother times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28009','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10237','Interface {#IFDESCR}: Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27082',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28010','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10237','Interface {#IFDESCR}: Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27083',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28011','20','1.3.6.1.2.1.2.2.1.16.{#SNMPINDEX}','10237','Interface {#IFDESCR}: Bits sent','net.if.out[ifOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27085',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. Discontinuities in the value of this counter can occurat re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28012','20','1.3.6.1.2.1.2.2.1.5.{#SNMPINDEX}','10237','Interface {#IFDESCR}: Speed','net.if.speed[ifSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27081',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in bits per second.
For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made,
this object should contain the nominal bandwidth.
If the bandwidth of the interface is greater than the maximum value reportable by this object then
this object should report its maximum value (4,294,967,295) and ifHighSpeed must be used to report the interace''s speed.
For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28013','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10237','Interface {#IFDESCR}: Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27087','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28014','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10237','Interface {#IFDESCR}: Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27080','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28018','17','','10237','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28022','20','1.3.6.1.2.1.1.5.0','10237','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28025','5','','10237','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28118','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10250','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28119','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10250','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28120','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10250','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28121','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10250','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28122','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10250','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28123','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10250','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28124','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10250','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28125','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10250','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28126','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10250','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28127','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10250','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28128','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10250','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28129','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10250','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28133','17','','10250','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28137','20','1.3.6.1.2.1.1.5.0','10250','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28140','5','','10250','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28207','20','discovery[{#ENT_CLASS},1.3.6.1.2.1.47.1.1.1.1.5,{#ENT_NAME},1.3.6.1.2.1.47.1.1.1.1.7,{#ENT_SN},1.3.6.1.2.1.47.1.1.1.1.11]','10253','Entity Serial Numbers Discovery','entity_sn.discovery','1h','90d','0','0','4','','','','','27393',NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28208','20','1.3.6.1.2.1.47.1.1.1.1.11.{#SNMPINDEX}','10253','{#ENT_NAME}: Hardware serial number','system.hw.serialnumber[entPhysicalSerialNum.{#SNMPINDEX}]','1h','2w','0','0','1','','','','','27419',NULL,'','','0','','','','','2',NULL,'MIB: ENTITY-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28209','20','1.3.6.1.2.1.47.1.1.1.1.13.1','10253','Hardware model name','system.hw.model','1h','2w','0','0','1','','','','','27379',NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','29','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28210','20','1.3.6.1.2.1.47.1.1.1.1.11.1','10253','Hardware serial number','system.hw.serialnumber','1h','2w','0','0','1','','','','','27378',NULL,'','','0','','','','','0',NULL,'MIB: ENTITY-MIB','8','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28212','20','discovery[{#SENSOR_INFO},1.3.6.1.4.1.9.9.13.1.4.1.2]','10253','FAN Discovery','fan.discovery','1h','90d','0','0','4','','','','','27396',NULL,'','','0','','','','','1',NULL,'The table of fan status maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28213','20','discovery[{#SENSOR_INFO},1.3.6.1.4.1.9.9.13.1.5.1.2]','10253','PSU Discovery','psu.discovery','1h','90d','0','0','4','','','','','27395',NULL,'','','0','','','','','1',NULL,'The table of power supply status maintained by the environmental monitor card.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28214','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.13.1.3.1.2]','10253','Temperature Discovery','temperature.discovery','1h','90d','0','0','4','','','','','27394',NULL,'','','0','','','','','1',NULL,'Discovery of ciscoEnvMonTemperatureTable (ciscoEnvMonTemperatureDescr), a table of ambient temperature status
maintained by the environmental monitor.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28215','20','1.3.6.1.4.1.9.9.13.1.4.1.3.{#SNMPINDEX}','10253','{#SENSOR_INFO}: Fan status','sensor.fan.status[ciscoEnvMonFanState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','','27423','28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28216','20','1.3.6.1.4.1.9.9.13.1.5.1.3.{#SNMPINDEX}','10253','{#SENSOR_INFO}: Power supply status','sensor.psu.status[ciscoEnvMonSupplyState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','','27422','28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28217','20','1.3.6.1.4.1.9.9.13.1.3.1.6.{#SNMPINDEX}','10253','{#SNMPVALUE}: Temperature status','sensor.temp.status[ciscoEnvMonTemperatureState.{#SNMPINDEX}]','3m','2w','0d','0','3','','','','','27420','28','','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
The current state of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28218','20','1.3.6.1.4.1.9.9.13.1.3.1.3.{#SNMPINDEX}','10253','{#SNMPVALUE}: Temperature','sensor.temp.value[ciscoEnvMonTemperatureValue.{#SNMPINDEX}]','3m','90d','365d','0','0','','°C','','','27421',NULL,'','','0','','','','','2',NULL,'MIB: CISCO-ENVMON-MIB
The current measurement of the test point being instrumented.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28219','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.48.1.1.1.2]','10253','Memory Discovery','memory.discovery','1h','90d','0','0','4','','','','','27390',NULL,'','','0','','','','','1',NULL,'Discovery of ciscoMemoryPoolTable, a table of memory pool monitoring entries.
http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28220','20','1.3.6.1.4.1.9.9.48.1.1.1.6.{#SNMPINDEX}','10253','{#SNMPVALUE}: Free memory','vm.memory.free[ciscoMemoryPoolFree.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','27415',NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Indicates the number of bytes from the memory pool that are currently unused on the managed device. Note that the sum of ciscoMemoryPoolUsed and ciscoMemoryPoolFree is the total amount of memory in the pool
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28222','20','1.3.6.1.4.1.9.9.48.1.1.1.5.{#SNMPINDEX}','10253','{#SNMPVALUE}: Used memory','vm.memory.used[ciscoMemoryPoolUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','27416',NULL,'','','0','','','','','2',NULL,'MIB: CISCO-MEMORY-POOL-MIB
Indicates the number of bytes from the memory pool that are currently in use by applications on the managed device.
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15216-contiguous-memory.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28223','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10253','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28224','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10253','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28225','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10253','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28226','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10253','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28227','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10253','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28228','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10253','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28229','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10253','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28230','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10253','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28231','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10253','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28232','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10253','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28236','17','','10253','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28240','20','1.3.6.1.2.1.1.5.0','10253','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28243','5','','10253','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28245','20','discovery[{#SNMPVALUE},1.3.6.1.4.1.9.9.109.1.1.1.1.5]','10253','CPU Discovery','cpu.discovery','1h','90d','0','0','4','','','','','28244',NULL,'','','0','','','','','1',NULL,'If your IOS device has several CPUs, you must use CISCO-PROCESS-MIB and its object cpmCPUTotal5minRev from the table called cpmCPUTotalTable ,
indexed with cpmCPUTotalIndex .
This table allows CISCO-PROCESS-MIB to keep CPU statistics for different physical entities in the router,
like different CPU chips, group of CPUs, or CPUs in different modules/cards.
In case of a single CPU, cpmCPUTotalTable has only one entry.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28247','20','1.3.6.1.4.1.9.9.109.1.1.1.1.5.{#SNMPINDEX}','10253','{#SNMPVALUE}: CPU utilization','system.cpu.util[cpmCPUTotal5min.{#SNMPINDEX}]','5m','7d','365d','0','0','','%','','','28246',NULL,'','','0','','','','','2',NULL,'MIB: CISCO-PROCESS-MIB
The overall CPU busy percentage in the last 5 minute
period. This object deprecates the avgBusy5 object from
the OLD-CISCO-SYSTEM-MIB. This object is deprecated
by cpmCPUTotal5minRev which has the changed range
of value (0..100)
Reference: http://www.cisco.com/c/en/us/support/docs/ip/simple-network-management-protocol-snmp/15215-collect-cpu-util-snmp.html','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28249','5','','10084','Zabbix server: Preprocessing queue','zabbix[preprocessing_queue]','1m','1w','365d','0','3','','','','','28248',NULL,'','','0','','','','','0',NULL,'Count of values enqueued in the preprocessing queue.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28280','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10254','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28281','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10254','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28285','17','','10254','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28289','20','1.3.6.1.2.1.1.5.0','10254','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28292','5','','10254','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28293','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10254','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28294','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10254','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28295','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10254','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28296','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10254','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28297','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10254','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28298','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10254','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28299','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10254','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28300','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10254','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28301','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10254','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28302','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10254','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28333','17','','10255','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28337','20','1.3.6.1.2.1.1.5.0','10255','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28340','5','','10255','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28380','17','','10256','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28384','20','1.3.6.1.2.1.1.5.0','10256','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28387','5','','10256','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28457','17','','10258','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28461','20','1.3.6.1.2.1.1.5.0','10258','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28464','5','','10258','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28485','17','','10259','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28489','20','1.3.6.1.2.1.1.5.0','10259','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28492','5','','10259','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28534','5','','10084','Zabbix server: LLD queue','zabbix[lld_queue]','1m','1w','365d','0','3','','','','','28533',NULL,'','','0','','','','','0',NULL,'Count of values enqueued in the low-level discovery processing queue.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28536','5','','10084','Zabbix server: Utilization of LLD manager internal processes, in %','zabbix[process,lld manager,avg,busy]','1m','1w','365d','0','0','','%','','','28535',NULL,'','','0','','','','','0',NULL,'Average percentage of time lld manager processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28538','5','','10084','Zabbix server: Utilization of LLD worker internal processes, in %','zabbix[process,lld worker,avg,busy]','1m','1w','365d','0','0','','%','','','28537',NULL,'','','0','','','','','0',NULL,'Average percentage of time lld worker processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28955','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.10.7.2.1.19,{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2]','10248','EtherLike-MIB Discovery','net.if.duplex.discovery','1h','90d','0','0','4','','','','','27031',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB and EtherLike-MIB. Interfaces with up(1) Operational Status are discovered.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28956','20','1.3.6.1.2.1.10.7.2.1.19.{#SNMPINDEX}','10248','Interface {#IFNAME}({#IFALIAS}): Duplex status','net.if.duplex[dot3StatsDuplexStatus.{#SNMPINDEX}]','1m','7d','365d','0','3','','','','','27032','19','','','0','','','','','2',NULL,'MIB: EtherLike-MIB
The current mode of operation of the MAC
entity.  ''unknown'' indicates that the current
duplex mode could not be determined.

Management control of the duplex mode is
accomplished through the MAU MIB.  When
an interface does not support autonegotiation,
or when autonegotiation is not enabled, the
duplex mode is controlled using
ifMauDefaultType.  When autonegotiation is
supported and enabled, duplex mode is controlled
using ifMauAutoNegAdvertisedBits.  In either
case, the currently operating duplex mode is
reflected both in this object and in ifMauType.

Note that this object provides redundant
information with ifMauType.  Normally, redundant
objects are discouraged.  However, in this
instance, it allows a management application to
determine the duplex status of an interface
without having to know every possible value of
ifMauType.  This was felt to be sufficiently
valuable to justify the redundancy.
Reference: [IEEE 802.3 Std.], 30.3.1.1.32,aDuplexStatus.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28960','17','','10248','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28964','20','1.3.6.1.2.1.1.5.0','10248','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28967','5','','10248','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28968','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10248','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27098',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28969','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10248','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27099',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28970','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10248','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27106',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28971','20','1.3.6.1.2.1.31.1.1.1.6.{#SNMPINDEX}','10248','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifHCInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27104',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface, including framing characters. This object is a 64-bit version of ifInOctets. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28972','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10248','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27102',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28973','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10248','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27103',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28974','20','1.3.6.1.2.1.31.1.1.1.10.{#SNMPINDEX}','10248','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifHCOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27105',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. This object is a 64-bit version of ifOutOctets.Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28975','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10248','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27101',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28976','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10248','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27107','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28977','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10248','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27100','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28993','15','','10248','Memory utilization','vm.memory.util[snmp]','1m','7d','365d','0','0','','%','','','28978',NULL,'(last("vm.memory.total[memTotalReal.0]")-(last("vm.memory.free[memAvailReal.0]")+last("vm.memory.buffers[memBuffer.0]")+last("vm.memory.cached[memCached.0]")))/last("vm.memory.total[memTotalReal.0]")*100','','0','','','','','0',NULL,'Please note that memory utilization is a rough estimate, since memory available is calculated as free+buffers+cached, which is not 100% accurate, but the best we can get using SNMP.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28994','20','1.3.6.1.4.1.2021.4.6.0','10248','Free memory','vm.memory.free[memAvailReal.0]','1m','7d','365d','0','3','','B','','','28979',NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28995','20','1.3.6.1.4.1.2021.4.14.0','10248','Memory (buffers)','vm.memory.buffers[memBuffer.0]','1m','7d','365d','0','3','','B','','','28980',NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB
Memory used by kernel buffers (Buffers in /proc/meminfo)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28996','20','1.3.6.1.4.1.2021.4.15.0','10248','Memory (cached)','vm.memory.cached[memCached.0]','1m','7d','365d','0','3','','B','','','28981',NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB
Memory used by the page cache and slabs (Cached and Slab in /proc/meminfo)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28997','20','1.3.6.1.4.1.2021.4.5.0','10248','Total memory','vm.memory.total[memTotalReal.0]','1m','7d','365d','0','3','','B','','','28982',NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB
Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28998','15','','10248','Available memory','vm.memory.available[snmp]','1m','7d','365d','0','3','','B','','','28983',NULL,'last("vm.memory.free[memAvailReal.0]")+last("vm.memory.buffers[memBuffer.0]")+last("vm.memory.cached[memCached.0]")','','0','','','','','0',NULL,'Please note that memory utilization is a rough estimate, since memory available is calculated as free+buffers+cached, which is not 100% accurate, but the best we can get using SNMP.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28999','20','1.3.6.1.4.1.2021.4.3.0','10248','Total swap space','system.swap.total[memTotalSwap.0]','1m','7d','365d','0','3','','B','','','28984',NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB
The total amount of swap space configured for this host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29000','20','1.3.6.1.4.1.2021.4.4.0','10248','Free swap space','system.swap.free[memAvailSwap.0]','1m','7d','365d','0','3','','B','','','28985',NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB
The amount of swap space currently unused or available.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29001','15','','10248','Free swap space in %','system.swap.pfree[snmp]','1m','7d','365d','0','0','','%','','','28986',NULL,'last("system.swap.free[memAvailSwap.0]")/last("system.swap.total[memTotalSwap.0]")*100','','0','','','','','0',NULL,'The free space of swap volume/file in percent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29002','20','1.3.6.1.4.1.2021.10.1.3["index","1.3.6.1.4.1.2021.10.1.2", "Load-1"]','10248','Load average (1m avg)','system.cpu.load.avg1[laLoad.1]','1m','7d','365d','0','0','','','','','28987',NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29003','20','1.3.6.1.4.1.2021.10.1.3["index","1.3.6.1.4.1.2021.10.1.2", "Load-5"]','10248','Load average (5m avg)','system.cpu.load.avg5[laLoad.2]','1m','7d','365d','0','0','','','','','28988',NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29004','20','1.3.6.1.4.1.2021.10.1.3["index","1.3.6.1.4.1.2021.10.1.2", "Load-15"]','10248','Load average (15m avg)','system.cpu.load.avg15[laLoad.3]','1m','7d','365d','0','0','','','','','28989',NULL,'','','0','','','','','0',NULL,'MIB: UCD-SNMP-MIB','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29005','20','discovery[{#SNMPVALUE},1.3.6.1.2.1.25.3.3.1.1]','10248','Number of CPUs','system.cpu.num[snmp]','1m','7d','365d','0','3','','','','','28990',NULL,'','','0','','','','','0',NULL,'MIB: HOST-RESOURCES-MIB
Count the number of CPU cores by counting number of cores discovered in hrProcessorTable using LLD','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29006','20','1.3.6.1.4.1.2021.11.59.0','10248','Interrupts per second','system.cpu.intr[ssRawInterrupts.0]','1m','7d','365d','0','0','','','','','28991',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29007','20','1.3.6.1.4.1.2021.11.60.0','10248','Context switches per second','system.cpu.switches[ssRawContexts.0]','1m','7d','365d','0','0','','','','','28992',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29011','20','discovery[{#DEVNAME},1.3.6.1.4.1.2021.13.15.1.1.2]','10248','Block devices discovery','vfs.dev.discovery[snmp]','1h','90d','0','0','4','','','','','29008',NULL,'','','0','','','','','1',NULL,'Block devices are discovered from UCD-DISKIO-MIB::diskIOTable (http://net-snmp.sourceforge.net/docs/mibs/ucdDiskIOMIB.html#diskIOTable)','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29013','20','discovery[{#FSNAME},1.3.6.1.2.1.25.2.3.1.3,{#FSTYPE},1.3.6.1.2.1.25.2.3.1.2,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4]','10248','Mounted filesystem discovery','vfs.fs.discovery[snmp]','1h','90d','0','0','4','','','','','29010',NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with storage filter','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29031','20','1.3.6.1.4.1.2021.13.15.1.1.5.{#SNMPINDEX}','10248','{#DEVNAME}: Disk read rate','vfs.dev.read.rate[diskIOReads.{#SNMPINDEX}]','1m','7d','365d','0','0','','!r/s','','','29014',NULL,'','','0','','','','','2',NULL,'MIB: UCD-DISKIO-MIB
The number of read accesses from this device since boot.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29032','20','1.3.6.1.4.1.2021.13.15.1.1.6.{#SNMPINDEX}','10248','{#DEVNAME}: Disk write rate','vfs.dev.write.rate[diskIOWrites.{#SNMPINDEX}]','1m','7d','365d','0','0','','!w/s','','','29015',NULL,'','','0','','','','','2',NULL,'MIB: UCD-DISKIO-MIB
The number of write accesses from this device since boot.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29033','20','1.3.6.1.4.1.2021.13.15.1.1.9.{#SNMPINDEX}','10248','{#DEVNAME}: Disk utilization','vfs.dev.util[diskIOLA1.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29016',NULL,'','','0','','','','','2',NULL,'MIB: UCD-DISKIO-MIB
The 1 minute average load of disk (%)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29034','20','1.3.6.1.4.1.2021.11.53.0','10248','CPU idle time','system.cpu.idle[ssCpuRawIdle.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29017',NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The time the CPU has spent doing nothing.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29035','20','1.3.6.1.4.1.2021.11.52.0','10248','CPU system time','system.cpu.system[ssCpuRawSystem.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29018',NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The time the CPU has spent running the kernel and its processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29036','20','1.3.6.1.4.1.2021.11.50.0','10248','CPU user time','system.cpu.user[ssCpuRawUser.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29019',NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The time the CPU has spent running users'' processes that are not niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29037','20','1.3.6.1.4.1.2021.11.64.0','10248','CPU steal time','system.cpu.steal[ssCpuRawSteal.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29020',NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The amount of CPU ''stolen'' from this virtual machine by the hypervisor for other tasks (such as running another virtual machine).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29038','20','1.3.6.1.4.1.2021.11.61.0','10248','CPU softirq time','system.cpu.softirq[ssCpuRawSoftIRQ.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29021',NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The amount of time the CPU has been servicing software interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29039','20','1.3.6.1.4.1.2021.11.51.0','10248','CPU nice time','system.cpu.nice[ssCpuRawNice.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29022',NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The time the CPU has spent running users'' processes that have been niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29040','20','1.3.6.1.4.1.2021.11.54.0','10248','CPU iowait time','system.cpu.iowait[ssCpuRawWait.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29023',NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
Amount of time the CPU has been waiting for I/O to complete.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29041','20','1.3.6.1.4.1.2021.11.56.0','10248','CPU interrupt time','system.cpu.interrupt[ssCpuRawInterrupt.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29024',NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
The amount of time the CPU has been servicing hardware interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29042','20','1.3.6.1.4.1.2021.11.65.0','10248','CPU guest time','system.cpu.guest[ssCpuRawGuest.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29025',NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
Guest  time (time  spent  running  a  virtual  CPU  for  a  guest  operating  system)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29043','20','1.3.6.1.4.1.2021.11.66.0','10248','CPU guest nice time','system.cpu.guest_nice[ssCpuRawGuestNice.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29026',NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
Time spent running a niced guest (virtual CPU for guest operating systems under the control of the Linux kernel)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29044','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10248','{#FSNAME}: Used space','vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','29027',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29045','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10248','{#FSNAME}: Total space','vfs.fs.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','29028',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in units of hrStorageAllocationUnits.
This object is writable to allow remote configuration of the size of the storage area in those cases where such an operation makes sense and is possible on the underlying system.
For example, the amount of main storage allocated to a buffer pool might be modified or the amount of disk space allocated to virtual storage might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29046','15','','10248','{#FSNAME}: Space utilization','vfs.fs.pused[storageUsedPercentage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29029',NULL,'(last("vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]")/last("vfs.fs.total[hrStorageSize.{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29047','20','1.3.6.1.4.1.2021.9.1.10["index","1.3.6.1.4.1.2021.9.1.2", "{#FSNAME}"]','10248','{#FSNAME}: Free inodes in %','vfs.fs.inode.pfree[dskPercentNode.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','29030',NULL,'','','0','','','','','2',NULL,'MIB: UCD-SNMP-MIB
If having problems collecting this item make sure access to UCD-SNMP-MIB is allowed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29053','17','','10249','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29057','20','1.3.6.1.2.1.1.5.0','10249','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29060','5','','10249','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29077','20','discovery[{#IFOPERSTATUS},1.3.6.1.2.1.2.2.1.8,{#IFADMINSTATUS},1.3.6.1.2.1.2.2.1.7,{#IFALIAS},1.3.6.1.2.1.31.1.1.1.18,{#IFNAME},1.3.6.1.2.1.31.1.1.1.1,{#IFDESCR},1.3.6.1.2.1.2.2.1.2,{#IFTYPE},1.3.6.1.2.1.2.2.1.3]','10249','Network interfaces discovery','net.if.discovery','1h','90d','0','0','4','','','','','27118',NULL,'','','0','','','','','1',NULL,'Discovering interfaces from IF-MIB.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29078','20','1.3.6.1.2.1.2.2.1.13.{#SNMPINDEX}','10249','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in.discards[ifInDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27119',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of inbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29079','20','1.3.6.1.2.1.2.2.1.14.{#SNMPINDEX}','10249','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in.errors[ifInErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27126',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of inbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of inbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29080','20','1.3.6.1.2.1.2.2.1.10.{#SNMPINDEX}','10249','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in[ifInOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27124',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets received on the interface,including framing characters. Discontinuities in the value of this counter can occur at re-initialization of the management system, and atother times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29081','20','1.3.6.1.2.1.2.2.1.19.{#SNMPINDEX}','10249','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out.discards[ifOutDiscards.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27122',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The number of outbound packets which were chosen to be discarded
even though no errors had been detected to prevent their being deliverable to a higher-layer protocol.
One possible reason for discarding such a packet could be to free up buffer space.
Discontinuities in the value of this counter can occur at re-initialization of the management system,
and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29082','20','1.3.6.1.2.1.2.2.1.20.{#SNMPINDEX}','10249','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out.errors[ifOutErrors.{#SNMPINDEX}]','3m','7d','365d','0','3','','','','','27123',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
For packet-oriented interfaces, the number of outbound packets that contained errors preventing them from being deliverable to a higher-layer protocol.  For character-oriented or fixed-length interfaces, the number of outbound transmission units that contained errors preventing them from being deliverable to a higher-layer protocol. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29083','20','1.3.6.1.2.1.2.2.1.16.{#SNMPINDEX}','10249','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out[ifOutOctets.{#SNMPINDEX}]','3m','7d','365d','0','3','','bps','','','27125',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
The total number of octets transmitted out of the interface, including framing characters. Discontinuities in the value of this counter can occur at re-initialization of the management system, and at other times as indicated by the value of ifCounterDiscontinuityTime.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29084','20','1.3.6.1.2.1.31.1.1.1.15.{#SNMPINDEX}','10249','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed[ifHighSpeed.{#SNMPINDEX}]','5m','7d','0d','0','3','','bps','','','27121',NULL,'','','0','','','','','2',NULL,'MIB: IF-MIB
An estimate of the interface''s current bandwidth in units of 1,000,000 bits per second. If this object reports a value of `n'' then the speed of the interface is somewhere in the range of `n-500,000'' to`n+499,999''.  For interfaces which do not vary in bandwidth or for those where no accurate estimation can be made, this object should contain the nominal bandwidth. For a sub-layer which has no concept of bandwidth, this object should be zero.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29085','20','1.3.6.1.2.1.2.2.1.8.{#SNMPINDEX}','10249','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status[ifOperStatus.{#SNMPINDEX}]','1m','7d','0','0','3','','','','','27127','20','','','0','','','','','2',NULL,'MIB: IF-MIB
The current operational state of the interface.
- The testing(3) state indicates that no operational packet scan be passed
- If ifAdminStatus is down(2) then ifOperStatus should be down(2)
- If ifAdminStatus is changed to up(1) then ifOperStatus should change to up(1) if the interface is ready to transmit and receive network traffic
- It should change todormant(5) if the interface is waiting for external actions (such as a serial line waiting for an incoming connection)
- It should remain in the down(2) state if and only if there is a fault that prevents it from going to the up(1) state
- It should remain in the notPresent(6) state if the interface has missing(typically, hardware) components.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29086','20','1.3.6.1.2.1.2.2.1.3.{#SNMPINDEX}','10249','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type[ifType.{#SNMPINDEX}]','1h','7d','0d','0','3','','','','','27120','21','','','0','','','','','2',NULL,'MIB: IF-MIB
The type of interface.
Additional values for ifType are assigned by the Internet Assigned NumbersAuthority (IANA),
through updating the syntax of the IANAifType textual convention.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29124','0','','10001','Number of CPUs','system.cpu.num','1m','7d','365d','0','3','','','','','29087',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29125','0','','10001','CPU iowait time','system.cpu.util[,iowait]','1m','7d','365d','0','0','','%','','','29088',NULL,'','','0','','','','','0',NULL,'Amount of time the CPU has been waiting for I/O to complete.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29126','0','','10001','Context switches per second','system.cpu.switches','1m','7d','365d','0','0','','','','','29089',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29127','0','','10001','CPU guest nice time','system.cpu.util[,guest_nice]','1m','7d','365d','0','0','','%','','','29090',NULL,'','','0','','','','','0',NULL,'Time spent running a niced guest (virtual CPU for guest operating systems under the control of the Linux kernel)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29128','0','','10001','CPU guest time','system.cpu.util[,guest]','1m','7d','365d','0','0','','%','','','29091',NULL,'','','0','','','','','0',NULL,'Guest  time (time  spent  running  a  virtual  CPU  for  a  guest  operating  system)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29129','0','','10001','CPU softirq time','system.cpu.util[,softirq]','1m','7d','365d','0','0','','%','','','29092',NULL,'','','0','','','','','0',NULL,'The amount of time the CPU has been servicing software interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29130','0','','10001','CPU interrupt time','system.cpu.util[,interrupt]','1m','7d','365d','0','0','','%','','','29093',NULL,'','','0','','','','','0',NULL,'The amount of time the CPU has been servicing hardware interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29131','0','','10001','CPU steal time','system.cpu.util[,steal]','1m','7d','365d','0','0','','%','','','29094',NULL,'','','0','','','','','0',NULL,'The amount of CPU ''stolen'' from this virtual machine by the hypervisor for other tasks (such as running another virtual machine).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29132','0','','10001','CPU nice time','system.cpu.util[,nice]','1m','7d','365d','0','0','','%','','','29095',NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that have been niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29133','0','','10001','Load average (1m avg)','system.cpu.load[all,avg1]','1m','7d','365d','0','0','','','','','29096',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29134','0','','10001','CPU user time','system.cpu.util[,user]','1m','7d','365d','0','0','','%','','','29097',NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that are not niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29135','0','','10001','CPU system time','system.cpu.util[,system]','1m','7d','365d','0','0','','%','','','29098',NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running the kernel and its processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29136','0','','10001','CPU idle time','system.cpu.util[,idle]','1m','7d','365d','0','0','','%','','','29099',NULL,'','','0','','','','','0',NULL,'The time the CPU has spent doing nothing.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29137','0','','10001','Load average (15m avg)','system.cpu.load[all,avg15]','1m','7d','365d','0','0','','','','','29100',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29138','0','','10001','Load average (5m avg)','system.cpu.load[all,avg5]','1m','7d','365d','0','0','','','','','29101',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29139','0','','10001','Interrupts per second','system.cpu.intr','1m','7d','365d','0','0','','','','','29102',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29140','0','','10001','Available memory in %','vm.memory.size[pavailable]','1m','7d','365d','0','0','','%','','','29103',NULL,'','','0','','','','','0',NULL,'Available memory as percentage of total. See also: https://www.zabbix.com/documentation/5.0/manual/appendix/items/vm.memory.size_params','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29141','0','','10001','Total memory','vm.memory.size[total]','1m','7d','365d','0','3','','B','','','29104',NULL,'','','0','','','','','0',NULL,'Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29142','0','','10001','Available memory','vm.memory.size[available]','1m','7d','365d','0','3','','B','','','29105',NULL,'','','0','','','','','0',NULL,'Available memory, in Linux, available = free + buffers + cache. On other platforms calculation may vary. See also: https://www.zabbix.com/documentation/5.0/manual/appendix/items/vm.memory.size_params','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29143','0','','10001','Total swap space','system.swap.size[,total]','1m','7d','365d','0','3','','B','','','29106',NULL,'','','0','','','','','0',NULL,'The total space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29144','0','','10001','Free swap space','system.swap.size[,free]','1m','7d','365d','0','3','','B','','','29107',NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29145','0','','10001','Free swap space in %','system.swap.size[,pfree]','1m','7d','365d','0','0','','%','','','29108',NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in percent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29147','0','','10001','System uptime','system.uptime','30s','2w','0d','0','3','','uptime','','','29110',NULL,'','','0','','','','','0',NULL,'System uptime in ''N days, hh:mm:ss'' format.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29148','0','','10001','System boot time','system.boottime','15m','7d','365d','0','3','','unixtime','','','29111',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29149','0','','10001','System local time','system.localtime','1m','7d','365d','0','3','','unixtime','','','29112',NULL,'','','0','','','','','0',NULL,'System local time of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29150','0','','10001','System name','system.hostname','1h','2w','0','0','1','','','','','29113',NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29151','0','','10001','System description','system.uname','1h','2w','0','0','1','','','','','29114',NULL,'','','0','','','','','0',NULL,'The information as normally returned by ''uname -a''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29152','0','','10001','Number of logged in users','system.users.num','1m','7d','365d','0','3','','','','','29115',NULL,'','','0','','','','','0',NULL,'Number of users who are currently logged in.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29153','0','','10001','Maximum number of open file descriptors','kernel.maxfiles','1h','7d','365d','0','3','','','','','29116',NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29154','0','','10001','Maximum number of processes','kernel.maxproc','1h','7d','365d','0','3','','','','','29117',NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29155','0','','10001','Number of processes','proc.num','1m','7d','365d','0','3','','','','','29118',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29156','0','','10001','Number of running processes','proc.num[,,run]','1m','7d','365d','0','3','','','','','29119',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29157','0','','10001','Checksum of /etc/passwd','vfs.file.cksum[/etc/passwd]','15m','7d','0','0','1','','','','','29120',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29158','0','','10001','Operating system','system.sw.os','1h','2w','0','0','1','','','','','29121',NULL,'','','0','','','','','0',NULL,'','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29159','0','','10001','Operating system architecture','system.sw.arch','1h','2w','0','0','1','','','','','29122',NULL,'','','0','','','','','0',NULL,'Operating system architecture of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29160','0','','10001','Software installed','system.sw.packages','1h','2w','0','0','4','','','','','29123',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29204','0','','10001','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','','29201',NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29206','0','','10001','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','','29203',NULL,'','','0','','','','','1',NULL,'Discovery of network interfaces.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29224','0','','10001','{#FSNAME}: Used space','vfs.fs.size[{#FSNAME},used]','1m','7d','365d','0','3','','B','','','29210',NULL,'','','0','','','','','2',NULL,'Used storage in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29225','0','','10001','{#FSNAME}: Total space','vfs.fs.size[{#FSNAME},total]','1m','7d','365d','0','3','','B','','','29211',NULL,'','','0','','','','','2',NULL,'Total space in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29226','0','','10001','{#FSNAME}: Space utilization','vfs.fs.size[{#FSNAME},pused]','1m','7d','365d','0','0','','%','','','29212',NULL,'','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29227','0','','10001','{#FSNAME}: Free inodes in %','vfs.fs.inode[{#FSNAME},pfree]','1m','7d','365d','0','0','','%','','','29213',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29230','0','','10001','Interface {#IFNAME}: Bits received','net.if.in["{#IFNAME}"]','3m','7d','365d','0','3','','bps','','','29216',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29231','0','','10001','Interface {#IFNAME}: Bits sent','net.if.out["{#IFNAME}"]','3m','7d','365d','0','3','','bps','','','29217',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29232','0','','10001','Interface {#IFNAME}: Outbound packets with errors','net.if.out["{#IFNAME}",errors]','3m','7d','365d','0','3','','','','','29218',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29233','0','','10001','Interface {#IFNAME}: Inbound packets with errors','net.if.in["{#IFNAME}",errors]','3m','7d','365d','0','3','','','','','29219',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29234','0','','10001','Interface {#IFNAME}: Outbound packets discarded','net.if.out["{#IFNAME}",dropped]','3m','7d','365d','0','3','','','','','29220',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29235','0','','10001','Interface {#IFNAME}: Inbound packets discarded','net.if.in["{#IFNAME}",dropped]','3m','7d','365d','0','3','','','','','29221',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29236','0','','10001','Interface {#IFNAME}: Operational status','vfs.file.contents["/sys/class/net/{#IFNAME}/operstate"]','1m','7d','0','0','3','','','','','29222','20','','','0','','','','','2',NULL,'Indicates the interface RFC2863 operational state as a string.
Possible values are:"unknown", "notpresent", "down", "lowerlayerdown", "testing","dormant", "up".
Reference: https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-class-net','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29237','0','','10001','Interface {#IFNAME}: Interface type','vfs.file.contents["/sys/class/net/{#IFNAME}/type"]','1h','7d','0d','0','3','','','','','29223','78','','','0','','','','','2',NULL,'Indicates the interface protocol type as a decimal value.
See include/uapi/linux/if_arp.h for all possible values.
Reference: https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-class-net','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29310','7','','10284','Number of CPUs','system.cpu.num','1m','7d','365d','0','3','','','','','29273',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29311','7','','10284','CPU iowait time','system.cpu.util[,iowait]','1m','7d','365d','0','0','','%','','','29274',NULL,'','','0','','','','','0',NULL,'Amount of time the CPU has been waiting for I/O to complete.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29312','7','','10284','Context switches per second','system.cpu.switches','1m','7d','365d','0','0','','','','','29275',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29313','7','','10284','CPU guest nice time','system.cpu.util[,guest_nice]','1m','7d','365d','0','0','','%','','','29276',NULL,'','','0','','','','','0',NULL,'Time spent running a niced guest (virtual CPU for guest operating systems under the control of the Linux kernel)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29314','7','','10284','CPU guest time','system.cpu.util[,guest]','1m','7d','365d','0','0','','%','','','29277',NULL,'','','0','','','','','0',NULL,'Guest  time (time  spent  running  a  virtual  CPU  for  a  guest  operating  system)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29315','7','','10284','CPU softirq time','system.cpu.util[,softirq]','1m','7d','365d','0','0','','%','','','29278',NULL,'','','0','','','','','0',NULL,'The amount of time the CPU has been servicing software interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29316','7','','10284','CPU interrupt time','system.cpu.util[,interrupt]','1m','7d','365d','0','0','','%','','','29279',NULL,'','','0','','','','','0',NULL,'The amount of time the CPU has been servicing hardware interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29317','7','','10284','CPU steal time','system.cpu.util[,steal]','1m','7d','365d','0','0','','%','','','29280',NULL,'','','0','','','','','0',NULL,'The amount of CPU ''stolen'' from this virtual machine by the hypervisor for other tasks (such as running another virtual machine).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29318','7','','10284','CPU nice time','system.cpu.util[,nice]','1m','7d','365d','0','0','','%','','','29281',NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that have been niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29319','7','','10284','Load average (1m avg)','system.cpu.load[all,avg1]','1m','7d','365d','0','0','','','','','29282',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29320','7','','10284','CPU user time','system.cpu.util[,user]','1m','7d','365d','0','0','','%','','','29283',NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running users'' processes that are not niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29321','7','','10284','CPU system time','system.cpu.util[,system]','1m','7d','365d','0','0','','%','','','29284',NULL,'','','0','','','','','0',NULL,'The time the CPU has spent running the kernel and its processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29322','7','','10284','CPU idle time','system.cpu.util[,idle]','1m','7d','365d','0','0','','%','','','29285',NULL,'','','0','','','','','0',NULL,'The time the CPU has spent doing nothing.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29323','7','','10284','Load average (15m avg)','system.cpu.load[all,avg15]','1m','7d','365d','0','0','','','','','29286',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29324','7','','10284','Load average (5m avg)','system.cpu.load[all,avg5]','1m','7d','365d','0','0','','','','','29287',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29325','7','','10284','Interrupts per second','system.cpu.intr','1m','7d','365d','0','0','','','','','29288',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29326','7','','10284','Available memory in %','vm.memory.size[pavailable]','1m','7d','365d','0','0','','%','','','29289',NULL,'','','0','','','','','0',NULL,'Available memory as percentage of total. See also: https://www.zabbix.com/documentation/5.0/manual/appendix/items/vm.memory.size_params','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29327','7','','10284','Total memory','vm.memory.size[total]','1m','7d','365d','0','3','','B','','','29290',NULL,'','','0','','','','','0',NULL,'Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29328','7','','10284','Available memory','vm.memory.size[available]','1m','7d','365d','0','3','','B','','','29291',NULL,'','','0','','','','','0',NULL,'Available memory, in Linux, available = free + buffers + cache. On other platforms calculation may vary. See also: https://www.zabbix.com/documentation/5.0/manual/appendix/items/vm.memory.size_params','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29329','7','','10284','Total swap space','system.swap.size[,total]','1m','7d','365d','0','3','','B','','','29292',NULL,'','','0','','','','','0',NULL,'The total space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29330','7','','10284','Free swap space','system.swap.size[,free]','1m','7d','365d','0','3','','B','','','29293',NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29331','7','','10284','Free swap space in %','system.swap.size[,pfree]','1m','7d','365d','0','0','','%','','','29294',NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in percent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29333','7','','10284','System uptime','system.uptime','30s','2w','0d','0','3','','uptime','','','29296',NULL,'','','0','','','','','0',NULL,'System uptime in ''N days, hh:mm:ss'' format.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29334','7','','10284','System boot time','system.boottime','15m','7d','365d','0','3','','unixtime','','','29297',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29335','0','','10284','System local time','system.localtime','1m','7d','365d','1','3','','unixtime','','','29298',NULL,'','','0','','','','','0',NULL,'System local time of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29336','7','','10284','System name','system.hostname','1h','2w','0','0','1','','','','','29299',NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29337','7','','10284','System description','system.uname','1h','2w','0','0','1','','','','','29300',NULL,'','','0','','','','','0',NULL,'The information as normally returned by ''uname -a''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29338','7','','10284','Number of logged in users','system.users.num','1m','7d','365d','0','3','','','','','29301',NULL,'','','0','','','','','0',NULL,'Number of users who are currently logged in.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29339','7','','10284','Maximum number of open file descriptors','kernel.maxfiles','1h','7d','365d','0','3','','','','','29302',NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29340','7','','10284','Maximum number of processes','kernel.maxproc','1h','7d','365d','0','3','','','','','29303',NULL,'','','0','','','','','0',NULL,'It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29341','7','','10284','Number of processes','proc.num','1m','7d','365d','0','3','','','','','29304',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29342','7','','10284','Number of running processes','proc.num[,,run]','1m','7d','365d','0','3','','','','','29305',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29343','7','','10284','Checksum of /etc/passwd','vfs.file.cksum[/etc/passwd]','15m','7d','0','0','1','','','','','29306',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29344','7','','10284','Operating system','system.sw.os','1h','2w','0','0','1','','','','','29307',NULL,'','','0','','','','','0',NULL,'','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29345','7','','10284','Operating system architecture','system.sw.arch','1h','2w','0','0','1','','','','','29308',NULL,'','','0','','','','','0',NULL,'Operating system architecture of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29346','7','','10284','Software installed','system.sw.packages','1h','2w','0','0','4','','','','','29309',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29352','7','','10284','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','','29349',NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29354','7','','10284','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','','29351',NULL,'','','0','','','','','1',NULL,'Discovery of network interfaces.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29369','7','','10284','{#FSNAME}: Used space','vfs.fs.size[{#FSNAME},used]','1m','7d','365d','0','3','','B','','','29355',NULL,'','','0','','','','','2',NULL,'Used storage in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29370','7','','10284','{#FSNAME}: Total space','vfs.fs.size[{#FSNAME},total]','1m','7d','365d','0','3','','B','','','29356',NULL,'','','0','','','','','2',NULL,'Total space in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29371','7','','10284','{#FSNAME}: Space utilization','vfs.fs.size[{#FSNAME},pused]','1m','7d','365d','0','0','','%','','','29357',NULL,'','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29372','7','','10284','{#FSNAME}: Free inodes in %','vfs.fs.inode[{#FSNAME},pfree]','1m','7d','365d','0','0','','%','','','29358',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29375','7','','10284','Interface {#IFNAME}: Bits received','net.if.in["{#IFNAME}"]','3m','7d','365d','0','3','','bps','','','29361',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29376','7','','10284','Interface {#IFNAME}: Bits sent','net.if.out["{#IFNAME}"]','3m','7d','365d','0','3','','bps','','','29362',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29377','7','','10284','Interface {#IFNAME}: Outbound packets with errors','net.if.out["{#IFNAME}",errors]','3m','7d','365d','0','3','','','','','29363',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29378','7','','10284','Interface {#IFNAME}: Inbound packets with errors','net.if.in["{#IFNAME}",errors]','3m','7d','365d','0','3','','','','','29364',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29379','7','','10284','Interface {#IFNAME}: Outbound packets discarded','net.if.out["{#IFNAME}",dropped]','3m','7d','365d','0','3','','','','','29365',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29380','7','','10284','Interface {#IFNAME}: Inbound packets discarded','net.if.in["{#IFNAME}",dropped]','3m','7d','365d','0','3','','','','','29366',NULL,'','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29381','7','','10284','Interface {#IFNAME}: Operational status','vfs.file.contents["/sys/class/net/{#IFNAME}/operstate"]','1m','7d','0','0','3','','','','','29367','20','','','0','','','','','2',NULL,'Indicates the interface RFC2863 operational state as a string.
Possible values are:"unknown", "notpresent", "down", "lowerlayerdown", "testing","dormant", "up".
Reference: https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-class-net','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29382','7','','10284','Interface {#IFNAME}: Interface type','vfs.file.contents["/sys/class/net/{#IFNAME}/type"]','1h','7d','0d','0','3','','','','','29368','78','','','0','','','','','2',NULL,'Indicates the interface protocol type as a decimal value.
See include/uapi/linux/if_arp.h for all possible values.
Reference: https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-class-net','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29480','0','','10081','CPU utilization','system.cpu.util','1m','7d','365d','0','0','','%','','','29454',NULL,'','','0','','','','','0',NULL,'CPU utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29481','0','','10081','CPU interrupt time','perf_counter_en["\Processor Information(_total)\% Interrupt Time"]','1m','7d','365d','0','0','','%','','','29455',NULL,'','','0','','','','','0',NULL,'The Processor Information\% Interrupt Time is the time the processor spends receiving and servicing 
hardware interrupts during sample intervals. This value is an indirect indicator of the activity of 
devices that generate interrupts, such as the system clock, the mouse, disk drivers, data communication 
lines, network interface cards and other peripheral devices. This is an easy way to identify a potential 
hardware failure. This should never be higher than 20%.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29482','0','','10081','Context switches per second','perf_counter_en["\System\Context Switches/sec"]','1m','7d','365d','0','0','','','','','29456',NULL,'','','0','','','','','0',NULL,'Context Switches/sec is the combined rate at which all processors on the computer are switched from one thread to another.
Context switches occur when a running thread voluntarily relinquishes the processor, is preempted by a higher priority ready thread, or switches between user-mode and privileged (kernel) mode to use an Executive or subsystem service.
It is the sum of Thread\\Context Switches/sec for all threads running on all processors in the computer and is measured in numbers of switches.
There are context switch counters on the System and Thread objects. This counter displays the difference between the values observed in the last two samples, divided by the duration of the sample interval.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29483','0','','10081','CPU privileged time','perf_counter_en["\Processor Information(_total)\% Privileged Time"]','1m','7d','365d','0','0','','%','','','29457',NULL,'','','0','','','','','0',NULL,'The Processor Information\% Privileged Time counter shows the percent of time that the processor is spent 
executing in Kernel (or Privileged) mode. Privileged mode includes services interrupts inside Interrupt 
Service Routines (ISRs), executing Deferred Procedure Calls (DPCs), Device Driver calls and other kernel-mode 
functions of the Windows® Operating System.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29484','0','','10081','CPU user time','perf_counter_en["\Processor Information(_total)\% User Time"]','1m','7d','365d','0','0','','%','','','29458',NULL,'','','0','','','','','0',NULL,'The Processor Information\% User Time counter shows the percent of time that the processor(s) is spent executing 
in User mode.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29485','0','','10081','CPU queue length','perf_counter_en["\System\Processor Queue Length"]','1m','7d','365d','0','0','','','','','29459',NULL,'','','0','','','','','0',NULL,'The Processor Queue Length shows the number of threads that are observed as delayed in the processor Ready Queue 
and are waiting to be executed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29486','0','','10081','Used memory','vm.memory.size[used]','1m','7d','365d','0','3','','B','','','29460',NULL,'','','0','','','','','0',NULL,'Used memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29487','0','','10081','Total memory','vm.memory.size[total]','1m','7d','365d','0','3','','B','','','29461',NULL,'','','0','','','','','0',NULL,'Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29488','15','','10081','Memory utilization','vm.memory.util','1m','7d','365d','0','0','','%','','','29462',NULL,'last("vm.memory.size[used]") / last("vm.memory.size[total]") * 100','','0','','','','','0',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29489','0','','10081','Cache bytes','perf_counter_en["\Memory\Cache Bytes"]','1m','7d','365d','0','3','','B','','','29463',NULL,'','','0','','','','','0',NULL,'Cache Bytes is the sum of the Memory\\System Cache Resident Bytes, Memory\\System Driver Resident Bytes, 
Memory\\System Code Resident Bytes, and Memory\\Pool Paged Resident Bytes counters. This counter displays 
the last observed value only; it is not an average.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29492','0','','10081','Total swap space','system.swap.size[,total]','1m','7d','365d','0','3','','B','','','29466',NULL,'','','0','','','','','0',NULL,'The total space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29493','0','','10081','Free system page table entries','perf_counter_en["\Memory\Free System Page Table Entries"]','1m','7d','365d','0','3','','','','','29467',NULL,'','','0','','','','','0',NULL,'This indicates the number of page table entries not currently in use by the system. If the number is less 
than 5,000, there may well be a memory leak or you running out of memory.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29494','0','','10081','Memory page faults per second','perf_counter_en["\Memory\Page Faults/sec"]','1m','7d','365d','0','0','','','','','29468',NULL,'','','0','','','','','0',NULL,'Page Faults/sec is the average number of pages faulted per second. It is measured in number of pages 
faulted per second because only one page is faulted in each fault operation, hence this is also equal 
to the number of page fault operations. This counter includes both hard faults (those that require 
disk access) and soft faults (where the faulted page is found elsewhere in physical memory.) Most 
processors can handle large numbers of soft faults without significant consequence. However, hard faults, 
which require disk access, can cause significant delays.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29495','0','','10081','Memory pages per second','perf_counter_en["\Memory\Pages/sec"]','1m','7d','365d','0','0','','','','','29469',NULL,'','','0','','','','','0',NULL,'This measures the rate at which pages are read from or written to disk to resolve hard page faults. 
If the value is greater than 1,000, as a result of excessive paging, there may be a memory leak.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29496','0','','10081','Memory pool non-paged','perf_counter_en["\Memory\Pool Nonpaged Bytes"]','1m','7d','365d','0','3','','B','','','29470',NULL,'','','0','','','','','0',NULL,'This measures the size, in bytes, of the non-paged pool. This is an area of system memory for objects 
that cannot be written to disk but instead must remain in physical memory as long as they are allocated. 
There is a possible memory leak if the value is greater than 175MB (or 100MB with the /3GB switch). 
A typical Event ID 2019 is recorded in the system event log.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29498','0','','10081','Uptime','system.uptime','30s','2w','0d','0','3','','uptime','','','29472',NULL,'','','0','','','','','0',NULL,'System uptime in ''N days, hh:mm:ss'' format.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29499','0','','10081','System local time','system.localtime','1m','7d','365d','0','3','','unixtime','','','29473',NULL,'','','0','','','','','0',NULL,'System local time of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29500','0','','10081','System name','system.hostname','1h','2w','0','0','1','','','','','29474',NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29501','0','','10081','System description','system.uname','1h','2w','0','0','1','','','','','29475',NULL,'','','0','','','','','0',NULL,'System description of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29502','0','','10081','Number of processes','proc.num[]','1m','7d','365d','0','3','','','','','29476',NULL,'','','0','','','','','0',NULL,'The number of processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29503','0','','10081','Number of threads','perf_counter_en["\System\Threads"]','1m','7d','365d','0','3','','','','','29477',NULL,'','','0','','','','','0',NULL,'The number of threads used by all running processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29504','0','','10081','Operating system architecture','system.sw.arch','1h','2w','0','0','1','','','','','29478',NULL,'','','0','','','','','0',NULL,'Operating system architecture of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29509','0','','10081','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','','29506',NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29521','0','','10081','{#FSNAME}: Used space','vfs.fs.size[{#FSNAME},used]','1m','7d','365d','0','3','','B','','','29512',NULL,'','','0','','','','','2',NULL,'Used storage in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29522','0','','10081','{#FSNAME}: Total space','vfs.fs.size[{#FSNAME},total]','1m','7d','365d','0','3','','B','','','29513',NULL,'','','0','','','','','2',NULL,'Total space in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29523','0','','10081','{#FSNAME}: Space utilization','vfs.fs.size[{#FSNAME},pused]','1m','7d','365d','0','0','','%','','','29514',NULL,'','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29548','5','','10001','Zabbix agent availability','zabbix[host,agent,available]','1m','7d','365d','0','3','','','','','29544','22','','','0','','','','','0',NULL,'Monitoring agent availability status','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29549','5','','10074','Zabbix agent availability','zabbix[host,agent,available]','1m','7d','365d','0','3','','','','','29544','22','','','0','','','','','0',NULL,'Monitoring agent availability status','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29550','5','','10075','Zabbix agent availability','zabbix[host,agent,available]','1m','7d','365d','0','3','','','','','29544','22','','','0','','','','','0',NULL,'Monitoring agent availability status','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29551','5','','10076','Zabbix agent availability','zabbix[host,agent,available]','1m','7d','365d','0','3','','','','','29544','22','','','0','','','','','0',NULL,'Monitoring agent availability status','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29552','5','','10077','Zabbix agent availability','zabbix[host,agent,available]','1m','7d','365d','0','3','','','','','29544','22','','','0','','','','','0',NULL,'Monitoring agent availability status','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29553','5','','10078','Zabbix agent availability','zabbix[host,agent,available]','1m','7d','365d','0','3','','','','','29544','22','','','0','','','','','0',NULL,'Monitoring agent availability status','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29554','5','','10079','Zabbix agent availability','zabbix[host,agent,available]','1m','7d','365d','0','3','','','','','29544','22','','','0','','','','','0',NULL,'Monitoring agent availability status','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29555','5','','10081','Zabbix agent availability','zabbix[host,agent,available]','1m','7d','365d','0','3','','','','','29544','22','','','0','','','','','0',NULL,'Monitoring agent availability status','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29558','7','','10299','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','','29546',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29559','7','','10299','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','','29547','10','','','0','','','','','0',NULL,'The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29560','7','','10299','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','','29545',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29587','7','','10299','CPU utilization','system.cpu.util','1m','7d','365d','0','0','','%','','','29561',NULL,'','','0','','','','','0',NULL,'CPU utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29588','7','','10299','CPU interrupt time','perf_counter_en["\Processor Information(_total)\% Interrupt Time"]','1m','7d','365d','0','0','','%','','','29562',NULL,'','','0','','','','','0',NULL,'The Processor Information\% Interrupt Time is the time the processor spends receiving and servicing 
hardware interrupts during sample intervals. This value is an indirect indicator of the activity of 
devices that generate interrupts, such as the system clock, the mouse, disk drivers, data communication 
lines, network interface cards and other peripheral devices. This is an easy way to identify a potential 
hardware failure. This should never be higher than 20%.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29589','7','','10299','Context switches per second','perf_counter_en["\System\Context Switches/sec"]','1m','7d','365d','0','0','','','','','29563',NULL,'','','0','','','','','0',NULL,'Context Switches/sec is the combined rate at which all processors on the computer are switched from one thread to another.
Context switches occur when a running thread voluntarily relinquishes the processor, is preempted by a higher priority ready thread, or switches between user-mode and privileged (kernel) mode to use an Executive or subsystem service.
It is the sum of Thread\\Context Switches/sec for all threads running on all processors in the computer and is measured in numbers of switches.
There are context switch counters on the System and Thread objects. This counter displays the difference between the values observed in the last two samples, divided by the duration of the sample interval.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29590','7','','10299','CPU privileged time','perf_counter_en["\Processor Information(_total)\% Privileged Time"]','1m','7d','365d','0','0','','%','','','29564',NULL,'','','0','','','','','0',NULL,'The Processor Information\% Privileged Time counter shows the percent of time that the processor is spent 
executing in Kernel (or Privileged) mode. Privileged mode includes services interrupts inside Interrupt 
Service Routines (ISRs), executing Deferred Procedure Calls (DPCs), Device Driver calls and other kernel-mode 
functions of the Windows® Operating System.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29591','7','','10299','CPU user time','perf_counter_en["\Processor Information(_total)\% User Time"]','1m','7d','365d','0','0','','%','','','29565',NULL,'','','0','','','','','0',NULL,'The Processor Information\% User Time counter shows the percent of time that the processor(s) is spent executing 
in User mode.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29592','7','','10299','CPU queue length','perf_counter_en["\System\Processor Queue Length"]','1m','7d','365d','0','0','','','','','29566',NULL,'','','0','','','','','0',NULL,'The Processor Queue Length shows the number of threads that are observed as delayed in the processor Ready Queue 
and are waiting to be executed.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29593','7','','10299','Used memory','vm.memory.size[used]','1m','7d','365d','0','3','','B','','','29567',NULL,'','','0','','','','','0',NULL,'Used memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29594','7','','10299','Total memory','vm.memory.size[total]','1m','7d','365d','0','3','','B','','','29568',NULL,'','','0','','','','','0',NULL,'Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29595','15','','10299','Memory utilization','vm.memory.util','1m','7d','365d','0','0','','%','','','29569',NULL,'last("vm.memory.size[used]") / last("vm.memory.size[total]") * 100','','0','','','','','0',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29596','7','','10299','Cache bytes','perf_counter_en["\Memory\Cache Bytes"]','1m','7d','365d','0','3','','B','','','29570',NULL,'','','0','','','','','0',NULL,'Cache Bytes is the sum of the Memory\\System Cache Resident Bytes, Memory\\System Driver Resident Bytes, 
Memory\\System Code Resident Bytes, and Memory\\Pool Paged Resident Bytes counters. This counter displays 
the last observed value only; it is not an average.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29599','7','','10299','Total swap space','system.swap.size[,total]','1m','7d','365d','0','3','','B','','','29573',NULL,'','','0','','','','','0',NULL,'The total space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29600','7','','10299','Free system page table entries','perf_counter_en["\Memory\Free System Page Table Entries"]','1m','7d','365d','0','3','','','','','29574',NULL,'','','0','','','','','0',NULL,'This indicates the number of page table entries not currently in use by the system. If the number is less 
than 5,000, there may well be a memory leak or you running out of memory.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29601','7','','10299','Memory page faults per second','perf_counter_en["\Memory\Page Faults/sec"]','1m','7d','365d','0','0','','','','','29575',NULL,'','','0','','','','','0',NULL,'Page Faults/sec is the average number of pages faulted per second. It is measured in number of pages 
faulted per second because only one page is faulted in each fault operation, hence this is also equal 
to the number of page fault operations. This counter includes both hard faults (those that require 
disk access) and soft faults (where the faulted page is found elsewhere in physical memory.) Most 
processors can handle large numbers of soft faults without significant consequence. However, hard faults, 
which require disk access, can cause significant delays.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29602','7','','10299','Memory pages per second','perf_counter_en["\Memory\Pages/sec"]','1m','7d','365d','0','0','','','','','29576',NULL,'','','0','','','','','0',NULL,'This measures the rate at which pages are read from or written to disk to resolve hard page faults. 
If the value is greater than 1,000, as a result of excessive paging, there may be a memory leak.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29603','7','','10299','Memory pool non-paged','perf_counter_en["\Memory\Pool Nonpaged Bytes"]','1m','7d','365d','0','3','','B','','','29577',NULL,'','','0','','','','','0',NULL,'This measures the size, in bytes, of the non-paged pool. This is an area of system memory for objects 
that cannot be written to disk but instead must remain in physical memory as long as they are allocated. 
There is a possible memory leak if the value is greater than 175MB (or 100MB with the /3GB switch). 
A typical Event ID 2019 is recorded in the system event log.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29605','7','','10299','Uptime','system.uptime','30s','2w','0d','0','3','','uptime','','','29579',NULL,'','','0','','','','','0',NULL,'System uptime in ''N days, hh:mm:ss'' format.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29606','0','','10299','System local time','system.localtime','1m','7d','365d','1','3','','unixtime','','','29580',NULL,'','','0','','','','','0',NULL,'System local time of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29607','7','','10299','System name','system.hostname','1h','2w','0','0','1','','','','','29581',NULL,'','','0','','','','','0',NULL,'System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29608','7','','10299','System description','system.uname','1h','2w','0','0','1','','','','','29582',NULL,'','','0','','','','','0',NULL,'System description of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29609','7','','10299','Number of processes','proc.num[]','1m','7d','365d','0','3','','','','','29583',NULL,'','','0','','','','','0',NULL,'The number of processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29610','7','','10299','Number of threads','perf_counter_en["\System\Threads"]','1m','7d','365d','0','3','','','','','29584',NULL,'','','0','','','','','0',NULL,'The number of threads used by all running processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29611','7','','10299','Operating system architecture','system.sw.arch','1h','2w','0','0','1','','','','','29585',NULL,'','','0','','','','','0',NULL,'Operating system architecture of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29616','7','','10299','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','','29613',NULL,'','','0','','','','','1',NULL,'Discovery of file systems of different types.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29628','7','','10299','{#FSNAME}: Used space','vfs.fs.size[{#FSNAME},used]','1m','7d','365d','0','3','','B','','','29619',NULL,'','','0','','','','','2',NULL,'Used storage in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29629','7','','10299','{#FSNAME}: Total space','vfs.fs.size[{#FSNAME},total]','1m','7d','365d','0','3','','B','','','29620',NULL,'','','0','','','','','2',NULL,'Total space in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29630','7','','10299','{#FSNAME}: Space utilization','vfs.fs.size[{#FSNAME},pused]','1m','7d','365d','0','0','','%','','','29621',NULL,'','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29823','5','','10084','Zabbix server: Utilization of alert syncer internal processes, in %','zabbix[process,alert syncer,avg,busy]','1m','1w','365d','0','0','','%','','','29822',NULL,'','','0','','','','','0',NULL,'Average percentage of time alert syncer processes have been busy in the last minute','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29834','20','1.3.6.1.2.1.1.3.0','10237','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29835','20','1.3.6.1.2.1.1.6.0','10237','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29836','20','1.3.6.1.2.1.1.4.0','10237','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29837','20','1.3.6.1.2.1.1.2.0','10237','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29838','20','1.3.6.1.2.1.1.1.0','10237','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29849','20','1.3.6.1.2.1.1.3.0','10207','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29850','20','1.3.6.1.2.1.1.6.0','10207','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29851','20','1.3.6.1.2.1.1.4.0','10207','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29852','20','1.3.6.1.2.1.1.2.0','10207','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29853','20','1.3.6.1.2.1.1.1.0','10207','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29854','20','1.3.6.1.2.1.1.3.0','10208','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29855','20','1.3.6.1.2.1.1.6.0','10208','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29856','20','1.3.6.1.2.1.1.4.0','10208','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29857','20','1.3.6.1.2.1.1.2.0','10208','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29858','20','1.3.6.1.2.1.1.1.0','10208','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29859','20','1.3.6.1.2.1.1.3.0','10210','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29860','20','1.3.6.1.2.1.1.6.0','10210','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29861','20','1.3.6.1.2.1.1.4.0','10210','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29862','20','1.3.6.1.2.1.1.2.0','10210','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29863','20','1.3.6.1.2.1.1.1.0','10210','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29864','20','1.3.6.1.2.1.1.3.0','10211','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29865','20','1.3.6.1.2.1.1.6.0','10211','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29866','20','1.3.6.1.2.1.1.4.0','10211','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29867','20','1.3.6.1.2.1.1.2.0','10211','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29868','20','1.3.6.1.2.1.1.1.0','10211','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29869','20','1.3.6.1.2.1.1.3.0','10218','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29870','20','1.3.6.1.2.1.1.6.0','10218','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29871','20','1.3.6.1.2.1.1.4.0','10218','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29872','20','1.3.6.1.2.1.1.2.0','10218','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29873','20','1.3.6.1.2.1.1.1.0','10218','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29874','20','1.3.6.1.2.1.1.3.0','10220','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29875','20','1.3.6.1.2.1.1.6.0','10220','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29876','20','1.3.6.1.2.1.1.4.0','10220','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29877','20','1.3.6.1.2.1.1.2.0','10220','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29878','20','1.3.6.1.2.1.1.1.0','10220','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29879','20','1.3.6.1.2.1.1.3.0','10221','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29880','20','1.3.6.1.2.1.1.6.0','10221','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29881','20','1.3.6.1.2.1.1.4.0','10221','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29882','20','1.3.6.1.2.1.1.2.0','10221','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29883','20','1.3.6.1.2.1.1.1.0','10221','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29884','20','1.3.6.1.2.1.1.3.0','10222','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29885','20','1.3.6.1.2.1.1.6.0','10222','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29886','20','1.3.6.1.2.1.1.4.0','10222','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29887','20','1.3.6.1.2.1.1.2.0','10222','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29888','20','1.3.6.1.2.1.1.1.0','10222','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29889','20','1.3.6.1.2.1.1.3.0','10223','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29890','20','1.3.6.1.2.1.1.6.0','10223','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29891','20','1.3.6.1.2.1.1.4.0','10223','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29892','20','1.3.6.1.2.1.1.2.0','10223','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29893','20','1.3.6.1.2.1.1.1.0','10223','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29894','20','1.3.6.1.2.1.1.3.0','10224','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29895','20','1.3.6.1.2.1.1.6.0','10224','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29896','20','1.3.6.1.2.1.1.4.0','10224','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29897','20','1.3.6.1.2.1.1.2.0','10224','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29898','20','1.3.6.1.2.1.1.1.0','10224','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29899','20','1.3.6.1.2.1.1.3.0','10226','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29900','20','1.3.6.1.2.1.1.6.0','10226','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29901','20','1.3.6.1.2.1.1.4.0','10226','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29902','20','1.3.6.1.2.1.1.2.0','10226','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29903','20','1.3.6.1.2.1.1.1.0','10226','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29904','20','1.3.6.1.2.1.1.3.0','10227','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29905','20','1.3.6.1.2.1.1.6.0','10227','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29906','20','1.3.6.1.2.1.1.4.0','10227','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29907','20','1.3.6.1.2.1.1.2.0','10227','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29908','20','1.3.6.1.2.1.1.1.0','10227','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29909','20','1.3.6.1.2.1.1.3.0','10229','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29910','20','1.3.6.1.2.1.1.6.0','10229','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29911','20','1.3.6.1.2.1.1.4.0','10229','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29912','20','1.3.6.1.2.1.1.2.0','10229','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29913','20','1.3.6.1.2.1.1.1.0','10229','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29914','20','1.3.6.1.2.1.1.3.0','10230','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29915','20','1.3.6.1.2.1.1.6.0','10230','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29916','20','1.3.6.1.2.1.1.4.0','10230','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29917','20','1.3.6.1.2.1.1.2.0','10230','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29918','20','1.3.6.1.2.1.1.1.0','10230','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29919','20','1.3.6.1.2.1.1.3.0','10231','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29920','20','1.3.6.1.2.1.1.6.0','10231','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29921','20','1.3.6.1.2.1.1.4.0','10231','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29922','20','1.3.6.1.2.1.1.2.0','10231','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29923','20','1.3.6.1.2.1.1.1.0','10231','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29924','20','1.3.6.1.2.1.1.3.0','10233','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29925','20','1.3.6.1.2.1.1.6.0','10233','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29926','20','1.3.6.1.2.1.1.4.0','10233','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29927','20','1.3.6.1.2.1.1.2.0','10233','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29928','20','1.3.6.1.2.1.1.1.0','10233','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29929','20','1.3.6.1.2.1.1.3.0','10234','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29930','20','1.3.6.1.2.1.1.6.0','10234','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29931','20','1.3.6.1.2.1.1.4.0','10234','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29932','20','1.3.6.1.2.1.1.2.0','10234','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29933','20','1.3.6.1.2.1.1.1.0','10234','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29934','20','1.3.6.1.2.1.1.3.0','10235','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29935','20','1.3.6.1.2.1.1.6.0','10235','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29936','20','1.3.6.1.2.1.1.4.0','10235','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29937','20','1.3.6.1.2.1.1.2.0','10235','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29938','20','1.3.6.1.2.1.1.1.0','10235','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29939','20','1.3.6.1.2.1.1.3.0','10236','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29940','20','1.3.6.1.2.1.1.6.0','10236','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29941','20','1.3.6.1.2.1.1.4.0','10236','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29942','20','1.3.6.1.2.1.1.2.0','10236','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29943','20','1.3.6.1.2.1.1.1.0','10236','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29944','20','1.3.6.1.2.1.1.3.0','10250','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29945','20','1.3.6.1.2.1.1.6.0','10250','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29946','20','1.3.6.1.2.1.1.4.0','10250','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29947','20','1.3.6.1.2.1.1.2.0','10250','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29948','20','1.3.6.1.2.1.1.1.0','10250','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29954','20','1.3.6.1.2.1.1.3.0','10253','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29955','20','1.3.6.1.2.1.1.6.0','10253','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29956','20','1.3.6.1.2.1.1.4.0','10253','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29957','20','1.3.6.1.2.1.1.2.0','10253','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29958','20','1.3.6.1.2.1.1.1.0','10253','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29959','20','1.3.6.1.2.1.1.3.0','10254','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29960','20','1.3.6.1.2.1.1.6.0','10254','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29961','20','1.3.6.1.2.1.1.4.0','10254','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29962','20','1.3.6.1.2.1.1.2.0','10254','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29963','20','1.3.6.1.2.1.1.1.0','10254','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29964','20','1.3.6.1.2.1.1.3.0','10255','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29965','20','1.3.6.1.2.1.1.6.0','10255','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29966','20','1.3.6.1.2.1.1.4.0','10255','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29967','20','1.3.6.1.2.1.1.2.0','10255','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29968','20','1.3.6.1.2.1.1.1.0','10255','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29969','20','1.3.6.1.2.1.1.3.0','10256','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29970','20','1.3.6.1.2.1.1.6.0','10256','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29971','20','1.3.6.1.2.1.1.4.0','10256','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29972','20','1.3.6.1.2.1.1.2.0','10256','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29973','20','1.3.6.1.2.1.1.1.0','10256','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29974','20','1.3.6.1.2.1.1.3.0','10258','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29975','20','1.3.6.1.2.1.1.6.0','10258','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29976','20','1.3.6.1.2.1.1.4.0','10258','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29977','20','1.3.6.1.2.1.1.2.0','10258','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29978','20','1.3.6.1.2.1.1.1.0','10258','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29979','20','1.3.6.1.2.1.1.3.0','10259','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29980','20','1.3.6.1.2.1.1.6.0','10259','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29981','20','1.3.6.1.2.1.1.4.0','10259','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29982','20','1.3.6.1.2.1.1.2.0','10259','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29983','20','1.3.6.1.2.1.1.1.0','10259','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29984','20','1.3.6.1.2.1.1.3.0','10248','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29985','20','1.3.6.1.2.1.1.6.0','10248','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29986','20','1.3.6.1.2.1.1.4.0','10248','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29987','20','1.3.6.1.2.1.1.2.0','10248','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29988','20','1.3.6.1.2.1.1.1.0','10248','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29989','20','1.3.6.1.2.1.1.3.0','10249','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29990','20','1.3.6.1.2.1.1.6.0','10249','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29991','20','1.3.6.1.2.1.1.4.0','10249','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29992','20','1.3.6.1.2.1.1.2.0','10249','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29993','20','1.3.6.1.2.1.1.1.0','10249','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29995','7','','10284','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','','29546',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29996','7','','10284','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','','29547','10','','','0','','','','','0',NULL,'The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29997','7','','10284','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','','29545',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30049','17','','10304','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30050','20','1.3.6.1.2.1.1.4.0','10304','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30051','20','1.3.6.1.2.1.1.1.0','10304','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30052','20','1.3.6.1.2.1.1.6.0','10304','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30053','20','1.3.6.1.2.1.1.5.0','10304','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30054','20','1.3.6.1.2.1.1.2.0','10304','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30055','20','1.3.6.1.2.1.1.3.0','10304','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30056','5','','10304','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30095','20','1.3.6.1.4.1.1991.1.1.2.1.53.0','10210','Memory utilization','vm.memory.util[snAgGblDynMemUtil.0]','1m','7d','365d','0','0','','%','','','30094',NULL,'','','0','','','','','0',NULL,'MIB: FOUNDRY-SN-AGENT-MIB
The system dynamic memory utilization, in unit of percentage.
Deprecated: Refer to snAgSystemDRAMUtil.
For NI platforms, refer to snAgentBrdMemoryUtil100thPercent','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30096','20','1.3.6.1.4.1.1991.1.1.2.1.53.0','10211','Memory utilization','vm.memory.util[snAgGblDynMemUtil.0]','1m','7d','365d','0','0','','%','','','30094',NULL,'','','0','','','','','0',NULL,'MIB: FOUNDRY-SN-AGENT-MIB
The system dynamic memory utilization, in unit of percentage.
Deprecated: Refer to snAgSystemDRAMUtil.
For NI platforms, refer to snAgentBrdMemoryUtil100thPercent','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30098','20','1.3.6.1.2.1.1.1.0','10218','Operating system','system.sw.os[sysDescr.0]','1h','2w','0','0','1','','','','','30097',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30099','20','1.3.6.1.2.1.1.1.0','10220','Operating system','system.sw.os[sysDescr.0]','1h','2w','0','0','1','','','','','30097',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30100','20','1.3.6.1.2.1.1.1.0','10253','Operating system','system.sw.os[sysDescr.0]','1h','2w','0','0','1','','','','','30097',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30102','15','','10218','{#SNMPVALUE}: Memory utilization','vm.memory.util[vm.memory.util.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','30101',NULL,'last("vm.memory.used[ciscoMemoryPoolUsed.{#SNMPINDEX}]")/(last("vm.memory.free[ciscoMemoryPoolFree.{#SNMPINDEX}]")+last("vm.memory.used[ciscoMemoryPoolUsed.{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30103','15','','10220','{#SNMPVALUE}: Memory utilization','vm.memory.util[vm.memory.util.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','30101',NULL,'last("vm.memory.used[ciscoMemoryPoolUsed.{#SNMPINDEX}]")/(last("vm.memory.free[ciscoMemoryPoolFree.{#SNMPINDEX}]")+last("vm.memory.used[ciscoMemoryPoolUsed.{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30104','15','','10253','{#SNMPVALUE}: Memory utilization','vm.memory.util[vm.memory.util.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','30101',NULL,'last("vm.memory.used[ciscoMemoryPoolUsed.{#SNMPINDEX}]")/(last("vm.memory.free[ciscoMemoryPoolFree.{#SNMPINDEX}]")+last("vm.memory.used[ciscoMemoryPoolUsed.{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30138','0','','10081','CPU DPC time','perf_counter_en["\Processor Information(_total)\% DPC Time"]','1m','7d','365d','0','0','','%','','','30137',NULL,'','','0','','','','','0',NULL,'Processor DPC time is the time that a single processor spent receiving and servicing deferred procedure 
calls (DPCs). DPCs are interrupts that run at a lower priority than standard interrupts. % DPC Time is a 
component of % Privileged Time because DPCs are executed in privileged mode. If a high % DPC Time is 
sustained, there may be a processor bottleneck or an application or hardware related issue that can 
significantly diminish overall system performance.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30140','7','','10299','CPU DPC time','perf_counter_en["\Processor Information(_total)\% DPC Time"]','1m','7d','365d','0','0','','%','','','30139',NULL,'','','0','','','','','0',NULL,'Processor DPC time is the time that a single processor spent receiving and servicing deferred procedure 
calls (DPCs). DPCs are interrupts that run at a lower priority than standard interrupts. % DPC Time is a 
component of % Privileged Time because DPCs are executed in privileged mode. If a high % DPC Time is 
sustained, there may be a processor bottleneck or an application or hardware related issue that can 
significantly diminish overall system performance.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30143','20','discovery[{#CPU.UTIL},1.3.6.1.2.1.25.3.3.1.2]','10185','CPU utilization','system.cpu.util','1m','7d','365d','0','0','','%','','','30142',NULL,'','','0','','','','','0',NULL,'MIB: HOST-RESOURCES-MIB
The average, over the last minute, of the percentage of time that processors was not idle.
Implementations may approximate this one minute smoothing period if necessary.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30149','20','discovery[{#MEMNAME},1.3.6.1.2.1.25.2.3.1.3,{#MEMTYPE},1.3.6.1.2.1.25.2.3.1.2,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4]','10185','Memory discovery','vm.memory.discovery','1h','90d','0','0','4','','','','','30147',NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with memory filter','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30150','20','discovery[{#FSNAME},1.3.6.1.2.1.25.2.3.1.3,{#FSTYPE},1.3.6.1.2.1.25.2.3.1.2,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4]','10185','Storage discovery','vfs.fs.discovery[snmp]','1h','90d','0','0','4','','','','','30148',NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with storage filter.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30163','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10185','{#MEMNAME}: Total memory','vm.memory.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','30157',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in units of hrStorageAllocationUnits.
This object is writable to allow remote configuration of the size of the storage area in those cases where such an operation makes sense and is possible on the underlying system.
For example, the amount of main memory allocated to a buffer pool might be modified or the amount of disk space allocated to virtual memory might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30164','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10185','{#MEMNAME}: Used memory','vm.memory.used[hrStorageUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','30158',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30165','15','','10185','{#MEMNAME}: Memory utilization','vm.memory.util[memoryUsedPercentage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','30159',NULL,'last("vm.memory.used[hrStorageUsed.{#SNMPINDEX}]")/last("vm.memory.total[hrStorageSize.{#SNMPINDEX}]")*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30166','15','','10185','{#FSNAME}: Space utilization','vfs.fs.pused[storageUsedPercentage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','30160',NULL,'(last("vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]")/last("vfs.fs.total[hrStorageSize.{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30167','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10185','{#FSNAME}: Total space','vfs.fs.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','30161',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in units of hrStorageAllocationUnits.
This object is writable to allow remote configuration of the size of the storage area in those cases where such an operation makes sense and is possible on the underlying system.
For example, the amount of main storage allocated to a buffer pool might be modified or the amount of disk space allocated to virtual storage might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30168','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10185','{#FSNAME}: Used space','vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','30162',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30424','0','','10081','Windows services discovery','service.discovery','1h','90d','0','0','4','','','','','30423',NULL,'','','0','','','','','1',NULL,'Discovery of Windows services of different types as defined in template''s macros.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30426','0','','10081','State of service "{#SERVICE.NAME}" ({#SERVICE.DISPLAYNAME})','service.info["{#SERVICE.NAME}",state]','1m','7d','365d','0','3','','','','','30425','3','','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30428','7','','10299','Windows services discovery','service.discovery','1h','90d','0','0','4','','','','','30427',NULL,'','','0','','','','','1',NULL,'Discovery of Windows services of different types as defined in template''s macros.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30430','7','','10299','State of service "{#SERVICE.NAME}" ({#SERVICE.DISPLAYNAME})','service.info["{#SERVICE.NAME}",state]','1m','7d','365d','0','3','','','','','30429','3','','','0','','','','','2',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31274','0','','10001','Block devices discovery','vfs.dev.discovery','1h','90d','0','0','4','','','','','31273',NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31279','15','','10001','{#DEVNAME}: Disk read request avg waiting time (r_await)','vfs.dev.read.await[{#DEVNAME}]','1m','7d','365d','0','0','','!ms','','','31276',NULL,'(last("vfs.dev.read.time.rate[{#DEVNAME}]")/(last("vfs.dev.read.rate[{#DEVNAME}]")+(last("vfs.dev.read.rate[{#DEVNAME}]")=0)))*1000*(last("vfs.dev.read.rate[{#DEVNAME}]") > 0)','','0','','','','','2',NULL,'This formula contains two boolean expressions that evaluates to 1 or 0 in order to set calculated metric to zero and to avoid division by zero exception.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31280','15','','10001','{#DEVNAME}: Disk write request avg waiting time (w_await)','vfs.dev.write.await[{#DEVNAME}]','1m','7d','365d','0','0','','!ms','','','31277',NULL,'(last("vfs.dev.write.time.rate[{#DEVNAME}]")/(last("vfs.dev.write.rate[{#DEVNAME}]")+(last("vfs.dev.write.rate[{#DEVNAME}]")=0)))*1000*(last("vfs.dev.write.rate[{#DEVNAME}]") > 0)','','0','','','','','2',NULL,'This formula contains two boolean expressions that evaluates to 1 or 0 in order to set calculated metric to zero and to avoid division by zero exception.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31281','0','','10001','{#DEVNAME}: Get stats','vfs.file.contents[/sys/block/{#DEVNAME}/stat]','1m','0','0','0','4','','','','','31278',NULL,'','','0','','','','','2',NULL,'Get contents of /sys/block/{#DEVNAME}/stat for disk stats.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31306','7','','10284','Block devices discovery','vfs.dev.discovery','1h','90d','0','0','4','','','','','31305',NULL,'','','0','','','','','1',NULL,'','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31310','15','','10284','{#DEVNAME}: Disk read request avg waiting time (r_await)','vfs.dev.read.await[{#DEVNAME}]','1m','7d','365d','0','0','','!ms','','','31307',NULL,'(last("vfs.dev.read.time.rate[{#DEVNAME}]")/(last("vfs.dev.read.rate[{#DEVNAME}]")+(last("vfs.dev.read.rate[{#DEVNAME}]")=0)))*1000*(last("vfs.dev.read.rate[{#DEVNAME}]") > 0)','','0','','','','','2',NULL,'This formula contains two boolean expressions that evaluates to 1 or 0 in order to set calculated metric to zero and to avoid division by zero exception.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31311','15','','10284','{#DEVNAME}: Disk write request avg waiting time (w_await)','vfs.dev.write.await[{#DEVNAME}]','1m','7d','365d','0','0','','!ms','','','31308',NULL,'(last("vfs.dev.write.time.rate[{#DEVNAME}]")/(last("vfs.dev.write.rate[{#DEVNAME}]")+(last("vfs.dev.write.rate[{#DEVNAME}]")=0)))*1000*(last("vfs.dev.write.rate[{#DEVNAME}]") > 0)','','0','','','','','2',NULL,'This formula contains two boolean expressions that evaluates to 1 or 0 in order to set calculated metric to zero and to avoid division by zero exception.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31312','7','','10284','{#DEVNAME}: Get stats','vfs.file.contents[/sys/block/{#DEVNAME}/stat]','1m','0','0','0','4','','','','','31309',NULL,'','','0','','','','','2',NULL,'Get contents of /sys/block/{#DEVNAME}/stat for disk stats.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31328','0','','10081','Number of cores','wmi.get[root/cimv2,"Select NumberOfLogicalProcessors from Win32_ComputerSystem"]','1m','7d','365d','0','3','','','','','31325',NULL,'','','0','','','','','0',NULL,'The number of logical processors available on the computer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31329','0','','10081','Used swap space in %','perf_counter_en["\Paging file(_Total)\% Usage"]','1m','7d','365d','0','0','','%','','','31326',NULL,'','','0','','','','','0',NULL,'The used space of swap volume/file in percent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31330','15','','10081','Free swap space','system.swap.free','1m','7d','365d','0','3','','B','','','31327',NULL,'last("system.swap.size[,total]") - last("system.swap.size[,total]") / 100 * last("perf_counter_en[\"\Paging file(_Total)\% Usage\"]")','','0','','','','','0',NULL,'The free space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31334','0','','10081','Physical disks discovery','perf_instance_en.discovery[PhysicalDisk]','1h','90d','0','0','4','','','','','31333',NULL,'','','0','','','','','1',NULL,'Discovery of installed physical disks.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31339','0','','10081','{#DEVNAME}: Disk utilization','perf_counter_en["\PhysicalDisk({#DEVNAME})\% Disk Time",60]','1m','7d','365d','0','0','','%','','','31335',NULL,'','','0','','','','','2',NULL,'This item is the percentage of elapsed time that the selected disk drive was busy servicing read or writes requests.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31340','0','','10081','{#DEVNAME}: Disk average queue size (avgqu-sz)','perf_counter_en["\PhysicalDisk({#DEVNAME})\Current Disk Queue Length",60]','1m','7d','365d','0','0','','','','','31336',NULL,'','','0','','','','','2',NULL,'Current average disk queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31341','0','','10081','{#DEVNAME}: Disk read rate','perf_counter_en["\PhysicalDisk({#DEVNAME})\Disk Reads/sec",60]','1m','7d','365d','0','0','','!r/s','','','31337',NULL,'','','0','','','','','2',NULL,'Rate of read operations on the disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31342','0','','10081','{#DEVNAME}: Disk write rate','perf_counter_en["\PhysicalDisk({#DEVNAME})\Disk Writes/sec",60]','1m','7d','365d','0','0','','!w/s','','','31338',NULL,'','','0','','','','','2',NULL,'Rate of write operations on the disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31346','7','','10299','Number of cores','wmi.get[root/cimv2,"Select NumberOfLogicalProcessors from Win32_ComputerSystem"]','1m','7d','365d','0','3','','','','','31343',NULL,'','','0','','','','','0',NULL,'The number of logical processors available on the computer.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31347','7','','10299','Used swap space in %','perf_counter_en["\Paging file(_Total)\% Usage"]','1m','7d','365d','0','0','','%','','','31344',NULL,'','','0','','','','','0',NULL,'The used space of swap volume/file in percent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31348','15','','10299','Free swap space','system.swap.free','1m','7d','365d','0','3','','B','','','31345',NULL,'last("system.swap.size[,total]") - last("system.swap.size[,total]") / 100 * last("perf_counter_en[\"\Paging file(_Total)\% Usage\"]")','','0','','','','','0',NULL,'The free space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31352','7','','10299','Physical disks discovery','perf_instance_en.discovery[PhysicalDisk]','1h','90d','0','0','4','','','','','31351',NULL,'','','0','','','','','1',NULL,'Discovery of installed physical disks.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31357','7','','10299','{#DEVNAME}: Disk utilization','perf_counter_en["\PhysicalDisk({#DEVNAME})\% Disk Time",60]','1m','7d','365d','0','0','','%','','','31353',NULL,'','','0','','','','','2',NULL,'This item is the percentage of elapsed time that the selected disk drive was busy servicing read or writes requests.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31358','7','','10299','{#DEVNAME}: Disk average queue size (avgqu-sz)','perf_counter_en["\PhysicalDisk({#DEVNAME})\Current Disk Queue Length",60]','1m','7d','365d','0','0','','','','','31354',NULL,'','','0','','','','','2',NULL,'Current average disk queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31359','7','','10299','{#DEVNAME}: Disk read rate','perf_counter_en["\PhysicalDisk({#DEVNAME})\Disk Reads/sec",60]','1m','7d','365d','0','0','','!r/s','','','31355',NULL,'','','0','','','','','2',NULL,'Rate of read operations on the disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31360','7','','10299','{#DEVNAME}: Disk write rate','perf_counter_en["\PhysicalDisk({#DEVNAME})\Disk Writes/sec",60]','1m','7d','365d','0','0','','!w/s','','','31356',NULL,'','','0','','','','','2',NULL,'Rate of write operations on the disk.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32449','0','','10081','{#DEVNAME}: Average disk read queue length','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk Read Queue Length",60]','1m','7d','365d','0','0','','','','','32445',NULL,'','','0','','','','','2',NULL,'Average disk read queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32450','0','','10081','{#DEVNAME}: Disk read request avg waiting time','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk sec/Read",60]','1m','7d','365d','0','0','','s','','','32446',NULL,'','','0','','','','','2',NULL,'The average time for read requests issued to the device to be served. This includes the time spent by the requests in queue and the time spent servicing them.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32451','0','','10081','{#DEVNAME}: Disk write request avg waiting time','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk sec/Write",60]','1m','7d','365d','0','0','','s','','','32447',NULL,'','','0','','','','','2',NULL,'The average time for write requests issued to the device to be served. This includes the time spent by the requests in queue and the time spent servicing them.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32452','0','','10081','{#DEVNAME}: Average disk write queue length','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk Write Queue Length",60]','1m','7d','365d','0','0','','','','','32448',NULL,'','','0','','','','','2',NULL,'Average disk write queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32457','7','','10299','{#DEVNAME}: Average disk read queue length','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk Read Queue Length",60]','1m','7d','365d','0','0','','','','','32453',NULL,'','','0','','','','','2',NULL,'Average disk read queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32458','7','','10299','{#DEVNAME}: Disk read request avg waiting time','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk sec/Read",60]','1m','7d','365d','0','0','','s','','','32454',NULL,'','','0','','','','','2',NULL,'The average time for read requests issued to the device to be served. This includes the time spent by the requests in queue and the time spent servicing them.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32459','7','','10299','{#DEVNAME}: Disk write request avg waiting time','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk sec/Write",60]','1m','7d','365d','0','0','','s','','','32455',NULL,'','','0','','','','','2',NULL,'The average time for write requests issued to the device to be served. This includes the time spent by the requests in queue and the time spent servicing them.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32460','7','','10299','{#DEVNAME}: Average disk write queue length','perf_counter_en["\PhysicalDisk({#DEVNAME})\Avg. Disk Write Queue Length",60]','1m','7d','365d','0','0','','','','','32456',NULL,'','','0','','','','','2',NULL,'Average disk write queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32604','17','','10353','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32605','20','1.3.6.1.2.1.1.4.0','10353','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32606','20','1.3.6.1.2.1.1.1.0','10353','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32607','20','1.3.6.1.2.1.1.6.0','10353','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32608','20','1.3.6.1.2.1.1.5.0','10353','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32609','20','1.3.6.1.2.1.1.2.0','10353','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32610','20','1.3.6.1.2.1.1.3.0','10353','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32611','5','','10353','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32768','17','','10357','SNMP traps (fallback)','snmptrap.fallback','1m','2w','0','0','2','','','','hh:mm:sszyyyy/MM/dd','27157',NULL,'','','0','','','','','0',NULL,'Item is used to collect all SNMP traps unmatched by other snmptrap items','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32769','20','1.3.6.1.2.1.1.4.0','10357','System contact details','system.contact[sysContact.0]','1h','2w','0','0','1','','','','','29846',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The textual identification of the contact person for this managed node, together with information on how to contact this person.  If no contact information is known, the value is the zero-length string.','23','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32770','20','1.3.6.1.2.1.1.1.0','10357','System description','system.descr[sysDescr.0]','1h','2w','0','0','1','','','','','29848',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
A textual description of the entity. This value should
include the full name and version identification of the system''s hardware type, software operating-system, and
networking software.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32771','20','1.3.6.1.2.1.1.6.0','10357','System location','system.location[sysLocation.0]','1h','2w','0','0','1','','','','','29845',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The physical location of this node (e.g., `telephone closet, 3rd floor'').  If the location is unknown, the value is the zero-length string.','24','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32772','20','1.3.6.1.2.1.1.5.0','10357','System name','system.name','1h','2w','0','0','1','','','','','27152',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
An administratively-assigned name for this managed node.By convention, this is the node''s fully-qualified domain name.  If the name is unknown, the value is the zero-length string.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32773','20','1.3.6.1.2.1.1.2.0','10357','System object ID','system.objectid[sysObjectID.0]','15m','2w','0','0','1','','','','','29847',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The vendor''s authoritative identification of the network management subsystem contained in the entity.  This value is allocated within the SMI enterprises subtree (1.3.6.1.4.1) and provides an easy and unambiguous means for determining`what kind of box'' is being managed.  For example, if vendor`Flintstones, Inc.'' was assigned the subtree1.3.6.1.4.1.4242, it could assign the identifier 1.3.6.1.4.1.4242.1.1 to its `Fred Router''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32774','20','1.3.6.1.2.1.1.3.0','10357','Uptime','system.uptime[sysUpTime.0]','30s','2w','0d','0','3','','uptime','','','29844',NULL,'','','0','','','','','0',NULL,'MIB: SNMPv2-MIB
The time (in hundredths of a second) since the network management portion of the system was last re-initialized.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32775','5','','10357','SNMP agent availability','zabbix[host,snmp,available]','1m','7d','365d','0','3','','','','','27154','22','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('34196','5','','10084','Zabbix server: Version','zabbix[version]','1m','1w','0','0','1','','','','','34189',NULL,'','','0','','','','','0',NULL,'Version of Zabbix server.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36580','0','','10081','Network interfaces WMI get','wmi.getall[root\cimv2,"select Name,Description,NetConnectionID,Speed,AdapterTypeId,NetConnectionStatus,GUID from win32_networkadapter where PhysicalAdapter=True and NetConnectionStatus>0"]','1m','0','0','0','4','','','','','36579',NULL,'','','0','','','','','0',NULL,'Raw data of win32_networkadapter.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36589','0','','10081','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in["{#IFGUID}",dropped]','3m','7d','365d','0','3','','','','','36583',NULL,'','','0','','','','','2',NULL,'The number of incoming packets dropped on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36590','0','','10081','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in["{#IFGUID}",errors]','3m','7d','365d','0','3','','','','','36584',NULL,'','','0','','','','','2',NULL,'The number of incoming packets with errors on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36591','0','','10081','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in["{#IFGUID}"]','3m','7d','365d','0','3','','bps','','','36585',NULL,'','','0','','','','','2',NULL,'Incoming traffic on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36592','0','','10081','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out["{#IFGUID}",dropped]','3m','7d','365d','0','3','','','','','36586',NULL,'','','0','','','','','2',NULL,'The number of outgoing packets dropped on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36593','0','','10081','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out["{#IFGUID}",errors]','3m','7d','365d','0','3','','','','','36587',NULL,'','','0','','','','','2',NULL,'The number of outgoing packets with errors on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36594','0','','10081','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out["{#IFGUID}"]','3m','7d','365d','0','3','','bps','','','36588',NULL,'','','0','','','','','2',NULL,'Outgoing traffic on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36602','7','','10299','Network interfaces WMI get','wmi.getall[root\cimv2,"select Name,Description,NetConnectionID,Speed,AdapterTypeId,NetConnectionStatus,GUID from win32_networkadapter where PhysicalAdapter=True and NetConnectionStatus>0"]','1m','0','0','0','4','','','','','36601',NULL,'','','0','','','','','0',NULL,'Raw data of win32_networkadapter.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36611','7','','10299','Interface {#IFNAME}({#IFALIAS}): Inbound packets discarded','net.if.in["{#IFGUID}",dropped]','3m','7d','365d','0','3','','','','','36605',NULL,'','','0','','','','','2',NULL,'The number of incoming packets dropped on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36612','7','','10299','Interface {#IFNAME}({#IFALIAS}): Inbound packets with errors','net.if.in["{#IFGUID}",errors]','3m','7d','365d','0','3','','','','','36606',NULL,'','','0','','','','','2',NULL,'The number of incoming packets with errors on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36613','7','','10299','Interface {#IFNAME}({#IFALIAS}): Bits received','net.if.in["{#IFGUID}"]','3m','7d','365d','0','3','','bps','','','36607',NULL,'','','0','','','','','2',NULL,'Incoming traffic on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36614','7','','10299','Interface {#IFNAME}({#IFALIAS}): Outbound packets discarded','net.if.out["{#IFGUID}",dropped]','3m','7d','365d','0','3','','','','','36608',NULL,'','','0','','','','','2',NULL,'The number of outgoing packets dropped on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36615','7','','10299','Interface {#IFNAME}({#IFALIAS}): Outbound packets with errors','net.if.out["{#IFGUID}",errors]','3m','7d','365d','0','3','','','','','36609',NULL,'','','0','','','','','2',NULL,'The number of outgoing packets with errors on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36616','7','','10299','Interface {#IFNAME}({#IFALIAS}): Bits sent','net.if.out["{#IFGUID}"]','3m','7d','365d','0','3','','bps','','','36610',NULL,'','','0','','','','','2',NULL,'Outgoing traffic on the network interface.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29012','18','','10248','CPU discovery','cpu.discovery[snmp]','0','90d','0','0','4','','','','','29009',NULL,'','','0','','','','','1',NULL,'This discovery will create set of per core CPU metrics from UCD-SNMP-MIB, using {#CPU.COUNT} in preprocessing. That''s the only reason why LLD is used.','0','30d','0','','29005','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29049','18','','10248','CPU utilization','system.cpu.util[snmp,{#SNMPINDEX}]','0','7d','365d','0','0','','%','','','29048',NULL,'','','0','','','','','2',NULL,'CPU utilization in %','0','30d','0','','29034','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29199','18','','10001','CPU utilization','system.cpu.util','0','7d','365d','0','0','','%','','','29198',NULL,'','','0','','','','','0',NULL,'CPU utilization in %','0','30d','0','','29136','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29348','18','','10284','CPU utilization','system.cpu.util','0','7d','365d','0','0','','%','','','29347',NULL,'','','0','','','','','0',NULL,'CPU utilization in %','0','30d','0','','29322','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31271','18','','10001','Memory utilization','vm.memory.utilization','0','7d','365d','0','0','','%','','','31270',NULL,'','','0','','','','','0',NULL,'Memory used percentage is calculated as (100-pavailable)','0','30d','0','','29140','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31291','18','','10001','{#DEVNAME}: Disk average queue size (avgqu-sz)','vfs.dev.queue_size[{#DEVNAME}]','0','7d','365d','0','0','','','','','31285',NULL,'','','0','','','','','2',NULL,'Current average disk queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','','31281','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31292','18','','10001','{#DEVNAME}: Disk read rate','vfs.dev.read.rate[{#DEVNAME}]','0','7d','365d','0','0','','!r/s','','','31286',NULL,'','','0','','','','','2',NULL,'r/s. The number (after merges) of read requests completed per second for the device.','0','30d','0','','31281','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31293','18','','10001','{#DEVNAME}: Disk read time (rate)','vfs.dev.read.time.rate[{#DEVNAME}]','0','7d','365d','0','0','','','','','31287',NULL,'','','0','','','','','2',NULL,'Rate of total read time counter. Used in r_await calculation','0','30d','0','','31281','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31294','18','','10001','{#DEVNAME}: Disk utilization','vfs.dev.util[{#DEVNAME}]','0','7d','365d','0','0','','%','','','31288',NULL,'','','0','','','','','2',NULL,'This item is the percentage of elapsed time that the selected disk drive was busy servicing read or writes requests.','0','30d','0','','31281','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31295','18','','10001','{#DEVNAME}: Disk write rate','vfs.dev.write.rate[{#DEVNAME}]','0','7d','365d','0','0','','!w/s','','','31289',NULL,'','','0','','','','','2',NULL,'w/s. The number (after merges) of write requests completed per second for the device.','0','30d','0','','31281','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31296','18','','10001','{#DEVNAME}: Disk write time (rate)','vfs.dev.write.time.rate[{#DEVNAME}]','0','7d','365d','0','0','','','','','31290',NULL,'','','0','','','','','2',NULL,'Rate of total write time counter. Used in w_await calculation','0','30d','0','','31281','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31304','18','','10284','Memory utilization','vm.memory.utilization','0','7d','365d','0','0','','%','','','31303',NULL,'','','0','','','','','0',NULL,'Memory used percentage is calculated as (100-pavailable)','0','30d','0','','29326','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31319','18','','10284','{#DEVNAME}: Disk average queue size (avgqu-sz)','vfs.dev.queue_size[{#DEVNAME}]','0','7d','365d','0','0','','','','','31313',NULL,'','','0','','','','','2',NULL,'Current average disk queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','','31312','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31320','18','','10284','{#DEVNAME}: Disk read rate','vfs.dev.read.rate[{#DEVNAME}]','0','7d','365d','0','0','','!r/s','','','31314',NULL,'','','0','','','','','2',NULL,'r/s. The number (after merges) of read requests completed per second for the device.','0','30d','0','','31312','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31321','18','','10284','{#DEVNAME}: Disk read time (rate)','vfs.dev.read.time.rate[{#DEVNAME}]','0','7d','365d','0','0','','','','','31315',NULL,'','','0','','','','','2',NULL,'Rate of total read time counter. Used in r_await calculation','0','30d','0','','31312','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31322','18','','10284','{#DEVNAME}: Disk utilization','vfs.dev.util[{#DEVNAME}]','0','7d','365d','0','0','','%','','','31316',NULL,'','','0','','','','','2',NULL,'This item is the percentage of elapsed time that the selected disk drive was busy servicing read or writes requests.','0','30d','0','','31312','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31323','18','','10284','{#DEVNAME}: Disk write rate','vfs.dev.write.rate[{#DEVNAME}]','0','7d','365d','0','0','','!w/s','','','31317',NULL,'','','0','','','','','2',NULL,'w/s. The number (after merges) of write requests completed per second for the device.','0','30d','0','','31312','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31324','18','','10284','{#DEVNAME}: Disk write time (rate)','vfs.dev.write.time.rate[{#DEVNAME}]','0','7d','365d','0','0','','','','','31318',NULL,'','','0','','','','','2',NULL,'Rate of total write time counter. Used in w_await calculation','0','30d','0','','31312','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31332','18','','10081','Free swap space in %','system.swap.pfree','0','7d','365d','0','0','','%','','','31331',NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in percent.','0','30d','0','','31329','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31350','18','','10299','Free swap space in %','system.swap.pfree','0','7d','365d','0','0','','%','','','31349',NULL,'','','0','','','','','0',NULL,'The free space of swap volume/file in percent.','0','30d','0','','31347','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36582','18','','10081','Network interfaces discovery','net.if.discovery','0','90d','0','0','4','','','','','36581',NULL,'','','0','','','','','1',NULL,'Discovery of installed network interfaces.','0','30d','1','','36580','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36598','18','','10081','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed["{#IFGUID}"]','0','7d','0d','0','3','','bps','','','36595',NULL,'','','0','','','','','2',NULL,'Estimated bandwidth of the network interface if any.','0','30d','0','','36580','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36599','18','','10081','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status["{#IFGUID}"]','0','7d','0','0','3','','','','','36596','81','','','0','','','','','2',NULL,'The operational status of the network interface.','0','30d','0','','36580','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36600','18','','10081','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type["{#IFGUID}"]','0','7d','0d','0','3','','','','','36597','79','','','0','','','','','2',NULL,'The type of the network interface.','0','30d','0','','36580','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36604','18','','10299','Network interfaces discovery','net.if.discovery','0','90d','0','0','4','','','','','36603',NULL,'','','0','','','','','1',NULL,'Discovery of installed network interfaces.','0','30d','1','','36602','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36620','18','','10299','Interface {#IFNAME}({#IFALIAS}): Speed','net.if.speed["{#IFGUID}"]','0','7d','0d','0','3','','bps','','','36617',NULL,'','','0','','','','','2',NULL,'Estimated bandwidth of the network interface if any.','0','30d','0','','36602','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36621','18','','10299','Interface {#IFNAME}({#IFALIAS}): Operational status','net.if.status["{#IFGUID}"]','0','7d','0','0','3','','','','','36618','81','','','0','','','','','2',NULL,'The operational status of the network interface.','0','30d','0','','36602','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('36622','18','','10299','Interface {#IFNAME}({#IFALIAS}): Interface type','net.if.type["{#IFGUID}"]','0','7d','0d','0','3','','','','','36619','79','','','0','','','','','2',NULL,'The type of the network interface.','0','30d','0','','36602','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23287','0','','10084','Zabbix agent ping','agent.ping','1m','7d','365d','0','3','','','','','10020','10','','','0','','','','','0','1','The agent always returns 1 for this item. It could be used in combination with nodata() for availability check.','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23288','0','','10084','Version of Zabbix agent running','agent.version','1h','7d','0','0','1','','','','','10059',NULL,'','','0','','','','','0','1','','0','0','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('23327','0','','10084','Host name of Zabbix agent running','agent.hostname','1h','7d','0','0','1','','','','','23319',NULL,'','','0','','','','','0','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27192','3','','10207','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27193','3','','10207','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27194','3','','10207','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27225','3','','10208','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27226','3','','10208','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27227','3','','10208','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27261','3','','10210','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27262','3','','10210','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27263','3','','10210','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27282','3','','10211','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27283','3','','10211','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27284','3','','10211','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27333','3','','10218','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27334','3','','10218','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27335','3','','10218','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27365','3','','10220','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27366','3','','10220','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27367','3','','10220','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27462','3','','10221','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27463','3','','10221','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27464','3','','10221','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27496','3','','10222','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27497','3','','10222','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27498','3','','10222','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27532','3','','10223','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27533','3','','10223','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27534','3','','10223','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27568','3','','10224','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27569','3','','10224','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27570','3','','10224','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27631','3','','10226','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27632','3','','10226','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27633','3','','10226','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27654','3','','10227','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27655','3','','10227','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27656','3','','10227','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27734','3','','10229','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27735','3','','10229','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27736','3','','10229','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27766','3','','10230','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27767','3','','10230','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27768','3','','10230','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27800','3','','10231','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27801','3','','10231','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27802','3','','10231','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27882','3','','10233','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27883','3','','10233','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27884','3','','10233','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27919','3','','10234','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27920','3','','10234','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27921','3','','10234','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27956','3','','10235','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27957','3','','10235','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27958','3','','10235','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27986','3','','10236','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27987','3','','10236','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('27988','3','','10236','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28015','3','','10237','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28016','3','','10237','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28017','3','','10237','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28130','3','','10250','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28131','3','','10250','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28132','3','','10250','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28233','3','','10253','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28234','3','','10253','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28235','3','','10253','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28282','3','','10254','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28283','3','','10254','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28284','3','','10254','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28330','3','','10255','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28331','3','','10255','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28332','3','','10255','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28377','3','','10256','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28378','3','','10256','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28379','3','','10256','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28454','3','','10258','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28455','3','','10258','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28456','3','','10258','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28482','3','','10259','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28483','3','','10259','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28484','3','','10259','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28957','3','','10248','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28958','3','','10248','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('28959','3','','10248','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29050','3','','10249','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29051','3','','10249','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29052','3','','10249','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29161','0','','10084','Number of CPUs','system.cpu.num','1m','7d','365d','0','3','','','','','29124',NULL,'','','0','','','','','0','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29162','0','','10084','CPU iowait time','system.cpu.util[,iowait]','1m','7d','365d','0','0','','%','','','29125',NULL,'','','0','','','','','0','1','Amount of time the CPU has been waiting for I/O to complete.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29163','0','','10084','Context switches per second','system.cpu.switches','1m','7d','365d','0','0','','','','','29126',NULL,'','','0','','','','','0','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29164','0','','10084','CPU guest nice time','system.cpu.util[,guest_nice]','1m','7d','365d','0','0','','%','','','29127',NULL,'','','0','','','','','0','1','Time spent running a niced guest (virtual CPU for guest operating systems under the control of the Linux kernel)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29165','0','','10084','CPU guest time','system.cpu.util[,guest]','1m','7d','365d','0','0','','%','','','29128',NULL,'','','0','','','','','0','1','Guest  time (time  spent  running  a  virtual  CPU  for  a  guest  operating  system)','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29166','0','','10084','CPU softirq time','system.cpu.util[,softirq]','1m','7d','365d','0','0','','%','','','29129',NULL,'','','0','','','','','0','1','The amount of time the CPU has been servicing software interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29167','0','','10084','CPU interrupt time','system.cpu.util[,interrupt]','1m','7d','365d','0','0','','%','','','29130',NULL,'','','0','','','','','0','1','The amount of time the CPU has been servicing hardware interrupts.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29168','0','','10084','CPU steal time','system.cpu.util[,steal]','1m','7d','365d','0','0','','%','','','29131',NULL,'','','0','','','','','0','1','The amount of CPU ''stolen'' from this virtual machine by the hypervisor for other tasks (such as running another virtual machine).','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29169','0','','10084','CPU nice time','system.cpu.util[,nice]','1m','7d','365d','0','0','','%','','','29132',NULL,'','','0','','','','','0','1','The time the CPU has spent running users'' processes that have been niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29170','0','','10084','Load average (1m avg)','system.cpu.load[all,avg1]','1m','7d','365d','0','0','','','','','29133',NULL,'','','0','','','','','0','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29171','0','','10084','CPU user time','system.cpu.util[,user]','1m','7d','365d','0','0','','%','','','29134',NULL,'','','0','','','','','0','1','The time the CPU has spent running users'' processes that are not niced.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29172','0','','10084','CPU system time','system.cpu.util[,system]','1m','7d','365d','0','0','','%','','','29135',NULL,'','','0','','','','','0','1','The time the CPU has spent running the kernel and its processes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29173','0','','10084','CPU idle time','system.cpu.util[,idle]','1m','7d','365d','0','0','','%','','','29136',NULL,'','','0','','','','','0','1','The time the CPU has spent doing nothing.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29174','0','','10084','Load average (15m avg)','system.cpu.load[all,avg15]','1m','7d','365d','0','0','','','','','29137',NULL,'','','0','','','','','0','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29175','0','','10084','Load average (5m avg)','system.cpu.load[all,avg5]','1m','7d','365d','0','0','','','','','29138',NULL,'','','0','','','','','0','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29176','0','','10084','Interrupts per second','system.cpu.intr','1m','7d','365d','0','0','','','','','29139',NULL,'','','0','','','','','0','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29177','0','','10084','Available memory in %','vm.memory.size[pavailable]','1m','7d','365d','0','0','','%','','','29140',NULL,'','','0','','','','','0','1','Available memory as percentage of total. See also: https://www.zabbix.com/documentation/5.0/manual/appendix/items/vm.memory.size_params','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29178','0','','10084','Total memory','vm.memory.size[total]','1m','7d','365d','0','3','','B','','','29141',NULL,'','','0','','','','','0','1','Total memory in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29179','0','','10084','Available memory','vm.memory.size[available]','1m','7d','365d','0','3','','B','','','29142',NULL,'','','0','','','','','0','1','Available memory, in Linux, available = free + buffers + cache. On other platforms calculation may vary. See also: https://www.zabbix.com/documentation/5.0/manual/appendix/items/vm.memory.size_params','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29180','0','','10084','Total swap space','system.swap.size[,total]','1m','7d','365d','0','3','','B','','','29143',NULL,'','','0','','','','','0','1','The total space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29181','0','','10084','Free swap space','system.swap.size[,free]','1m','7d','365d','0','3','','B','','','29144',NULL,'','','0','','','','','0','1','The free space of swap volume/file in bytes.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29182','0','','10084','Free swap space in %','system.swap.size[,pfree]','1m','7d','365d','0','0','','%','','','29145',NULL,'','','0','','','','','0','1','The free space of swap volume/file in percent.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29184','0','','10084','System uptime','system.uptime','30s','2w','0d','0','3','','uptime','','','29147',NULL,'','','0','','','','','0','1','System uptime in ''N days, hh:mm:ss'' format.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29185','0','','10084','System boot time','system.boottime','15m','7d','365d','0','3','','unixtime','','','29148',NULL,'','','0','','','','','0','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29186','0','','10084','System local time','system.localtime','1m','7d','365d','0','3','','unixtime','','','29149',NULL,'','','0','','','','','0','1','System local time of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29187','0','','10084','System name','system.hostname','1h','2w','0','0','1','','','','','29150',NULL,'','','0','','','','','0','1','System host name.','3','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29188','0','','10084','System description','system.uname','1h','2w','0','0','1','','','','','29151',NULL,'','','0','','','','','0','1','The information as normally returned by ''uname -a''.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29189','0','','10084','Number of logged in users','system.users.num','1m','7d','365d','0','3','','','','','29152',NULL,'','','0','','','','','0','1','Number of users who are currently logged in.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29190','0','','10084','Maximum number of open file descriptors','kernel.maxfiles','1h','7d','365d','0','3','','','','','29153',NULL,'','','0','','','','','0','1','It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29191','0','','10084','Maximum number of processes','kernel.maxproc','1h','7d','365d','0','3','','','','','29154',NULL,'','','0','','','','','0','1','It could be increased by using sysctrl utility or modifying file /etc/sysctl.conf.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29192','0','','10084','Number of processes','proc.num','1m','7d','365d','0','3','','','','','29155',NULL,'','','0','','','','','0','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29193','0','','10084','Number of running processes','proc.num[,,run]','1m','7d','365d','0','3','','','','','29156',NULL,'','','0','','','','','0','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29194','0','','10084','Checksum of /etc/passwd','vfs.file.cksum[/etc/passwd]','15m','7d','0','0','1','','','','','29157',NULL,'','','0','','','','','0','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29195','0','','10084','Operating system','system.sw.os','1h','2w','0','0','1','','','','','29158',NULL,'','','0','','','','','0','1','','5','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29196','0','','10084','Operating system architecture','system.sw.arch','1h','2w','0','0','1','','','','','29159',NULL,'','','0','','','','','0','1','Operating system architecture of the host.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29197','0','','10084','Software installed','system.sw.packages','1h','2w','0','0','4','','','','','29160',NULL,'','','0','','','','','0','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29207','0','','10084','Mounted filesystem discovery','vfs.fs.discovery','1h','90d','0','0','4','','','','','29204',NULL,'','','0','','','','','1','1','Discovery of file systems of different types.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29209','0','','10084','Network interface discovery','net.if.discovery','1h','90d','0','0','4','','','','','29206',NULL,'','','0','','','','','1','1','Discovery of network interfaces.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29238','0','','10084','{#FSNAME}: Used space','vfs.fs.size[{#FSNAME},used]','1m','7d','365d','0','3','','B','','','29224',NULL,'','','0','','','','','2','1','Used storage in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29239','0','','10084','{#FSNAME}: Total space','vfs.fs.size[{#FSNAME},total]','1m','7d','365d','0','3','','B','','','29225',NULL,'','','0','','','','','2','1','Total space in Bytes','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29240','0','','10084','{#FSNAME}: Space utilization','vfs.fs.size[{#FSNAME},pused]','1m','7d','365d','0','0','','%','','','29226',NULL,'','','0','','','','','2','1','Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29241','0','','10084','{#FSNAME}: Free inodes in %','vfs.fs.inode[{#FSNAME},pfree]','1m','7d','365d','0','0','','%','','','29227',NULL,'','','0','','','','','2','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29244','0','','10084','Interface {#IFNAME}: Bits received','net.if.in["{#IFNAME}"]','3m','7d','365d','0','3','','bps','','','29230',NULL,'','','0','','','','','2','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29245','0','','10084','Interface {#IFNAME}: Bits sent','net.if.out["{#IFNAME}"]','3m','7d','365d','0','3','','bps','','','29231',NULL,'','','0','','','','','2','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29246','0','','10084','Interface {#IFNAME}: Outbound packets with errors','net.if.out["{#IFNAME}",errors]','3m','7d','365d','0','3','','','','','29232',NULL,'','','0','','','','','2','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29247','0','','10084','Interface {#IFNAME}: Inbound packets with errors','net.if.in["{#IFNAME}",errors]','3m','7d','365d','0','3','','','','','29233',NULL,'','','0','','','','','2','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29248','0','','10084','Interface {#IFNAME}: Outbound packets discarded','net.if.out["{#IFNAME}",dropped]','3m','7d','365d','0','3','','','','','29234',NULL,'','','0','','','','','2','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29249','0','','10084','Interface {#IFNAME}: Inbound packets discarded','net.if.in["{#IFNAME}",dropped]','3m','7d','365d','0','3','','','','','29235',NULL,'','','0','','','','','2','1','','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29250','0','','10084','Interface {#IFNAME}: Operational status','vfs.file.contents["/sys/class/net/{#IFNAME}/operstate"]','1m','7d','0','0','3','','','','','29236','20','','','0','','','','','2','1','Indicates the interface RFC2863 operational state as a string.
Possible values are:"unknown", "notpresent", "down", "lowerlayerdown", "testing","dormant", "up".
Reference: https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-class-net','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29251','0','','10084','Interface {#IFNAME}: Interface type','vfs.file.contents["/sys/class/net/{#IFNAME}/type"]','1h','7d','0d','0','3','','','','','29237','78','','','0','','','','','2','1','Indicates the interface protocol type as a decimal value.
See include/uapi/linux/if_arp.h for all possible values.
Reference: https://www.kernel.org/doc/Documentation/ABI/testing/sysfs-class-net','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29557','5','','10084','Zabbix agent availability','zabbix[host,agent,available]','1m','7d','365d','0','3','','','','','29548','22','','','0','','','','','0',NULL,'Monitoring agent availability status','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30046','3','','10304','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30047','3','','10304','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30048','3','','10304','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30145','20','discovery[{#CPU.UTIL},1.3.6.1.2.1.25.3.3.1.2]','10249','CPU utilization','system.cpu.util','1m','7d','365d','0','0','','%','','','30143',NULL,'','','0','','','','','0',NULL,'MIB: HOST-RESOURCES-MIB
The average, over the last minute, of the percentage of time that processors was not idle.
Implementations may approximate this one minute smoothing period if necessary.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30146','20','discovery[{#CPU.UTIL},1.3.6.1.2.1.25.3.3.1.2]','10254','CPU utilization','system.cpu.util','1m','7d','365d','0','0','','%','','','30143',NULL,'','','0','','','','','0',NULL,'MIB: HOST-RESOURCES-MIB
The average, over the last minute, of the percentage of time that processors was not idle.
Implementations may approximate this one minute smoothing period if necessary.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30153','20','discovery[{#MEMNAME},1.3.6.1.2.1.25.2.3.1.3,{#MEMTYPE},1.3.6.1.2.1.25.2.3.1.2,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4]','10249','Memory discovery','vm.memory.discovery','1h','90d','0','0','4','','','','','30149',NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with memory filter','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30154','20','discovery[{#FSNAME},1.3.6.1.2.1.25.2.3.1.3,{#FSTYPE},1.3.6.1.2.1.25.2.3.1.2,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4]','10249','Storage discovery','vfs.fs.discovery[snmp]','1h','90d','0','0','4','','','','','30150',NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with storage filter.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30155','20','discovery[{#MEMNAME},1.3.6.1.2.1.25.2.3.1.3,{#MEMTYPE},1.3.6.1.2.1.25.2.3.1.2,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4]','10254','Memory discovery','vm.memory.discovery','1h','90d','0','0','4','','','','','30149',NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with memory filter','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30156','20','discovery[{#FSNAME},1.3.6.1.2.1.25.2.3.1.3,{#FSTYPE},1.3.6.1.2.1.25.2.3.1.2,{#ALLOC_UNITS},1.3.6.1.2.1.25.2.3.1.4]','10254','Storage discovery','vfs.fs.discovery[snmp]','1h','90d','0','0','4','','','','','30150',NULL,'','','0','','','','','1',NULL,'HOST-RESOURCES-MIB::hrStorage discovery with storage filter.','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30175','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10249','{#MEMNAME}: Total memory','vm.memory.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','30163',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in units of hrStorageAllocationUnits.
This object is writable to allow remote configuration of the size of the storage area in those cases where such an operation makes sense and is possible on the underlying system.
For example, the amount of main memory allocated to a buffer pool might be modified or the amount of disk space allocated to virtual memory might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30176','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10249','{#MEMNAME}: Used memory','vm.memory.used[hrStorageUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','30164',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30177','15','','10249','{#MEMNAME}: Memory utilization','vm.memory.util[memoryUsedPercentage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','30165',NULL,'last("vm.memory.used[hrStorageUsed.{#SNMPINDEX}]")/last("vm.memory.total[hrStorageSize.{#SNMPINDEX}]")*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30178','15','','10249','{#FSNAME}: Space utilization','vfs.fs.pused[storageUsedPercentage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','30166',NULL,'(last("vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]")/last("vfs.fs.total[hrStorageSize.{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30179','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10249','{#FSNAME}: Total space','vfs.fs.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','30167',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in units of hrStorageAllocationUnits.
This object is writable to allow remote configuration of the size of the storage area in those cases where such an operation makes sense and is possible on the underlying system.
For example, the amount of main storage allocated to a buffer pool might be modified or the amount of disk space allocated to virtual storage might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30180','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10249','{#FSNAME}: Used space','vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','30168',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30181','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10254','{#MEMNAME}: Total memory','vm.memory.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','30163',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in units of hrStorageAllocationUnits.
This object is writable to allow remote configuration of the size of the storage area in those cases where such an operation makes sense and is possible on the underlying system.
For example, the amount of main memory allocated to a buffer pool might be modified or the amount of disk space allocated to virtual memory might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30182','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10254','{#MEMNAME}: Used memory','vm.memory.used[hrStorageUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','30164',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30183','15','','10254','{#MEMNAME}: Memory utilization','vm.memory.util[memoryUsedPercentage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','30165',NULL,'last("vm.memory.used[hrStorageUsed.{#SNMPINDEX}]")/last("vm.memory.total[hrStorageSize.{#SNMPINDEX}]")*100','','0','','','','','2',NULL,'Memory utilization in %','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30184','15','','10254','{#FSNAME}: Space utilization','vfs.fs.pused[storageUsedPercentage.{#SNMPINDEX}]','1m','7d','365d','0','0','','%','','','30166',NULL,'(last("vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]")/last("vfs.fs.total[hrStorageSize.{#SNMPINDEX}]"))*100','','0','','','','','2',NULL,'Space utilization in % for {#FSNAME}','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30185','20','1.3.6.1.2.1.25.2.3.1.5.{#SNMPINDEX}','10254','{#FSNAME}: Total space','vfs.fs.total[hrStorageSize.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','30167',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The size of the storage represented by this entry, in units of hrStorageAllocationUnits.
This object is writable to allow remote configuration of the size of the storage area in those cases where such an operation makes sense and is possible on the underlying system.
For example, the amount of main storage allocated to a buffer pool might be modified or the amount of disk space allocated to virtual storage might be modified.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('30186','20','1.3.6.1.2.1.25.2.3.1.6.{#SNMPINDEX}','10254','{#FSNAME}: Used space','vfs.fs.used[hrStorageUsed.{#SNMPINDEX}]','1m','7d','365d','0','3','','B','','','30168',NULL,'','','0','','','','','2',NULL,'MIB: HOST-RESOURCES-MIB
The amount of the storage represented by this entry that is allocated, in units of hrStorageAllocationUnits.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31275','0','','10084','Block devices discovery','vfs.dev.discovery','1h','90d','0','0','4','','','','','31274',NULL,'','','0','','','','','1','1','','0','30d','1','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31282','15','','10084','{#DEVNAME}: Disk read request avg waiting time (r_await)','vfs.dev.read.await[{#DEVNAME}]','1m','7d','365d','0','0','','!ms','','','31279',NULL,'(last("vfs.dev.read.time.rate[{#DEVNAME}]")/(last("vfs.dev.read.rate[{#DEVNAME}]")+(last("vfs.dev.read.rate[{#DEVNAME}]")=0)))*1000*(last("vfs.dev.read.rate[{#DEVNAME}]") > 0)','','0','','','','','2',NULL,'This formula contains two boolean expressions that evaluates to 1 or 0 in order to set calculated metric to zero and to avoid division by zero exception.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31283','15','','10084','{#DEVNAME}: Disk write request avg waiting time (w_await)','vfs.dev.write.await[{#DEVNAME}]','1m','7d','365d','0','0','','!ms','','','31280',NULL,'(last("vfs.dev.write.time.rate[{#DEVNAME}]")/(last("vfs.dev.write.rate[{#DEVNAME}]")+(last("vfs.dev.write.rate[{#DEVNAME}]")=0)))*1000*(last("vfs.dev.write.rate[{#DEVNAME}]") > 0)','','0','','','','','2',NULL,'This formula contains two boolean expressions that evaluates to 1 or 0 in order to set calculated metric to zero and to avoid division by zero exception.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31284','0','','10084','{#DEVNAME}: Get stats','vfs.file.contents[/sys/block/{#DEVNAME}/stat]','1m','0','0','0','4','','','','','31281',NULL,'','','0','','','','','2','1','Get contents of /sys/block/{#DEVNAME}/stat for disk stats.','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32601','3','','10353','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32602','3','','10353','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32603','3','','10353','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32765','3','','10357','ICMP ping','icmpping','1m','1w','365d','0','3','','','','','27149','1','','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32766','3','','10357','ICMP loss','icmppingloss','1m','1w','365d','0','0','','%','','','27150',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('32767','3','','10357','ICMP response time','icmppingsec','1m','1w','365d','0','0','','s','','','27151',NULL,'','','0','','','','','0',NULL,'','0','30d','0','',NULL,'3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('29200','18','','10084','CPU utilization','system.cpu.util','0','7d','365d','0','0','','%','','','29199',NULL,'','','0','','','','','0',NULL,'CPU utilization in %','0','30d','0','','29173','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31272','18','','10084','Memory utilization','vm.memory.utilization','0','7d','365d','0','0','','%','','','31271',NULL,'','','0','','','','','0',NULL,'Memory used percentage is calculated as (100-pavailable)','0','30d','0','','29177','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31297','18','','10084','{#DEVNAME}: Disk average queue size (avgqu-sz)','vfs.dev.queue_size[{#DEVNAME}]','0','7d','365d','0','0','','','','','31291',NULL,'','','0','','','','','2',NULL,'Current average disk queue, the number of requests outstanding on the disk at the time the performance data is collected.','0','30d','0','','31284','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31298','18','','10084','{#DEVNAME}: Disk read rate','vfs.dev.read.rate[{#DEVNAME}]','0','7d','365d','0','0','','!r/s','','','31292',NULL,'','','0','','','','','2',NULL,'r/s. The number (after merges) of read requests completed per second for the device.','0','30d','0','','31284','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31299','18','','10084','{#DEVNAME}: Disk read time (rate)','vfs.dev.read.time.rate[{#DEVNAME}]','0','7d','365d','0','0','','','','','31293',NULL,'','','0','','','','','2',NULL,'Rate of total read time counter. Used in r_await calculation','0','30d','0','','31284','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31300','18','','10084','{#DEVNAME}: Disk utilization','vfs.dev.util[{#DEVNAME}]','0','7d','365d','0','0','','%','','','31294',NULL,'','','0','','','','','2',NULL,'This item is the percentage of elapsed time that the selected disk drive was busy servicing read or writes requests.','0','30d','0','','31284','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31301','18','','10084','{#DEVNAME}: Disk write rate','vfs.dev.write.rate[{#DEVNAME}]','0','7d','365d','0','0','','!w/s','','','31295',NULL,'','','0','','','','','2',NULL,'w/s. The number (after merges) of write requests completed per second for the device.','0','30d','0','','31284','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO items (itemid,type,snmp_oid,hostid,name,key_,delay,history,trends,status,value_type,trapper_hosts,units,formula,logtimefmt,templateid,valuemapid,params,ipmi_sensor,authtype,username,password,publickey,privatekey,flags,interfaceid,description,inventory_link,lifetime,evaltype,jmx_endpoint,master_itemid,timeout,url,query_fields,posts,status_codes,follow_redirects,post_type,headers,retrieve_mode,request_method,output_format,verify_peer,verify_host,allow_traps,discover) values ('31302','18','','10084','{#DEVNAME}: Disk write time (rate)','vfs.dev.write.time.rate[{#DEVNAME}]','0','7d','365d','0','0','','','','','31296',NULL,'','','0','','','','','2',NULL,'Rate of total write time counter. Used in w_await calculation','0','30d','0','','31284','3s','','','','200','1','0','','0','0','0','0','0','0','0');
INSERT INTO optemplate (optemplateid,operationid,templateid) values ('1','1','10001');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13285','{13159}=0','Telnet service is down on {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13332','{13089}>30','Too many processes running on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13333','{13088}>300','Too many processes on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13334','{13087}>5','Processor load is too high on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13336','{12723}>0','Hostname was changed on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13338','{12725}>0','Host information was changed on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13339','{12726}<0','{HOST.NAME} has just been restarted','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13340','{12727}>0','/etc/passwd has been changed on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13348','{13074}>30','Too many processes running on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13349','{13073}>300','Too many processes on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13350','{13072}>5','Processor load is too high on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13352','{12739}>0','Hostname was changed on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13354','{12741}>0','Host information was changed on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13355','{12742}<0','{HOST.NAME} has just been restarted','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13356','{12743}>0','/etc/passwd has been changed on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13364','{13071}>30','Too many processes running on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13365','{13070}>300','Too many processes on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13366','{13069}>5','Processor load is too high on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13367','{13068}>20','Disk I/O is overloaded on {HOST.NAME}','','0','2','OS spends significant time waiting for I/O (input/output) operations. It could be indicator of performance issues with storage system.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13368','{12755}>0','Hostname was changed on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13370','{12757}>0','Host information was changed on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13371','{12758}<0','{HOST.NAME} has just been restarted','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13372','{12759}>0','/etc/passwd has been changed on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13382','{13075}>5','Processor load is too high on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13384','{12771}>0','Hostname was changed on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13386','{12773}>0','Host information was changed on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13388','{12775}>0','/etc/passwd has been changed on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13396','{13093}>30','Too many processes running on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13397','{13092}>300','Too many processes on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13398','{13091}>5','Processor load is too high on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13399','{13090}>20','Disk I/O is overloaded on {HOST.NAME}','','0','2','OS spends significant time waiting for I/O (input/output) operations. It could be indicator of performance issues with storage system.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13400','{12787}>0','Hostname was changed on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13402','{12789}>0','Host information was changed on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13403','{12790}<0','{HOST.NAME} has just been restarted','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13404','{12791}>0','/etc/passwd has been changed on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13414','{13086}>5','Processor load is too high on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13416','{12803}>0','Hostname was changed on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13418','{12805}>0','Host information was changed on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13419','{12806}<0','{HOST.NAME} has just been restarted','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13420','{12807}>0','/etc/passwd has been changed on {HOST.NAME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13517','{12946}>75','More than 75% used in the configuration cache','','0','3','Consider increasing CacheSize in the zabbix_proxy.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13518','{12947}>75','More than 75% used in the history cache','','0','3','Consider increasing HistoryCacheSize in the zabbix_proxy.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13519','{12948}>75','More than 75% used in the history index cache','','0','3','Consider increasing HistoryIndexCacheSize in the zabbix_proxy.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13520','{12949}>100','More than 100 items having missing data for more than 10 minutes','','0','2','zabbix[queue,10m] item is collecting data about how many items are missing data for more than 10 minutes',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13521','{13206}>75','Zabbix configuration syncer processes more than 75% busy','','0','3','',NULL,'0','0','1','{13206}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13522','{13208}>75','Zabbix discoverer processes more than 75% busy','','0','3','',NULL,'0','0','1','{13208}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13523','{13210}>75','Zabbix history syncer processes more than 75% busy','','0','3','',NULL,'0','0','1','{13210}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13524','{13211}>75','Zabbix housekeeper processes more than 75% busy','','0','3','',NULL,'0','0','1','{13211}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13525','{13212}>75','Zabbix http poller processes more than 75% busy','','0','3','',NULL,'0','0','1','{13212}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13526','{13213}>75','Zabbix icmp pinger processes more than 75% busy','','0','3','',NULL,'0','0','1','{13213}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13527','{13214}>75','Zabbix ipmi poller processes more than 75% busy','','0','3','',NULL,'0','0','1','{13214}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13528','{13215}>75','Zabbix java poller processes more than 75% busy','','0','3','',NULL,'0','0','1','{13215}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13529','{13216}>75','Zabbix poller processes more than 75% busy','','0','3','',NULL,'0','0','1','{13216}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13530','{13217}>75','Zabbix self-monitoring processes more than 75% busy','','0','3','',NULL,'0','0','1','{13217}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13531','{13218}>75','Zabbix snmp trapper processes more than 75% busy','','0','3','',NULL,'0','0','1','{13218}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13532','{13219}>75','Zabbix trapper processes more than 75% busy','','0','3','',NULL,'0','0','1','{13219}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13533','{13220}>75','Zabbix unreachable poller processes more than 75% busy','','0','3','',NULL,'0','0','1','{13220}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13534','{13207}>75','Zabbix data sender processes more than 75% busy','','0','3','',NULL,'0','0','1','{13207}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13535','{13209}>75','Zabbix heartbeat sender processes more than 75% busy','','0','3','',NULL,'0','0','1','{13209}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13544','{12994}=0','FTP service is down on {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13545','{12995}=0','HTTP service is down on {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13546','{12996}=0','HTTPS service is down on {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13547','{12997}=0','IMAP service is down on {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13548','{12998}=0','LDAP service is down on {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13549','{13154}=0','NNTP service is down on {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13550','{13156}=0','NTP service is down on {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13551','{13152}=0','POP service is down on {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13552','{13157}=0','SMTP service is down on {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13553','{13158}=0','SSH service is down on {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13564','{13224}>75','Zabbix ipmi manager processes more than 75% busy','','0','3','',NULL,'0','0','1','{13224}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('13565','{13225}>75','Zabbix task manager processes more than 75% busy','','0','3','',NULL,'0','0','1','{13225}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14251','{14378}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14252','{14379}>{$ICMP_LOSS_WARN} and {14379}<100','High ICMP ping loss','','0','2','',NULL,'0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14253','{14380}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','',NULL,'0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14318','{14515}>{$TEMP_WARN:""}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14516}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14319','{14517}>{$TEMP_CRIT:""}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14518}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14320','{14519}<{$TEMP_CRIT_LOW:""}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{14520}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14322','{14522}=1 and {14523}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14336','{14545}=1 and {14546}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14337','{14547}=1 and {14548}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14339','{14552}>{$TEMP_CRIT:""}','{#SENSOR_INFO}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14553}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14340','{14554}<{$TEMP_CRIT_LOW:""}','{#SENSOR_INFO}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{14555}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14363','{14594}=1 and {14595}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14364','{14596}=1 and {14597}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14365','{14598}=1 and {14599}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14372','{14606}>{$TEMP_WARN:""}','{#SENSOR_DESCR}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14607}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14373','{14608}>{$TEMP_CRIT:""}','{#SENSOR_DESCR}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14609}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14374','{14610}<{$TEMP_CRIT_LOW:""}','{#SENSOR_DESCR}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{14611}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14380','{14620}>{$TEMP_WARN:""}','{#SENSOR_DESCR}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14621}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14381','{14622}>{$TEMP_CRIT:""}','{#SENSOR_DESCR}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14623}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14382','{14624}<{$TEMP_CRIT_LOW:""}','{#SENSOR_DESCR}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{14625}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14383','{14626}=1 and {14627}>0','Unit {#SNMPVALUE}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14409','{14669}=1 and {14670}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14417','{14681}=1 and {14682}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14460','{14756}>{$TEMP_WARN:""}','Device {#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14757}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14461','{14758}>{$TEMP_CRIT:""}','Device {#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14759}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14462','{14760}<{$TEMP_CRIT_LOW:""}','Device {#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{14761}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14463','{14762}=1 and {14763}>0','#{#SNMPVALUE}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14474','{14782}=1 and {14783}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14476','{14785}>{$TEMP_WARN:""}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14786}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14477','{14787}>{$TEMP_CRIT:""}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14788}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14478','{14789}<{$TEMP_CRIT_LOW:""}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{14790}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14492','{14812}=1 and {14813}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14493','{14814}=1 and {14815}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14495','{14817}>{$TEMP_WARN:""}','#{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14818}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14496','{14819}>{$TEMP_CRIT:""}','#{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14820}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14497','{14821}<{$TEMP_CRIT_LOW:""}','#{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{14822}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14511','{14844}>{$TEMP_WARN:""}','Device: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','0','1','{14845}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14513','{14849}<{$TEMP_CRIT_LOW:""}','Device: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','0','1','{14850}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14514','{14851}=1 and {14852}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14515','{14853}=1 and {14854}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14551','{14914}>{$TEMP_WARN:""}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14915}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14552','{14916}>{$TEMP_CRIT:""}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14917}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14553','{14918}<{$TEMP_CRIT_LOW:""}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{14919}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14556','{14922}=1 and {14923}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14557','{14924}=1 and {14925}>0','{#ENT_NAME}: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14589','{14979}>{$TEMP_WARN:""}','{#ENT_NAME}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14980}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14590','{14981}>{$TEMP_CRIT:""}','{#ENT_NAME}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{14982}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14591','{14983}<{$TEMP_CRIT_LOW:""}','{#ENT_NAME}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{14984}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14592','{14985}=1 and {14986}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14603','{15005}=1 and {15006}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14606','{15013}<{$TEMP_CRIT_LOW:""}','{#SENSOR_INFO}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{15014}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14607','{15015}=1 and {15016}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14621','{15038}=1 and {15039}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14624','{15042}>{$TEMP_WARN:""}','{#SENSOR_INFO}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{15043}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14625','{15044}>{$TEMP_CRIT:""}','{#SENSOR_INFO}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{15045}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14626','{15046}<{$TEMP_CRIT_LOW:""}','{#SENSOR_INFO}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{15047}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14661','{15106}=1 and {15107}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14662','{15108}=1 and {15109}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14664','{15111}>{$TEMP_WARN:"CPU"}','CPU: Temperature is above warning threshold: >{$TEMP_WARN:"CPU"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{15112}<{$TEMP_WARN:"CPU"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14665','{15113}>{$TEMP_CRIT:"CPU"}','CPU: Temperature is above critical threshold: >{$TEMP_CRIT:"CPU"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{15114}<{$TEMP_CRIT:"CPU"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14666','{15115}<{$TEMP_CRIT_LOW:"CPU"}','CPU: Temperature is too low: <{$TEMP_CRIT_LOW:"CPU"}','','0','3','',NULL,'0','2','1','{15116}>{$TEMP_CRIT_LOW:"CPU"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14680','{15138}=1 and {15139}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14683','{15146}<{$TEMP_CRIT_LOW:""}','#{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{15147}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14698','{15170}=1 and {15171}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14699','{15172}=1 and {15173}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14709','{15191}=1 and {15192}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14710','{15193}=1 and {15194}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14724','{15216}=1 and {15217}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14912','{15684}=1 and {15685}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14913','{15686}=1 and {15687}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14914','{15688}>{$TEMP_WARN:""}','{#SENSOR_INFO}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{15689}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14915','{15690}>{$TEMP_CRIT:""}','{#SENSOR_INFO}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{15691}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14916','{15692}<{$TEMP_CRIT_LOW:""}','{#SENSOR_INFO}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{15693}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14937','{15726}=1 and {15727}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14941','{15731}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15330','{16818}=1','#{#SNMPINDEX}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15331','{16819}=1','PSU {#SNMPVALUE}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15332','{16820}=1','PSU {#SNMPVALUE}: Power supply is not in normal state','','0','1','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15333','{16821}=1','Fan {#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15334','{16822}=1','Fan {#SNMPVALUE}: Fan is not in normal state','','0','1','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15337','{16829}=1','{#SNMPVALUE}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15338','{16830}=1','{#SNMPVALUE}: Power supply is in warning state','','0','2','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15339','{16831}=1','{#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15340','{16832}=1','#{#SNMPVALUE}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15341','{16833}=1','#{#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15344','{16840}=1 or {16841}=1','{#SENSOR_INFO}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15345','{16842}=1 or {16843}=1','{#SENSOR_INFO}: Power supply is in warning state','','0','2','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15346','{16844}=1 or {16845}=1','{#SENSOR_INFO}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15347','{16846}=1 or {16847}=1','{#SENSOR_INFO}: Fan is in warning state','','0','2','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15366','{16890}=1','{#SNMPVALUE}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15367','{16891}=1','{#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15369','{16895}=1','PSU {#SNMPVALUE}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15370','{16896}=1','Fan {#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15371','{16897}=1 or {16898}=1','{#ENT_NAME}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15372','{16899}=1 or {16900}=1 or {16901}=1','{#ENT_NAME}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15373','{16902}=1','{#ENT_DESCR}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15374','{16903}=1','{#ENT_DESCR}: Fan is in warning state','','0','2','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15375','{16904}=1','{#ENT_DESCR}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15376','{16905}=1','{#ENT_DESCR}: Power supply is in warning state','','0','2','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15377','{16906}=1','{#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15378','{16907}=1','{#SNMPVALUE}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15379','{16908}=1','PSU {#PSU_INDEX}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15380','{16909}=1','PSU {#PSU_INDEX}: Power supply is not in normal state','','0','1','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15381','{16910}=1','Fan {#FAN_INDEX}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15382','{16911}=1','Fan {#FAN_INDEX}: Fan is not in normal state','','0','1','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15383','{16912}=1','Unit {#PSU_UNIT} PSU {#PSU_INDEX}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15384','{16913}=1','Unit {#PSU_UNIT} PSU {#PSU_INDEX}: Power supply is not in normal state','','0','1','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15385','{16914}=1','Unit {#FAN_UNIT} Fan {#FAN_INDEX}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15386','{16915}=1','Unit {#FAN_UNIT} Fan {#FAN_INDEX}: Fan is not in normal state','','0','1','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15391','{16924}=1','{#SENSOR_INFO}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15392','{16925}=1','{#SENSOR_INFO}: Power supply is not in normal state','','0','1','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15393','{16926}=1','{#SENSOR_INFO}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15394','{16927}=1','{#SENSOR_INFO}: Fan is not in normal state','','0','1','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15395','{16928}=1','#{#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15398','{16935}=1','#{#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15399','{16936}=1','#{#SNMPVALUE}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15493','{$IFCONTROL:"{#IFNAME}"}=1 and ({17243}=2 and {17244}=1)','Interface {#IFDESCR}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{17243}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15640','{17657}>75','More than 75% used in the vmware cache','','0','3','Consider increasing VMwareCacheSize in the zabbix_proxy.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15641','{17658}>75','Zabbix vmware collector processes more than 75% busy','','0','3','',NULL,'0','0','1','{17658}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15671','{17692}<0 and {17693}>0
and (
{17694}=6 or
{17694}=7 or
{17694}=11 or
{17694}=62 or
{17694}=69 or
{17694}=117
)
and
({17695}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({17692}>0 and {17696}>0) or
({17695}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15695','{17812}<0 and {17813}>0
and (
{17814}=6 or
{17814}=7 or
{17814}=11 or
{17814}=62 or
{17814}=69 or
{17814}=117
)
and
({17815}<>2)','Interface {#IFDESCR}: Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({17812}>0 and {17816}>0) or
({17815}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15698','{17827}<0 and {17828}>0
and (
{17829}=6 or
{17829}=7 or
{17829}=11 or
{17829}=62 or
{17829}=69 or
{17829}=117
)
and
({17830}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({17827}>0 and {17831}>0) or
({17830}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15717','{17866}=1','{#SENSOR_INFO}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15718','{17867}=1 and {17868}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15719','{17869}=1','{#ENT_NAME}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15720','{17870}=1','System status is in critical state','','0','4','Please check the device for errors',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15721','{17871}=1 or {17872}=1','System status is in warning state','','0','2','Please check the device for warnings',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15722','{17873}=1','System status is in critical state','','0','4','Please check the device for errors',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15728','{17879}=1','System is in unrecoverable state!','','0','4','Please check the device for faults',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15729','{17880}=1','System status is in critical state','','0','4','Please check the device for errors',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15730','{17881}=1','System status is in warning state','','0','2','Please check the device for warnings',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15731','{17882}=1 and {17883}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15732','{17884}=1 and {17885}>0','Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15735','{17892}<{$TEMP_CRIT_LOW:"CPU"}','{#SENSOR_LOCALE}: Temperature is too low: <{$TEMP_CRIT_LOW:"CPU"}','','0','3','',NULL,'0','2','1','{17893}>{$TEMP_CRIT_LOW:"CPU"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15738','{17900}<{$TEMP_CRIT_LOW:"Ambient"}','{#SENSOR_LOCALE}: Temperature is too low: <{$TEMP_CRIT_LOW:"Ambient"}','','0','3','',NULL,'0','2','1','{17901}>{$TEMP_CRIT_LOW:"Ambient"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15739','{17902}=1 or {17903}=1','{#PSU_DESCR}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15740','{17904}=1','{#PSU_DESCR}: Power supply is in warning state','','0','2','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15741','{17905}=1 or {17906}=1 or {17907}=1 or {17908}=1 or {17909}=1','{#FAN_DESCR}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15742','{17910}=1 or {17911}=1','{#FAN_DESCR}: Fan is in warning state','','0','2','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15743','{17912}=1 or {17913}=1','{#DISK_NAME}: Physical disk failed','','0','4','Please check physical disk for warnings or errors',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15744','{17914}=1','{#DISK_NAME}: Physical disk is in warning state','','0','2','Please check physical disk for warnings or errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15745','{17915}=1 and {17916}>0','{#DISK_NAME}: Disk has been replaced (new serial number received)','','0','1','Disk serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15746','{17917}=1','{#DISK_NAME}: Physical disk S.M.A.R.T. failed','','0','4','Disk probably requires replacement.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15747','{17918}=1','Disk {#SNMPVALUE}({#DISK_NAME}): Virtual disk failed','','0','4','Please check virtual disk for warnings or errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15748','{17919}=1','Disk {#SNMPVALUE}({#DISK_NAME}): Virtual disk is in warning state','','0','3','Please check virtual disk for warnings or errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15749','{17920}=1','{#CNTLR_NAME}: Disk array controller is in unrecoverable state!','','0','5','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15750','{17921}=1','{#CNTLR_NAME}: Disk array controller is in critical state','','0','4','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15751','{17922}=1','{#CNTLR_NAME}: Disk array controller is in warning state','','0','3','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15752','{17923}=1','Battery {#BATTERY_NUM}: Disk array cache controller battery is in warning state','','0','2','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15753','{17924}=1','Battery {#BATTERY_NUM}: Disk array cache controller battery is not in optimal state','','0','2','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15754','{17925}=1','Battery {#BATTERY_NUM}: Disk array cache controller battery is in critical state!','','0','3','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15762','{17933}=1 and {17934}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15781','{17971}=1','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15782','{17972}=1','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply is in warning state','','0','2','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15783','{17973}=1','Fan {#SNMPINDEX}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15784','{17974}=1','Fan {#SNMPINDEX}: Fan is in warning state','','0','2','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15785','{17975}=1','{#CNTLR_LOCATION}: Disk array controller is in critical state','','0','4','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15786','{17976}=1','{#CNTLR_LOCATION}: Disk array controller is in warning state','','0','3','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15787','{17977}=1','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is in critical state!','','0','3','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15790','{17983}=1 or {17984}=1','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery is in critical state!','','0','3','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15792','{17987}=1','{#DISK_LOCATION}: Physical disk failed','','0','4','Please check physical disk for warnings or errors',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15793','{17988}=1','{#DISK_LOCATION}: Physical disk is in warning state','','0','2','Please check physical disk for warnings or errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15794','{17989}=1 or {17990}=1','{#DISK_LOCATION}: Physical disk S.M.A.R.T. failed','','0','4','Disk probably requires replacement.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15795','{17991}=1 and {17992}>0','{#DISK_LOCATION}: Disk has been replaced (new serial number received)','','0','1','Disk serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15796','{17993}=1','Disk {#SNMPINDEX}({#DISK_NAME}): Virtual disk failed','','0','4','Please check virtual disk for warnings or errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15797','{17994}=1','Disk {#SNMPINDEX}({#DISK_NAME}): Virtual disk is not in OK state','','0','2','Please check virtual disk for warnings or errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15824','{18031}=1','System is in unrecoverable state!','','0','4','Please check the device for faults',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15825','{18032}=1','System status is in critical state','','0','4','Please check the device for errors',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15826','{18033}=1','System status is in warning state','','0','2','Please check the device for warnings',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15827','{18034}=1 and {18035}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15828','{18036}>{$TEMP_WARN:""}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{18037}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15829','{18038}>{$TEMP_CRIT:""}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{18039}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15830','{18040}<{$TEMP_CRIT_LOW:""}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{18041}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15831','{18042}>{$TEMP_WARN:"Ambient"}','Ambient: Temperature is above warning threshold: >{$TEMP_WARN:"Ambient"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{18043}<{$TEMP_WARN:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15832','{18044}>{$TEMP_CRIT:"Ambient"}','Ambient: Temperature is above critical threshold: >{$TEMP_CRIT:"Ambient"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{18045}<{$TEMP_CRIT:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15833','{18046}<{$TEMP_CRIT_LOW:"Ambient"}','Ambient: Temperature is too low: <{$TEMP_CRIT_LOW:"Ambient"}','','0','3','',NULL,'0','2','1','{18047}>{$TEMP_CRIT_LOW:"Ambient"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15834','{18048}>{$TEMP_WARN:"CPU"}','CPU: Temperature is above warning threshold: >{$TEMP_WARN:"CPU"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{18049}<{$TEMP_WARN:"CPU"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15835','{18050}>{$TEMP_CRIT:"CPU"}','CPU: Temperature is above critical threshold: >{$TEMP_CRIT:"CPU"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{18051}<{$TEMP_CRIT:"CPU"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15836','{18052}<{$TEMP_CRIT_LOW:"CPU"}','CPU: Temperature is too low: <{$TEMP_CRIT_LOW:"CPU"}','','0','3','',NULL,'0','2','1','{18053}>{$TEMP_CRIT_LOW:"CPU"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15837','{18054}=1','{#PSU_DESCR}: Power supply is not in normal state','','0','1','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15838','{18055}=1','{#FAN_DESCR}: Fan is not in normal state','','0','1','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15839','{18056}=1','{#SNMPINDEX}: Physical disk is not in OK state','','0','2','Please check physical disk for warnings or errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15845','{18062}>{$TEMP_WARN:""}','{#SENSOR_DESCR}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{18063}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15846','{18064}>{$TEMP_CRIT:""}','{#SENSOR_DESCR}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{18065}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15847','{18066}<{$TEMP_CRIT_LOW:""}','{#SENSOR_DESCR}: Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','2','1','{18067}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15890','{18113}>75','More than 75% used in the configuration cache','','0','3','Consider increasing CacheSize in the zabbix_proxy.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15891','{18114}>75','More than 75% used in the history cache','','0','3','Consider increasing HistoryCacheSize in the zabbix_proxy.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15892','{18115}>75','More than 75% used in the history index cache','','0','3','Consider increasing HistoryIndexCacheSize in the zabbix_proxy.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15893','{18116}>75','More than 75% used in the vmware cache','','0','3','Consider increasing VMwareCacheSize in the zabbix_proxy.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15894','{18117}>100','More than 100 items having missing data for more than 10 minutes','','0','2','zabbix[stats,{$IP},{$PORT},queue,10m] item is collecting data about how many items are missing data for more than 10 minutes',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15895','{18118}>75','Zabbix configuration syncer processes more than 75% busy','','0','3','',NULL,'0','0','1','{18118}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15896','{18119}>75','Zabbix data sender processes more than 75% busy','','0','3','',NULL,'0','0','1','{18119}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15897','{18120}>75','Zabbix discoverer processes more than 75% busy','','0','3','',NULL,'0','0','1','{18120}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15898','{18121}>75','Zabbix heartbeat sender processes more than 75% busy','','0','3','',NULL,'0','0','1','{18121}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15899','{18122}>75','Zabbix history syncer processes more than 75% busy','','0','3','',NULL,'0','0','1','{18122}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15900','{18123}>75','Zabbix housekeeper processes more than 75% busy','','0','3','',NULL,'0','0','1','{18123}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15901','{18124}>75','Zabbix http poller processes more than 75% busy','','0','3','',NULL,'0','0','1','{18124}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15902','{18125}>75','Zabbix icmp pinger processes more than 75% busy','','0','3','',NULL,'0','0','1','{18125}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15903','{18126}>75','Zabbix ipmi manager processes more than 75% busy','','0','3','',NULL,'0','0','1','{18126}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15904','{18127}>75','Zabbix ipmi poller processes more than 75% busy','','0','3','',NULL,'0','0','1','{18127}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15905','{18128}>75','Zabbix java poller processes more than 75% busy','','0','3','',NULL,'0','0','1','{18128}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15906','{18129}>75','Zabbix poller processes more than 75% busy','','0','3','',NULL,'0','0','1','{18129}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15907','{18130}>75','Zabbix self-monitoring processes more than 75% busy','','0','3','',NULL,'0','0','1','{18130}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15908','{18131}>75','Zabbix snmp trapper processes more than 75% busy','','0','3','',NULL,'0','0','1','{18131}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15909','{18132}>75','Zabbix task manager processes more than 75% busy','','0','3','',NULL,'0','0','1','{18132}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15910','{18133}>75','Zabbix trapper processes more than 75% busy','','0','3','',NULL,'0','0','1','{18133}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15911','{18134}>75','Zabbix unreachable poller processes more than 75% busy','','0','3','',NULL,'0','0','1','{18134}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15912','{18135}>75','Zabbix vmware collector processes more than 75% busy','','0','3','',NULL,'0','0','1','{18135}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15913','{18136}>75','Zabbix preprocessing manager processes more than 75% busy','','0','3','',NULL,'0','0','1','{18136}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15914','{18137}>75','Zabbix preprocessing worker processes more than 75% busy','','0','3','',NULL,'0','0','1','{18137}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15926','{18150} < {$PG.CACHE_HITRATIO.MIN.WARN}','PostgreSQL: Cache hit ratio too low (under {$PG.CACHE_HITRATIO.MIN.WARN} in 5m)','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15927','{18151}=1 and {18152}>0','PostgreSQL: Configuration has changed','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15928','{18153} = 1','PostgreSQL: Failed to get items (no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15929','{18154}=0','PostgreSQL: Replication is down','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15930','{18155} > {$PG.CHECKPOINTS_REQ.MAX.WARN}','PostgreSQL: Required checkpoints occurs too frequently (over {$PG.CHECKPOINTS_REQ.MAX.WARN})','','0','3','Checkpoints are points in the sequence of transactions at which it is guaranteed that the heap and index data files have been updated with all information written before that checkpoint. At checkpoint time, all dirty data pages are flushed to disk and a special checkpoint record is written to the log file.
https://www.postgresql.org/docs/current/wal-configuration.html',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15931','{18156} > {$PG.PING_TIME.MAX.WARN}','PostgreSQL: Response too long (over {$PG.PING_TIME.MAX.WARN})','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15932','{18157} < 10m','PostgreSQL: Service has been restarted (uptime < 10m)','','0','1','PostgreSQL uptime is less than 10 minutes',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15933','{18158} = 0','PostgreSQL: Service is down','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15934','{18159} > {$PG.REPL_LAG.MAX.WARN}','PostgreSQL: Streaming lag with {#MASTER} is too high (over {$PG.REPL_LAG.MAX.WARN} in 5m)','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15935','{18160} > {$PG.CONN_TOTAL_PCT.MAX.WARN}','PostgreSQL: Total number of connections is too high (over {$PG.CONN_TOTAL_PCT.MAX.WARN} in 5m)','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15936','{18161}=1 and {18162}>0','PostgreSQL: Version has changed (new version value received: {ITEM.VALUE})','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15938','{18164}>{$PG.LOCKS.MAX.WARN:"{#DBNAME}"}','Database {#DBNAME}: Number of locks is too high (over {$PG.LOCKS.MAX.WARN:"{#DBNAME}"} in 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15939','{18165} > {$PG.CONFLICTS.MAX.WARN:"{#DBNAME}"}','Database {#DBNAME}: Too many recovery conflicts (over {$PG.CONFLICTS.MAX.WARN:"{#DBNAME}"} in 5m)','','0','3','The primary and standby servers are in many ways loosely connected. Actions on the primary will have an effect on the standby. As a result, there is potential for negative interactions or conflicts between them.
https://www.postgresql.org/docs/current/hot-standby.html#HOT-STANDBY-CONFLICT',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15940','{18166}>{$PG.SLOW_QUERIES.MAX.WARN:"{#DBNAME}"}','Database {#DBNAME}: Too many slow queries (over {$PG.SLOW_QUERIES.MAX.WARN:"{#DBNAME}"} in 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15941','{18167}<{$PG.FROZENXID_PCT_STOP.MIN.HIGH:"{#DBNAME}"}','Database {#DBNAME}: VACUUM FREEZE is required to prevent wraparound (frozen XID less then {$PG.FROZENXID_PCT_STOP.MIN.HIGH:"{#DBNAME}"} %)','','0','3','Preventing Transaction ID Wraparound Failures
https://www.postgresql.org/docs/current/routine-vacuuming.html#VACUUM-FOR-WRAPAROUND',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15943','{18169}=0','Apache: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15944','{18170}>{$APACHE.RESPONSE_TIME.MAX.WARN}','Apache: Service response time is too high (over {$APACHE.RESPONSE_TIME.MAX.WARN}s for 5m)','','0','2','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15947','{18174}=0','Apache: Process is not running','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15948','{18175}=1','Apache: Failed to fetch status page (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15949','{18176}=0','Apache: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15950','{18177}>{$APACHE.RESPONSE_TIME.MAX.WARN}','Apache: Service response time is too high (over {$APACHE.RESPONSE_TIME.MAX.WARN}s for 5m)','','0','2','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15951','{18178}<10m','Apache: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15952','{18179}=1 and {18180}>0','Apache: Version has changed (new version: {ITEM.VALUE})','','0','1','Apache version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15954','{18183}=0','Nginx: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15955','{18184}>{$NGINX.RESPONSE_TIME.MAX.WARN}','Nginx: Service response time is too high (over {$NGINX.RESPONSE_TIME.MAX.WARN}s for 5m)','','0','2','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15956','{18185} > {$NGINX.DROP_RATE.MAX.WARN}','Nginx: High connections drop rate (more than {$NGINX.DROP_RATE.MAX.WARN} for 5m)','','0','2','The dropping rate connections is greater than {$NGINX.DROP_RATE.MAX.WARN} for the last 5 minutes.',NULL,'0','0','0','','0','','0','Current rate: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15957','{18186}=0','Nginx: Process is not running','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15958','{18187}=1 and {18188}>0','Nginx: Version has changed (new version: {ITEM.VALUE})','','0','1','Nginx version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15960','{18191}=0','Nginx: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15961','{18192}>{$NGINX.RESPONSE_TIME.MAX.WARN}','Nginx: Service response time is too high (over {$NGINX.RESPONSE_TIME.MAX.WARN}s for 5m)','','0','2','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15962','{18193} > {$NGINX.DROP_RATE.MAX.WARN}','Nginx: High connections drop rate (more than {$NGINX.DROP_RATE.MAX.WARN} for 5m)','','0','2','The dropping rate connections is greater than {$NGINX.DROP_RATE.MAX.WARN} for the last 5 minutes.',NULL,'0','0','0','','0','','0','Current rate: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15963','{18194}=1 and {18195}>0','Nginx: Version has changed (new version: {ITEM.VALUE})','','0','1','Nginx version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15978','{18211}=1','MySQL: Failed to get items (no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15979','{18212}>0','MySQL: Refused connections (max_connections limit reached)','','0','3','Number of refused connections due to the max_connections limit being reached.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15980','{18213}>{$MYSQL.ABORTED_CONN.MAX.WARN}','MySQL: Server has aborted connections (over {$MYSQL.ABORTED_CONN.MAX.WARN} for 5m)','','0','3','The number of failed attempts to connect to the MySQL server is more than {$MYSQL.ABORTED_CONN.MAX.WARN} in the last 5 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15981','{18214}>{$MYSQL.SLOW_QUERIES.MAX.WARN}','MySQL: Server has slow queries (over {$MYSQL.SLOW_QUERIES.MAX.WARN} for 5m)','','0','2','The number of slow queries is more than {$MYSQL.SLOW_QUERIES.MAX.WARN} in the last 5 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15982','{18215}<10m','MySQL: Service has been restarted (uptime < 10m)','','0','1','MySQL uptime is less than 10 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15983','{18216}=0','MySQL: Service is down','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15984','{18217}=1 and  {18218}>0','MySQL: Version has changed (new version value received: {ITEM.VALUE})','','0','1','MySQL version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15985','{18219}>{$MYSQL.REPL_LAG.MAX.WARN}','MySQL: Replication lag is too high (over {$MYSQL.REPL_LAG.MAX.WARN} for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15986','{18220}=1','MySQL: The slave I/O thread is not connected to a replication master','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15987','{18221}=1','MySQL: The slave I/O thread is not running','','0','3','Whether the I/O thread for reading the master''s binary log is running.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15988','{18222}=1','MySQL: The SQL thread is not running','','0','2','Whether the SQL thread for executing events in the relay log is running.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16007','{18255}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16008','{18256}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({18257}-{18258})<5G or {18259}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16009','{18260}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({18261}-{18262})<10G or {18263}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16010','{18264}<{$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}%)','','0','3','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.',NULL,'0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16011','{18265}<{$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}%)','','0','2','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.',NULL,'0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16031','{18300}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16035','{18306}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','The host uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16036','{18307}=0','System time is out of sync (diff with Zabbix server > {$SYSTEM.FUZZYTIME.MAX}s)','','0','2','The host system time is different from the Zabbix server time.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16038','{18310}<{$KERNEL.MAXFILES.MIN}','Configured max number of open filedescriptors is too low (< {$KERNEL.MAXFILES.MIN})','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16039','{18311}<{$KERNEL.MAXPROC.MIN}','Configured max number of processes is too low (< {$KERNEL.MAXPROC.MIN})','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16040','{18312}/{18313}*100>80','Getting closer to process limit (over 80% used)','','0','2','',NULL,'0','0','0','','0','','0','{ITEM.LASTVALUE1} active, {ITEM.LASTVALUE2} limit.','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16041','{18314}>0','/etc/passwd has been changed','','0','1','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16042','{18315}=1 and {18316}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16069','{18355}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({18356}-{18357})<5G or {18358}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16070','{18359}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({18360}-{18361})<10G or {18362}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16071','{18363}<{$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}%)','','0','3','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.',NULL,'0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16072','{18364}<{$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}%)','','0','2','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.',NULL,'0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16076','{18372}<0 and {18373}>0
and
({18373}=6
or {18373}=1)
and
({18374}<>2)','Interface {#IFNAME}: Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({18372}>0 and {18375}>0) or
({18374}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16097','{18423}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16101','{18429}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','The host uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16102','{18430}=0','System time is out of sync (diff with Zabbix server > {$SYSTEM.FUZZYTIME.MAX}s)','','0','2','The host system time is different from the Zabbix server time.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16104','{18433}<{$KERNEL.MAXFILES.MIN}','Configured max number of open filedescriptors is too low (< {$KERNEL.MAXFILES.MIN})','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16105','{18434}<{$KERNEL.MAXPROC.MIN}','Configured max number of processes is too low (< {$KERNEL.MAXPROC.MIN})','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16106','{18435}/{18436}*100>80','Getting closer to process limit (over 80% used)','','0','2','',NULL,'0','0','0','','0','','0','{ITEM.LASTVALUE1} active, {ITEM.LASTVALUE2} limit.','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16107','{18437}>0','/etc/passwd has been changed','','0','1','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16108','{18438}=1 and {18439}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16122','{18459}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({18460}-{18461})<5G or {18462}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16123','{18463}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({18464}-{18465})<10G or {18466}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16124','{18467}<{$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}%)','','0','3','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.',NULL,'0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16125','{18468}<{$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}%)','','0','2','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.',NULL,'0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16129','{18476}<0 and {18477}>0
and
({18477}=6
or {18477}=1)
and
({18478}<>2)','Interface {#IFNAME}: Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({18476}>0 and {18479}>0) or
({18478}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16138','{18501}=1','node_exporter is not available (or no data for 30m)','','0','2','Failed to fetch system metrics from node_exporter in time.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16139','{18502}=0','System time is out of sync (diff with Zabbix server > {$SYSTEM.FUZZYTIME.MAX}s)','','0','2','The host system time is different from the Zabbix server time.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16141','{18505}<{$KERNEL.MAXFILES.MIN}','Configured max number of open filedescriptors is too low (< {$KERNEL.MAXFILES.MIN})','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16142','{18506}/{18507}*100>80','Running out of file descriptors (less than < 20% free)','','0','2','',NULL,'0','0','0','','0','','0','{ITEM.LASTVALUE1} of {ITEM.LASTVALUE2} file descriptors are in use.','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16143','{18508}=1 and {18509}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16144','{18510}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','The device uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16146','{18513}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16152','{18526}<0 and {18527}>0
and (
{18528}=6 or
{18528}=7 or
{18528}=11 or
{18528}=62 or
{18528}=69 or
{18528}=117
)
and
({18529}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({18526}>0 and {18530}>0) or
({18529}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16153','{18531}<0 and {18532}>0
and
({18532}=6
or {18532}=1)
and
({18533}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({18531}>0 and {18534}>0) or
({18533}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16155','{18537}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({18538}-{18539})<5G or {18540}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16156','{18541}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({18542}-{18543})<10G or {18544}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16157','{18545}<{$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}%)','','0','3','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.',NULL,'0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16158','{18546}<{$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}%)','','0','2','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.',NULL,'0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16160','{18548}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16161','{18549}>{$CPU.INTERRUPT.CRIT.MAX}','CPU interrupt time is too high (over {$CPU.INTERRUPT.CRIT.MAX}% for 5m)','','0','2','"The CPU Interrupt Time in the last 5 minutes exceeds {$CPU.INTERRUPT.CRIT.MAX}%."
The Processor Information\% Interrupt Time is the time the processor spends receiving and servicing 
hardware interrupts during sample intervals. This value is an indirect indicator of the activity of 
devices that generate interrupts, such as the system clock, the mouse, disk drivers, data communication 
lines, network interface cards and other peripheral devices. This is an easy way to identify a potential 
hardware failure. This should never be higher than 20%.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16162','{18550}>{$CPU.PRIV.CRIT.MAX}','CPU privileged time is too high (over {$CPU.PRIV.CRIT.MAX}% for 5m)','','0','2','The CPU privileged time in the last 5 minutes exceeds {$CPU.PRIV.CRIT.MAX}%.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16166','{18555}<{$MEM.PAGE_TABLE_CRIT.MIN}','Number of free system page table entries is too low (less {$MEM.PAGE_TABLE_CRIT.MIN} for 5m)','','0','2','The Memory Free System Page Table Entries is less than {$MEM.PAGE_TABLE_CRIT.MIN} for 5 minutes. If the number is less than 5,000, there may well be a memory leak.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16167','{18556}>{$MEM.PAGE_SEC.CRIT.MAX}','The Memory Pages/sec is too high (over {$MEM.PAGE_SEC.CRIT.MAX} for 5m)','','0','2','The Memory Pages/sec in the last 5 minutes exceeds {$MEM.PAGE_SEC.CRIT.MAX}. If the value is greater than 1,000, as a result of excessive paging, there may be a memory leak.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16168','{18557}<10m','Host has been restarted (uptime < 10m)','','0','2','The device uptime is less than 10 minutes.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16169','{18558}=0','System time is out of sync (diff with Zabbix server > {$SYSTEM.FUZZYTIME.MAX}s)','','0','2','The host system time is different from the Zabbix server time.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16182','{18574}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({18575}-{18576})<5G or {18577}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16183','{18578}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({18579}-{18580})<10G or {18581}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16196','{18620}=0','Zabbix agent is not available (for {$AGENT.TIMEOUT})','','0','3','For passive only agents, host availability is used with {$AGENT.TIMEOUT} as time threshold.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16197','{18621}=1','Zabbix agent is not available (or nodata for {$AGENT.NODATA_TIMEOUT})','','0','3','For active agents, nodata() with agent.ping is used with {$AGENT.NODATA_TIMEOUT} as time threshold.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16209','{18633}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16210','{18634}>{$CPU.INTERRUPT.CRIT.MAX}','CPU interrupt time is too high (over {$CPU.INTERRUPT.CRIT.MAX}% for 5m)','','0','2','"The CPU Interrupt Time in the last 5 minutes exceeds {$CPU.INTERRUPT.CRIT.MAX}%."
The Processor Information\% Interrupt Time is the time the processor spends receiving and servicing 
hardware interrupts during sample intervals. This value is an indirect indicator of the activity of 
devices that generate interrupts, such as the system clock, the mouse, disk drivers, data communication 
lines, network interface cards and other peripheral devices. This is an easy way to identify a potential 
hardware failure. This should never be higher than 20%.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16211','{18635}>{$CPU.PRIV.CRIT.MAX}','CPU privileged time is too high (over {$CPU.PRIV.CRIT.MAX}% for 5m)','','0','2','The CPU privileged time in the last 5 minutes exceeds {$CPU.PRIV.CRIT.MAX}%.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16215','{18640}<{$MEM.PAGE_TABLE_CRIT.MIN}','Number of free system page table entries is too low (less {$MEM.PAGE_TABLE_CRIT.MIN} for 5m)','','0','2','The Memory Free System Page Table Entries is less than {$MEM.PAGE_TABLE_CRIT.MIN} for 5 minutes. If the number is less than 5,000, there may well be a memory leak.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16216','{18641}>{$MEM.PAGE_SEC.CRIT.MAX}','The Memory Pages/sec is too high (over {$MEM.PAGE_SEC.CRIT.MAX} for 5m)','','0','2','The Memory Pages/sec in the last 5 minutes exceeds {$MEM.PAGE_SEC.CRIT.MAX}. If the value is greater than 1,000, as a result of excessive paging, there may be a memory leak.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16217','{18642}<10m','Host has been restarted (uptime < 10m)','','0','2','The device uptime is less than 10 minutes.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16218','{18643}=0','System time is out of sync (diff with Zabbix server > {$SYSTEM.FUZZYTIME.MAX}s)','','0','2','The host system time is different from the Zabbix server time.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16231','{18659}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({18660}-{18661})<5G or {18662}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16232','{18663}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({18664}-{18665})<10G or {18666}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16250','{18711}>0','RabbitMQ: Number of network partitions is too high (more than 0 for 5m)','','0','2','https://www.rabbitmq.com/partitions.html#detecting',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16251','{18712}=0','RabbitMQ: Node is not running','','0','3','RabbitMQ node is not running',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16254','{18715}<10m','RabbitMQ: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16255','{18716}=0','RabbitMQ: Process is not running','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16256','{18717}=0','RabbitMQ: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16257','{18718}>{$RABBITMQ.RESPONSE_TIME.MAX.WARN}','RabbitMQ: Service response time is too high (over {$RABBITMQ.RESPONSE_TIME.MAX.WARN}s for 5m)','','0','2','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16258','{18719}>{$RABBITMQ.MESSAGES.MAX.WARN:"{#QUEUE}"}','RabbitMQ: Too many messages in queue (over {$RABBITMQ.MESSAGES.MAX.WARN} for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16259','{18720}=1','RabbitMQ: Failed to fetch overview data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16264','{18726}>0','RabbitMQ: Number of network partitions is too high (more than 0 for 5m)','','0','2','https://www.rabbitmq.com/partitions.html#detecting',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16265','{18727}=0','RabbitMQ: Node is not running','','0','3','RabbitMQ node is not running',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16268','{18730}<10m','RabbitMQ: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16269','{18731}=0','RabbitMQ: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16270','{18732}>{$RABBITMQ.RESPONSE_TIME.MAX.WARN}','RabbitMQ: Service response time is too high (over {$RABBITMQ.RESPONSE_TIME.MAX.WARN}s for 5m)','','0','2','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16271','{18733}>{$RABBITMQ.MESSAGES.MAX.WARN:"{#QUEUE}"}','RabbitMQ: Too many messages in queue (over {$RABBITMQ.MESSAGES.MAX.WARN} for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16287','{18753}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16289','{18756}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16439','{19090}=1','System status is in critical state','','0','4','Please check the device for errors',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16440','{19091}=1','System status is in warning state','','0','2','Please check the device for warnings',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16442','{19093}=1','RabbitMQ: Failed to fetch overview data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16443','{19094}=1','RabbitMQ: Failed to fetch nodes data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16444','{19095}=0','RabbitMQ: Node healthcheck failed','','0','3','https://www.rabbitmq.com/monitoring.html#health-checks',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16445','{19096}=1 and {19097}>0','RabbitMQ: Version has changed (new version: {ITEM.VALUE})','','0','1','RabbitMQ version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16446','{19098}=1','RabbitMQ: Memory alarm (Memory usage threshold has been reached)','','0','3','https://www.rabbitmq.com/memory.html',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16447','{19099}=1','RabbitMQ: Free disk space alarm (Free space threshold has been reached)','','0','3','https://www.rabbitmq.com/disk-alarms.html',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16448','{19100}=1','RabbitMQ: Failed to fetch nodes data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16449','{19101}=0','RabbitMQ: Node healthcheck failed','','0','3','https://www.rabbitmq.com/monitoring.html#health-checks',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16450','{19102}=1 and {19103}>0','RabbitMQ: Version has changed (new version: {ITEM.VALUE})','','0','1','RabbitMQ version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16451','{19104}=1','RabbitMQ: Memory alarm (Memory usage threshold has been reached)','','0','3','https://www.rabbitmq.com/memory.html',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16452','{19105}=1','RabbitMQ: Free disk space alarm (Free space threshold has been reached)','','0','3','https://www.rabbitmq.com/disk-alarms.html',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16459','{19113}>{$TEMP_WARN:"Ambient"}','{#SENSOR_LOCATION}.Ambient: Temperature is above warning threshold: >{$TEMP_WARN:"Ambient"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{19114}<{$TEMP_WARN:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16460','{19115}>{$TEMP_CRIT:"Ambient"}','{#SENSOR_LOCATION}.Ambient: Temperature is above critical threshold: >{$TEMP_CRIT:"Ambient"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{19116}<{$TEMP_CRIT:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16461','{19117}<{$TEMP_CRIT_LOW:"Ambient"}','{#SENSOR_LOCATION}.Ambient: Temperature is too low: <{$TEMP_CRIT_LOW:"Ambient"}','','0','3','',NULL,'0','2','1','{19118}>{$TEMP_CRIT_LOW:"Ambient"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16462','{19119}>{$TEMP_WARN:"Ambient"}','{#SENSOR_LOCATION}.Front: Temperature is above warning threshold: >{$TEMP_WARN:"Ambient"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{19120}<{$TEMP_WARN:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16463','{19121}>{$TEMP_CRIT:"Ambient"}','{#SENSOR_LOCATION}.Front: Temperature is above critical threshold: >{$TEMP_CRIT:"Ambient"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{19122}<{$TEMP_CRIT:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16464','{19123}<{$TEMP_CRIT_LOW:"Ambient"}','{#SENSOR_LOCATION}.Front: Temperature is too low: <{$TEMP_CRIT_LOW:"Ambient"}','','0','3','',NULL,'0','2','1','{19124}>{$TEMP_CRIT_LOW:"Ambient"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16465','{19125}>{$TEMP_WARN:"Ambient"}','{#SENSOR_LOCATION}.Rear: Temperature is above warning threshold: >{$TEMP_WARN:"Ambient"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{19126}<{$TEMP_WARN:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16466','{19127}>{$TEMP_CRIT:"Ambient"}','{#SENSOR_LOCATION}.Rear: Temperature is above critical threshold: >{$TEMP_CRIT:"Ambient"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{19128}<{$TEMP_CRIT:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16467','{19129}<{$TEMP_CRIT_LOW:"Ambient"}','{#SENSOR_LOCATION}.Rear: Temperature is too low: <{$TEMP_CRIT_LOW:"Ambient"}','','0','3','',NULL,'0','2','1','{19130}>{$TEMP_CRIT_LOW:"Ambient"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16468','{19131}>{$TEMP_WARN:"Ambient"}','{#SENSOR_LOCATION}.IOH: Temperature is above warning threshold: >{$TEMP_WARN:"Ambient"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{19132}<{$TEMP_WARN:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16469','{19133}>{$TEMP_CRIT:"Ambient"}','{#SENSOR_LOCATION}.IOH: Temperature is above critical threshold: >{$TEMP_CRIT:"Ambient"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{19134}<{$TEMP_CRIT:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16470','{19135}<{$TEMP_CRIT_LOW:"Ambient"}','{#SENSOR_LOCATION}.IOH: Temperature is too low: <{$TEMP_CRIT_LOW:"Ambient"}','','0','3','',NULL,'0','2','1','{19136}>{$TEMP_CRIT_LOW:"Ambient"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16471','{19137}>{$TEMP_WARN:"CPU"}','{#SENSOR_LOCATION}: Temperature is above warning threshold: >{$TEMP_WARN:"CPU"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{19138}<{$TEMP_WARN:"CPU"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16472','{19139}>{$TEMP_CRIT:"CPU"}','{#SENSOR_LOCATION}: Temperature is above critical threshold: >{$TEMP_CRIT:"CPU"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{19140}<{$TEMP_CRIT:"CPU"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16473','{19141}<{$TEMP_CRIT_LOW:"CPU"}','{#SENSOR_LOCATION}: Temperature is too low: <{$TEMP_CRIT_LOW:"CPU"}','','0','3','',NULL,'0','2','1','{19142}>{$TEMP_CRIT_LOW:"CPU"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16474','{19143}=1','{#PSU_LOCATION}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16475','{19144}=1','{#PSU_LOCATION}: Power supply is in warning state','','0','2','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16476','{19145}=1 or {19146}=1 or {19147}=1 or {19148}=1','{#UNIT_LOCATION}: System status is in critical state','','0','4','Please check the device for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16477','{19149}=1 or {19150}=1 or {19151}=1 or {19152}=1 or {19153}=1','{#UNIT_LOCATION}: System status is in warning state','','0','2','Please check the device for warnings',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16478','{19154}=1 and {19155}>0','{#UNIT_LOCATION}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16479','{19156}=1','{#FAN_LOCATION}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16480','{19157}=1','{#FAN_LOCATION}: Fan is in warning state','','0','2','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16481','{19158}=1','{#DISK_LOCATION}: Physical disk failed','','0','4','Please check physical disk for warnings or errors',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16482','{19159}=1 or {19160}=1','{#DISK_LOCATION}: Physical disk error','','0','3','Please check physical disk for warnings or errors',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16483','{19161}=1','{#VDISK_LOCATION}: Virtual disk is not in OK state','','0','2','Please check virtual disk for warnings or errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16484','{19162}=1','{#DISKARRAY_LOCATION}: Disk array controller is in critical state','','0','4','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16485','{19163}=1','{#DISKARRAY_LOCATION}: Disk array controller is in warning state','','0','3','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16486','{19164}=1','{#DISKARRAY_LOCATION}: Disk array controller is not in optimal state','','0','2','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16487','{19165}=1','{#DISKARRAY_CACHE_LOCATION}: Disk array cache controller battery is in critical state!','','0','3','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16488','{19166}=1','{#DISKARRAY_CACHE_LOCATION}: Disk array cache controller battery is not in optimal state','','0','2','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16491','{19171}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16492','{19172}=1 and {19173}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16494','{19175}=1','#{#SNMPINDEX}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16495','{19176}=1','#{#SNMPINDEX}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16496','{19177}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16498','{19179}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16504','{19185}>{$TEMP_WARN:"Chassis"}','Chassis #{#SNMPINDEX}: Temperature is above warning threshold: >{$TEMP_WARN:"Chassis"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{19186}<{$TEMP_WARN:"Chassis"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16505','{19187}>{$TEMP_CRIT:"Chassis"}','Chassis #{#SNMPINDEX}: Temperature is above critical threshold: >{$TEMP_CRIT:"Chassis"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{19188}<{$TEMP_CRIT:"Chassis"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16506','{19189}<{$TEMP_CRIT_LOW:"Chassis"}','Chassis #{#SNMPINDEX}: Temperature is too low: <{$TEMP_CRIT_LOW:"Chassis"}','','0','3','',NULL,'0','2','1','{19190}>{$TEMP_CRIT_LOW:"Chassis"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16507','{19191}=1 and {19192}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16508','{19193}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16514','{19202}>{$CPU.UTIL.CRIT}','{#SNMPVALUE}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16515','{19203}>{$CPU.UTIL.CRIT}','#{#SNMPINDEX}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16521','{19209}>{$CPU.UTIL.CRIT}','#{#SNMPINDEX}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16523','{19211}=1 and {19212}>0','#{#SNMPVALUE}: Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16524','{19213}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16525','{19214}=1 and {19215}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16527','{19217}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16529','{19219}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16530','{19220}=1 and {19221}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16532','{19223}=1 and {19224}>0','{#ENT_NAME}: Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16533','{19225}>{$CPU.UTIL.CRIT}','{#MODULE_NAME}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16535','{19227}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16537','{19229}>{$CPU.UTIL.CRIT}','{#ENT_NAME}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16538','{19230}=1 and {19231}>0','{#ENT_NAME}: Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16540','{19233}=1 and {19234}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16541','{19235}>{$CPU.UTIL.CRIT}','{#SNMPVALUE}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16543','{19237}=1 and {19238}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16545','{19240}>{$CPU.UTIL.CRIT}','#{#SNMPINDEX}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16546','{19241}>{$VFS.FS.PUSED.MAX.CRIT:"Disk-{#SNMPINDEX}"} and
(({19242}-{19243})<5G or {19244}<1d)','Disk-{#SNMPINDEX}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"Disk-{#SNMPINDEX}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"Disk-{#SNMPINDEX}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16547','{19245}>{$VFS.FS.PUSED.MAX.WARN:"Disk-{#SNMPINDEX}"} and
(({19246}-{19247})<10G or {19248}<1d)','Disk-{#SNMPINDEX}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"Disk-{#SNMPINDEX}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"Disk-{#SNMPINDEX}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16548','{19249}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16549','{19250}=1 and {19251}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16551','{19253}>{$TEMP_WARN:""}','Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','0','1','{19254}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16552','{19255}>{$TEMP_CRIT:""}','Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','0','1','{19256}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16553','{19257}<{$TEMP_CRIT_LOW:""}','Temperature is too low: <{$TEMP_CRIT_LOW:""}','','0','3','',NULL,'0','0','1','{19258}>{$TEMP_CRIT_LOW:""}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16554','{19259}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16555','{19260}=1 and {19261}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16557','{19263}=1','{#SNMPINDEX}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16558','{19264}=1','{#SNMPINDEX}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16559','{19265}>{$CPU.UTIL.CRIT}','#{#SNMPVALUE}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16561','{19267}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16563','{19269}/{19270}>{$LOAD_AVG_PER_CPU.MAX.WARN}
and {19271}>0
and {19272}>0','Load average is too high (per CPU load over {$LOAD_AVG_PER_CPU.MAX.WARN} for 5m)','','0','3','Per CPU load average is too high. Your system may be slow to respond.',NULL,'0','0','0','','0','','0','Load averages(1m 5m 15m): ({ITEM.LASTVALUE1} {ITEM.LASTVALUE3} {ITEM.LASTVALUE4}), # of CPUs: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16569','{19287}/{19288}>{$LOAD_AVG_PER_CPU.MAX.WARN}
and {19289}>0
and {19290}>0','Load average is too high (per CPU load over {$LOAD_AVG_PER_CPU.MAX.WARN} for 5m)','','0','3','Per CPU load average is too high. Your system may be slow to respond.',NULL,'0','0','0','','0','','0','Load averages(1m 5m 15m): ({ITEM.LASTVALUE1} {ITEM.LASTVALUE3} {ITEM.LASTVALUE4}), # of CPUs: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16573','{19299}/{19300}>{$LOAD_AVG_PER_CPU.MAX.WARN}
and {19301}>0
and {19302}>0','Load average is too high (per CPU load over {$LOAD_AVG_PER_CPU.MAX.WARN} for 5m)','','0','3','Per CPU load average is too high. Your system may be slow to respond.',NULL,'0','0','0','','0','','0','Load averages(1m 5m 15m): ({ITEM.LASTVALUE1} {ITEM.LASTVALUE3} {ITEM.LASTVALUE4}), # of CPUs: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16575','{19305}/{19306}>{$LOAD_AVG_PER_CPU.MAX.WARN}
and {19307}>0
and {19308}>0','Load average is too high (per CPU load over {$LOAD_AVG_PER_CPU.MAX.WARN} for 5m)','','0','3','Per CPU load average is too high. Your system may be slow to respond.',NULL,'0','0','0','','0','','0','Load averages(1m 5m 15m): ({ITEM.LASTVALUE1} {ITEM.LASTVALUE3} {ITEM.LASTVALUE4}), # of CPUs: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16577','{19313}=1 and {19314}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16579','{19316}=1 and {19317}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16582','{19322}=1 and {19323}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16584','{19326}=1 and {19327}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16585','{19328}=1 and {19329}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16587','{19332}=1 and {19333}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16593','{19344}=1 and {19345}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16624','{19406}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16630','{19412}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({19413}-{19414})<5G or {19415}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16631','{19416}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({19417}-{19418})<10G or {19419}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16644','{19456}<10m','HAProxy: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16645','{19457}=1 and {19458}>0','HAProxy: Version has changed (new version: {ITEM.VALUE})','','0','1','HAProxy version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16646','{19459}>{$HAPROXY.RESPONSE_TIME.MAX.WARN}','HAProxy: Service response time is too high (over {$HAPROXY.RESPONSE_TIME.MAX.WARN} for 5m)','','0','2','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16647','{19460}=0','HAProxy: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16661','{19474}<10m','HAProxy: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16662','{19475}=1 and {19476}>0','HAProxy: Version has changed (new version: {ITEM.VALUE})','','0','1','HAProxy version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16678','{19492}=0 or
 {19493}=1','Nginx: Failed to fetch stub status page (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16679','{19494}=0 or
 {19495}=1','Nginx: Failed to fetch stub status page (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16680','{19496} > {$PG.DEADLOCKS.MAX.WARN:"{#DBNAME}"}','Database {#DBNAME}: Deadlock occurred (over {$PG.DEADLOCKS.MAX.WARN:"{#DBNAME}"} in 5m)','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16681','{19497}/{19498}*100>{$REDIS.CLIENTS.PRC.MAX.WARN}','Redis: Total number of connected clients is too high (over {$REDIS.CLIENTS.PRC.MAX.WARN}% in 5m)','','0','2','When the number of clients reaches the value of the "maxclients" parameter, new connections will be rejected.

https://redis.io/topics/clients#maximum-number-of-clients',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16682','{19499}=1 and {19500}>0','Redis: Configuration has changed','','0','1','Redis configuration has changed. Ack to close.',NULL,'0','0','2','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16683','{19501}=1','Redis: Failed to fetch info data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16684','{19502}>{$REDIS.MEM.FRAG_RATIO.MAX.WARN}','Redis: Memory fragmentation ratio is too high (over {$REDIS.MEM.FRAG_RATIO.MAX.WARN} in 15m)','','0','2','This ratio is an indication of memory mapping efficiency:
  — Value over 1.0 indicate that memory fragmentation is very likely. Consider restarting the Redis server so the operating system can recover fragmented memory, especially with a ratio over 1.5.
  — Value under 1.0 indicate that Redis likely has insufficient memory available. Consider optimizing memory usage or adding more RAM.

Note: If your peak memory usage is much higher than your current memory usage, the memory fragmentation ratio may be unreliable.

https://redis.io/topics/memory-optimization',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16685','{19503}=0','Redis: Last AOF write operation failed','','0','2','Detailed information about persistence: https://redis.io/topics/persistence',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16686','{19504}=0','Redis: Last RDB save operation failed','','0','2','Detailed information about persistence: https://redis.io/topics/persistence',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16687','{19505}=0','Redis: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16688','{19506}=1','Redis: Number of slaves has changed','','0','1','Redis number of slaves has changed. Ack to close.',NULL,'0','0','2','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16689','{19507}=1 and {19508}>0','Redis: Replication role has changed (new role: {ITEM.VALUE})','','0','2','Redis replication role has changed. Ack to close.',NULL,'0','0','2','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16690','{19509}=1 and {19510}>0','Redis: Version has changed (new version: {ITEM.VALUE})','','0','1','Redis version has changed. Ack to close.',NULL,'0','0','2','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16691','{19511}<10m','Redis: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16692','{19512}>{$REDIS.SLOWLOG.COUNT.MAX.WARN}','Redis: Too many entries in the slowlog (over {$REDIS.SLOWLOG.COUNT.MAX.WARN} per second in 5m)','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16693','{19513}>0','Redis: Connections are rejected','','0','4','The number of connections has reached the value of "maxclients".

https://redis.io/topics/clients',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16694','{19514}=0','Redis: Process is not running','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16696','{19517}>{$REDIS.REPL.LAG.MAX.WARN}','Redis: Replication lag with master is too high (over {$REDIS.REPL.LAG.MAX.WARN} in 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16710','{19548} > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"} or {19549} > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk read/write request responses are too high (read > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"} ms for 15m or write > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"} ms for 15m)','','0','2','This trigger might indicate disk {#DEVNAME} saturation.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16713','{19552}<>0','"{#SERVICE.NAME}" ({#SERVICE.DISPLAYNAME}) is not running (startup type {#SERVICE.STARTUPNAME})','','0','3','The service has a state other than "Running" for the last three times.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16717','{19556}<>0','"{#SERVICE.NAME}" ({#SERVICE.DISPLAYNAME}) is not running (startup type {#SERVICE.STARTUPNAME})','','0','3','The service has a state other than "Running" for the last three times.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16719','{19558}>{$MYSQL.ABORTED_CONN.MAX.WARN}','MySQL: Server has aborted connections (over {$MYSQL.ABORTED_CONN.MAX.WARN} for 5m)','','0','3','The number of failed attempts to connect to the MySQL server is more than {$MYSQL.ABORTED_CONN.MAX.WARN} in the last 5 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16721','{19560}>0','MySQL: Refused connections (max_connections limit reached)','','0','3','Number of refused connections due to the max_connections limit being reached.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16723','{19562}=0','MySQL: Service is down','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16724','{19563}>{$MYSQL.SLOW_QUERIES.MAX.WARN}','MySQL: Server has slow queries (over {$MYSQL.SLOW_QUERIES.MAX.WARN} for 5m)','','0','2','The number of slow queries is more than {$MYSQL.SLOW_QUERIES.MAX.WARN} in the last 5 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16725','{19564}<10m','MySQL: Service has been restarted (uptime < 10m)','','0','1','MySQL uptime is less than 10 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16726','{19565}=1 and {19566}>0','MySQL: Version has changed (new version value received: {ITEM.VALUE})','','0','1','MySQL version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16727','{19567}>{$MYSQL.REPL_LAG.MAX.WARN}','MySQL: Replication lag is too high (over {$MYSQL.REPL_LAG.MAX.WARN} for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16728','{19568}=1','MySQL: The slave I/O thread is not running','','0','3','Whether the I/O thread for reading the master''s binary log is running.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16729','{19569}=1','MySQL: The slave I/O thread is not connected to a replication master','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16730','{19570}=1','MySQL: The SQL thread is not running','','0','2','Whether the SQL thread for executing events in the relay log is running.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16732','{19572}=0','MySQL: Service is down','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16733','{19573}=1 and {19574}>0','MySQL: Version has changed (new version value received: {ITEM.VALUE})','','0','1','MySQL version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16734','{19575}>{$MYSQL.ABORTED_CONN.MAX.WARN}','MySQL: Server has aborted connections (over {$MYSQL.ABORTED_CONN.MAX.WARN} for 5m)','','0','3','The number of failed attempts to connect to the MySQL server is more than {$MYSQL.ABORTED_CONN.MAX.WARN} in the last 5 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16736','{19577}>0','MySQL: Refused connections (max_connections limit reached)','','0','3','Number of refused connections due to the max_connections limit being reached.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16737','{19578}>{$MYSQL.SLOW_QUERIES.MAX.WARN}','MySQL: Server has slow queries (over {$MYSQL.SLOW_QUERIES.MAX.WARN} for 5m)','','0','2','The number of slow queries is more than {$MYSQL.SLOW_QUERIES.MAX.WARN} in the last 5 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16738','{19579}<10m','MySQL: Service has been restarted (uptime < 10m)','','0','1','MySQL uptime is less than 10 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16739','{19580}>{$MYSQL.REPL_LAG.MAX.WARN}','MySQL: Replication lag is too high (over {$MYSQL.REPL_LAG.MAX.WARN} for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16740','{19581}=1','MySQL: The slave I/O thread is not running','','0','3','Whether the I/O thread for reading the master''s binary log is running.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16741','{19582}=1','MySQL: The slave I/O thread is not connected to a replication master','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16742','{19583}=1','MySQL: The SQL thread is not running','','0','2','Whether the SQL thread for executing events in the relay log is running.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16743','{19584}=1','Docker: Failed to fetch info data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16744','{19585}=0','Docker: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16745','{19586}=1 and {19587}>0','Docker: Version has changed (new version: {ITEM.VALUE})','','0','1','Docker version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16746','{19588}>0 and {19589}=0','Container {#NAME}: Container has been stopped with error code','','0','3','',NULL,'0','2','0','','0','','1','Exit code: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16747','{19590}=1 and {19591}>0','Container {#NAME}: An error has occurred in the container','','0','2','Container {#NAME} has an error. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16748','{19592}/{19593}*100>{$MEMCACHED.MEM.PUSED.MAX.WARN}','Memcached: Memory usage is too high (over {$MEMCACHED.MEM.PUSED.MAX.WARN} in 5m)','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16749','{19594}/{19595}*100>{$MEMCACHED.CONN.PRC.MAX.WARN}','Memcached: Total number of connected clients is too high (over {$MEMCACHED.CONN.PRC.MAX.WARN}% in 5m)','','0','2','When the number of connections reaches the value of the "max_connections" parameter, new connections will be rejected.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16750','{19596}>{$MEMCACHED.CONN.QUEUED.MAX.WARN}','Memcached: Too many queued connections (over {$MEMCACHED.CONN.QUEUED.MAX.WARN} in 5m)','','0','2','The max number of connections is reachedand and a new connection had to wait in the queue as a result.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16751','{19597}>{$MEMCACHED.CONN.THROTTLED.MAX.WARN}','Memcached: Too many throttled connections (over {$MEMCACHED.CONN.THROTTLED.MAX.WARN} in 5m)','','0','2','Number of times a client connection was throttled is too high.
When sending GETs in batch mode and the connection contains too many requests (limited by -R parameter) the connection might be throttled to prevent starvation.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16752','{19598}=1','Memcached: Failed to fetch info data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16753','{19599}=0','Memcached: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16754','{19600}<10m','Memcached: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16755','{19601}=1 and {19602}>0','Memcached: Version has changed (new version: {ITEM.VALUE})','','0','1','Memcached version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16756','{19603}>{$MYSQL.ABORTED_CONN.MAX.WARN}','MySQL: Server has aborted connections (over {$MYSQL.ABORTED_CONN.MAX.WARN} for 5m)','','0','3','The number of failed attempts to connect to the MySQL server is more than {$MYSQL.ABORTED_CONN.MAX.WARN} in the last 5 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16758','{19605}>0','MySQL: Refused connections (max_connections limit reached)','','0','3','Number of refused connections due to the max_connections limit being reached.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16759','{19606}=0','MySQL: Service is down','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16760','{19607}>{$MYSQL.SLOW_QUERIES.MAX.WARN}','MySQL: Server has slow queries (over {$MYSQL.SLOW_QUERIES.MAX.WARN} for 5m)','','0','2','The number of slow queries is more than {$MYSQL.SLOW_QUERIES.MAX.WARN} in the last 5 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16761','{19608}<10m','MySQL: Service has been restarted (uptime < 10m)','','0','1','MySQL uptime is less than 10 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16762','{19609}=1 and {19610}>0','MySQL: Version has changed (new version value received: {ITEM.VALUE})','','0','1','MySQL version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16763','{19611}>{$MYSQL.REPL_LAG.MAX.WARN}','MySQL: Replication lag is too high (over {$MYSQL.REPL_LAG.MAX.WARN} for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16764','{19612}=1','MySQL: The slave I/O thread is not running','','0','3','Whether the I/O thread for reading the master''s binary log is running.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16765','{19613}=1','MySQL: The slave I/O thread is not connected to a replication master','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16766','{19614}=1','MySQL: The SQL thread is not running','','0','2','Whether the SQL thread for executing events in the relay log is running.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16767','{19615}=1','IPMI: {#SENSOR_ID} value has changed','','0','1','The trigger is informing about changes in a state of the discrete IPMI sensor. A problem generated by this trigger can be manually closed.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16768','{19616}<{#SENSOR_LO_WARN}','IPMI: {#SENSOR_ID} value is below non-critical low (less than {#SENSOR_LO_WARN} for 5m)','','0','2','The trigger is informing that a value less than the lower non-critical threshold has been reached.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16769','{19617}<{#SENSOR_LO_CRIT}','IPMI: {#SENSOR_ID} value is below critical low (less than {#SENSOR_LO_CRIT} for 5m)','','0','4','The trigger is informing that a value less than the lower critical threshold has been reached.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16770','{19618}<{#SENSOR_LO_DISAST}','IPMI: {#SENSOR_ID} value is below non-recoverable low (less than {#SENSOR_LO_DISAST} for 5m)','','0','5','The trigger is informing that a value less than the lower non-recoverable threshold has been reached.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16771','{19619}>{#SENSOR_HI_WARN}','IPMI: {#SENSOR_ID} value is above non-critical high (greater than {#SENSOR_HI_WARN} for 5m)','','0','2','The trigger is informing that a value higher than the upper non-critical threshold has been reached.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16772','{19620}>{#SENSOR_HI_CRIT}','IPMI: {#SENSOR_ID} value is above critical high (greater than {#SENSOR_HI_CRIT} for 5m)','','0','4','The trigger is informing that a value higher than the upper critical threshold has been reached.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16773','{19621}>{#SENSOR_HI_DISAST}','IPMI: {#SENSOR_ID} value is above non-recoverable high (greater than {#SENSOR_HI_DISAST} for 5m)','','0','5','The trigger is informing that a value higher than the upper non-recoverable threshold has been reached.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16774','({19622}-{19623})/({19624}-1)>{19623}','ES: Cluster does not have enough space for resharding','','0','4','There is not enough disk space for index resharding.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16775','{19625}>0','ES: Cluster has the initializing shards','','0','3','The cluster has the initializing shards longer than 10 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16776','{19626}<0','ES: The number of nodes within the cluster has decreased','','0','1','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16777','{19627}>0','ES: The number of nodes within the cluster has increased','','0','1','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16778','{19628}=1','ES: Health is YELLOW','','0','3','All primary shards are assigned, but one or more replica shards are unassigned. 
If a node in the cluster fails, some data could be unavailable until that node is repaired.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16779','{19629}=2','ES: Health is RED','','0','4','One or more primary shards are unassigned, so some data is unavailable. 
This can occur briefly during cluster startup as primary shards are assigned.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16780','{19630}=255','ES: Health is UNKNOWN','','0','4','The health status of the cluster is unknown or cannot be obtained.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16781','{19631}>0','ES: Cluster has the unassigned shards','','0','3','The cluster has the unassigned shards longer than 10 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16782','{19632}=2','ES: Cluster has only two master nodes','','0','5','The cluster has only two nodes with a master role and will be unavailable if one of them breaks.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16783','{19633}<10m','ES: Cluster has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16784','{19634}>{$ELASTICSEARCH.RESPONSE_TIME.MAX.WARN}','ES: Service response time is too high (over {$ELASTICSEARCH.RESPONSE_TIME.MAX.WARN} for 5m)','','0','2','The performance of the TCP service is very low.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16785','{19635}=0','ES: Service is down','','0','3','The service is unavailable or does not accept TCP connections.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16786','{19636}>{$ELASTICSEARCH.FLUSH_LATENCY.MAX.WARN}','ES {#ES.NODE}: Flush latency is too high (over {$ELASTICSEARCH.FLUSH_LATENCY.MAX.WARN}ms for 5m)','','0','2','If you see this metric increasing steadily, it may indicate a problem with slow disks; this problem may escalate 
and eventually prevent you from being able to add new information to your index.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16787','{19637}>{$ELASTICSEARCH.INDEXING_LATENCY.MAX.WARN}','ES {#ES.NODE}: Indexing latency is too high (over {$ELASTICSEARCH.INDEXING_LATENCY.MAX.WARN}ms for 5m)','','0','2','If the latency is increasing, it may indicate that you are indexing too many documents at the same time (Elasticsearch’s documentation 
recommends starting with a bulk indexing size of 5 to 15 megabytes and increasing slowly from there).',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16788','{19638}>{$ELASTICSEARCH.FETCH_LATENCY.MAX.WARN}','ES {#ES.NODE}: Fetch latency is too high (over {$ELASTICSEARCH.FETCH_LATENCY.MAX.WARN}ms for 5m)','','0','2','The fetch phase should typically take much less time than the query phase. If you notice this metric consistently increasing, 
this could indicate a problem with slow disks, enriching of documents (highlighting the relevant text in search results, etc.), 
or requesting too many results.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16789','{19639}>{$ELASTICSEARCH.QUERY_LATENCY.MAX.WARN}','ES {#ES.NODE}: Query latency is too high (over {$ELASTICSEARCH.QUERY_LATENCY.MAX.WARN}ms for 5m)','','0','2','If latency exceeds a threshold, look for potential resource bottlenecks, or investigate whether you need to optimize your queries.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16790','{19640}>{$ELASTICSEARCH.HEAP_USED.MAX.WARN}','ES {#ES.NODE}: Percent of JVM heap in use is high (over {$ELASTICSEARCH.HEAP_USED.MAX.WARN}% for 1h)','','0','2','This indicates that the rate of garbage collection isn’t keeping up with the rate of garbage creation. 
To address this problem, you can either increase your heap size (as long as it remains below the recommended 
guidelines stated above), or scale out the cluster by adding more nodes.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16791','{19641}>{$ELASTICSEARCH.HEAP_USED.MAX.CRIT}','ES {#ES.NODE}: Percent of JVM heap in use is critical (over {$ELASTICSEARCH.HEAP_USED.MAX.CRIT}% for 1h)','','0','4','This indicates that the rate of garbage collection isn’t keeping up with the rate of garbage creation. 
To address this problem, you can either increase your heap size (as long as it remains below the recommended 
guidelines stated above), or scale out the cluster by adding more nodes.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16792','{19642}<10m','ES {#ES.NODE}: Node {#ES.NODE} has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16793','{19643}>0','ES {#ES.NODE}: Refresh thread pool executor has the rejected tasks (for 5m)','','0','2','The number of tasks rejected by the refresh thread pool executor is over 0 for 5m.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16794','{19644}>0','ES {#ES.NODE}: Search thread pool executor has the rejected tasks (for 5m)','','0','2','The number of tasks rejected by the search thread pool executor is over 0 for 5m.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16795','{19645}>0','ES {#ES.NODE}: Write thread pool executor has the rejected tasks (for 5m)','','0','2','The number of tasks rejected by the write thread pool executor is over 0 for 5m.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16809','{19659}>{$HAPROXY.RESPONSE_TIME.MAX.WARN}','HAProxy: Service response time is too high (over {$HAPROXY.RESPONSE_TIME.MAX.WARN} for 5m)','','0','2','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16810','{19660}=0','HAProxy: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16824','{19674}>{$CLICKHOUSE.DELAYED.FILES.DISTRIBUTED.COUNT.MAX.WARN}','ClickHouse: Too many distributed files to insert (over {$CLICKHOUSE.DELAYED.FILES.DISTRIBUTED.COUNT.MAX.WARN} for 5 min)','','0','2','"Clickhouse servers and <remote_servers> in config.xml
https://clickhouse.tech/docs/en/operations/table_engines/distributed/"',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16825','{19675}>{$CLICKHOUSE.DELAYED.INSERTS.MAX.WARN}','ClickHouse: Too many throttled insert queries (over {$CLICKHOUSE.DELAYED.INSERTS.MAX.WARN) for 5 min)','','0','2','Clickhouse have INSERT queries that are throttled due to high number of active data parts for partition in a MergeTree, please decrease INSERT frequency',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16826','{19676}>{$CLICKHOUSE.PARTS.PER.PARTITION.WARN} * 0.9','ClickHouse: Too many MergeTree parts (over 90% of {$CLICKHOUSE.PARTS.PER.PARTITION.WARN})','','0','2','"Descease INSERT queries frequency.
Clickhouse MergeTree table engine split each INSERT query to partitions (PARTITION BY expression) 
and add one or more PARTS per INSERT inside each partition, 
after that background merge process run, and when you have too much unmerged parts inside partition, 
SELECT queries performance can significate degrade, so clickhouse try delay insert, or abort it"',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16827','{19677}>{$CLICKHOUSE.NETWORK.ERRORS.MAX.WARN}','ClickHouse: Too many network errors (over {$CLICKHOUSE.NETWORK.ERRORS.MAX.WARN} in 5m)','','0','2','Number of errors (timeouts and connection failures) during query execution, background pool tasks and DNS cache update is too high.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16829','{19679}>{$CLICKHOUSE.QUERY_TIME.MAX.WARN}','ClickHouse: There are queries running more than {$CLICKHOUSE.QUERY_TIME.MAX.WARN} seconds','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16830','{19680}>{$CLICKHOUSE.REPLICA.MAX.WARN}','ClickHouse: Replication lag is too high (over {$CLICKHOUSE.REPLICA.MAX.WARN} sec for 5min)','','0','2','"When replica have too much lag, it can be skipped from Distributed SELECT Queries without errors 
and you will have wrong query results."',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16831','{19681}=1 and {19682}>0','ClickHouse: Configuration has been changed','','0','1','ClickHouse configuration has been changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16832','{19683}<10m','ClickHouse: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16833','{19684}=1','ClickHouse: Failed to fetch info data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16834','{19685}=1 and {19686}>0','ClickHouse: Version has changed (new version: {ITEM.VALUE})','','0','1','ClickHouse version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16835','{19687}>1','ClickHouse: Too many ZooKeeper sessions opened','','0','2','"Number of sessions (connections) to ZooKeeper. 
Should be no more than one, because using more than one connection to ZooKeeper may lead to bugs due to lack of linearizability (stale reads) that ZooKeeper consistency model allows."',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16836','{19688} < {19689}','ClickHouse: {#DB}.{#TABLE}: Number of active replicas less than number of total replicas','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16837','{19690}=1','ClickHouse: {#DB}.{#TABLE} Replica is readonly','','0','2','This mode is turned on if the config doesn’t have sections with ZooKeeper, if an unknown error occurred when reinitializing sessions in ZooKeeper, and during session reinitialization in ZooKeeper.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16838','{19691}=1','ClickHouse: {#DB}.{#TABLE} Replica session is expired','','0','2','This mode is turned on if the config doesn’t have sections with ZooKeeper, if an unknown error occurred when reinitializing sessions in ZooKeeper, and during session reinitialization in ZooKeeper.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16839','{19692} > {$CLICKHOUSE.LOG_POSITION.DIFF.MAX.WARN}','ClickHouse: {#DB}.{#TABLE}: Difference between log_max_index and log_pointer is too high (More than {$CLICKHOUSE.LOG_POSITION.DIFF.MAX.WARN} for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16840','{19693}>{$CLICKHOUSE.QUEUE.SIZE.MAX.WARN:"{#TABLE}"}','ClickHouse: {#DB}.{#TABLE}: Too many operations in queue (over {$CLICKHOUSE.QUEUE.SIZE.MAX.WARN} for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16841','{$IFCONTROL:"{#IFNAME}"}=1 and ({19694}=2 and {19695}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{19694}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16863','{$IFCONTROL:"{#IFNAME}"}=1 and ({19738}=2 and {19739}=1)','Interface {#IFDESCR}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{19738}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16866','{$IFCONTROL:"{#IFNAME}"}=1 and ({19744}=2 and {19745}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{19744}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16871','{19756}<{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','','0','3','',NULL,'0','2','1','{19757}>{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16883','{$IFCONTROL:"{#IFNAME}"}=1 and ({19786}=2 and {19787}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{19786}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16886','{19792}<10m','Apache: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16887','{19793}=1 and {19794}>0','Apache: Version has changed (new version: {ITEM.VALUE})','','0','1','Apache version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16888','{19795}=1','Apache: Failed to fetch status page (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16889','{19796}/{19797}*100>{$ETCD.OPEN.FDS.MAX.WARN}','Etcd: Current number of open files is too high (over {$ETCD.OPEN.FDS.MAX.WARN}% for 5m)','','0','2','"Heavy file descriptor usage (i.e., near the process’s file descriptor limit) indicates a potential file descriptor exhaustion issue. 
If the file descriptors are exhausted, etcd may panic because it cannot create new WAL files."',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16890','{19798}=1 and {19799}>0','Etcd: Cluster version has changed (new version: {ITEM.VALUE})','','0','1','Etcd version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16891','{19800}=0','Etcd: Member has no leader','','0','3','"If a member does not have a leader, it is totally unavailable."',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16892','{19801}=0','Etcd: Node healthcheck failed','','0','3','https://etcd.io/docs/v3.4.0/op-guide/monitoring/#health-check',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16893','{19802}>{$ETCD.HTTP.FAIL.MAX.WARN}','Etcd: Too many HTTP requests failures (over {$ETCD.HTTP.FAIL.MAX.WARN} for 5m)''','','0','2','"Too many reqvests failed on etcd instance with 5xx HTTP code"',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16894','{19803}=1','Etcd: Failed to fetch info data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16895','{19804}>{$ETCD.LEADER.CHANGES.MAX.WARN}','Etcd: Instance has seen too many leader changes (over {$ETCD.LEADER.CHANGES.MAX.WARN} for 15m)''','','0','2','Rapid leadership changes impact the performance of etcd significantly. It also signals that the leader is unstable, perhaps due to network connectivity issues or excessive load hitting the etcd cluster.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16896','{19805}>{$ETCD.PROPOSAL.FAIL.MAX.WARN}','Etcd: Too many proposal failures (over {$ETCD.PROPOSAL.FAIL.MAX.WARN} for 5m)''','','0','2','"Normally related to two issues: temporary failures related to a leader election or 
longer downtime caused by a loss of quorum in the cluster."',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16897','{19806}>{$ETCD.PROPOSAL.PENDING.MAX.WARN}','Etcd: Too many proposals are queued to commit (over {$ETCD.PROPOSAL.PENDING.MAX.WARN} for 5m)''','','0','2','"Rising pending proposals suggests there is a high client load or the member cannot commit proposals."',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16898','{19807}=1 and {19808}>0','Etcd: Server version has changed (new version: {ITEM.VALUE})','','0','1','Etcd version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16899','{19809}<10m','Etcd: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16900','{19810}=0','Etcd: Service is unavailable','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16901','{19811}>{$ETCD.GRPC.ERRORS.MAX.WARN}','Etcd: Too many failed gRPC requests with code: {#GRPC.CODE} (over {$ETCD.GRPC.ERRORS.MAX.WARN} in 5m)','','0','2','',NULL,'0','2','0','','0','','0','','1');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16902','{19812}=0','IIS: Port {$IIS.PORT} is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16903','{19813}<10m','IIS: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16904','{19814}<>0','IIS: The World Wide Web Publishing Service (W3SVC) is not running','','0','4','The World Wide Web Publishing Service (W3SVC) is not in running state. IIS cannot start.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16905','{19815}<>0','IIS: Windows process Activation Service (WAS) is not the running','','0','4','Windows Process Activation Service (WAS) is not in the running state. IIS cannot start.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16906','{19816}<>3 and {$IIS.APPPOOL.MONITORED:"{#APPPOOL}"}=1','IIS: Application pool {#APPPOOL} is not in Running state','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16907','{19817}<10m','IIS: {#APPPOOL} has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16908','{19818}=1 and {$IIS.APPPOOL.MONITORED:"{#APPPOOL}"}=1','IIS: Application pool {#APPPOOL} has been recycled','','0','1','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16909','{19819}>{$IIS.QUEUE.MAX.WARN}','IIS: Request queue of {#APPPOOL} is too large (over {$IIS.QUEUE.MAX.WARN})','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16910','{19820}=0','IIS: Port {$IIS.PORT} is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16911','{19821}<10m','IIS: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16912','{19822}<>0','IIS: The World Wide Web Publishing Service (W3SVC) is not running','','0','4','The World Wide Web Publishing Service (W3SVC) is not in running state. IIS cannot start.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16913','{19823}<>0','IIS: Windows process Activation Service (WAS) is not the running','','0','4','Windows Process Activation Service (WAS) is not in the running state. IIS cannot start.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16914','{19824}<>3 and {$IIS.APPPOOL.MONITORED:"{#APPPOOL}"}=1','IIS: Application pool {#APPPOOL} is not in Running state','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16915','{19825}<10m','IIS: {#APPPOOL} has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16916','{19826}=1 and {$IIS.APPPOOL.MONITORED:"{#APPPOOL}"}=1','IIS: Application pool {#APPPOOL} has been recycled','','0','1','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16917','{19827}>{$IIS.QUEUE.MAX.WARN}','IIS: Request queue of {#APPPOOL} is too large (over {$IIS.QUEUE.MAX.WARN})','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16918','{19828}=1 and {19829}>0','Zabbix version has changed (new version: {ITEM.VALUE})','','0','1','Zabbix proxy version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16920','{19832}=0 or {19833} = 0','ClickHouse: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16921','{19834}=0','ClickHouse: Port {$CLICKHOUSE.PORT} is unavaliable','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16925','{19841} * 100 > 10 * {19842}','MSSQL: Too frequently pointers using','','0','2','Rows with varchar columns can experience expansion when varchar values are updated with a longer string.  In the case where the row cannot fit in the existing page, the row migrates and access to the row will traverse a pointer.  This only happens on heaps (tables without clustered indexes). Evaluate clustered index for heap tables.  In cases where clustered indexes cannot be used, drop non-clustered indexes, build a clustered index to reorg pages and rows, drop the clustered index, then recreate non-clustered indexes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16927','{19845}>{$MSSQL.AVERAGE_WAIT_TIME.MAX}','MSSQL: Total average wait time for locks is high (over {$MSSQL.AVERAGE_WAIT_TIME.MAX}ms for 5m)','','0','2','An average wait time longer than 500ms may indicate excessive blocking. This value should generally correlate to ''Lock Waits/sec'' and move up or down with it accordingly.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16928','{19846}<{$MSSQL.BUFFER_CACHE_RATIO.MIN.CRIT}','MSSQL: Percentage of the buffer cache efficiency is low (below {$MSSQL.BUFFER_CACHE_RATIO.MIN.CRIT}% for 5m)','','0','4','Too low buffer cache hit ratio.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16929','{19847}<{$MSSQL.BUFFER_CACHE_RATIO.MIN.WARN}','MSSQL: Percentage of the buffer cache efficiency is low (below {$MSSQL.BUFFER_CACHE_RATIO.MIN.WARN}% for 5m)','','0','2','Low buffer cache hit ratio.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16930','{19848}>{$MSSQL.FREE_LIST_STALLS.MAX}','MSSQL: Number of rps waiting for a free page is high (over {$MSSQL.FREE_LIST_STALLS.MAX} for 5m)','','0','2','Some requests have to wait for a free page.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16931','{19849}>{$MSSQL.LAZY_WRITES.MAX}','MSSQL: Number of buffers written per second by the lazy writer is high (over {$MSSQL.LAZY_WRITES.MAX} for 5m)','','0','2','The number of buffers written per second by the buffer manager''s lazy writer exceeds the threshold.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16932','{19850}>{$MSSQL.LOCK_REQUESTS.MAX}','MSSQL: Total number of locks per second is high (over {$MSSQL.LOCK_REQUESTS.MAX} for 5m)','','0','2','Number of new locks and lock conversions per second requested from the lock manager is high.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16933','{19851}>{$MSSQL.LOCK_TIMEOUTS.MAX}','MSSQL: Total lock requests per second that timed out is high (over {$MSSQL.LOCK_TIMEOUTS.MAX} for 5m)','','0','2','The total number of timed out lock requests per second, including requests for NOWAIT locks, is high.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16934','{19852}>0','MSSQL: Some blocking is occurring for 5m','','0','3','Values greater than zero indicate at least some blocking is occurring, while a value of zero can quickly eliminate blocking as a potential root-cause problem.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16935','{19853}>{$MSSQL.DEADLOCKS.MAX}','MSSQL: Number of deadlock is high (over {$MSSQL.DEADLOCKS.MAX} for 5m)','','0','3','Too many deadlocks are occurring currently.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16936','{19854}<{$MSSQL.PAGE_LIFE_EXPECTANCY.MIN}','MSSQL: Page life expectancy is low (less {$MSSQL.PAGE_LIFE_EXPECTANCY.MIN}min for 15m)','','0','4','The page stays in the buffer pool without references of less time than the threshold value.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16937','{19855}>{$MSSQL.PAGE_READS.MAX}','MSSQL: Number of physical database page reads per second is high (over {$MSSQL.PAGE_READS.MAX} for 5m)','','0','2','The physical database page reads are issued too frequently.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16938','{19856}>{$MSSQL.PAGE_WRITES.MAX}','MSSQL: Number of physical database page writes per second is high (over {$MSSQL.PAGE_WRITES.MAX} for 5m)','','0','2','The physical database page writes are issued too frequently.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16939','{19857}<10m','MSSQL: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16940','{19858}=1','MSSQL: Failed to fetch info data (or no data for 30m)','','0','1','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16941','{19859}=1 and {19860}>0','MSSQL: Version has changed (new version value received: {ITEM.VALUE})','','0','1','MSSQL version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16944','{19863}<{$MSSQL.WORKTABLES_FROM_CACHE_RATIO.MIN.CRIT}','MSSQL: Percentage of work tables available from the work table cache is low (below {$MSSQL.WORKTABLES_FROM_CACHE_RATIO.MIN.CRIT}% for 5m)','','0','4','A value less than 90% may indicate insufcient memory, since execution plans are being dropped, or on 32-bit systems, may indicate the need for an upgrade to a 64-bit system',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16946','{19865}=0','MSSQL AG ''{#GROUP_NAME}'': Primary replica recovery health in progress','','0','2','The primary replica is in the synchronization process.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16947','{19866}=0','MSSQL AG ''{#GROUP_NAME}'': Secondary replica recovery health in progress','','0','2','The secondary replica is in the synchronization process.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16948','{19867}=0','MSSQL AG ''{#GROUP_NAME}'': All replicas unhealthy','','0','5','None of the availability replicas have a healthy synchronization.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16949','{19868}=1','MSSQL AG ''{#GROUP_NAME}'': Some replicas unhealthy','','0','4','The synchronization health of some, but not all, availability replicas is healthy.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16950','{19869}>{$MSSQL.LOG_FLUSH_WAIT_TIME.MAX:"{#DBNAME}"}','MSSQL DB ''{#DBNAME}'': Total wait time to flush the log is high (over {$MSSQL.LOG_FLUSH_WAIT_TIME.MAX:"{#DBNAME}"}ms for 5m)','','0','2','The wait time to flush the log is too long.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16951','{19870}>{$MSSQL.LOG_FLUSH_WAITS.MAX:"{#DBNAME}"}','MSSQL DB ''{#DBNAME}'': Number of commits waiting for the log flush is high (over {$MSSQL.LOG_FLUSH_WAITS.MAX:"{#DBNAME}"}/sec for 5m)','','0','2','Too many commits are waiting for the log flush.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16954','{19873}>{$MSSQL.PERCENT_LOG_USED.MAX:"{#DBNAME}"}','MSSQL DB ''{#DBNAME}'': Percent of log using is high (over {$MSSQL.PERCENT_LOG_USED.MAX:"{#DBNAME}"}% for 5m)','','0','2','There''s not enough space left in the log.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16955','{19874}>1','MSSQL DB ''{#DBNAME}'': State is {ITEM.VALUE}','','0','4','The DB has a non-working state.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16956','{19875}>0','MSSQL AG ''{#GROUP_NAME}'' Local DB ''{#DBNAME}'': "{#DBNAME}" is {ITEM.VALUE}','','0','2','The local availability database has a non-working state.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16957','{19876}=0','MSSQL AG ''{#GROUP_NAME}'' Local DB ''{#DBNAME}'': "{#DBNAME}" is Not healthy','','0','4','The synchronization state of the local availability database is NOT SYNCHRONIZING.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16958','{19877}=1','MSSQL AG ''{#GROUP_NAME}'' Local DB ''{#DBNAME}'': "{#DBNAME}" is Partially healthy','','0','3','A database on a synchronous-commit availability replica is considered partially healthy if synchronization state is SYNCHRONIZING.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16959','{19878}>=0 and {19878}<=2','MSSQL Mirroring ''{#DBNAME}'': "{#DBNAME}" is {ITEM.VALUE}','','0','1','The state of the mirror database and of the database mirroring session is "Suspended", "Disconnected from the other partner", or "Synchronizing".',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16960','{19879}=3','MSSQL Mirroring ''{#DBNAME}'': "{#DBNAME}" is {ITEM.VALUE}','','0','2','The state of the mirror database and of the database mirroring session is "Pending Failover".',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16961','{19880}=5','MSSQL Mirroring ''{#DBNAME}'': "{#DBNAME}" is {ITEM.VALUE}','','0','4','The state of the mirror database and of the database mirroring session is "Not synchronized". The partners are not synchronized. A failover is not possible now.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16962','{19881}=2','MSSQL Mirroring ''{#DBNAME}'': "{#DBNAME}" Witness is disconnected','','0','2','The state of the witness in the database mirroring session of the database is "Disconnected".',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16965','{19888}=0 and {19889}=2','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': {#REPLICA_NAME} is disconnected','','0','2','The response of an availability replica to the DISCONNECTED state depends on its role: 
On the primary replica, if a secondary replica is disconnected, its secondary databases are marked as NOT SYNCHRONIZED on the primary replica, which waits for the secondary to reconnect; On a secondary replica, upon detecting that it is disconnected, the secondary replica attempts to reconnect to the primary replica.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16966','{19890}=0 or {19890}=1 or {19890}=3','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': {#REPLICA_NAME} is {ITEM.VALUE}','','0','2','The operational state of the replica in a given availability group is "Pending" or "Offline".',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16967','{19891}=4','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': {#REPLICA_NAME} is {ITEM.VALUE}','','0','3','The operational state of the replica in a given availability group is "Failed".',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16968','{19892}=5','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': {#REPLICA_NAME} is {ITEM.VALUE}','','0','4','The operational state of the replica in a given availability group is "Failed, no quorum".',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16969','{19893}=0','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': {#REPLICA_NAME} Recovery in progress','','0','1','At least one joined database has a database state other than ONLINE.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16970','{19894}=0','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': {#REPLICA_NAME} is Not healthy','','0','3','At least one joined database is in the NOT SYNCHRONIZING state.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16971','{19895}=1','MSSQL AG ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}'': {#REPLICA_NAME} is Partially healthy','','0','2','Some replicas are not in the target synchronization state: synchronous-commit replicas should be synchronized, and asynchronous-commit replicas should be synchronizing.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16972','{19896}>{$MYSQL.CREATED_TMP_DISK_TABLES.MAX.WARN}','MySQL: Number of on-disk temporary tables created per second is high (over {$MYSQL.CREATED_TMP_DISK_TABLES.MAX.WARN} for 5m)','','0','2','Possibly the application using the database is in need of query optimization.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16973','{19897}>{$MYSQL.CREATED_TMP_FILES.MAX.WARN}','MySQL: Number of temporary files created per second is high (over {$MYSQL.CREATED_TMP_FILES.MAX.WARN} for 5m)','','0','2','Possibly the application using the database is in need of query optimization.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16974','{19898}>{$MYSQL.CREATED_TMP_TABLES.MAX.WARN}','MySQL: Number of internal temporary tables created per second is high (over {$MYSQL.CREATED_TMP_TABLES.MAX.WARN} for 5m)','','0','2','Possibly the application using the database is in need of query optimization.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16975','{19899}=1','MySQL: Failed to fetch info data (or no data for 30m)','','0','1','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16976','{19900}>{$MYSQL.CREATED_TMP_DISK_TABLES.MAX.WARN}','MySQL: Number of on-disk temporary tables created per second is high (over {$MYSQL.CREATED_TMP_DISK_TABLES.MAX.WARN} for 5m)','','0','2','Possibly the application using the database is in need of query optimization.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16977','{19901}>{$MYSQL.CREATED_TMP_FILES.MAX.WARN}','MySQL: Number of temporary files created per second is high (over {$MYSQL.CREATED_TMP_FILES.MAX.WARN} for 5m)','','0','2','Possibly the application using the database is in need of query optimization.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16978','{19902}>{$MYSQL.CREATED_TMP_TABLES.MAX.WARN}','MySQL: Number of internal temporary tables created per second is high (over {$MYSQL.CREATED_TMP_TABLES.MAX.WARN} for 5m)','','0','2','Possibly the application using the database is in need of query optimization.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16979','{19903}=1','MySQL: Failed to fetch info data (or no data for 30m)','','0','1','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16980','{19904}>{$MYSQL.CREATED_TMP_DISK_TABLES.MAX.WARN}','MySQL: Number of on-disk temporary tables created per second is high (over {$MYSQL.CREATED_TMP_DISK_TABLES.MAX.WARN} for 5m)','','0','2','Possibly the application using the database is in need of query optimization.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16981','{19905}>{$MYSQL.CREATED_TMP_FILES.MAX.WARN}','MySQL: Number of temporary files created per second is high (over {$MYSQL.CREATED_TMP_FILES.MAX.WARN} for 5m)','','0','2','Possibly the application using the database is in need of query optimization.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16982','{19906}>{$MYSQL.CREATED_TMP_TABLES.MAX.WARN}','MySQL: Number of internal temporary tables created per second is high (over {$MYSQL.CREATED_TMP_TABLES.MAX.WARN} for 5m)','','0','2','Possibly the application using the database is in need of query optimization.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16983','{19907}=1','MySQL: Failed to fetch info data (or no data for 30m)','','0','1','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16984','{19908} > {$PG.CONN_TOTAL_PCT.MAX.WARN}','Connections sum: Total number of connections is too high (over {$PG.CONN_TOTAL_PCT.MAX.WARN} in 5m)','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16986','{19910}=0','PostgreSQL: Service is down','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16987','{19911} < 600','PostgreSQL: Service has been restarted (uptime={ITEM.LASTVALUE})','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16988','{19912} > {$PG.CONFLICTS.MAX.WARN:"{#DBNAME}"}','DB {#DBNAME}: Too many recovery conflicts (over {$PG.CONFLICTS.MAX.WARN:"{#DBNAME}"} in 5m)','','0','3','The primary and standby servers are in many ways loosely connected. Actions on the primary will have an effect on the standby. As a result, there is potential for negative interactions or conflicts between them.
https://www.postgresql.org/docs/current/hot-standby.html#HOT-STANDBY-CONFLICT',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16989','{19913} > {$PG.DEADLOCKS.MAX.WARN:"{#DBNAME}"}','DB {#DBNAME}: Deadlock occurred (over {$PG.DEADLOCKS.MAX.WARN:"{#DBNAME}"} in 5m)','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16993','{19917} > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"} or {19918} > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk read/write request responses are too high (read > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"} ms for 15m or write > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"} ms for 15m)','','0','2','This trigger might indicate disk {#DEVNAME} saturation.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16994','{$IFCONTROL:"{#IFNAME}"}=1 and ({19919}=2 and {19920}=1)','Interface {#IFNAME}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{19919}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17001','{19931} > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"} or {19932} > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk read/write request responses are too high (read > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"} ms for 15m or write > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"} ms for 15m)','','0','2','This trigger might indicate disk {#DEVNAME} saturation.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17002','{$IFCONTROL:"{#IFNAME}"}=1 and ({19933}=2 and {19934}=1)','Interface {#IFNAME}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{19933}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17005','{19939} - {19940} * 2 > {$CPU.QUEUE.CRIT.MAX}','CPU queue length is too high (over {$CPU.QUEUE.CRIT.MAX} for 5m)','','0','2','The CPU Queue Length in the last 5 minutes exceeds {$CPU.QUEUE.CRIT.MAX}. According to actual observations, PQL should not exceed the number of cores * 2. To fine-tune the conditions, use the macro {$CPU.QUEUE.CRIT.MAX }.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17009','{19947}>{$VFS.DEV.UTIL.MAX.WARN}','{#DEVNAME}: Disk is overloaded (util > {$VFS.DEV.UTIL.MAX.WARN}% for 15m)','','0','2','The disk appears to be under heavy load',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17011','{19949} - {19950} * 2 > {$CPU.QUEUE.CRIT.MAX}','CPU queue length is too high (over {$CPU.QUEUE.CRIT.MAX} for 5m)','','0','2','The CPU Queue Length in the last 5 minutes exceeds {$CPU.QUEUE.CRIT.MAX}. According to actual observations, PQL should not exceed the number of cores * 2. To fine-tune the conditions, use the macro {$CPU.QUEUE.CRIT.MAX }.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17015','{19957}>{$VFS.DEV.UTIL.MAX.WARN}','{#DEVNAME}: Disk is overloaded (util > {$VFS.DEV.UTIL.MAX.WARN}% for 15m)','','0','2','The disk appears to be under heavy load',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17063','{20054}>{20055}','GarbageCollector: Concurrent Mark Sweep in fire fighting mode','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17064','{20056}>{20057}','GarbageCollector: Mark Sweep Compact in fire fighting mode','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17065','{20058}>{20059}','GarbageCollector: PS Mark Sweep in fire fighting mode','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17066','{20060}>({20061}*{$JMX.HEAP.MEM.USAGE.MAX}/100)','Memory: Heap memory usage more than {$JMX.HEAP.USAGE.MAX}% for {$JMX.HEAP.MEM.USAGE.TIME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17067','{20062}>({20063}*{$JMX.NONHEAP.MEM.USAGE.MAX}/100)','Memory: Non-Heap memory usage more than {$JMX.NONHEAP.MEM.USAGE.MAX}% for {$JMX.NONHEAP.MEM.USAGE.TIME}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17068','{20064}>({20065}*{$JMX.MP.USAGE.MAX:"CMS Old Gen"}/100)','MemoryPool: CMS Old Gen memory usage more than {$JMX.MP.USAGE.MAX:"CMS Old Gen"}% for {$JMX.MP.USAGE.TIME:"CMS Old Gen"}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17069','{20066}>({20067}*{$JMX.MP.USAGE.MAX:"CMS Perm Gen"}/100)','MemoryPool: CMS Perm Gen memory usage more than {$JMX.MP.USAGE.MAX:"CMS Perm Gen"}% for {$JMX.MP.USAGE.TIME:"CMS Perm Gen"}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17070','{20068}>({20069}*{$JMX.MP.USAGE.MAX:"Code Cache"}/100)','MemoryPool: Code Cache memory usage more than {$JMX.MP.USAGE.MAX:"Code Cache"}% for {$JMX.MP.USAGE.TIME:"Code Cache"}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17071','{20070}>({20071}*{$JMX.MP.USAGE.MAX:"Perm Gen"}/100)','MemoryPool: Perm Gen memory usage more than {$JMX.MP.USAGE.MAX:"Perm Gen"}% for {$JMX.MP.USAGE.TIME:"Perm Gen"}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17072','{20072}>({20073}*{$JMX.MP.USAGE.MAX:"PS Old Gen"}/100)','MemoryPool: PS Old Gen memory usage more than {$JMX.MP.USAGE.MAX:"PS Old Gen"}% for {$JMX.MP.USAGE.TIME:"PS Old Gen"}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17073','{20074}>({20075}*{$JMX.MP.USAGE.MAX:"PS Perm Gen"}/100)','MemoryPool: PS Perm Gen memory usage more than {$JMX.MP.USAGE.MAX:"PS Perm Gen"}% for {$JMX.MP.USAGE.TIME:"PS Perm Gen"}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17074','{20076}>({20077}*{$JMX.MP.USAGE.MAX:"Tenured Gen"}/100)','MemoryPool: Tenured Gen memory usage more than {$JMX.MP.USAGE.MAX:"Tenured Gen"}% for {$JMX.MP.USAGE.TIME:"Tenured Gen"}','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17075','{20078}>({20079}*{$JMX.FILE.DESCRIPTORS.MAX}/100)','OperatingSystem: Opened file descriptor count more than {$JMX.FILE.DESCRIPTORS.MAX}% of maximum','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17076','{20080}=1','Compilation: {HOST.NAME} uses suboptimal JIT compiler','','0','1','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17077','{20081}>{$JMX.CPU.LOAD.MAX}','OperatingSystem: Process CPU Load more than {$JMX.CPU.LOAD.MAX}% for {$JMX.CPU.LOAD.TIME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17078','{20082}=1','Runtime: JVM is not reachable','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17079','{20083}<>1','Runtime: {HOST.NAME} runs suboptimal VM type','','0','1','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17080','{20084}<10m','VMware: {HOST.HOST} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17081','{20085}=3','VMware: The {HOST.HOST} health is Red','','0','4','One or more components in the appliance might be in an unusable status and the appliance might become unresponsive soon. Security patches might be available.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17082','{20086}=2','VMware: The {HOST.HOST} health is Yellow','','0','3','One or more components in the appliance might become overloaded soon.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17083','{20087}=3','VMware: The {HOST.HOST} health is Red','','0','4','One or more components in the appliance might be in an unusable status and the appliance might become unresponsive soon. Security patches might be available.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17084','{20088}=2','VMware: The {HOST.HOST} health is Yellow','','0','3','One or more components in the appliance might become overloaded soon.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17085','{20089}<10m','VMware: {HOST.HOST} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17089','{20096}<20M','Lack of available memory on server {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17090','{20097}<20','Free disk space is less than 20% on volume {#FSNAME}','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17091','{20098}<20','Free inodes is less than 20% on volume {#FSNAME}','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17092','{20099}<1024','Configured max number of opened files is too low on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17093','{20100}<256','Configured max number of processes is too low on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17094','{20101}<20M','Lack of available memory on server {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17095','{20102}<50','Lack of free swap space on {HOST.NAME}','','0','2','It probably means that the systems requires more physical memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17096','{20103}<20','Free disk space is less than 20% on volume {#FSNAME}','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17097','{20104}<20','Free inodes is less than 20% on volume {#FSNAME}','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17098','{20105}<20M','Lack of available memory on server {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17099','{20106}<20','Free disk space is less than 20% on volume {#FSNAME}','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17100','{20107}<20','Free inodes is less than 20% on volume {#FSNAME}','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17101','{20108}<1024','Configured max number of opened files is too low on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17102','{20109}<256','Configured max number of processes is too low on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17103','{20110}<20M','Lack of available memory on server {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17104','{20111}<20','Free disk space is less than 20% on volume {#FSNAME}','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17105','{20112}<20','Free inodes is less than 20% on volume {#FSNAME}','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17106','{20113}<1024','Configured max number of opened files is too low on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17107','{20114}<256','Configured max number of processes is too low on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17108','{20115}<20M','Lack of available memory on server {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17109','{20116}<50','Lack of free swap space on {HOST.NAME}','','0','2','It probably means that the systems requires more physical memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17110','{20117}<20','Free disk space is less than 20% on volume {#FSNAME}','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17111','{20118}<20','Free inodes is less than 20% on volume {#FSNAME}','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17112','{20119}<256','Configured max number of processes is too low on {HOST.NAME}','','0','1','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17113','{20120}<20M','Lack of available memory on server {HOST.NAME}','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17114','{20121}<50','Lack of free swap space on {HOST.NAME}','','0','2','It probably means that the systems requires more physical memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17115','{20122}<20','Free disk space is less than 20% on volume {#FSNAME}','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17116','{20123}<20','Free inodes is less than 20% on volume {#FSNAME}','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17117','{20124}<1.597 or {20124}>2.019','BB +1.8V SM Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17118','{20125}<1.646 or {20125}>1.960','BB +1.8V SM Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17119','{20126}<2.876 or {20126}>3.729','BB +3.3V Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17120','{20127}<2.970 or {20127}>3.618','BB +3.3V Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17121','{20128}<2.876 or {20128}>3.729','BB +3.3V STBY Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17122','{20129}<2.970 or {20129}>3.618','BB +3.3V STBY Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17123','{20130}<4.362 or {20130}>5.663','BB +5.0V Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17124','{20131}<4.483 or {20131}>5.495','BB +5.0V Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17125','{20132}<5 or {20132}>66','BB Ambient Temp Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17126','{20133}<10 or {20133}>61','BB Ambient Temp Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17127','{20134}=0','Power','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17128','{20135}<5 or {20135}>90','Baseboard Temp Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17129','{20136}<10 or {20136}>83','Baseboard Temp Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17130','{20137}<0.953 or {20137}>1.149','BB +1.05V PCH Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17131','{20138}<0.985 or {20138}>1.117','BB +1.05V PCH Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17132','{20139}<0.683 or {20139}>1.543','BB +1.1V P1 Vccp Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17133','{20140}<0.708 or {20140}>1.501','BB +1.1V P1 Vccp Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17134','{20141}<1.362 or {20141}>1.635','BB +1.5V P1 DDR3 Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17135','{20142}<1.401 or {20142}>1.589','BB +1.5V P1 DDR3 Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17136','{20143}<2.982 or {20143}>3.625','BB +3.3V Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17137','{20144}<3.067 or {20144}>3.525','BB +3.3V Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17138','{20145}<2.982 or {20145}>3.625','BB +3.3V STBY Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17139','{20146}<3.067 or {20146}>3.525','BB +3.3V STBY Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17140','{20147}<4.471 or {20147}>5.538','BB +5.0V Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17141','{20148}<4.630 or {20148}>5.380','BB +5.0V Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17142','{20149}<0 or {20149}>48','Front Panel Temp Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17143','{20150}<5 or {20150}>44','Front Panel Temp Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17144','{20151}=0','Power','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17145','{20152}<324','System Fan 2 Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17146','{20153}<378','System Fan 2 Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17147','{20154}<324','System Fan 3 Critical [{ITEM.VALUE}]','','0','5','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17148','{20155}<378','System Fan 3 Non-Critical [{ITEM.VALUE}]','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17149','{20156} > {$MSSQL.PERCENT_READAHEAD.MAX} / 100 * {20157}','MSSQL: Too many physical reads occurring','','0','2','If this value makes up even a sizeable minority of the total Page Reads/sec (say, greater than 20% of the total page reads), you may have too many physical reads occurring.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17150','{20158} > {$MSSQL.PERCENT_COMPILATIONS.MAX}','MSSQL: Percent of adhoc queries running is over {$MSSQL.PERCENT_COMPILATIONS.MAX}% for 15m','','0','2','The lower this value is the better. High values often indicate excessive adhoc querying and should be as low as possible. If excessive adhoc querying is happening, try rewriting the queries as procedures or invoke the queries using sp_executeSQL. When rewriting isn’t possible, consider using a plan guide or setting the database to parameterization forced mode.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17151','{20159} > {$MSSQL.PERCENT_RECOMPILATIONS.MAX}','MSSQL: Percent of times statement recompiles is over {$MSSQL.PERCENT_RECOMPILATIONS.MAX}% for 15m','','0','2','This number should be at or near zero, since recompiles can cause deadlocks and exclusive compile locks. This counter’s value should follow in proportion to “Batch Requests/sec” and “SQL Compilations/sec”.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17152','{20160} > 0.001','MSSQL: Index and table scans are often than index searches for 15m','','0','2','Index searches are preferable to index and table scans. For OLTP applications, optimize for more index searches and less scans (preferably, 1 full scan for every 1000 index searches). Index and table scans are expensive I/O operations.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17153','{20161}=0','MSSQL: Service is unavailable','','0','5','The TCP port of the MS SQL Server service is currently unavailable.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17154','{20162} * 100 / {20163} > {$ORACLE.PROCESSES.MAX.WARN}','Oracle: Too many active processes (over {$ORACLE.PROCESSES.MAX.WARN}% for 5 min)','','0','2','Active processes are using more than {$ORACLE.PROCESSES.MAX.WARN}% of the available number of processes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17155','{20164} * 100 / {20165} > {$ORACLE.SESSIONS.MAX.WARN}','Oracle: Too many active sessions (over {$ORACLE.SESSIONS.MAX.WARN}% for 5 min)','','0','2','Active sessions are using more than {$ORACLE.SESSIONS.MAX.WARN}% of the available sessions.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17156','{20166} * 100 / {20167} > {$ORACLE.DB.FILE.MAX.WARN}','Oracle: Too many database files (over {$ORACLE.DB.FILE.MAX.WARN}% for 5 min)','','0','2','Number of datafiles is higher than {$ORACLE.DB.FILE.MAX.WARN}% of the available datafile files limit.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17157','{20168} * 100 / {20169} > {$ORACLE.PGA.USE.MAX.WARN}','Oracle: Total PGA inuse is too high (over {$ORACLE.PGA.USE.MAX.WARN}% for 5 min)','','0','2','Total PGA in use is more than {$ORACLE.PGA.USE.MAX.WARN}% of PGA_AGGREGATE_TARGET.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17158','{20170}=1 and {20171}>0','Oracle: Instance hostname has changed (new hostname received: {ITEM.VALUE})','','0','1','Oracle DB Instance hostname has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17159','{20172}=1 and {20173}>0','Oracle: Instance name has changed (new name received: {ITEM.VALUE})','','0','1','Oracle DB Instance name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17160','{20174}=0','Oracle: Connection to database is unavailable','','0','5','Connection to Oracle Database is currently unavailable.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17161','{20175} < {$ORACLE.REDO.MIN.WARN}','Oracle: Number of REDO logs available for switching is too low (less {$ORACLE.REDO.MIN.WARN} for 5 min)','','0','2','Number of available for log switching inactive/unused REDOs is low (Database down risk)',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17163','{20177} > {$ORACLE.SESSIONS.LOCK.MAX.WARN}','Oracle: Too many locked sessions (over {$ORACLE.SESSIONS.LOCK.MAX.WARN}% for 5 min)','','0','2','Number of locked sessions is over {$ORACLE.SESSIONS.LOCK.MAX.WARN}% of the running sessions.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17164','{20178} > {$ORACLE.SESSION.LONG.LOCK.MAX.WARN}','Oracle: Too many sessions locked over {$ORACLE.SESSION.LOCK.MAX.TIME}s (over {$ORACLE.SESSION.LONG.LOCK.MAX.WARN} for 5 min)','','0','2','Number of sessions locked over {$ORACLE.SESSION.LOCK.MAX.TIME} seconds is too high. Long-term locks can negatively affect database performance, therefore, if they are detected, you should first find the most difficult queries from the database point of view and analyze possible resource leaks.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17165','{20179}<{$ORACLE.SHARED.FREE.MIN.WARN}','Oracle: Shared pool free is too low (less {$ORACLE.SHARED.FREE.MIN.WARN}% for 5m)','','0','2','The shared pool free memory percent has been less than {$ORACLE.SHARED.FREE.MIN.WARN}% in the last 5 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17166','{20180}=1','Oracle: Failed to fetch info data (or no data for 30m)','','0','1','Zabbix has not received data for items for the last 5 minutes. The database might be unavailable for connecting.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17167','{20181}<10m','Oracle: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17168','{20182}  < {$ORACLE.EXPIRE.PASSWORD.MIN.WARN}','Oracle: Zabbix account will expire soon (under {$ORACLE.EXPIRE.PASSWORD.MIN.WARN} days)','','0','2','Password for zabbix user in the database will expire soon.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17169','{20183}=1 and {20184}>0','Oracle: Version has changed (new version value received: {ITEM.VALUE})','','0','1','Oracle DB version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17170','{20185}<2','Archivelog ''{#DEST_NAME}'': Log Archive is not valid','','0','4','ARL destination not in 3 - Valid or 2 - Deferred.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17171','{20186} = 0 and {20187} = 1','Oracle Database ''{#DBNAME}'': Force logging is deactivated for DB with active Archivelog','','0','2','Force Logging mode  - it is very important metric for Databases in ''ARCHIVELOG''. This feature allows to forcibly write all transactions to the REDO.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17172','{20188}=1','Oracle Database ''{#DBNAME}'': Open status in mount mode','','0','2','The Oracle DB has a MOUNTED state.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17173','{20189}=1','Oracle Database ''{#DBNAME}'': Open status has changed (new value received: {ITEM.VALUE})','','0','1','Oracle DB open status has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17174','{20190}=1','Oracle Database ''{#DBNAME}'': Role has changed (new value received: {ITEM.VALUE})','','0','1','Oracle DB role has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17175','{20191}>{$ORACLE.ASM.USED.PCT.MAX.WARN}','ASM ''{#DG_NAME}'': Disk group usage is too high (over {$ORACLE.ASM.USED.PCT.MAX.WARN}% for 5m)','','0','2','Usage percent of ASM disk group is over {$ORACLE.ASM.USED.PCT.MAX.WARN}',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17176','{20192}>{$ORACLE.ASM.USED.PCT.MAX.HIGH}','ASM ''{#DG_NAME}'': Disk group usage is too high (over {$ORACLE.ASM.USED.PCT.MAX.HIGH}% for 5m)','','0','4','Usage percent of ASM disk group is over {$ORACLE.ASM.USED.PCT.MAX.WARN}',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17177','{20193}=1','Oracle Database ''{#DBNAME}'': Open status in mount mode','','0','2','The Oracle DB has a MOUNTED state.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17178','{20194}=1','Oracle Database ''{#DBNAME}'': Open status has changed (new value received: {ITEM.VALUE})','','0','1','Oracle DB open status has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17179','{20195}=2','Oracle TBS ''{#TABLESPACE}'': Tablespase is OFFLINE','','0','2','The tablespase is in the offline state.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17180','{20196}=1','Oracle TBS ''{#TABLESPACE}'': Tablespace status has changed (new value received: {ITEM.VALUE})','','0','1','Oracle tablespace status has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17194','{20216}>{$TEMP_WARN:""}
or
{20217}={$TEMP_WARN_STATUS}','{#SENSOR_INFO}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20218}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17195','{20219}>{$TEMP_CRIT:"{#SNMPVALUE}"}
or
{20220}={$TEMP_CRIT_STATUS}
or
{20220}={$TEMP_DISASTER_STATUS}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:"{#SNMPVALUE}"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20221}<{$TEMP_CRIT:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17196','{20222}>{$TEMP_WARN:"{#SNMPVALUE}"}
or
{20223}={$TEMP_WARN_STATUS}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:"{#SNMPVALUE}"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20224}<{$TEMP_WARN:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17203','{20243}>{$TEMP_CRIT:""}
or
{20244}={$TEMP_CRIT_STATUS}','Device: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','0','1','{20245}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17204','{20246}>{$TEMP_CRIT:""}
or
{20247}={$TEMP_CRIT_STATUS}','{#SENSOR_INFO}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20248}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17205','{20249}>{$TEMP_WARN:""}
or
{20250}={$TEMP_WARN_STATUS}','{#SENSOR_INFO}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20251}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17207','{20255}>{$TEMP_WARN:"Device"}','Device: Temperature is above warning threshold: >{$TEMP_WARN:"Device"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20256}<{$TEMP_WARN:"Device"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17208','{20257}>{$TEMP_CRIT:"Device"}','Device: Temperature is above critical threshold: >{$TEMP_CRIT:"Device"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20258}<{$TEMP_CRIT:"Device"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17209','{20259}<{$TEMP_CRIT_LOW:"Device"}','Device: Temperature is too low: <{$TEMP_CRIT_LOW:"Device"}','','0','3','',NULL,'0','2','1','{20260}>{$TEMP_CRIT_LOW:"Device"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17210','{20261}<>"running-ap"','Interface {#IFNAME}({#IFALIAS}): AP interface {#IFNAME}({#IFALIAS}) is not running','','0','2','Access point interface can be not running by different reasons - disabled interface, power off, network link down.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17211','{20262}>{$TEMP_CRIT:""}
or
{20263}={$TEMP_CRIT_STATUS}','#{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:""}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20264}<{$TEMP_CRIT:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17212','{20265}>{$TEMP_WARN:""}
or
{20266}={$TEMP_WARN_STATUS}','#{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:""}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20267}<{$TEMP_WARN:""}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17213','{20268}>{$TEMP_CRIT:"Ambient"}
or
{20269}={$TEMP_CRIT_STATUS}
or
{20269}={$TEMP_DISASTER_STATUS}','{#SENSOR_LOCALE}: Temperature is above critical threshold: >{$TEMP_CRIT:"Ambient"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20270}<{$TEMP_CRIT:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17214','{20271}>{$TEMP_WARN:"Ambient"}
or
{20272}={$TEMP_WARN_STATUS}','{#SENSOR_LOCALE}: Temperature is above warning threshold: >{$TEMP_WARN:"Ambient"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20273}<{$TEMP_WARN:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17215','{20274}>{$TEMP_CRIT:"CPU"}
or
{20275}={$TEMP_CRIT_STATUS}
or
{20275}={$TEMP_DISASTER_STATUS}','{#SENSOR_LOCALE}: Temperature is above critical threshold: >{$TEMP_CRIT:"CPU"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20276}<{$TEMP_CRIT:"CPU"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17216','{20277}>{$TEMP_WARN:"CPU"}
or
{20278}={$TEMP_WARN_STATUS}','{#SENSOR_LOCALE}: Temperature is above warning threshold: >{$TEMP_WARN:"CPU"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{20279}<{$TEMP_WARN:"CPU"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17217','{20280}=1 and {20281}>0','Ceph: Minimum monitor release version has changed (new version: {ITEM.VALUE})','','0','1','Ceph version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17218','{20282}=2','Ceph: Cluster in ERROR state','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17219','{20283}=1','Ceph: Cluster in WARNING state','','0','2','',NULL,'0','0','1','{20283}=0','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17220','{20284}=0','Ceph: Can not connect to cluster','','0','3','Connection to Ceph RESTful module is broken (if there is any error presented including AUTH and configuration issues).',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17221','{20285} > {20286}*100','Ceph: OSD osd.{#OSDNAME} is full','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17222','{20287} > {20288}*100','Ceph: Ceph OSD osd.{#OSDNAME} is near full','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17223','{20289} = 0','Ceph: OSD osd.{#OSDNAME} is down','','0','3','OSD osd.{#OSDNAME} is marked "down" in the osdmap.
The OSD daemon may have been stopped, or peer OSDs may be unable to reach the OSD over the network.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17224','{20290}  > {$PHP_FPM.QUEUE.WARN.MAX}','PHP-FPM: Queue utilization is high (over {$PHP_FPM.QUEUE.WARN.MAX}% for 15m)','','0','2','The queue for this pool reached {$PHP_FPM.QUEUE.WARN.MAX}% of its maximum capacity. Items in queue represent the current number of connections that have been initiated on this pool, but not yet accepted.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17225','{20291}=0 or {20292}=1','PHP-FPM: Service is down','','0','4','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17226','{20293}=1','PHP-FPM: Manager  changed (new value received: {ITEM.VALUE})','','0','1','PHP-FPM manager changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17227','{20294}>0','PHP-FPM: Detected slow requests','','0','2','PHP-FPM detected slow request. A slow request means that it took more time to execute than expected (defined in the configuration of your pool).',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17228','{20295}=1','PHP-FPM: Failed to fetch info data (or no data for 30m)','','0','1','Zabbix has not received data for items for the last 30 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17229','{20296}<10m','PHP-FPM: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17230','{20297}=1 and {20298}>0','PHP-FPM: Version has changed (new version: {ITEM.VALUE})','','0','1','PHP-FPM version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17231','{20299}=0','PHP-FPM: Process is not running','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17232','{20300}  > {$PHP_FPM.QUEUE.WARN.MAX}','PHP-FPM: Queue utilization is high (over {$PHP_FPM.QUEUE.WARN.MAX}% for 15m)','','0','2','The queue for this pool reached {$PHP_FPM.QUEUE.WARN.MAX}% of its maximum capacity. Items in queue represent the current number of connections that have been initiated on this pool, but not yet accepted.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17233','{20301}=0 or {20302}=1','PHP-FPM: Service is down','','0','4','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17234','{20303}=1','PHP-FPM: Manager  changed (new value received: {ITEM.VALUE})','','0','1','PHP-FPM manager changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17235','{20304}>0','PHP-FPM: Detected slow requests','','0','2','PHP-FPM detected slow request. A slow request means that it took more time to execute than expected (defined in the configuration of your pool).',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17236','{20305}=1','PHP-FPM: Failed to fetch info data (or no data for 30m)','','0','1','Zabbix has not received data for items for the last 30 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17237','{20306}<10m','PHP-FPM: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17238','{20307}=1 and {20308}>0','PHP-FPM: Version has changed (new version: {ITEM.VALUE})','','0','1','PHP-FPM version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17240','{20311}>{20312}*{20313}/100','Squid: Swap usage is more than high watermark (>{ITEM.VALUE2}%)','','0','4','',NULL,'0','0','0','','0','','0','Used: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17241','{20314}>{20315}*{20316}/100','Squid: Swap usage is more than low watermark (>{ITEM.VALUE2}%)','','0','2','',NULL,'0','0','0','','0','','0','Used: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17242','{20317}=0','Squid: Port {$SQUID.HTTP.PORT} is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17243','{20318}<{$SQUID.FILE.DESC.WARN.MIN}','Squid: Squid is running out of file descriptors (<{$SQUID.FILE.DESC.WARN.MIN})','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17244','{20319}<10m','Squid: Squid has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17245','{20320}=1 and {20321}>0','Squid: Squid version has been changed','','0','1','Squid version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17246','{20322} < {$LTEMODEM.RSRP.MIN.WARN}','Interface {#IFNAME}({#IFALIAS}): LTE modem RSRP is low (below {$LTEMODEM.RSRP.MIN.WARN}dbm for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17247','{20323} < {$LTEMODEM.RSRQ.MIN.WARN}','Interface {#IFNAME}({#IFALIAS}): LTE modem RSRQ is low (below {$LTEMODEM.RSRQ.MIN.WARN}db for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17248','{20324} < {$LTEMODEM.RSSI.MIN.WARN}','Interface {#IFNAME}({#IFALIAS}): LTE modem RSSI is low (below {$LTEMODEM.RSSI.MIN.WARN}dbm for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17249','{20325} < {$LTEMODEM.SINR.MIN.WARN}','Interface {#IFNAME}({#IFALIAS}): LTE modem SINR is low (below {$LTEMODEM.SINR.MIN.WARN}db for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17263','{20340}>0','NameNode: Cluster has missing blocks','','0','3','A missing block is far worse than a corrupt block, because a missing block cannot be recovered by copying a replica.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17264','{20341}>0','NameNode: Cluster has DataNodes in Dead state','','0','3','The death of a DataNode causes a flurry of network activity, as the NameNode initiates replication of blocks lost on the dead nodes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17265','{20342}<{$HADOOP.CAPACITY_REMAINING.MIN.WARN}','NameNode: Cluster capacity remaining is low (below {$HADOOP.CAPACITY_REMAINING.MIN.WARN}% for 15m)','','0','2','A good practice is to ensure that disk use never exceeds 80 percent capacity.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17266','{20343}<10m','NameNode: Service has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17267','{20344}=1','NameNode: Failed to fetch NameNode API page (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17268','{20345}>0','NameNode: Cluster has volume failures','','0','3','HDFS now allows for disks to fail in place, without affecting DataNode operations, until a threshold value is reached. This is set on each DataNode via the dfs.datanode.failed.volumes.tolerated property; it defaults to 0, meaning that any volume failure will shut down the DataNode; on a production cluster where DataNodes typically have 6, 8, or 12 disks, setting this parameter to 1 or 2 is typically the best practice.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17269','{20346}=0','ResourceManager: Cluster has no active NodeManagers','','0','4','Cluster is unable to execute any jobs without at least one NodeManager.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17270','{20347}>0','ResourceManager: Cluster has unhealthy NodeManagers','','0','3','YARN considers any node with disk utilization exceeding the value specified under the property yarn.nodemanager.disk-health-checker.max-disk-utilization-per-disk-percentage (in yarn-site.xml) to be unhealthy. Ample disk space is critical to ensure uninterrupted operation of a Hadoop cluster, and large numbers of unhealthyNodes (the number to alert on depends on the size of your cluster) should be quickly investigated and resolved.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17271','{20348}<10m','ResourceManager: Service has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17272','{20349}=1','ResourceManager: Failed to fetch ResourceManager API page (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17273','{20350}>{$HADOOP.NAMENODE.RESPONSE_TIME.MAX.WARN}','NameNode: Service response time is too high (over {$HADOOP.NAMENODE.RESPONSE_TIME.MAX.WARN} for 5m)','','0','2','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17274','{20351}>{$HADOOP.RESOURCEMANAGER.RESPONSE_TIME.MAX.WARN}','ResourceManager: Service response time is too high (over {$HADOOP.RESOURCEMANAGER.RESPONSE_TIME.MAX.WARN} for 5m)','','0','2','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17275','{20352}=0','NameNode: Service is unavailable','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17276','{20353}=0','ResourceManager: Service is unavailable','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17277','{20354}<>"Live"','{#HOSTNAME}: DataNode has state {ITEM.VALUE}.','','0','3','The state is different from normal.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17278','{20355}<10m','{#HOSTNAME}: Service has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17279','{20356}=1','{#HOSTNAME}: Failed to fetch DataNode API page (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17280','{20357}<>"RUNNING"','{#HOSTNAME}: NodeManager has state {ITEM.VALUE}.','','0','3','The state is different from normal.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17281','{20358}<10m','{#HOSTNAME}: Service has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17282','{20359}=1','{#HOSTNAME}: Failed to fetch NodeManager API page (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17283','{20360}>0','Kafka: Unclean leader election detected','','0','3','Unclean leader elections occur when there is no qualified partition leader among Kafka brokers. If Kafka is configured to allow an unclean leader election, a leader is chosen from the out-of-sync replicas, and any messages that were not synced prior to the loss of the former leader are lost forever. Essentially, unclean leader elections sacrifice consistency for availability.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17284','{20361} > 0','Kafka: One or more partitions have no leader','','0','2','Any partition without an active leader will be completely inaccessible, and both consumers and producers of that partition will be blocked until a leader becomes available.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17285','{20362} > 0','Kafka: There are offline log directories','','0','2','The offline log directory count metric indicate the number of log directories which are offline (due to an hardware failure for example) so that the broker cannot store incoming messages anymore.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17286','{20363}<{$KAFKA.NET_PROC_AVG_IDLE.MIN.WARN}','Kafka: Network processor average idle percent is too low (under {$KAFKA.NET_PROC_AVG_IDLE.MIN.WARN} for 15m)','','0','3','The network processor idle ratio metric indicates the percentage of time the network processor are not in use. The lower this number, the more loaded the broker is.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17287','{20364}=1','Kafka: Failed to fetch info data (or no data for 15m)','','0','2','Zabbix has not received data for items for the last 15 minutes',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17288','{20365}<10m','Kafka: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17289','{20366}=1 and {20367}>0','Kafka: Version has changed (new version: {ITEM.VALUE})','','0','1','Kafka version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17290','{20368}<{$KAFKA.REQUEST_HANDLER_AVG_IDLE.MIN.WARN}','Kafka: Request handler average idle percent is too low (under {$KAFKA.REQUEST_HANDLER_AVG_IDLE.MIN.WARN} for 15m)','','0','3','The request handler idle ratio metric indicates the percentage of time the request handlers are not in use. The lower this number, the more loaded the broker is.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17291','{20369}>0','Kafka: There are partitions under the min ISR','','0','3','The Under min ISR partitions metric displays the number of partitions, where the number of In-Sync Replicas (ISR) is less than the minimum number of in-sync replicas specified. The two most common causes of under-min ISR partitions are that one or more brokers is unresponsive, or the cluster is experiencing performance issues and one or more brokers are falling behind.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17292','{20370}>0','Kafka: There are under replicated partitions','','0','3','The Under replicated partitions metric displays the number of partitions that do not have enough replicas to meet the desired replication factor. A partition will also be considered under-replicated if the correct number of replicas exist, but one or more of the replicas have fallen significantly behind the partition leader. The two most common causes of under-replicated partitions are that one or more brokers is unresponsive, or the cluster is experiencing performance issues and one or more brokers have fallen behind.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17293','{20371}=0','Kafka: Broker is not connected to ZooKeeper','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17294','{20372}=1 and {20373}>0','Tomcat: Version has been changed','','0','1','Tomcat version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17295','{20374} = 1','{#JMXVALUE}: Gzip compression is disabled','','0','1','gzip compression is disabled for connector {#JMXVALUE}.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17296','{20375}>{20376}*{$TOMCAT.THREADS.MAX.PCT:"{#JMXNAME}"}/100','{#JMXNAME}: Busy worker threads count are more than {$TOMCAT.THREADS.MAX.PCT:"{#JMXNAME}"}% of the limit for {$TOMCAT.THREADS.MAX.TIME:"{#JMXNAME}"}','','0','4','When current threads busy counter reaches the limit, no more requests could be handled, and the application chokes.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17297','{20377} * 100 / {20378} > {$ZOOKEEPER.FILE_DESCRIPTORS.MAX.WARN}','Zookeeper: Too many file descriptors used (over {$ZOOKEEPER.FILE_DESCRIPTORS.MAX.WARN}% for 5 min)','','0','2','Number of file descriptors used more than {$ZOOKEEPER.FILE_DESCRIPTORS.MAX.WARN}% of the available number of file descriptors.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17298','{20379}>{$ZOOKEEPER.OUTSTANDING_REQ.MAX.WARN}','Zookeeper: Too many queued requests (over {$ZOOKEEPER.OUTSTANDING_REQ.MAX.WARN}% for 5 min)','','0','3','Number of queued requests in the server. This goes up when the server receives more requests than it can process.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17299','{20380}=1 and {20381}>0','Zookeeper: Server mode has changed (new mode: {ITEM.VALUE})','','0','1','Zookeeper node state has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17300','{20382}<10m','Zookeeper: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17301','{20383}=1','Zookeeper: Failed to fetch info data (or no data for 10m)','','0','2','Zabbix has not received data for items for the last 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17302','{20384}=1 and {20385}>0','Zookeeper: Version has changed (new version: {ITEM.VALUE})','','0','1','Zookeeper version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17303','{20386} < {20387}-1','Zookeeper: Too few active followers','','0','3','The number of followers should equal the total size of your ZooKeeper ensemble, minus 1 (the leader is not included in the follower count). If the ensemble fails to maintain quorum, all automatic failover features are suspended.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17304','{20388}>{$ZOOKEEPER.PENDING_SYNCS.MAX.WARN}','Zookeeper: Too many pending syncs (over {$ZOOKEEPER.PENDING_SYNCS.MAX.WARN}% for 5 min)','','0','3','',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17305','{20389}=1 and {20390}>0','Version has changed (new version: {ITEM.VALUE})','','0','1','Cassandra version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17306','{20391}>{$CASSANDRA.PENDING_TASKS.MAX.WARN}','Many pending tasks (over {$CASSANDRA.PENDING_TASKS.MAX.WARN} for 15m)','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17307','{20392}>{$CASSANDRA.PENDING_TASKS.MAX.HIGH}','Too many pending tasks (over {$CASSANDRA.PENDING_TASKS.MAX.HIGH} for 15m)','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17308','{20393}>0','Too many storage exceptions','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17309','{20394}=1','Failed to fetch info data (or no data for 15m)','','0','2','Zabbix has not received data for items for the last 15 minutes',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17310','{20395}>0','There are down nodes in cluster','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17311','{20396} < {#THRESHOLD_LO_WARN}','{#SENSOR_INFO}: Fan speed is below the warning threshold of {#THRESHOLD_LO_WARN}rpm for 5m','','0','2','This trigger uses fan sensor values defined in the device.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17312','{20397} < {#THRESHOLD_LO_CRIT}','{#SENSOR_INFO}: Fan speed is below the critical threshold of {#THRESHOLD_LO_CRIT}rpm for 5m','','0','4','This trigger uses fan sensor values defined in the device.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17313','{20398} > {#THRESHOLD_HI_WARN}','{#SENSOR_INFO}: Fan speed is above the warning threshold of {#THRESHOLD_HI_WARN}rpm for 5m','','0','2','This trigger uses fan sensor values defined in the device.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17314','{20399} > {#THRESHOLD_HI_CRIT}','{#SENSOR_INFO}: Fan speed is above the critical threshold of {#THRESHOLD_HI_CRIT}rpm for 5m','','0','4','This trigger uses fan sensor values defined in the device.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17315','{20400} < {#THRESHOLD_LO_WARN}','{#SENSOR_INFO}: Temperature is below the warning threshold of {#THRESHOLD_LO_WARN}°C for 5m','','0','2','This trigger uses temperature sensor values defined in the device.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17316','{20401} < {#THRESHOLD_LO_CRIT}','{#SENSOR_INFO}: Temperature is below the critical threshold of {#THRESHOLD_LO_CRIT}°C for 5m','','0','4','This trigger uses temperature sensor values defined in the device.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17317','{20402} > {#THRESHOLD_HI_WARN}','{#SENSOR_INFO}: Temperature is above the warning threshold of {#THRESHOLD_HI_WARN}°C for 5m','','0','2','This trigger uses temperature sensor values defined in the device.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17318','{20403} > {#THRESHOLD_HI_CRIT}','{#SENSOR_INFO}: Temperature is above the critical threshold of {#THRESHOLD_HI_CRIT}°C for 5m','','0','4','This trigger uses temperature sensor values defined in the device.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17319','{20404} < {#THRESHOLD_LO_WARN}','{#SENSOR_INFO}: Voltage is below the warning threshold of {#THRESHOLD_LO_WARN}V for 5m','','0','2','This trigger uses voltage sensor values defined in the device.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17320','{20405} < {#THRESHOLD_LO_CRIT}','{#SENSOR_INFO}: Voltage is below the critical threshold of {#THRESHOLD_LO_CRIT}V for 5m','','0','4','This trigger uses voltage sensor values defined in the device.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17321','{20406} > {#THRESHOLD_HI_WARN}','{#SENSOR_INFO}: Voltage is above the warning threshold of {#THRESHOLD_HI_WARN}V for 5m','','0','2','This trigger uses voltage sensor values defined in the device.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17322','{20407} > {#THRESHOLD_HI_CRIT}','{#SENSOR_INFO}: Voltage is above the critical threshold of {#THRESHOLD_HI_CRIT}V for 5m','','0','4','This trigger uses voltage sensor values defined in the device.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17323','{20408}={$CHARGE.STATE.WARN}','Battery: Device charge in warning state','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17324','{20409}={$CHARGE.STATE.CRIT}','Battery: Device charge in critical state','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17325','{20410}={$LOAD.STATE.WARN:"lvdWarning"}  or {20410}={$LOAD.STATE.WARN:"override"}','Load: Device load in warning state','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17326','{20411}={$LOAD.STATE.CRIT:"lvd"} or {20411}={$LOAD.STATE.CRIT:"fault"}','Load: Device load in critical state','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17327','{20412}=2','Status: Device has "rtsShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17328','{20413}=2','Status: Device has "rtsDisconnected" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17329','{20414}=2','Status: Device has "heatsinkTempSensorOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17330','{20415}=2','Status: Device has "heatsinkTempSensorShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17331','{20416}=2','Status: Device has "heatsinkTempLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17332','{20417}=2','Status: Device has "inductorTempSensorOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17333','{20418}=2','Status: Device has "inductorTempSensorShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17334','{20419}=2','Status: Device has "inductorTempLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17335','{20420}=2','Status: Device has "currentLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17336','{20421}=2','Status: Device has "currentMeasurementError" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17337','{20422}=2','Status: Device has "batterySenseOutOfRange" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17338','{20423}=2','Status: Device has "batterySenseDisconnected" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17339','{20424}=2','Status: Device has "uncalibrated" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17340','{20425}=2','Status: Device has "tb5v" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17341','{20426}=2','Status: Device has "fp10SupplyOutOfRange" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17342','{20427}=2','Status: Device has "mosfetOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17343','{20428}=2','Status: Device has "arrayCurrentOffset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17344','{20429}=2','Status: Device has "loadCurrentOffset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17345','{20430}=2','Status: Device has "p33SupplyOutOfRange" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17346','{20431}=2','Status: Device has "p12SupplyOutOfRange" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17347','{20432}=2','Status: Device has "hightInputVoltageLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17348','{20433}=2','Status: Device has "controllerReset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17349','{20434}=2','Status: Device has "loadLvd" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17350','{20435}=2','Status: Device has "logTimeout" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17351','{20436}=2','Status: Device has "eepromAccessFailure" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17352','{20437}=2','Status: Device has "overcurrent" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17353','{20438}=2','Status: Device has "mosfetSShorted" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17354','{20439}=2','Status: Device has "software" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17355','{20440}=2','Status: Device has "batteryHvd" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17356','{20441}=2','Status: Device has "arrayHvd" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17357','{20442}=2','Status: Device has "customSettingsEdit" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17358','{20443}=2','Status: Device has "rtsShorted" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17359','{20444}=2','Status: Device has "rtsNoLongerValid" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17360','{20445}=2','Status: Device has "localTempSensorDamaged" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17361','{20446}=2','Status: Device has "batteryLowVoltageDisconnect" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17362','{20447}=2','Status: Device has "slaveTimeout" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17363','{20448}=2','Status: Device has "dipSwitchChanged" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17364','{20449}=2','Status: Device has "externalShortCircuit" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17365','{20450}=2','Status: Device has "overcurrent" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17366','{20451}=2','Status: Device has "mosfetShorted" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17367','{20452}=2','Status: Device has "software" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17368','{20453}=2','Status: Device has "loadHvd" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17369','{20454}=2','Status: Device has "highTempDisconnect" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17370','{20455}=2','Status: Device has "dipSwitchChanged" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17371','{20456}=2','Status: Device has "customSettingsEdit" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17372','{20457}<10m','Status: Device has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17373','{20458}=1','Status: Failed to fetch data (or no data for 5m)','','0','2','Zabbix has not received data for items for the last 5 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17374','{20459}<{$BATTERY.TEMP.MIN.WARN}','Temperature: Low battery temperature (below {$BATTERY.TEMP.MIN.WARN}C for 5m)','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17375','{20460}<{$BATTERY.TEMP.MIN.CRIT}','Temperature: Critically low battery temperature (below {$BATTERY.TEMP.MIN.WARN}C for 5m)','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17376','{20461}>{$BATTERY.TEMP.MAX.WARN}','Temperature: High battery temperature (over {$BATTERY.TEMP.MAX.WARN}C for 5m)','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17377','{20462}>{$BATTERY.TEMP.MAX.CRIT}','Temperature: Critically high battery temperature (over {$BATTERY.TEMP.MAX.CRIT}C for 5m)','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17378','{20463}<{#VOLTAGE.MIN.WARN}','Battery: Low battery voltage (below {#VOLTAGE.MIN.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17379','{20464}<{#VOLTAGE.MIN.CRIT}','Battery: Critically low battery voltage (below {#VOLTAGE.MIN.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17380','{20465}>{#VOLTAGE.MAX.WARN}','Battery: High battery voltage (over {#VOLTAGE.MAX.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17381','{20466}>{#VOLTAGE.MAX.CRIT}','Battery: Critically high battery voltage (over {#VOLTAGE.MAX.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17382','{20467}={$CHARGE.STATE.WARN}','Battery: Device charge in warning state','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17383','{20468}={$CHARGE.STATE.CRIT}','Battery: Device charge in critical state','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17384','{20469}={$LOAD.STATE.WARN:"lvdWarning"}  or {20469}={$LOAD.STATE.WARN:"override"}','Load: Device load in warning state','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17385','{20470}={$LOAD.STATE.CRIT:"lvd"} or {20470}={$LOAD.STATE.CRIT:"fault"}','Load: Device load in critical state','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17386','{20471}=2','Status: Device has "rtsShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17387','{20472}=2','Status: Device has "rtsDisconnected" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17388','{20473}=2','Status: Device has "heatsinkTempSensorOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17389','{20474}=2','Status: Device has "heatsinkTempSensorShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17390','{20475}=2','Status: Device has "heatsinkTempLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17391','{20476}=2','Status: Device has "currentLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17392','{20477}=2','Status: Device has "currentMeasurementError" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17393','{20478}=2','Status: Device has "batterySenseOutOfRange" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17394','{20479}=2','Status: Device has "batterySenseDisconnected" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17395','{20480}=2','Status: Device has "uncalibrated" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17396','{20481}=2','Status: Device has "batteryTempOutOfRange" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17397','{20482}=2','Status: Device has "fp10SupplyOutOfRange" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17398','{20483}=2','Status: Device has "mosfetOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17399','{20484}=2','Status: Device has "arrayCurrentOffset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17400','{20485}=2','Status: Device has "loadCurrentOffset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17401','{20486}=2','Status: Device has "p33SupplyOutOfRange" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17402','{20487}=2','Status: Device has "p12SupplyOutOfRange" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17403','{20488}=2','Status: Device has "hightInputVoltageLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17404','{20489}=2','Status: Device has "controllerReset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17405','{20490}=2','Status: Device has "loadLvd" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17406','{20491}=2','Status: Device has "logTimeout" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17407','{20492}=2','Status: Device has "eepromAccessFailure" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17408','{20493}=2','Status: Device has "overcurrent" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17409','{20494}=2','Status: Device has "mosfetSShorted" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17410','{20495}=2','Status: Device has "software" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17411','{20496}=2','Status: Device has "batteryHvd" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17412','{20497}=2','Status: Device has "arrayHvd" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17413','{20498}=2','Status: Device has "customSettingsEdit" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17414','{20499}=2','Status: Device has "rtsShorted" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17415','{20500}=2','Status: Device has "rtsNoLongerValid" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17416','{20501}=2','Status: Device has "localTempSensorDamaged" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17417','{20502}=2','Status: Device has "batteryLowVoltageDisconnect" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17418','{20503}=2','Status: Device has "slaveTimeout" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17419','{20504}=2','Status: Device has "dipSwitchChanged" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17420','{20505}=2','Status: Device has "p3Fault" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17421','{20506}=2','Status: Device has "externalShortCircuit" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17422','{20507}=2','Status: Device has "overcurrent" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17423','{20508}=2','Status: Device has "mosfetShorted" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17424','{20509}=2','Status: Device has "software" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17425','{20510}=2','Status: Device has "loadHvd" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17426','{20511}=2','Status: Device has "highTempDisconnect" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17427','{20512}=2','Status: Device has "dipSwitchChanged" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17428','{20513}=2','Status: Device has "customSettingsEdit" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17429','{20514}=2','Status: Device has "p3Fault" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17430','{20515}<10m','Status: Device has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17431','{20516}=1','Status: Failed to fetch data (or no data for 5m)','','0','2','Zabbix has not received data for items for the last 5 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17432','{20517}<{$BATTERY.TEMP.MIN.WARN}','Temperature: Low battery temperature (below {$BATTERY.TEMP.MIN.WARN}C for 5m)','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17433','{20518}<{$BATTERY.TEMP.MIN.CRIT}','Temperature: Critically low battery temperature (below {$BATTERY.TEMP.MIN.WARN}C for 5m)','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17434','{20519}>{$BATTERY.TEMP.MAX.WARN}','Temperature: High battery temperature (over {$BATTERY.TEMP.MAX.WARN}C for 5m)','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17435','{20520}>{$BATTERY.TEMP.MAX.CRIT}','Temperature: Critically high battery temperature (over {$BATTERY.TEMP.MAX.CRIT}C for 5m)','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17436','{20521}<{#VOLTAGE.MIN.WARN}','Battery: Low battery voltage (below {#VOLTAGE.MIN.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17437','{20522}<{#VOLTAGE.MIN.CRIT}','Battery: Critically low battery voltage (below {#VOLTAGE.MIN.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17438','{20523}>{#VOLTAGE.MAX.WARN}','Battery: High battery voltage (over {#VOLTAGE.MAX.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17439','{20524}>{#VOLTAGE.MAX.CRIT}','Battery: Critically high battery voltage (over {#VOLTAGE.MAX.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17440','{20525}={$CHARGE.STATE.WARN}','Battery: Device charge in warning state','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17441','{20526}={$CHARGE.STATE.CRIT}','Battery: Device charge in critical state','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17442','{20527}={$LOAD.STATE.WARN:"lvdWarning"}  or {20527}={$LOAD.STATE.WARN:"override"}','Load: Device load in warning state','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17443','{20528}={$LOAD.STATE.CRIT:"lvd"} or {20528}={$LOAD.STATE.CRIT:"fault"}','Load: Device load in critical state','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17444','{20529}=2','Status: Device has "rtsShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17445','{20530}=2','Status: Device has "rtsDisconnected" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17446','{20531}=2','Status: Device has "heatsinkTempSensorOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17447','{20532}=2','Status: Device has "heatsinkTempSensorShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17448','{20533}=2','Status: Device has "sspptHot" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17449','{20534}=2','Status: Device has "currentLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17450','{20535}=2','Status: Device has "currentOffset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17451','{20536}=2','Status: Device has "uncalibrated" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17452','{20537}=2','Status: Device has "rtsMiswire" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17453','{20538}=2','Status: Device has "systemMiswire" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17454','{20539}=2','Status: Device has "mosfetSOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17455','{20540}=2','Status: Device has "p12VoltageReferenceOff" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17456','{20541}=2','Status: Device has "highVaCurrentLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17457','{20542}=2','Status: Device has "overcurrent" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17458','{20543}=2','Status: Device has "mosfetSShorted" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17459','{20544}=2','Status: Device has "softwareFault" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17460','{20545}=2','Status: Device has "batteryHvd" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17461','{20546}=2','Status: Device has "arrayHvd" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17462','{20547}=2','Status: Device has "customSettingsEdit" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17463','{20548}=2','Status: Device has "rtsShorted" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17464','{20549}=2','Status: Device has "rtsNoLongerValid" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17465','{20550}=2','Status: Device has "localTempSensorDamaged" array faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17466','{20551}=2','Status: Device has "externalShortCircuit" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17467','{20552}=2','Status: Device has "overcurrent" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17468','{20553}=2','Status: Device has "mosfetShorted" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17469','{20554}=2','Status: Device has "software" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17470','{20555}=2','Status: Device has "loadHvd" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17471','{20556}=2','Status: Device has "highTempDisconnect" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17472','{20557}=2','Status: Device has "customSettingsEdit" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17473','{20558}=2','Status: Device has "unknownLoadFault" load faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17474','{20559}<10m','Status: Device has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17475','{20560}=1','Status: Failed to fetch data (or no data for 5m)','','0','2','Zabbix has not received data for items for the last 5 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17476','{20561}<{$BATTERY.TEMP.MIN.WARN}','Temperature: Low battery temperature (below {$BATTERY.TEMP.MIN.WARN}C for 5m)','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17477','{20562}<{$BATTERY.TEMP.MIN.CRIT}','Temperature: Critically low battery temperature (below {$BATTERY.TEMP.MIN.WARN}C for 5m)','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17478','{20563}>{$BATTERY.TEMP.MAX.WARN}','Temperature: High battery temperature (over {$BATTERY.TEMP.MAX.WARN}C for 5m)','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17479','{20564}>{$BATTERY.TEMP.MAX.CRIT}','Temperature: Critically high battery temperature (over {$BATTERY.TEMP.MAX.CRIT}C for 5m)','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17480','{20565}<{#VOLTAGE.MIN.WARN}','Battery: Low battery voltage (below {#VOLTAGE.MIN.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17481','{20566}<{#VOLTAGE.MIN.CRIT}','Battery: Critically low battery voltage (below {#VOLTAGE.MIN.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17482','{20567}>{#VOLTAGE.MAX.WARN}','Battery: High battery voltage (over {#VOLTAGE.MAX.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17483','{20568}>{#VOLTAGE.MAX.CRIT}','Battery: Critically high battery voltage (over {#VOLTAGE.MAX.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17484','{20569}={$LOAD.STATE.WARN:"lvdWarning"}  or {20569}={$LOAD.STATE.WARN:"override"}','Load: Device load in warning state','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17485','{20570}={$LOAD.STATE.CRIT:"lvd"} or {20570}={$LOAD.STATE.CRIT:"fault"}','Load: Device load in critical state','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17486','{20571}=2','Status: Device has "heatsinkTempSensorOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17487','{20572}=2','Status: Device has "heatsinkTempSensorShort" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17488','{20573}=2','Status: Device has "unknownAlarm" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17489','{20574}=2','Status: Device has "suresineHot" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17490','{20575}=2','Status: Device has "reset" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17491','{20576}=2','Status: Device has "overcurrent" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17492','{20577}=2','Status: Device has "unknownFault" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17493','{20578}=2','Status: Device has "software" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17494','{20579}=2','Status: Device has "highVoltageDisconnect" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17495','{20580}=2','Status: Device has "suresineHot" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17496','{20581}=2','Status: Device has "dipSwitchChanged" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17497','{20582}=2','Status: Device has "customSettingsEdit" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17498','{20583}<10m','Status: Device has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17499','{20584}=1','Status: Failed to fetch data (or no data for 5m)','','0','2','Zabbix has not received data for items for the last 5 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17500','{20585}<{#VOLTAGE.MIN.WARN}','Battery: Low battery voltage (below {#VOLTAGE.MIN.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17501','{20586}<{#VOLTAGE.MIN.CRIT}','Battery: Critically low battery voltage (below {#VOLTAGE.MIN.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17502','{20587}>{#VOLTAGE.MAX.WARN}','Battery: High battery voltage (over {#VOLTAGE.MAX.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17503','{20588}>{#VOLTAGE.MAX.CRIT}','Battery: Critically high battery voltage (over {#VOLTAGE.MAX.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17504','{20589}={$CHARGE.STATE.WARN}','Battery: Device charge in warning state','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17505','{20590}={$CHARGE.STATE.CRIT}','Battery: Device charge in critical state','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17506','{20591}=2','Status: Device has "rtsShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17507','{20592}=2','Status: Device has "rtsDisconnected" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17508','{20593}=2','Status: Device has "heatsinkTempSensorOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17509','{20594}=2','Status: Device has "heatsinkTempSensorShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17510','{20595}=2','Status: Device has "highTemperatureCurrentLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17511','{20596}=2','Status: Device has "currentLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17512','{20597}=2','Status: Device has "currentOffset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17513','{20598}=2','Status: Device has "batterySense" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17514','{20599}=2','Status: Device has "batterySenseDisconnected" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17515','{20600}=2','Status: Device has "uncalibrated" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17516','{20601}=2','Status: Device has "rtsMiswire" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17517','{20602}=2','Status: Device has "highVoltageDisconnect" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17518','{20603}=2','Status: Device has "systemMiswire" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17519','{20604}=2','Status: Device has "mosfetSOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17520','{20605}=2','Status: Device has "p12VoltageOutOfRange" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17521','{20606}=2','Status: Device has "highArrayVCurrentLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17522','{20607}=2','Status: Device has "maxAdcValueReached" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17523','{20608}=2','Status: Device has "controllerWasReset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17524','{20609}=2','Status: Device has "alarm21Internal" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17525','{20610}=2','Status: Device has "p3VoltageOutOfRange" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17526','{20611}=2','Status: Device has "derateLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17527','{20612}=2','Status: Device has "arrayCurrentOffset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17528','{20613}=2','Status: Device has "ee-i2cRetryLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17529','{20614}=2','Status: Device has "ethernetAlarm" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17530','{20615}=2','Status: Device has "lvd" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17531','{20616}=2','Status: Device has "software" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17532','{20617}=2','Status: Device has "fp12VoltageOutOfRange" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17533','{20618}=2','Status: Device has "extflashFault" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17534','{20619}=2','Status: Device has "slaveControlFault" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17535','{20620}=2','Status: Device has "overcurrent" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17536','{20621}=2','Status: Device has "fetShort" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17537','{20622}=2','Status: Device has "softwareFault" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17538','{20623}=2','Status: Device has "batteryHvd" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17539','{20624}=2','Status: Device has "arrayHvd" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17540','{20625}=2','Status: Device has "dipSwitchChange" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17541','{20626}=2','Status: Device has "customSettingsEdit" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17542','{20627}=2','Status: Device has "rtsShorted" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17543','{20628}=2','Status: Device has "rtsDisconnected" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17544','{20629}=2','Status: Device has "eepromRetryLimit" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17545','{20630}=2','Status: Device has "controllerWasReset" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17546','{20631}=2','Status: Device has "chargeSlaveControlTimeout" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17547','{20632}=2','Status: Device has "rs232SerialToMeterBridge" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17548','{20633}=2','Status: Device has "batteryLvd" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17549','{20634}=2','Status: Device has "powerboardCommunicationFault" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17550','{20635}=2','Status: Device has "fault16Software" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17551','{20636}=2','Status: Device has "fault17Software" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17552','{20637}=2','Status: Device has "fault18Software" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17553','{20638}=2','Status: Device has "fault19Software" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17554','{20639}=2','Status: Device has "fault20Software" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17555','{20640}=2','Status: Device has "fault21Software" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17556','{20641}=2','Status: Device has "fpgaVersion" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17557','{20642}=2','Status: Device has "currentSensorReferenceOutOfRange" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17558','{20643}=2','Status: Device has "ia-refSlaveModeTimeout" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17559','{20644}=2','Status: Device has "blockbusBoot" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17560','{20645}=2','Status: Device has "hscommMaster" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17561','{20646}=2','Status: Device has "hscomm" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17562','{20647}=2','Status: Device has "slave" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17563','{20648}<10m','Status: Device has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17564','{20649}=1','Status: Failed to fetch data (or no data for 5m)','','0','2','Zabbix has not received data for items for the last 5 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17565','{20650}<{$BATTERY.TEMP.MIN.WARN}','Temperature: Low battery temperature (below {$BATTERY.TEMP.MIN.WARN}C for 5m)','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17566','{20651}<{$BATTERY.TEMP.MIN.CRIT}','Temperature: Critically low battery temperature (below {$BATTERY.TEMP.MIN.WARN}C for 5m)','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17567','{20652}>{$BATTERY.TEMP.MAX.WARN}','Temperature: High battery temperature (over {$BATTERY.TEMP.MAX.WARN}C for 5m)','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17568','{20653}>{$BATTERY.TEMP.MAX.CRIT}','Temperature: Critically high battery temperature (over {$BATTERY.TEMP.MAX.CRIT}C for 5m)','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17569','{20654}<{#VOLTAGE.MIN.WARN}','Battery: Low battery voltage (below {#VOLTAGE.MIN.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17570','{20655}<{#VOLTAGE.MIN.CRIT}','Battery: Critically low battery voltage (below {#VOLTAGE.MIN.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17571','{20656}>{#VOLTAGE.MAX.WARN}','Battery: High battery voltage (over {#VOLTAGE.MAX.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17572','{20657}>{#VOLTAGE.MAX.CRIT}','Battery: Critically high battery voltage (over {#VOLTAGE.MAX.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17573','{20658}={$CHARGE.STATE.WARN}','Battery: Device charge in warning state','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17574','{20659}={$CHARGE.STATE.CRIT}','Battery: Device charge in critical state','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17575','{20660}=2','Status: Device has "rtsShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17576','{20661}=2','Status: Device has "rtsDisconnected" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17577','{20662}=2','Status: Device has "heatsinkTempSensorOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17578','{20663}=2','Status: Device has "heatsinkTempSensorShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17579','{20664}=2','Status: Device has "highTemperatureCurrentLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17580','{20665}=2','Status: Device has "currentLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17581','{20666}=2','Status: Device has "currentOffset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17582','{20667}=2','Status: Device has "batterySense" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17583','{20668}=2','Status: Device has "batterySenseDisconnected" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17584','{20669}=2','Status: Device has "uncalibrated" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17585','{20670}=2','Status: Device has "rtsMiswire" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17586','{20671}=2','Status: Device has "highVoltageDisconnect" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17587','{20672}=2','Status: Device has "systemMiswire" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17588','{20673}=2','Status: Device has "mosfetSOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17589','{20674}=2','Status: Device has "p12VoltageReferenceOff" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17590','{20675}=2','Status: Device has "highArrayVCurrentLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17591','{20676}=2','Status: Device has "maxAdcValueReached" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17592','{20677}=2','Status: Device has "controllerWasReset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17593','{20678}=2','Status: Device has "overcurrent" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17594','{20679}=2','Status: Device has "fetShort" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17595','{20680}=2','Status: Device has "softwareFault" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17596','{20681}=2','Status: Device has "batteryHvd" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17597','{20682}=2','Status: Device has "arrayHvd" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17598','{20683}=2','Status: Device has "dipSwitchChange" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17599','{20684}=2','Status: Device has "customSettingsEdit" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17600','{20685}=2','Status: Device has "rtsShorted" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17601','{20686}=2','Status: Device has "rtsDisconnected" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17602','{20687}=2','Status: Device has "eepromRetryLimit" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17603','{20688}=2','Status: Device has "slaveControlTimeout" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17604','{20689}<10m','Status: Device has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17605','{20690}=1','Status: Failed to fetch data (or no data for 5m)','','0','2','Zabbix has not received data for items for the last 5 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17606','{20691}<{$BATTERY.TEMP.MIN.WARN}','Temperature: Low battery temperature (below {$BATTERY.TEMP.MIN.WARN}C for 5m)','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17607','{20692}<{$BATTERY.TEMP.MIN.CRIT}','Temperature: Critically low battery temperature (below {$BATTERY.TEMP.MIN.WARN}C for 5m)','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17608','{20693}>{$BATTERY.TEMP.MAX.WARN}','Temperature: High battery temperature (over {$BATTERY.TEMP.MAX.WARN}C for 5m)','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17609','{20694}>{$BATTERY.TEMP.MAX.CRIT}','Temperature: Critically high battery temperature (over {$BATTERY.TEMP.MAX.CRIT}C for 5m)','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17610','{20695}<{#VOLTAGE.MIN.WARN}','Battery: Low battery voltage (below {#VOLTAGE.MIN.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17611','{20696}<{#VOLTAGE.MIN.CRIT}','Battery: Critically low battery voltage (below {#VOLTAGE.MIN.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17612','{20697}>{#VOLTAGE.MAX.WARN}','Battery: High battery voltage (over {#VOLTAGE.MAX.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17613','{20698}>{#VOLTAGE.MAX.CRIT}','Battery: Critically high battery voltage (over {#VOLTAGE.MAX.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17614','{20699}=2','Status: Device has "rtsShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17615','{20700}=2','Status: Device has "rtsDisconnected" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17616','{20701}=2','Status: Device has "heatsinkTempSensorOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17617','{20702}=2','Status: Device has "heatsinkTempSensorShorted" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17618','{20703}=2','Status: Device has "tristarHot" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17619','{20704}=2','Status: Device has "currentLimit" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17620','{20705}=2','Status: Device has "currentOffset" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17621','{20706}=2','Status: Device has "batterySense" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17622','{20707}=2','Status: Device has "batterySenseDisconnected" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17623','{20708}=2','Status: Device has "uncalibrated" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17624','{20709}=2','Status: Device has "rtsMiswire" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17625','{20710}=2','Status: Device has "highVoltageDisconnect" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17626','{20711}=2','Status: Device has "diversionLoadNearMax" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17627','{20712}=2','Status: Device has "systemMiswire" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17628','{20713}=2','Status: Device has "mosfetSOpen" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17629','{20714}=2','Status: Device has "p12VoltageReferenceOff" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17630','{20715}=2','Status: Device has "loadDisconnectState" alarm flag','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17631','{20716}=2','Status: Device has "externalShort" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17632','{20717}=2','Status: Device has "overcurrent" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17633','{20718}=2','Status: Device has "mosfetSShorted" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17634','{20719}=2','Status: Device has "softwareFault" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17635','{20720}=2','Status: Device has "highVoltageDisconnect" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17636','{20721}=2','Status: Device has "tristarHot" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17637','{20722}=2','Status: Device has "dipSwitchChange" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17638','{20723}=2','Status: Device has "customSettingsEdit" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17639','{20724}=2','Status: Device has "reset" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17640','{20725}=2','Status: Device has "systemMiswire" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17641','{20726}=2','Status: Device has "rtsShorted" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17642','{20727}=2','Status: Device has "rtsDisconnected" faults flag','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17643','{20728}<10m','Status: Device has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17644','{20729}=1','Status: Failed to fetch data (or no data for 5m)','','0','2','Zabbix has not received data for items for the last 5 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17645','{20730}<{$BATTERY.TEMP.MIN.WARN}','Temperature: Low battery temperature (below {$BATTERY.TEMP.MIN.WARN}C for 5m)','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17646','{20731}<{$BATTERY.TEMP.MIN.CRIT}','Temperature: Critically low battery temperature (below {$BATTERY.TEMP.MIN.WARN}C for 5m)','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17647','{20732}>{$BATTERY.TEMP.MAX.WARN}','Temperature: High battery temperature (over {$BATTERY.TEMP.MAX.WARN}C for 5m)','','0','2','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17648','{20733}>{$BATTERY.TEMP.MAX.CRIT}','Temperature: Critically high battery temperature (over {$BATTERY.TEMP.MAX.CRIT}C for 5m)','','0','4','',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17649','{20734}<{#VOLTAGE.MIN.WARN}','Battery: Low battery voltage (below {#VOLTAGE.MIN.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17650','{20735}<{#VOLTAGE.MIN.CRIT}','Battery: Critically low battery voltage (below {#VOLTAGE.MIN.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17651','{20736}>{#VOLTAGE.MAX.WARN}','Battery: High battery voltage (over {#VOLTAGE.MAX.WARN}V for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17652','{20737}>{#VOLTAGE.MAX.CRIT}','Battery: Critically high battery voltage (over {#VOLTAGE.MAX.CRIT}V for 5m)','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17653','{20738}={$CHARGE.STATE.WARN}','Battery: Device charge in warning state','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17654','{20739}={$CHARGE.STATE.CRIT}','Battery: Device charge in critical state','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17655','{20740}={$LOAD.STATE.WARN:"lvdWarning"}  or {20740}={$LOAD.STATE.WARN:"override"}','Load: Device load in warning state','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17656','{20741}={$LOAD.STATE.CRIT:"lvd"} or {20741}={$LOAD.STATE.CRIT:"fault"}','Load: Device load in critical state','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17661','{20754} > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk write request responses are too high (write > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}s for 15m)','','0','2','This trigger might indicate disk {#DEVNAME} saturation.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17662','{20755} > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk read request responses are too high (read > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"}s for 15m','','0','2','This trigger might indicate disk {#DEVNAME} saturation.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17665','{20758} > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk write request responses are too high (write > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}s for 15m)','','0','2','This trigger might indicate disk {#DEVNAME} saturation.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17666','{20759} > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk read request responses are too high (read > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"}s for 15m','','0','2','This trigger might indicate disk {#DEVNAME} saturation.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17673','{20766}<{$ACTIVEMQ.DESTINATION.CONSUMERS.MIN.HIGH:"{#JMXDESTINATIONNAME}"} and {20767}>{$ACTIVEMQ.BROKER.CONSUMERS.MIN.HIGH:"{#JMXBROKERNAME}"}','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Consumers count is too low (below {$ACTIVEMQ.DESTINATION.CONSUMERS.MIN.HIGH:"{#JMXDESTINATIONNAME}"} for {$ACTIVEMQ.DESTINATION.CONSUMERS.MIN.TIME:"{#JMXDESTINATIONNAME}"})','','0','3','',NULL,'0','2','1','{20768}>={$ACTIVEMQ.DESTINATION.CONSUMERS.MIN.HIGH:"{#JMXDESTINATIONNAME}"}','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17675','{20771}<{$ACTIVEMQ.DESTINATION.PRODUCERS.MIN.HIGH:"{#JMXDESTINATIONNAME}"} and {20772}>{$ACTIVEMQ.BROKER.PRODUCERS.MIN.HIGH:"{#JMXBROKERNAME}"}','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Producers count is too low (below {$ACTIVEMQ.DESTINATION.PRODUCERS.MIN.HIGH:"{#JMXDESTINATIONNAME}"} for {$ACTIVEMQ.DESTINATION.PRODUCERS.MIN.TIME:"{#JMXDESTINATIONNAME}"})','','0','3','',NULL,'0','2','1','{20773}>={$ACTIVEMQ.DESTINATION.PRODUCERS.MIN.HIGH:"{#JMXDESTINATIONNAME}"}','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17677','{20775}>{$ACTIVEMQ.MEM.MAX.WARN:"{#JMXDESTINATIONNAME}"}','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Memory usage is too high (over {$ACTIVEMQ.MEM.MAX.WARN:"{#JMXDESTINATIONNAME}"}%)','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17678','{20776}>{$ACTIVEMQ.MEM.MAX.HIGH:"{#JMXDESTINATIONNAME}"}','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Memory usage is too high (over {$ACTIVEMQ.MEM.MAX.HIGH:"{#JMXDESTINATIONNAME}"}%)','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17681','{20779}=1 and {20780}>0','Broker {#JMXBROKERNAME}: Version has been changed','','0','1','Broker {#JMXBROKERNAME} version has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17682','{20781}>{$ACTIVEMQ.MEM.MAX.WARN:"{#JMXBROKERNAME}"}','Broker {#JMXBROKERNAME}: Memory usage is too high (over {$ACTIVEMQ.MEM.MAX.WARN:"{#JMXBROKERNAME}"}%)','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17683','{20782}>{$ACTIVEMQ.MEM.MAX.HIGH:"{#JMXBROKERNAME}"}','Broker {#JMXBROKERNAME}: Memory usage is too high (over {$ACTIVEMQ.MEM.MAX.HIGH:"{#JMXBROKERNAME}"}%)','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17684','{20783}>{$ACTIVEMQ.STORE.MAX.WARN:"{#JMXBROKERNAME}"}','Broker {#JMXBROKERNAME}: Storage usage is too high (over {$ACTIVEMQ.STORE.MAX.WARN:"{#JMXBROKERNAME}"}%)','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17685','{20784}>{$ACTIVEMQ.STORE.MAX.HIGH:"{#JMXBROKERNAME}"}','Broker {#JMXBROKERNAME}: Storage usage is too high (over {$ACTIVEMQ.STORE.MAX.HIGH:"{#JMXBROKERNAME}"}%)','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17686','{20785}>{$ACTIVEMQ.TEMP.MAX.WARN}','Broker {#JMXBROKERNAME}: Temp usage is too high (over {$ACTIVEMQ.TEMP.MAX.WARN:"{#JMXBROKERNAME}"}%)','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17687','{20786}>{$ACTIVEMQ.TEMP.MAX.HIGH}','Broker {#JMXBROKERNAME}: Temp usage is too high (over {$ACTIVEMQ.TEMP.MAX.WARN:"{#JMXBROKERNAME}"}%)','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17688','{20787}<{$ACTIVEMQ.BROKER.CONSUMERS.MIN.HIGH:"{#JMXBROKERNAME}"}','Broker {#JMXBROKERNAME}: Consumers count is too low (below {$ACTIVEMQ.BROKER.CONSUMERS.MIN.HIGH:"{#JMXBROKERNAME}"} for {$ACTIVEMQ.BROKER.CONSUMERS.MIN.TIME:"{#JMXBROKERNAME}"})','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17689','{20788}<{$ACTIVEMQ.BROKER.PRODUCERS.MIN.HIGH:"{#JMXBROKERNAME}"}','Broker {#JMXBROKERNAME}: Producers count is too low (below {$ACTIVEMQ.BROKER.PRODUCERS.MIN.HIGH:"{#JMXBROKERNAME}"} for {$ACTIVEMQ.BROKER.PRODUCERS.MIN.TIME:"{#JMXBROKERNAME}"})','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17690','{20789}<10m','Broker {#JMXBROKERNAME}: Broker has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17691','{20790}>{$MS.EXCHANGE.LDAP.WARN}','Domain Controller [{#INSTANCE}]: LDAP read time is too high (>{$MS.EXCHANGE.LDAP.WARN}s for {$MS.EXCHANGE.LDAP.TIME})','','0','3','Should be less than 50ms at all times, with spikes less than 100ms.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17692','{20791}>{$MS.EXCHANGE.LDAP.WARN}','Domain Controller [{#INSTANCE}]: LDAP search time is too high (>{$MS.EXCHANGE.LDAP.WARN}s for {$MS.EXCHANGE.LDAP.TIME})','','0','3','Should be less than 50ms at all times, with spikes less than 100ms.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17693','{20792}>{20793}','Database Counters [{#INSTANCE}]: Average write time latency is higher than read time latency for {$MS.EXCHANGE.DB.PASSIVE.WRITE.TIME}','','0','2','Should be less than the read latency for the same instance, as measured by the MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Reads (Recovery) Average Latency counter.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17694','{20794}>{$MS.EXCHANGE.DB.FAULTS.WARN}','Information Store [{#INSTANCE}]: Page faults is too high (>{$MS.EXCHANGE.DB.FAULTS.WARN} for {$MS.EXCHANGE.DB.FAULTS.TIME})','','0','3','Too much page faults stalls for database "{#INSTANCE}". This counter should be 0 on production servers.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17695','{20795}>{$MS.EXCHANGE.LOG.STALLS.WARN}','Information Store [{#INSTANCE}]: Log records stalls is too high (>{$MS.EXCHANGE.LOG.STALLS.WARN} for {$MS.EXCHANGE.LOG.STALLS.TIME})','','0','3','Stalled log records too high. The average value should be less than 10 threads waiting.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17696','{20796}>{$MS.EXCHANGE.DB.ACTIVE.READ.WARN}','Database Counters [{#INSTANCE}]: Average read time latency is too high (>{$MS.EXCHANGE.DB.ACTIVE.READ.WARN}s for {$MS.EXCHANGE.DB.ACTIVE.READ.TIME})','','0','2','Should be less than 20ms on average.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17697','{20797}>{$MS.EXCHANGE.DB.PASSIVE.READ.WARN}','Database Counters [{#INSTANCE}]: Average read time latency is too high (>{$MS.EXCHANGE.DB.PASSIVE.READ.WARN}s for {$MS.EXCHANGE.DB.PASSIVE.READ.TIME})','','0','2','Should be less than 200ms on average.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17698','{20798}>{$MS.EXCHANGE.DB.ACTIVE.WRITE.WARN}','Database Counters [{#INSTANCE}]: Average write time latency is too high for {$MS.EXCHANGE.DB.ACTIVE.WRITE.TIME}','','0','2','Should be less than 50ms on average.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17699','{20799}>{$MS.EXCHANGE.RPC.WARN}','Information Store [{#INSTANCE}]: RPC Requests latency is too high (>{$MS.EXCHANGE.RPC.WARN}s for {$MS.EXCHANGE.RPC.TIME})','','0','2','Should be less than 50ms at all times, with spikes less than 100ms.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17700','{20800}>{$MS.EXCHANGE.RPC.COUNT.WARN}','Information Store [{#INSTANCE}]: RPC Requests total count is too high (>{$MS.EXCHANGE.RPC.COUNT.WARN} for {$MS.EXCHANGE.RPC.COUNT.TIME})','','0','2','Should be below 70 at all times.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17701','{20801}>{$MS.EXCHANGE.LDAP.WARN}','Domain Controller [{#INSTANCE}]: LDAP read time is too high (>{$MS.EXCHANGE.LDAP.WARN}s for {$MS.EXCHANGE.LDAP.TIME})','','0','3','Should be less than 50ms at all times, with spikes less than 100ms.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17702','{20802}>{$MS.EXCHANGE.LDAP.WARN}','Domain Controller [{#INSTANCE}]: LDAP search time is too high (>{$MS.EXCHANGE.LDAP.WARN}s for {$MS.EXCHANGE.LDAP.TIME})','','0','3','Should be less than 50ms at all times, with spikes less than 100ms.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17703','{20803}>{20804}','Database Counters [{#INSTANCE}]: Average write time latency is higher than read time latency for {$MS.EXCHANGE.DB.PASSIVE.WRITE.TIME}','','0','2','Should be less than the read latency for the same instance, as measured by the MSExchange Database ==> Instances({#INF.STORE}/_Total)\I/O Database Reads (Recovery) Average Latency counter.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17704','{20805}>{$MS.EXCHANGE.DB.FAULTS.WARN}','Information Store [{#INSTANCE}]: Page faults is too high (>{$MS.EXCHANGE.DB.FAULTS.WARN} for {$MS.EXCHANGE.DB.FAULTS.TIME})','','0','3','Too much page faults stalls for database "{#INSTANCE}". This counter should be 0 on production servers.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17705','{20806}>{$MS.EXCHANGE.LOG.STALLS.WARN}','Information Store [{#INSTANCE}]: Log records stalls is too high (>{$MS.EXCHANGE.LOG.STALLS.WARN} for {$MS.EXCHANGE.LOG.STALLS.TIME})','','0','3','Stalled log records too high. The average value should be less than 10 threads waiting.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17706','{20807}>{$MS.EXCHANGE.DB.ACTIVE.READ.WARN}','Database Counters [{#INSTANCE}]: Average read time latency is too high (>{$MS.EXCHANGE.DB.ACTIVE.READ.WARN}s for {$MS.EXCHANGE.DB.ACTIVE.READ.TIME})','','0','2','Should be less than 20ms on average.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17707','{20808}>{$MS.EXCHANGE.DB.PASSIVE.READ.WARN}','Database Counters [{#INSTANCE}]: Average read time latency is too high (>{$MS.EXCHANGE.DB.PASSIVE.READ.WARN}s for {$MS.EXCHANGE.DB.PASSIVE.READ.TIME})','','0','2','Should be less than 200ms on average.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17708','{20809}>{$MS.EXCHANGE.DB.ACTIVE.WRITE.WARN}','Database Counters [{#INSTANCE}]: Average write time latency is too high for {$MS.EXCHANGE.DB.ACTIVE.WRITE.TIME}','','0','2','Should be less than 50ms on average.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17709','{20810}>{$MS.EXCHANGE.RPC.WARN}','Information Store [{#INSTANCE}]: RPC Requests latency is too high (>{$MS.EXCHANGE.RPC.WARN}s for {$MS.EXCHANGE.RPC.TIME})','','0','2','Should be less than 50ms at all times, with spikes less than 100ms.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17710','{20811}>{$MS.EXCHANGE.RPC.COUNT.WARN}','Information Store [{#INSTANCE}]: RPC Requests total count is too high (>{$MS.EXCHANGE.RPC.COUNT.WARN} for {$MS.EXCHANGE.RPC.COUNT.TIME})','','0','2','Should be below 70 at all times.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17711','{20812}>{$ORACLE.TBS.USED.PCT.MAX.WARN}','Oracle TBS ''{#TABLESPACE}'': Tablespace usage is too high (over {$ORACLE.TBS.USED.PCT.MAX.WARN}% for 5m).','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17712','{20813}>{$ORACLE.TBS.USED.PCT.MAX.HIGH}','Oracle TBS ''{#TABLESPACE}'': Tablespace usage is too high (over {$ORACLE.TBS.USED.PCT.MAX.HIGH}% for 5m).','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17713','{20814}>{$ORACLE.TBS.USED.PCT.MAX.WARN}','Oracle TBS ''{#TABLESPACE}'': Tablespace utilization is too high (over {$ORACLE.TBS.USED.PCT.MAX.WARN}% for 5m).','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17714','{20815}>{$ORACLE.TBS.UTIL.PCT.MAX.HIGH}','Oracle TBS ''{#TABLESPACE}'': Tablespace utilization is too high (over {$ORACLE.TBS.UTIL.PCT.MAX.HIGH}% for 5m).','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17726','{20828}>0 and {20829}=1','NetApp FAS3220: Number of failed disks has changed','','0','2','{{ITEM.LASTVALUE2}.regsub("(.*)", \1)}',NULL,'1','0','1','{20828}=0','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17727','{20830}>0 and {20831}={20831}','Node {#NODE.NAME}: Degraded power supplies count is more than zero','','0','3','{{ITEM.VALUE2}.regsub("(.*)", \1)}',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17728','{20832}>0 and {20833}={20833}','Node {#NODE.NAME}: Failed FAN count is over than zero','','0','4','{{ITEM.VALUE2}.regsub("(.*)", \1)}',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17729','{20834}=2','Node {#NODE.NAME}: Temperature is over than recommended','','0','4','The hardware will shutdown if the temperature exceeds critical thresholds.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17730','{20835}=0','Node {#NODE.NAME}: Node can not communicate with the cluster','','0','4','',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17731','{20836}<>1','Node {#NODE.NAME}: NVRAM battery status is not OK','','0','3','',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17732','{20837}<10m','Node {#NODE.NAME}: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17733','{20838}>{$CPU.UTIL.CRIT}','Node {#NODE.NAME}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17734','{20839}<{$FAS3220.FS.AVAIL.MIN.CRIT:"{#FSNAME}"} and {$FAS3220.FS.USE.PCT:"{#FSNAME}"}=0','{#VSERVER}{#FSNAME}: Disk space is too low (below {$FAS3220.FS.AVAIL.MIN.CRIT:"{#FSNAME}"} for {$FAS3220.FS.TIME:"{#FSNAME}"})','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17735','{20840}>{$FAS3220.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and {$FAS3220.FS.USE.PCT:"{#FSNAME}"}=1','{#VSERVER}{#FSNAME}: Disk space is too low (used over {$FAS3220.FS.PUSED.MAX.CRIT:"{#FSNAME}"}% for {$FAS3220.FS.TIME:"{#FSNAME}"})','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17736','{20841}<>1','Node {#NODE.NAME}: Node cannot takeover it''s HA partner {#PARTNER.NAME}. Reason: {ITEM.VALUE}','','0','4','Possible reasons:
  unknownReason(2),
  disabledByOperator(3),
  interconnectOffline(4),
  disabledByPartner(5),
  takeoverFailed(6),
  mailboxIsInDegradedState(7),
  partnermailboxIsInUninitialisedState(8),
  mailboxVersionMismatch(9),
  nvramSizeMismatch(10),
  kernelVersionMismatch(11),
  partnerIsInBootingStage(12),
  diskshelfIsTooHot(13),
  partnerIsPerformingRevert(14),
  nodeIsPerformingRevert(15),
  sametimePartnerIsAlsoTryingToTakeUsOver(16),
  alreadyInTakenoverMode(17),
  nvramLogUnsynchronized(18),
  stateofBackupMailboxIsDoubtful(19).',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17737','{20842}=5','Node {#NODE.NAME}: Node has been taken over','','0','4','The thisNodeDead(5) setting indicates that this node has been takenover.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17738','{20843}=1','Node {#NODE.NAME}: HA is not licensed','','0','3','The value notConfigured(1) indicates that the HA is not licensed.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17740','{20848}<>2 and {20849}=1','Node {#NODE}: port {#IFNAME} ({#TYPE}): Link down','','0','3','Link state is not UP and the port status is set ''UP'' by an administrator.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17741','{20850}<>0 and {20851}>0','Node {#NODE}: port {#IFNAME} ({#TYPE}): Port is not healthy','','0','1','{{ITEM.LASTVALUE2}.regsub("(.*)", \1)}',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17743','{20854}=1 and {20855}>0','Cache group [{#JMXNAME}]: List of caches has changed','','0','1','List of caches has changed. Significant changes have occurred in the cluster. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17744','{20856}>0','Cache group [{#JMXNAME}]: Rebalance in progress','','0','1','Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17745','{20857}=0','Cache group [{#JMXNAME}]: There is no copy for partitions','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17746','{20858} > {$IGNITE.THREAD.QUEUE.MAX.WARN:"{#JMXNAME}"}','Thread pool [{#JMXNAME}]: Too many messages in queue (over {$IGNITE.THREAD.QUEUE.MAX.WARN:"{#JMXNAME}"} for 5 min)','','0','3','Number of messages in queue more than {$IGNITE.THREAD.QUEUE.MAX.WARN:"{#JMXNAME}"}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17747','{20859}/{20860}*100>{$IGNITE.CHECKPOINT.PUSED.MAX.HIGH}','Data region {#JMXNAME}: Checkpoint buffer utilization is too high (over {$IGNITE.CHECKPOINT.PUSED.MAX.HIGH} in 5m)','','0','4','Checkpoint buffer utilization is high. Threads will be throttled to avoid buffer overflow. It can be caused by high disk utilization.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17748','{20861}/{20862}*100>{$IGNITE.CHECKPOINT.PUSED.MAX.WARN}','Data region {#JMXNAME}: Checkpoint buffer utilization is too high (over {$IGNITE.CHECKPOINT.PUSED.MAX.WARN} in 5m)','','0','2','Checkpoint buffer utilization is high. Threads will be throttled to avoid buffer overflow. It can be caused by high disk utilization.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17749','{20863}/{20864}*100>{$IGNITE.DATA.REGION.PUSED.MAX.HIGH}','Data region {#JMXNAME}: Data region utilisation is too high (over {$IGNITE.DATA.REGION.PUSED.MAX.HIGH} in 5m)','','0','4','Data region utilization is high. Increase data region size or delete any data.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17750','{20865}/{20866}*100>{$IGNITE.DATA.REGION.PUSED.MAX.WARN}','Data region {#JMXNAME}: Data region utilisation is too high (over {$IGNITE.DATA.REGION.PUSED.MAX.WARN} in 5m)','','0','2','Data region utilization is high. Increase data region size or delete any data.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17751','{20867}>0','Data region {#JMXNAME}: Node started to evict pages','','0','1','You store more data then region can accommodate. Data started to move to disk it can make requests work slower. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17752','{20868}>0','Data region {#JMXNAME}: Pages replace rate more than 0','','0','2','There is more data than DataRegionMaxSize. Cluster started to replace pages in memory. Page replacement can slow down operations.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17753','{20869} > {$IGNITE.PME.DURATION.MAX.WARN}','Ignite [{#JMXIGNITEINSTANCENAME}]: PME duration is too long (over {$IGNITE.PME.DURATION.MAX.WARN} for 5 min)','','0','2','PME duration is over {$IGNITE.PME.DURATION.MAX.WARN}ms.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17754','{20870} > {$IGNITE.PME.DURATION.MAX.HIGH}','Ignite [{#JMXIGNITEINSTANCENAME}]: PME duration is too long (over {$IGNITE.PME.DURATION.MAX.HIGH} for 5 min)','','0','4','PME duration is over {$IGNITE.PME.DURATION.MAX.HIGH}ms. Looks like PME is hung.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17755','{20871} > {$IGNITE.THREADS.COUNT.MAX.WARN}','Ignite [{#JMXIGNITEINSTANCENAME}]: Number of running threads is too high (over {$IGNITE.THREADS.COUNT.MAX.WARN} for 15 min)','','0','2','Number of running threads is over {$IGNITE.THREADS.COUNT.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17756','{20872} > {$IGNITE.JOBS.QUEUE.MAX.WARN}','Ignite [{#JMXIGNITEINSTANCENAME}]: Number of queued jobs is too high (over {$IGNITE.JOBS.QUEUE.MAX.WARN} for 15 min)','','0','2','Number of queued jobs is over {$IGNITE.JOBS.QUEUE.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17757','{20873}>{20874}','Ignite [{#JMXIGNITEINSTANCENAME}]: There are nodes is not in topology','','0','1','One or more server node left the topology. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17758','{20875}<0','Ignite [{#JMXIGNITEINSTANCENAME}]: Server node left the topology','','0','2','One or more server node left the topology. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17759','{20876}>0','Ignite [{#JMXIGNITEINSTANCENAME}]: Server node added to the topology','','0','1','One or more server node added to the topology. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17760','{20877}=1 and {20878}>0','Ignite [{#JMXIGNITEINSTANCENAME}]: Version has changed (new version: {ITEM.VALUE})','','0','1','Ignite [{#JMXIGNITEINSTANCENAME}] version has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17761','{20879}<10m','Ignite [{#JMXIGNITEINSTANCENAME}]: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17762','{20880}=1','Ignite [{#JMXIGNITEINSTANCENAME}]: Failed to fetch info data (or no data for 10m)','','0','2','Zabbix has not received data for items for the last 10 minutes.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17763','{20881}=1 and {20882}>0','Ignite [{#JMXIGNITEINSTANCENAME}]: Coordinator has changed','','0','2','Ignite [{#JMXIGNITEINSTANCENAME}] version has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17764','{20883}={20884}','Cache group [{#JMXGROUP}]: All entries are in heap','','0','1','All entries are in heap. Possibly you use eager queries it may cause out of memory exceptions for big caches. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17765','{20885} > {20886}','Cache group [{#JMXGROUP}]: Success transactions less than rollbacks for 5m','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17766','{20887}>0 and {20888}=0','Cache group [{#JMXGROUP}]: There are no success transactions for cache for 5m','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17767','{20889}/{20890}*100>{$REDIS.MEM.PUSED.MAX.WARN}','Redis: Memory usage is too high (over {$REDIS.MEM.PUSED.MAX.WARN}% in 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17768','{20891}=1','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery is in warning state','','0','2','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17769','{20892}=1 or {20893}=1 or {20894}=1','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is in warning state','','0','2','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17770','{20895}=1 and {20896}<>{$DISK_ARRAY_CACHE_WARN_STATUS:"invalid"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is not in optimal state','','0','2','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17771','{20897} = 1','{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17772','{20898} = 3','{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17773','{20899} = 4','{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17774','{20900} = 1','Ambient: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17775','{20901} = 3','Ambient: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17776','{20902} = 4','Ambient: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17777','{20903} = 1','CPU-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17778','{20904} = 3','CPU-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17779','{20905} = 4','CPU-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17780','{20906} = 1','I/O-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17781','{20907} = 3','I/O-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17782','{20908} = 4','I/O-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17783','{20909} = 1','Memory-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17784','{20910} = 3','Memory-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17785','{20911} = 4','Memory-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17786','{20912} = 1','PSU-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17787','{20913} = 3','PSU-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17788','{20914} = 4','PSU-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17789','{20915} = 1','System-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17790','{20916} = 3','System-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17791','{20917} = 4','System-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17792','{20918}>={20919}','Cache group [{#JMXNAME}]: One or more backups are unavailable','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17793','{20920}>{$MEMORY.UTIL.MAX}','{#MEMNAME}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17798','({20925}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20926} or
{20927}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20926}) and
{20926}>0','Interface {#IFDESCR}: High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{20925}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20926} and
{20927}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20926}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17799','{20928}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {20929}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFDESCR}: High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{20930}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {20931}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17806','({20953}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20954} or
{20955}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20954}) and
{20954}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{20953}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20954} and
{20955}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20954}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17807','{20956}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {20957}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{20958}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {20959}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17850','({21107}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21108} or
{21109}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21108}) and
{21108}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21107}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21108} and
{21109}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21108}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17851','{21110}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21111}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21112}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21113}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17854','{21121} <= {#THRESH}','SMART [{#NAME}]: Attribute {#ID} {#ATTRNAME} is failed','','0','2','The value should be greater than THRESH.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17855','{21122}>90','SMART [{#NAME}]: NVMe disk percentage using is over 90% of estimated endurance','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17856','{21123}=1 and {21124}>0','SMART [{#NAME}]: Disk has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17857','{21125}>{$SMART.TEMPERATURE.MAX.WARN}','SMART [{#NAME}]: Average disk temperature is too high (over {$SMART.TEMPERATURE.MAX.WARN}°C for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17858','{21126}>{$SMART.TEMPERATURE.MAX.CRIT}','SMART [{#NAME}]: Average disk temperature is critical (over {$SMART.TEMPERATURE.MAX.CRIT}°C for 5m)','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17859','{21127}="false"','SMART [{#NAME}]: Disk self-test is not passed','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17860','{21128} <= {#THRESH}','SMART [{#NAME}]: Attribute {#ID} {#ATTRNAME} is failed','','0','2','The value should be greater than THRESH.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17861','{21129}>90','SMART [{#NAME}]: NVMe disk percentage using is over 90% of estimated endurance','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17862','{21130}=1 and {21131}>0','SMART [{#NAME}]: Disk has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17863','{21132}>{$SMART.TEMPERATURE.MAX.WARN}','SMART [{#NAME}]: Average disk temperature is too high (over {$SMART.TEMPERATURE.MAX.WARN}°C for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17864','{21133}>{$SMART.TEMPERATURE.MAX.CRIT}','SMART [{#NAME}]: Average disk temperature is critical (over {$SMART.TEMPERATURE.MAX.CRIT}°C for 5m)','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17865','{21134}="false"','SMART [{#NAME}]: Disk self-test is not passed','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17866','{21135}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17867','{21136}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17868','{21137}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17871','{21140}>{$MEMORY.UTIL.MAX}','{#SNMPVALUE}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17875','{21144}>{$MEMORY.UTIL.MAX}','#{#SNMPINDEX}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17876','{21145}>{$MEMORY.UTIL.MAX}','{#SNMPINDEX}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17877','{21146}>{$MEMORY.UTIL.MAX}','#{#SNMPVALUE}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17878','{21147}>{$MEMORY.UTIL.MAX}','#{#SNMPVALUE}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17879','{21148}>{$MEMORY.UTIL.MAX}','{#MODULE_NAME}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17880','{21149}>{$MEMORY.UTIL.MAX}','#{#SNMPVALUE}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17881','{21150}>{$MEMORY.UTIL.MAX}','{#ENT_NAME}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17882','{21151}>{$MEMORY.UTIL.MAX}','{#SNMPVALUE}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17883','{21152}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17884','{21153}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17885','{21154}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17886','{21155}>{$MEMORY.UTIL.MAX}','#{#SNMPVALUE}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17887','{21156}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17888','{21157}<{$SWAP.PFREE.MIN.WARN} and {21158}>0','High swap space usage (less than {$SWAP.PFREE.MIN.WARN}% free)','','0','2','This trigger is ignored, if there is no swap configured',NULL,'0','0','0','','0','','0','Free: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17889','{21159}<{$MEMORY.AVAILABLE.MIN} and {21160}>0','Lack of available memory (< {$MEMORY.AVAILABLE.MIN} of {ITEM.VALUE2})','','0','3','',NULL,'0','0','0','','0','','0','Available: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17890','{21161}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17897','{21172}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21173}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}: High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21174}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21175}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17900','{21184}<{$SWAP.PFREE.MIN.WARN} and {21185}>0','High swap space usage (less than {$SWAP.PFREE.MIN.WARN}% free)','','0','2','This trigger is ignored, if there is no swap configured',NULL,'0','0','0','','0','','0','Free: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17901','{21186}<{$MEMORY.AVAILABLE.MIN} and {21187}>0','Lack of available memory (< {$MEMORY.AVAILABLE.MIN} of {ITEM.VALUE2})','','0','3','',NULL,'0','0','0','','0','','0','Available: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17902','{21188}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17906','{21194}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21195}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}: High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21196}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21197}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17908','{21202}<{$SWAP.PFREE.MIN.WARN} and {21203}>0','High swap space usage (less than {$SWAP.PFREE.MIN.WARN}% free)','','0','2','This trigger is ignored, if there is no swap configured',NULL,'0','0','0','','0','','0','Free: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17909','{21204}<{$MEMORY.AVAILABLE.MIN} and {21205}>0','Lack of available memory (< {$MEMORY.AVAILABLE.MIN} of {ITEM.VALUE2})','','0','3','',NULL,'0','0','0','','0','','0','Available: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17910','{21206}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17911','({21207}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21208} or
{21209}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21208}) and
{21208}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21207}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21208} and
{21209}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21208}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17912','{21210}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21211}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21212}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21213}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17913','{21214}<{$SWAP.PFREE.MIN.WARN} and {21215}>0','High swap space usage (less than {$SWAP.PFREE.MIN.WARN}% free)','','0','2','This trigger is ignored, if there is no swap configured',NULL,'0','0','0','','0','','0','Free: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17914','{21216}<{$MEMORY.AVAILABLE.MIN} and {21217}>0','Lack of available memory (< {$MEMORY.AVAILABLE.MIN} of {ITEM.VALUE2})','','0','3','',NULL,'0','0','0','','0','','0','Available: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17915','{21218}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17919','{21224}<{$SWAP.PFREE.MIN.WARN} and {21225}>0','High swap space usage (less than {$SWAP.PFREE.MIN.WARN}% free)','','0','2','This trigger is ignored, if there is no swap configured',NULL,'0','0','0','','0','','0','Free: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17920','{21226}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17927','{21244}<{$SWAP.PFREE.MIN.WARN} and {21245}>0','High swap space usage (less than {$SWAP.PFREE.MIN.WARN}% free)','','0','2','This trigger is ignored, if there is no swap configured',NULL,'0','0','0','','0','','0','Free: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17928','{21246}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17941','{21271}=1 and {21272}>0','OceanStor 5300 V5: Storage version has been changed','','0','1','OceanStor 5300 V5 version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17942','{21273}<>1','BBU {#ID} on {#LOCATION}: Health status is not Normal','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17943','{21274}<>2','BBU {#ID} on {#LOCATION}: Running status is not Online','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17944','{21275}>{$CPU.UTIL.CRIT}','Controller {#ID}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17945','{21276}<>1','Controller {#ID}: Health status is not Normal','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17946','{21277}>{$HUAWEI.5300.MEM.MAX.WARN}','Controller {#ID}: Memory usage is too high (over {$HUAWEI.5300.MEM.MAX.WARN} for {$HUAWEI.5300.MEM.MAX.TIME})','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17947','{21278}=1','Controller {#ID}: Role has been changed','','0','2','',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17948','{21279}<>27','Controller {#ID}: Running status is not Online','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17949','{21280}<>1','Disk {#MODEL} on {#LOCATION}: Health status is not Normal','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17950','{21281}<>27','Disk {#MODEL} on {#LOCATION}: Running status is not Online','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17951','{21282}>{$HUAWEI.5300.DISK.TEMP.MAX.WARN:"{#MODEL}"}','Disk {#MODEL} on {#LOCATION}: Temperature is too high (over {$HUAWEI.5300.DISK.TEMP.MAX.WARN:"{#MODEL}"} for {$HUAWEI.5300.DISK.TEMP.MAX.TIME})','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17952','{21283}<>1','Enclosure {#NAME}: Health status is not Normal','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17953','{21284}<>27','Enclosure {#NAME}: Running status is not Online','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17954','{21285}>{$HUAWEI.5300.TEMP.MAX.WARN}','Enclosure {#NAME}: Temperature is too high (over {$HUAWEI.5300.TEMP.MAX.WARN} for {$HUAWEI.5300.TEMP.MAX.TIME})','','0','4','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17955','{21286}<>1','FAN {#ID} on {#LOCATION}: Health status is not Normal','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17956','{21287}<>2','FAN {#ID} on {#LOCATION}: Running status is not Running','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17957','{21288}>{$HUAWEI.5300.LUN.IO.TIME.MAX.WARN}','LUN {#NAME}: Average I/O response time is too high (over {$HUAWEI.5300.LUN.IO.TIME.MAX.WARN}ms for {$HUAWEI.5300.LUN.IO.TIME.MAX.TIME})','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17958','{21289}<>1','LUN {#NAME}: Status is not Normal','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17959','{21290}>{$CPU.UTIL.CRIT}','Node {#NODE}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17960','{21291}>{$HUAWEI.5300.NODE.IO.DELAY.MAX.WARN}','Node {#NODE}: Average I/O latency is too high (over {$HUAWEI.5300.NODE.IO.DELAY.MAX.WARN}ms for {$HUAWEI.5300.NODE.IO.DELAY.MAX.TIME})','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17961','{21292}>{#THRESHOLD}','Pool {#NAME}: Used capacity is too high (over {#THRESHOLD}%)','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17962','{21293}<>1','Pool {#NAME}: Health status is not Normal','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17963','{21294}<>27','Pool {#NAME}: Running status is not Online','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17965','{21299}=1','RabbitMQ: Failed to fetch overview data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17966','{21300}>{$RABBITMQ.RESPONSE_TIME.MAX.WARN}','RabbitMQ: Service response time is too high (over {$RABBITMQ.RESPONSE_TIME.MAX.WARN}s for 5m)','','0','2','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17967','{21301}=0','RabbitMQ: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17968','{21302}=0','RabbitMQ: Process is not running','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17969','{21303}=1','RabbitMQ: Free disk space alarm (Free space threshold has been reached)','','0','3','https://www.rabbitmq.com/disk-alarms.html',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17970','{21304}=1','RabbitMQ: Memory alarm (Memory usage threshold has been reached)','','0','3','https://www.rabbitmq.com/memory.html',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17971','{21305}=1 and {21306}>0','RabbitMQ: Version has changed (new version: {ITEM.VALUE})','','0','1','RabbitMQ version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17972','{21307}>0','RabbitMQ: Number of network partitions is too high (more than 0 for 5m)','','0','2','https://www.rabbitmq.com/partitions.html#detecting',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17973','{21308}=0','RabbitMQ: Node is not running','','0','3','RabbitMQ node is not running',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17974','{21309}<10m','RabbitMQ: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17975','{21310}=1','RabbitMQ: Failed to fetch nodes data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17976','{21311}=0','RabbitMQ: There are active alarms in the cluster','','0','3','http://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/index.html',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17977','{21312}=0','RabbitMQ: Node healthcheck failed','','0','3','https://www.rabbitmq.com/monitoring.html#health-checks',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17978','{21313}=0','RabbitMQ: There are valid TLS certificates expiring in the next month','','0','3','http://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/index.html',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17979','{21314}=0','RabbitMQ: There are active alarms in the node','','0','3','http://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/index.html',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17980','{21315}=0','RabbitMQ: There are queues that could potentially lose data if the this node goes offline.','','0','3','http://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/index.html',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17981','{21316}=0','RabbitMQ: There are queues that would lose their quorum and availability if the this node is shut down.','','0','3','http://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/index.html',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17982','{21317}=0','RabbitMQ: There are not running virtual hosts','','0','3','http://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/index.html',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17983','{21318}>{$RABBITMQ.MESSAGES.MAX.WARN:"{#QUEUE}"}','RabbitMQ: Too many messages in queue (over {$RABBITMQ.MESSAGES.MAX.WARN} for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17984','{21319}=1','RabbitMQ: Failed to fetch overview data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17985','{21320}>{$RABBITMQ.RESPONSE_TIME.MAX.WARN}','RabbitMQ: Service response time is too high (over {$RABBITMQ.RESPONSE_TIME.MAX.WARN}s for 5m)','','0','2','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17986','{21321}=0','RabbitMQ: Service is down','','0','3','',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17987','{21322}=1','RabbitMQ: Failed to fetch nodes data (or no data for 30m)','','0','2','Zabbix has not received data for items for the last 30 minutes.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17988','{21323}=1','RabbitMQ: Free disk space alarm (Free space threshold has been reached)','','0','3','https://www.rabbitmq.com/disk-alarms.html',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17989','{21324}=1','RabbitMQ: Memory alarm (Memory usage threshold has been reached)','','0','3','https://www.rabbitmq.com/memory.html',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17990','{21325}=1 and {21326}>0','RabbitMQ: Version has changed (new version: {ITEM.VALUE})','','0','1','RabbitMQ version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17991','{21327}>0','RabbitMQ: Number of network partitions is too high (more than 0 for 5m)','','0','2','https://www.rabbitmq.com/partitions.html#detecting',NULL,'0','0','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17992','{21328}=0','RabbitMQ: Node is not running','','0','3','RabbitMQ node is not running',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17993','{21329}<10m','RabbitMQ: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17994','{21330}=0','RabbitMQ: There are active alarms in the cluster','','0','3','http://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/index.html',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17995','{21331}=0','RabbitMQ: Node healthcheck failed','','0','3','https://www.rabbitmq.com/monitoring.html#health-checks',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17996','{21332}=0','RabbitMQ: There are valid TLS certificates expiring in the next month','','0','3','http://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/index.html',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17997','{21333}=0','RabbitMQ: There are active alarms in the node','','0','3','http://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/index.html',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17998','{21334}=0','RabbitMQ: There are queues that could potentially lose data if the this node goes offline.','','0','3','http://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/index.html',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17999','{21335}=0','RabbitMQ: There are queues that would lose their quorum and availability if the this node is shut down.','','0','3','http://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/index.html',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18000','{21336}=0','RabbitMQ: There are not running virtual hosts','','0','3','http://{HOST.CONN}:{$RABBITMQ.API.PORT}/api/index.html',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18001','{21337}>{$RABBITMQ.MESSAGES.MAX.WARN:"{#QUEUE}"}','RabbitMQ: Too many messages in queue (over {$RABBITMQ.MESSAGES.MAX.WARN} for 5m)','','0','2','',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18002','{21338}/({21339}+{21340})*100>{$MONGODB.CONNS.PCT.USED.MAX.WARN}','MongoDB: Total number of open connections is too high (over {$MONGODB.CONNS.PCT.USED.MAX.WARN%} in 5m)','','0','2','Too few available connections. If MongoDB runs low on connections, in may not be able to handle incoming requests in a timely manner.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18003','{21341}>{$MONGODB.CURSOR.OPEN.MAX.WARN}','MongoDB: Too many cursors opened by MongoDB for clients (over {$MONGODB.CURSOR.OPEN.MAX.WARN} in 5m)','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18004','{21342}>{$MONGODB.CURSOR.TIMEOUT.MAX.WARN}','MongoDB: Too many cursors are timing out (over {$MONGODB.CURSOR.TIMEOUT.MAX.WARN} per second in 5m)','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18005','{21343}=0','MongoDB: Connection to MongoDB is unavailable','','0','4','Connection to MongoDB instance is currently unavailable.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18006','{21344}<10m','MongoDB: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18007','{21345}=1','MongoDB: Failed to fetch info data (or no data for 10m)','','0','2','Zabbix has not received data for items for the last 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18008','{21346}=1 and {21347}>0','MongoDB: Version has changed (new version: {ITEM.VALUE})','','0','1','MongoDB version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18009','{21348}>0  and {21349}>0','MongoDB: There are unhealthy replicas in ReplicaSet','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18010','{21350}>{$MONGODB.REPL.LAG.MAX.WARN}','MongoDB: Replication lag with primary is too high (over {$MONGODB.REPL.LAG.MAX.WARN} in 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18012','{21352}<{$MONGODB.WIRED_TIGER.TICKETS.AVAILABLE.MIN.WARN}','MongoDB: Available WiredTiger read tickets less then {$MONGODB.WIRED_TIGER.TICKETS.AVAILABLE.MIN.WARN}','','0','2','"Too few available read tickets.
When the number of available read tickets remaining reaches zero, new read requests will be queued until a new read ticket is available."',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18013','{21353}<{$MONGODB.WIRED_TIGER.TICKETS.AVAILABLE.MIN.WARN}','MongoDB: Available WiredTiger write tickets less then {$MONGODB.WIRED_TIGER.TICKETS.AVAILABLE.MIN.WARN}','','0','2','"Too few available write tickets.
When the number of available write tickets remaining reaches zero, new write requests will be queued until a new write ticket is available."',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18014','{21354}<{$MONGODB.CONNS.AVAILABLE.MIN.WARN}','MongoDB cluster: Available connections less then {$MONGODB.CONNS.AVAILABLE.MIN.WARN}','','0','2','"Too few available connections.
Consider this value in combination with the value of connections current to understand the connection load on the database"',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18015','{21355}>{$MONGODB.CURSOR.OPEN.MAX.WARN}','MongoDB cluster: Too many cursors opened by MongoDB for clients (over {$MONGODB.CURSOR.OPEN.MAX.WARN} in 5m)','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18016','{21356}>{$MONGODB.CURSOR.TIMEOUT.MAX.WARN}','MongoDB cluster: Too many cursors are timing out (over {$MONGODB.CURSOR.TIMEOUT.MAX.WARN} per second in 5m)','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18017','{21357}=0','MongoDB cluster: Connection to mongos proxy is unavailable','','0','4','Connection to mongos proxy instance is currently unavailable.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18018','{21358}<10m','MongoDB cluster: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18019','{21359}=1','MongoDB cluster: Failed to fetch info data (or no data for 10m)','','0','2','Zabbix has not received data for items for the last 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18020','{21360}=1 and {21361}>0','MongoDB cluster: Version has changed (new version: {ITEM.VALUE})','','0','1','MongoDB cluster version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18021','{21362}>{21363} and {21363}>{21364}','MSSQL AG ''{#GROUP_NAME}'' Non-Local DB ''*{#REPLICA_NAME}*{#DBNAME}'': Log queue size is growing','','0','4','The log records of the primary database are not sent to the secondary databases.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18022','{21365}>{21366} and {21366}>{21367}','MSSQL AG ''{#GROUP_NAME}'' Non-Local DB ''*{#REPLICA_NAME}*{#DBNAME}'': Redo log queue size is growing','','0','4','The log records in the log files of the secondary replica have not yet been redone.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18023','{21368}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18024','{21369}>{$ICMP_LOSS_WARN} and {21369}<100','High ICMP ping loss','','0','2','',NULL,'0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18025','{21370}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','',NULL,'0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18026','{21371}=1 and {21372}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18027','{21373}=1 and {21374}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18028','{21375}=1 and {21376}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','2','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18029','{21377}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18030','{21378}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18031','{21379}>{$CPU.UTIL.CRIT}','#{#SNMPINDEX}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18032','{21380}=1 and {21381}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18033','{21382}=3 or {21382}=4','{#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18034','{21383}=2','{#SNMPVALUE}: Fan is in warning state','','0','2','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18035','{21384}>{$MEMORY.UTIL.MAX}','{#SNMPVALUE}: High memory utilization ( >{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18036','{21385}<0 and {21386}>0
and (
{21387}=6 or
{21387}=7 or
{21387}=11 or
{21387}=62 or
{21387}=69 or
{21387}=117
)
and
({21388}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({21385}>0 and {21389}>0) or
({21388}=2)','0','','0','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18037','({21390}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21391}) and
{21391}>0','Interface {#IFNAME}({#IFALIAS}): High inbound bandwidth usage ( > {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21390}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21391}','0','','0','In: {ITEM.LASTVALUE1}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18038','({21392}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21393}) and
{21393}>0','Interface {#IFNAME}({#IFALIAS}): High outbound bandwidth usage ( > {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21392}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21393}','0','','0','Out: {ITEM.LASTVALUE1}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18039','{21394}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High input error rate ( > {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21395}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','0','errors in: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18040','{21396}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High output error rate ( > {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21397}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','0','errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18041','{$IFCONTROL:"{#IFNAME}"}=1 and ({21398}=2)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18042','{21399}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18043','{21400}=3 or {21401}=4','{#SNMPVALUE}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18044','{21402}=2','{#SNMPVALUE}: Power supply is in warning state','','0','2','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18045','{21403}=3 or {21403}=4','{#SNMPVALUE}: Temperature is in critical state','','0','4','This trigger uses temperature sensor state',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18046','{21404}=2','{#SNMPVALUE}: Temperature is in warning state','','0','2','This trigger uses temperature sensor state',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18047','{21405}>{$TEMP_CRIT:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:"{#SNMPVALUE}"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{21406}<{$TEMP_CRIT:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18048','{21407}>{$TEMP_WARN:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:"{#SNMPVALUE}"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{21408}<{$TEMP_WARN:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18049','{21409}<{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','','0','3','',NULL,'0','2','1','{21410}>{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18050','{21411}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18051','{21412}>{$ICMP_LOSS_WARN} and {21412}<100','High ICMP ping loss','','0','2','',NULL,'0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18052','{21413}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','',NULL,'0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18053','{21414}=1 and {21415}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18054','{21416}=1 and {21417}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18055','{21418}=1 and {21419}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','2','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18056','{21420}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18057','{21421}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18058','{21422}>{$CPU.UTIL.CRIT}','#{#SNMPINDEX}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18059','{21423}=1 and {21424}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18060','{21425}=3 or {21425}=4','{#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18061','{21426}=2','{#SNMPVALUE}: Fan is in warning state','','0','2','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18062','{21427}>{$MEMORY.UTIL.MAX}','{#SNMPVALUE}: High memory utilization ( >{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18063','{21428}<0 and {21429}>0
and (
{21430}=6 or
{21430}=7 or
{21430}=11 or
{21430}=62 or
{21430}=69 or
{21430}=117
)
and
({21431}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({21428}>0 and {21432}>0) or
({21431}=2)','0','','0','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18064','({21433}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21434}) and
{21434}>0','Interface {#IFNAME}({#IFALIAS}): High inbound bandwidth usage ( > {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21433}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21434}','0','','0','In: {ITEM.LASTVALUE1}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18065','({21435}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21436}) and
{21436}>0','Interface {#IFNAME}({#IFALIAS}): High outbound bandwidth usage ( > {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21435}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21436}','0','','0','Out: {ITEM.LASTVALUE1}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18066','{21437}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High input error rate ( > {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21438}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','0','errors in: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18067','{21439}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High output error rate ( > {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21440}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','0','errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18068','{$IFCONTROL:"{#IFNAME}"}=1 and ({21441}=2)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18069','{21442}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18070','{21443}=3 or {21444}=4','{#SNMPVALUE}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18071','{21445}=2','{#SNMPVALUE}: Power supply is in warning state','','0','2','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18072','{21446}=3 or {21446}=4','{#SNMPVALUE}: Temperature is in critical state','','0','4','This trigger uses temperature sensor state',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18073','{21447}=2','{#SNMPVALUE}: Temperature is in warning state','','0','2','This trigger uses temperature sensor state',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18074','{21448}>{$TEMP_CRIT:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:"{#SNMPVALUE}"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{21449}<{$TEMP_CRIT:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18075','{21450}>{$TEMP_WARN:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:"{#SNMPVALUE}"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{21451}<{$TEMP_WARN:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18076','{21452}<{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','','0','3','',NULL,'0','2','1','{21453}>{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18077','{21454}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18078','{21455}>{$ICMP_LOSS_WARN} and {21455}<100','High ICMP ping loss','','0','2','',NULL,'0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18079','{21456}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','',NULL,'0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18080','{21457}=1 and {21458}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18081','{21459}=1 and {21460}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18082','{21461}=1 and {21462}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','2','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18083','{21463}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18084','{21464}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18085','{21465}>{$CPU.UTIL.CRIT}','#{#SNMPINDEX}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18086','{21466}=1 and {21467}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18087','{21468}=3 or {21468}=4','{#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18088','{21469}=2','{#SNMPVALUE}: Fan is in warning state','','0','2','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18089','{21470}>{$MEMORY.UTIL.MAX}','{#SNMPVALUE}: High memory utilization ( >{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18090','{21471}<0 and {21472}>0
and (
{21473}=6 or
{21473}=7 or
{21473}=11 or
{21473}=62 or
{21473}=69 or
{21473}=117
)
and
({21474}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({21471}>0 and {21475}>0) or
({21474}=2)','0','','0','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18091','({21476}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21477}) and
{21477}>0','Interface {#IFNAME}({#IFALIAS}): High inbound bandwidth usage ( > {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21476}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21477}','0','','0','In: {ITEM.LASTVALUE1}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18092','({21478}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21479}) and
{21479}>0','Interface {#IFNAME}({#IFALIAS}): High outbound bandwidth usage ( > {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21478}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21479}','0','','0','Out: {ITEM.LASTVALUE1}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18093','{21480}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High input error rate ( > {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21481}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','0','errors in: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18094','{21482}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High output error rate ( > {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21483}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','0','errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18095','{$IFCONTROL:"{#IFNAME}"}=1 and ({21484}=2)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18096','{21485}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18097','{21486}=3 or {21487}=4','{#SNMPVALUE}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18098','{21488}=2','{#SNMPVALUE}: Power supply is in warning state','','0','2','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18099','{21489}=3 or {21489}=4','{#SNMPVALUE}: Temperature is in critical state','','0','4','This trigger uses temperature sensor state',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18100','{21490}=2','{#SNMPVALUE}: Temperature is in warning state','','0','2','This trigger uses temperature sensor state',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18101','{21491}>{$TEMP_CRIT:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:"{#SNMPVALUE}"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{21492}<{$TEMP_CRIT:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18102','{21493}>{$TEMP_WARN:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:"{#SNMPVALUE}"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{21494}<{$TEMP_WARN:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18103','{21495}<{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','','0','3','',NULL,'0','2','1','{21496}>{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18104','{21497}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18105','{21498}>{$ICMP_LOSS_WARN} and {21498}<100','High ICMP ping loss','','0','2','',NULL,'0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18106','{21499}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','',NULL,'0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18107','{21500}=1 and {21501}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18108','{21502}=1 and {21503}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18109','{21504}=1 and {21505}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','2','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18110','{21506}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18111','{21507}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18112','{21508}>{$CPU.UTIL.CRIT}','#{#SNMPINDEX}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18113','{21509}=1 and {21510}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18114','{21511}=3 or {21511}=4','{#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18115','{21512}=2','{#SNMPVALUE}: Fan is in warning state','','0','2','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18116','{21513}>{$MEMORY.UTIL.MAX}','{#SNMPVALUE}: High memory utilization ( >{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18117','{21514}<0 and {21515}>0
and (
{21516}=6 or
{21516}=7 or
{21516}=11 or
{21516}=62 or
{21516}=69 or
{21516}=117
)
and
({21517}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({21514}>0 and {21518}>0) or
({21517}=2)','0','','0','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18118','({21519}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21520}) and
{21520}>0','Interface {#IFNAME}({#IFALIAS}): High inbound bandwidth usage ( > {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21519}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21520}','0','','0','In: {ITEM.LASTVALUE1}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18119','({21521}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21522}) and
{21522}>0','Interface {#IFNAME}({#IFALIAS}): High outbound bandwidth usage ( > {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21521}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21522}','0','','0','Out: {ITEM.LASTVALUE1}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18120','{21523}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High input error rate ( > {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21524}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','0','errors in: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18121','{21525}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High output error rate ( > {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21526}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','0','errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18122','{$IFCONTROL:"{#IFNAME}"}=1 and ({21527}=2)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18123','{21528}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18124','{21529}=3 or {21530}=4','{#SNMPVALUE}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18125','{21531}=2','{#SNMPVALUE}: Power supply is in warning state','','0','2','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18126','{21532}=3 or {21532}=4','{#SNMPVALUE}: Temperature is in critical state','','0','4','This trigger uses temperature sensor state',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18127','{21533}=2','{#SNMPVALUE}: Temperature is in warning state','','0','2','This trigger uses temperature sensor state',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18128','{21534}>{$TEMP_CRIT:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:"{#SNMPVALUE}"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{21535}<{$TEMP_CRIT:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18129','{21536}>{$TEMP_WARN:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:"{#SNMPVALUE}"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{21537}<{$TEMP_WARN:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18130','{21538}<{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','','0','3','',NULL,'0','2','1','{21539}>{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18131','{21540}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18132','{21541}>{$ICMP_LOSS_WARN} and {21541}<100','High ICMP ping loss','','0','2','',NULL,'0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18133','{21542}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','',NULL,'0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18134','{21543}=1 and {21544}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18135','{21545}=1 and {21546}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18136','{21547}=1 and {21548}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.',NULL,'0','0','2','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18137','{21549}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18138','{21550}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18139','{21551}>{$CPU.UTIL.CRIT}','#{#SNMPINDEX}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18140','{21552}=1 and {21553}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18141','{21554}=3 or {21554}=4','{#SNMPVALUE}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18142','{21555}=2','{#SNMPVALUE}: Fan is in warning state','','0','2','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18143','{21556}>{$MEMORY.UTIL.MAX}','{#SNMPVALUE}: High memory utilization ( >{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18144','{21557}<0 and {21558}>0
and (
{21559}=6 or
{21559}=7 or
{21559}=11 or
{21559}=62 or
{21559}=69 or
{21559}=117
)
and
({21560}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({21557}>0 and {21561}>0) or
({21560}=2)','0','','0','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18145','({21562}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21563}) and
{21563}>0','Interface {#IFNAME}({#IFALIAS}): High inbound bandwidth usage ( > {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21562}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21563}','0','','0','In: {ITEM.LASTVALUE1}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18146','({21564}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21565}) and
{21565}>0','Interface {#IFNAME}({#IFALIAS}): High outbound bandwidth usage ( > {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21564}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21565}','0','','0','Out: {ITEM.LASTVALUE1}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18147','{21566}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High input error rate ( > {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21567}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','0','errors in: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18148','{21568}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High output error rate ( > {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21569}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','0','errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18149','{$IFCONTROL:"{#IFNAME}"}=1 and ({21570}=2)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18150','{21571}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18151','{21572}=3 or {21573}=4','{#SNMPVALUE}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18152','{21574}=2','{#SNMPVALUE}: Power supply is in warning state','','0','2','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18153','{21575}=3 or {21575}=4','{#SNMPVALUE}: Temperature is in critical state','','0','4','This trigger uses temperature sensor state',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18154','{21576}=2','{#SNMPVALUE}: Temperature is in warning state','','0','2','This trigger uses temperature sensor state',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18155','{21577}>{$TEMP_CRIT:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:"{#SNMPVALUE}"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{21578}<{$TEMP_CRIT:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18156','{21579}>{$TEMP_WARN:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:"{#SNMPVALUE}"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{21580}<{$TEMP_WARN:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18157','{21581}<{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','','0','3','',NULL,'0','2','1','{21582}>{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18158','{21583}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18159','{21584}>{$ICMP.LOSS.WARN} and {21584}<100','High ICMP ping loss','','0','2','',NULL,'0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18160','{21585}>{$ICMP.RESPONSE_TIME.WARN}','High ICMP ping response time','','0','2','',NULL,'0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18161','{21586}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18162','{21587}=1 and {21588}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18163','{21589}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18164','{21590}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18165','{21591}=1','{#SENSOR_INFO}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18166','{21592}<0 and {21593}>0
and (
{21594}=6 or
{21594}=7 or
{21594}=11 or
{21594}=62 or
{21594}=69 or
{21594}=117
)
and
({21595}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','1','({21592}>0 and {21596}>0) or
({21595}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18167','({21597}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21598} or
{21599}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21598}) and
{21598}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage ( > {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{21597}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21598} and
{21599}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21598}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18168','{21600}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21601}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate ( > {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{21602}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21603}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18169','{$IFCONTROL:"{#IFNAME}"}=1 and ({21604}=2 and {21605}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{21604}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18170','{21606}=1','{#ENT_NAME}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18171','{21607}>{$TEMP.MAX.WARN:"{#SENSOR_INFO}"}
or
{21608}={$TEMP.STATUS.WARN}','{#SENSOR_INFO}: Temperature is above warning threshold: >{$TEMP.MAX.WARN:"{#SENSOR_INFO}"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{21609}<{$TEMP.MAX.WARN:"{#SENSOR_INFO}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18172','{21610}>{$TEMP.MAX.CRIT:"{#SENSOR_INFO}"}','{#SENSOR_INFO}: Temperature is above critical threshold: >{$TEMP.MAX.CRIT:"{#SENSOR_INFO}"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{21611}<{$TEMP.MAX.CRIT:"{#SENSOR_INFO}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18173','{21612}<{$TEMP.MIN.CRIT:"{#SENSOR_INFO}"}','{#SENSOR_INFO}: Temperature is too low: <{$TEMP.MIN.CRIT:"{#SENSOR_INFO}"}','','0','3','',NULL,'0','2','1','{21613}>{$TEMP.MIN.CRIT:"{#SENSOR_INFO}"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18174','{21614}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({21615}-{21616})<5G or {21617}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18175','{21618}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({21619}-{21620})<10G or {21621}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.',NULL,'0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18176','{21622}>{$MEMORY.UTIL.MAX}','{#MEMNAME}: High memory utilization ( >{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18177','{21623}=2','Battery needs replacement','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18178','{21624}=4','Battery has an internal error condition','','0','3','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18179','{21625}=3','Battery is Low','','0','3','The UPS will be unable to sustain the current load, and its services will be lost if power is not restored.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18180','{21626} > {$BATTERY.TEMP.MAX.WARN}','Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18184','{21630} > 0 and ({21630} > {$UPS.INPUT_FREQ.MAX.WARN} or {21631} < {$UPS.INPUT_FREQ.MIN.WARN})','Unacceptable input frequency (out of range {$UPS.INPUT_FREQ.MIN.WARN}-{$UPS.INPUT_FREQ.MAX.WARN}Hz for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current frequency: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18185','{21632} > 0 and ({21632} > {$UPS.INPUT_VOLT.MAX.WARN} or {21633} < {$UPS.INPUT_VOLT.MIN.WARN})','Unacceptable input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18186','{21634} > {$UPS.OUTPUT.MAX.WARN}','Output load is high (over {$UPS.OUTPUT.MAX.WARN}% for {$TIME.PERIOD})','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','Current load: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18187','{21635}=5','UPS is Timed Sleeping','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18188','{21636}=9','UPS is Switched Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18189','{21637}=6','UPS is Software Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18190','{21638}=11','UPS is Sleeping Until Power Return','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18191','{21639}=8','UPS is Rebooting','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18192','{21640}=12','UPS is On Smart Trim','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18193','{21641}=4','UPS is on Smart Boost','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18194','{21642}=3','UPS is on battery','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18195','{21643}=7','UPS is Off','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18196','{21644}=16','UPS is Emergency Static Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18197','{21645}=10','UPS is Hardware Failure Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18199','{21648}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18200','{21649}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18201','{21650}=1','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery lifetime is not okay','','0','2','The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18203','{21652} > {$BATTERY.TEMP.MAX.WARN}','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18204','{21653}=4','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18205','{21654}=2','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18206','{21655}=3','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18207','{21656}=4','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18208','{21657}=2','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18209','{21658}=3','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18210','{21659} > {$UPS.INPUT_VOLT.MAX.WARN} or {21660} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18211','({21661}<>"ok")','Cluster status is abnormal','','0','3','Any errors associated with the sample. For example, if the aggregation of data over multiple nodes fails then any of the partial errors might be returned, “ok” on success, or “error” on any internal uncategorized failure. Whenever a sample collection is missed but done at a later time, it is back filled to the previous 15 second timestamp and tagged with "backfilled_data". “Inconsistent_ delta_time” is encountered when the time between two collections is not the same for all nodes. Therefore, the aggregated value might be over or under inflated. “Negative_delta” is returned when an expected monotonically increasing value has decreased in value. “Inconsistent_old_data” is returned when one or more nodes do not have the latest data.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18212','{21662}=1 and {21663}>0','Version has changed (new version: {ITEM.VALUE})','','0','1','__RESOURCE__ version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18213','({21664}=1 and {21665}="error")','{#ID}: Chassis has something errors','','0','3','Something is wrong with the chassis.',NULL,'0','2','1','({21664}=1 and {21665}="ok")','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18214','({21666}=1 and {21667}<>"present")','{#DISKNAME}: Disk of the Node "{#NODENAME}" has state different from "present"','','0','3','Something is wrong with the disk.',NULL,'0','2','1','({21666}=1 and {21667}="present")','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18215','({21668}=1 and {21669}="error")','{#FRUID}: FRU of the chassis "{#ID}" state is error','','0','3','Something is wrong with the FRU.',NULL,'0','2','1','({21668}=1 and {21669}="ok")','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18216','({21670}=1 and {21671}<>"online")','{#LUNNAME}: LUN of the SVM "{#SVMNAME}" has abnormal container state','','0','3','LUNs are only available when their containers are available.',NULL,'0','2','1','({21670}=1 and {21671}="online")','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18217','({21672}=1 and {21673}<>"online")','{#LUNNAME}: LUN of the SVM "{#SVMNAME}" has abnormal state','','0','3','Normal states for a LUN are online and offline. Other states indicate errors.',NULL,'0','2','1','({21672}=1 and {21673}="online")','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18218','{21674}=1 and {21675}>0','{#NODENAME}: Version has changed (new version: {ITEM.VALUE})','','0','1','{#NODENAME} version has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18219','({21676}<>"normal")','{#NODENAME}: Node has over temperature','','0','3','The hardware shuts down if the temperature exceeds critical thresholds(item''s value is "over").',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18220','({21677}<>"up")','{#NODENAME}: Node state is abnormal','','0','3','The state of the node is different from up:
booting - Node is booting up.
down - Node has stopped or is dumping core.
taken_over - Node has been taken over by its HA partner and is not yet waiting for giveback.
waiting_for_giveback - Node has been taken over by its HA partner and is waiting for the HA partner to giveback disks.
degraded - Node has one or more critical services offline.
unknown - Node or its HA partner cannot be contacted and there is no information on the node’s state.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18221','{21678}<10m','{#NODENAME}: Node has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18222','({21679}=1 and {21680}="down")','{#ETHPORTNAME}: Ethernet port of the Node "{#NODENAME}" is down','','0','3','Something is wrong with the ethernet port.',NULL,'0','2','1','({21679}=1 and {21680}="up")','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18223','({21681}=1 and {21682}<>"online")','{#FCPORTNAME}: FC port of the Node "{#NODENAME}" has state different from "online"','','0','3','Something is wrong with the FC port.',NULL,'0','2','1','({21681}=1 and {21682}="online")','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18224','({21683}=1 and {21684}<>"running")','{#SVMNAME}: SVM state is abnormal','','0','3','Something is wrong with the SVM.',NULL,'0','2','1','({21683}=1 and {21684}="running")','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18225','({21685}=1 and {21686}<>"online")','{#VOLUMENAME}: Volume state is abnormal','','0','3','A volume can only be brought online if it is offline. Taking a volume offline removes its junction path. The ‘mixed’ state applies to FlexGroup volumes only and cannot be specified as a target state. An ‘error’ state implies that the volume is not in a state to serve data.',NULL,'0','2','1','({21685}=1 and {21686}="online")','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18226','{21687}>{21688}','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Message enqueue rate is higher than dequeue rate for {$ACTIVEMQ.MSG.RATE.WARN.TIME:"{#JMXDESTINATIONNAME}"}','','0','3','Enqueue rate is higher than dequeue rate. It may indicate performance problems.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18227','{21689}>{$ACTIVEMQ.EXPIRIED.WARN:"{#JMXDESTINATIONNAME}"}','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Expired messages count higher than {$ACTIVEMQ.EXPIRIED.WARN:"{#JMXDESTINATIONNAME}"}','','0','3','This metric represents the number of messages that expired before they could be delivered. If you expect all messages to be delivered and acknowledged within a certain amount of time, you can set an expiration for each message, and investigate if your ExpiredCount metric rises above zero.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18228','{21690}>{$ACTIVEMQ.QUEUE.WARN:"{#JMXDESTINATIONNAME}"} and {$ACTIVEMQ.QUEUE.ENABLED:"{#JMXDESTINATIONNAME}"}=1','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Queue size higher than {$ACTIVEMQ.QUEUE.WARN:"{#JMXDESTINATIONNAME}"} for {$ACTIVEMQ.QUEUE.TIME:"{#JMXDESTINATIONNAME}"}','','0','3','Queue size is higher than threshold. It may indicate performance problems.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18229','{21691}>{21691}','Broker {#JMXBROKERNAME}: Message enqueue rate is higher than dequeue rate for {$ACTIVEMQ.MSG.RATE.WARN.TIME:"{#JMXBROKERNAME}"}','','0','3','Enqueue rate is higher than dequeue rate. It may indicate performance problems.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18230','{21692}>{21693}/100*{$SQUID.PAGE.FAULT.WARN}','Squid: High sys page faults rate (>{$SQUID.PAGE.FAULT.WARN}% of received HTTP requests)','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18231','{21694} > {$ORACLE.CONCURRENCY.MAX.WARN}','Oracle: Too high database concurrency (over {$ORACLE.CONCURRENCY.MAX.WARN}% for 5 min)','','0','2','Concurrency rate is over {$ORACLE.CONCURRENCY.MAX.WARN}%. A high contention value does not indicate the root cause of the problem, but is a signal to search for it. In the case of high competition, an analysis of resource consumption should be carried out, the most "heavy" queries made in the database, possibly - session tracing. All this will help determine the root cause and possible optimization points both in the database configuration and in the logic of building queries of the application itself.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18233','{21696} < {$BATTERY.CAPACITY.MIN.WARN}','Battery has low capacity (below {$BATTERY.CAPACITY.MIN.WARN}%)','','0','4','',NULL,'0','0','0','','0','','0','Current capacity: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18234','{21697}=2','Battery needs replacement','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18235','{21698}=4','Battery has an internal error condition','','0','3','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18236','{21699}=3','Battery is Low','','0','3','The UPS will be unable to sustain the current load, and its services will be lost if power is not restored.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18237','{21700} > {$BATTERY.TEMP.MAX.WARN}','Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18241','{21704} > 0 and ({21704} > {$UPS.INPUT_FREQ.MAX.WARN} or {21705} < {$UPS.INPUT_FREQ.MIN.WARN})','Unacceptable input frequency (out of range {$UPS.INPUT_FREQ.MIN.WARN}-{$UPS.INPUT_FREQ.MAX.WARN}Hz for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current frequency: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18242','{21706} > 0 and ({21706} > {$UPS.INPUT_VOLT.MAX.WARN} or {21707} < {$UPS.INPUT_VOLT.MIN.WARN})','Unacceptable input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18243','{21708} > {$UPS.OUTPUT.MAX.WARN}','Output load is high (over {$UPS.OUTPUT.MAX.WARN}% for {$TIME.PERIOD})','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','Current load: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18244','{21709}=5','UPS is Timed Sleeping','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18245','{21710}=9','UPS is Switched Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18246','{21711}=6','UPS is Software Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18247','{21712}=11','UPS is Sleeping Until Power Return','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18248','{21713}=8','UPS is Rebooting','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18249','{21714}=12','UPS is On Smart Trim','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18250','{21715}=4','UPS is on Smart Boost','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18251','{21716}=3','UPS is on battery','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18252','{21717}=7','UPS is Off','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18253','{21718}=16','UPS is Emergency Static Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18254','{21719}=10','UPS is Hardware Failure Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18256','{21722}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18257','{21723}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18258','{21724}=1','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery lifetime is not okay','','0','2','The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18259','{21725}=0','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status is not okay','','0','2','The battery cartridge status:
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18260','{21726} > {$BATTERY.TEMP.MAX.WARN}','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18261','{21727}=4','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18262','{21728}=2','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18263','{21729}=3','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18264','{21730}=4','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18265','{21731}=2','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18266','{21732}=3','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18267','{21733} > {$UPS.INPUT_VOLT.MAX.WARN} or {21734} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18268','{21735} > {$UPS.INPUT_VOLT.MAX.WARN} or {21736} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} output voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18269','{21737} < {$BATTERY.CAPACITY.MIN.WARN}','Battery has low capacity (below {$BATTERY.CAPACITY.MIN.WARN}%)','','0','4','',NULL,'0','0','0','','0','','0','Current capacity: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18270','{21738}=2','Battery needs replacement','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18271','{21739}=4','Battery has an internal error condition','','0','3','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18272','{21740}=3','Battery is Low','','0','3','The UPS will be unable to sustain the current load, and its services will be lost if power is not restored.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18273','{21741} > {$BATTERY.TEMP.MAX.WARN}','Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18277','{21745} > 0 and ({21745} > {$UPS.INPUT_FREQ.MAX.WARN} or {21746} < {$UPS.INPUT_FREQ.MIN.WARN})','Unacceptable input frequency (out of range {$UPS.INPUT_FREQ.MIN.WARN}-{$UPS.INPUT_FREQ.MAX.WARN}Hz for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current frequency: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18278','{21747} > 0 and ({21747} > {$UPS.INPUT_VOLT.MAX.WARN} or {21748} < {$UPS.INPUT_VOLT.MIN.WARN})','Unacceptable input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18279','{21749} > {$UPS.OUTPUT.MAX.WARN}','Output load is high (over {$UPS.OUTPUT.MAX.WARN}% for {$TIME.PERIOD})','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','Current load: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18280','{21750}=5','UPS is Timed Sleeping','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18281','{21751}=9','UPS is Switched Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18282','{21752}=6','UPS is Software Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18283','{21753}=11','UPS is Sleeping Until Power Return','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18284','{21754}=8','UPS is Rebooting','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18285','{21755}=12','UPS is On Smart Trim','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18286','{21756}=4','UPS is on Smart Boost','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18287','{21757}=3','UPS is on battery','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18288','{21758}=7','UPS is Off','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18289','{21759}=16','UPS is Emergency Static Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18290','{21760}=10','UPS is Hardware Failure Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18292','{21763}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18293','{21764}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18294','{21765}=1','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery lifetime is not okay','','0','2','The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18295','{21766}=0','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status is not okay','','0','2','The battery cartridge status:
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18296','{21767} > {$BATTERY.TEMP.MAX.WARN}','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18297','{21768}=4','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18298','{21769}=2','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18299','{21770}=3','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18300','{21771}=4','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18301','{21772}=2','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18302','{21773}=3','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18303','{21774} > {$UPS.INPUT_VOLT.MAX.WARN} or {21775} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18304','{21776} > {$UPS.INPUT_VOLT.MAX.WARN} or {21777} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} output voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18305','{21778} < {$BATTERY.CAPACITY.MIN.WARN}','Battery has low capacity (below {$BATTERY.CAPACITY.MIN.WARN}%)','','0','4','',NULL,'0','0','0','','0','','0','Current capacity: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18306','{21779}=2','Battery needs replacement','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18307','{21780}=4','Battery has an internal error condition','','0','3','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18308','{21781}=3','Battery is Low','','0','3','The UPS will be unable to sustain the current load, and its services will be lost if power is not restored.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18309','{21782} > {$BATTERY.TEMP.MAX.WARN}','Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18313','{21786} > 0 and ({21786} > {$UPS.INPUT_FREQ.MAX.WARN} or {21787} < {$UPS.INPUT_FREQ.MIN.WARN})','Unacceptable input frequency (out of range {$UPS.INPUT_FREQ.MIN.WARN}-{$UPS.INPUT_FREQ.MAX.WARN}Hz for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current frequency: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18314','{21788} > 0 and ({21788} > {$UPS.INPUT_VOLT.MAX.WARN} or {21789} < {$UPS.INPUT_VOLT.MIN.WARN})','Unacceptable input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18315','{21790} > {$UPS.OUTPUT.MAX.WARN}','Output load is high (over {$UPS.OUTPUT.MAX.WARN}% for {$TIME.PERIOD})','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','Current load: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18316','{21791}=5','UPS is Timed Sleeping','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18317','{21792}=9','UPS is Switched Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18318','{21793}=6','UPS is Software Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18319','{21794}=11','UPS is Sleeping Until Power Return','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18320','{21795}=8','UPS is Rebooting','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18321','{21796}=12','UPS is On Smart Trim','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18322','{21797}=4','UPS is on Smart Boost','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18323','{21798}=3','UPS is on battery','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18324','{21799}=7','UPS is Off','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18325','{21800}=16','UPS is Emergency Static Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18326','{21801}=10','UPS is Hardware Failure Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18328','{21804}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18329','{21805}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18330','{21806}=1','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery lifetime is not okay','','0','2','The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18331','{21807}=0','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status is not okay','','0','2','The battery cartridge status:
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18332','{21808} > {$BATTERY.TEMP.MAX.WARN}','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18333','{21809}=4','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18334','{21810}=2','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18335','{21811}=3','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18336','{21812}=4','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18337','{21813}=2','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18338','{21814}=3','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18339','{21815} > {$UPS.INPUT_VOLT.MAX.WARN} or {21816} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18340','{21817} > {$UPS.INPUT_VOLT.MAX.WARN} or {21818} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} output voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18341','{21819} < {$BATTERY.CAPACITY.MIN.WARN}','Battery has low capacity (below {$BATTERY.CAPACITY.MIN.WARN}%)','','0','4','',NULL,'0','0','0','','0','','0','Current capacity: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18342','{21820}=2','Battery needs replacement','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18343','{21821}=4','Battery has an internal error condition','','0','3','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18344','{21822}=3','Battery is Low','','0','3','The UPS will be unable to sustain the current load, and its services will be lost if power is not restored.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18345','{21823} > {$BATTERY.TEMP.MAX.WARN}','Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18349','{21827} > 0 and ({21827} > {$UPS.INPUT_FREQ.MAX.WARN} or {21828} < {$UPS.INPUT_FREQ.MIN.WARN})','Unacceptable input frequency (out of range {$UPS.INPUT_FREQ.MIN.WARN}-{$UPS.INPUT_FREQ.MAX.WARN}Hz for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current frequency: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18350','{21829} > 0 and ({21829} > {$UPS.INPUT_VOLT.MAX.WARN} or {21830} < {$UPS.INPUT_VOLT.MIN.WARN})','Unacceptable input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18351','{21831} > {$UPS.OUTPUT.MAX.WARN}','Output load is high (over {$UPS.OUTPUT.MAX.WARN}% for {$TIME.PERIOD})','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','Current load: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18352','{21832}=5','UPS is Timed Sleeping','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18353','{21833}=9','UPS is Switched Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18354','{21834}=6','UPS is Software Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18355','{21835}=11','UPS is Sleeping Until Power Return','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18356','{21836}=8','UPS is Rebooting','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18357','{21837}=12','UPS is On Smart Trim','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18358','{21838}=4','UPS is on Smart Boost','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18359','{21839}=3','UPS is on battery','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18360','{21840}=7','UPS is Off','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18361','{21841}=16','UPS is Emergency Static Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18362','{21842}=10','UPS is Hardware Failure Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18364','{21845}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18365','{21846}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18366','{21847}=1','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery lifetime is not okay','','0','2','The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18367','{21848}=0','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status is not okay','','0','2','The battery cartridge status:
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18368','{21849} > {$BATTERY.TEMP.MAX.WARN}','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18369','{21850}=4','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18370','{21851}=2','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18371','{21852}=3','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18372','{21853}=4','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18373','{21854}=2','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18374','{21855}=3','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18375','{21856} > {$UPS.INPUT_VOLT.MAX.WARN} or {21857} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18376','{21858} > {$UPS.INPUT_VOLT.MAX.WARN} or {21859} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} output voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18377','{21860} < {$BATTERY.CAPACITY.MIN.WARN}','Battery has low capacity (below {$BATTERY.CAPACITY.MIN.WARN}%)','','0','4','',NULL,'0','0','0','','0','','0','Current capacity: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18378','{21861}=2','Battery needs replacement','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18379','{21862}=4','Battery has an internal error condition','','0','3','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18380','{21863}=3','Battery is Low','','0','3','The UPS will be unable to sustain the current load, and its services will be lost if power is not restored.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18381','{21864} > {$BATTERY.TEMP.MAX.WARN}','Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18385','{21868} > 0 and ({21868} > {$UPS.INPUT_FREQ.MAX.WARN} or {21869} < {$UPS.INPUT_FREQ.MIN.WARN})','Unacceptable input frequency (out of range {$UPS.INPUT_FREQ.MIN.WARN}-{$UPS.INPUT_FREQ.MAX.WARN}Hz for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current frequency: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18386','{21870} > 0 and ({21870} > {$UPS.INPUT_VOLT.MAX.WARN} or {21871} < {$UPS.INPUT_VOLT.MIN.WARN})','Unacceptable input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18387','{21872} > {$UPS.OUTPUT.MAX.WARN}','Output load is high (over {$UPS.OUTPUT.MAX.WARN}% for {$TIME.PERIOD})','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','Current load: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18388','{21873}=5','UPS is Timed Sleeping','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18389','{21874}=9','UPS is Switched Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18390','{21875}=6','UPS is Software Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18391','{21876}=11','UPS is Sleeping Until Power Return','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18392','{21877}=8','UPS is Rebooting','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18393','{21878}=12','UPS is On Smart Trim','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18394','{21879}=4','UPS is on Smart Boost','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18395','{21880}=3','UPS is on battery','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18396','{21881}=7','UPS is Off','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18397','{21882}=16','UPS is Emergency Static Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18398','{21883}=10','UPS is Hardware Failure Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18400','{21886}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18401','{21887}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18402','{21888}=1','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery lifetime is not okay','','0','2','The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18403','{21889}=0','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status is not okay','','0','2','The battery cartridge status:
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18404','{21890} > {$BATTERY.TEMP.MAX.WARN}','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18405','{21891}=4','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18406','{21892}=2','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18407','{21893}=3','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18408','{21894}=4','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18409','{21895}=2','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18410','{21896}=3','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18411','{21897} > {$UPS.INPUT_VOLT.MAX.WARN} or {21898} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18412','{21899} > {$UPS.INPUT_VOLT.MAX.WARN} or {21900} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} output voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18413','{21901} < {$BATTERY.CAPACITY.MIN.WARN}','Battery has low capacity (below {$BATTERY.CAPACITY.MIN.WARN}%)','','0','4','',NULL,'0','0','0','','0','','0','Current capacity: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18414','{21902}=2','Battery needs replacement','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18415','{21903}=4','Battery has an internal error condition','','0','3','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18416','{21904}=3','Battery is Low','','0','3','The UPS will be unable to sustain the current load, and its services will be lost if power is not restored.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18417','{21905} > {$BATTERY.TEMP.MAX.WARN}','Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18421','{21909} > 0 and ({21909} > {$UPS.INPUT_FREQ.MAX.WARN} or {21910} < {$UPS.INPUT_FREQ.MIN.WARN})','Unacceptable input frequency (out of range {$UPS.INPUT_FREQ.MIN.WARN}-{$UPS.INPUT_FREQ.MAX.WARN}Hz for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current frequency: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18422','{21911} > 0 and ({21911} > {$UPS.INPUT_VOLT.MAX.WARN} or {21912} < {$UPS.INPUT_VOLT.MIN.WARN})','Unacceptable input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18423','{21913} > {$UPS.OUTPUT.MAX.WARN}','Output load is high (over {$UPS.OUTPUT.MAX.WARN}% for {$TIME.PERIOD})','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','Current load: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18424','{21914}=5','UPS is Timed Sleeping','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18425','{21915}=9','UPS is Switched Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18426','{21916}=6','UPS is Software Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18427','{21917}=11','UPS is Sleeping Until Power Return','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18428','{21918}=8','UPS is Rebooting','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18429','{21919}=12','UPS is On Smart Trim','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18430','{21920}=4','UPS is on Smart Boost','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18431','{21921}=3','UPS is on battery','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18432','{21922}=7','UPS is Off','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18433','{21923}=16','UPS is Emergency Static Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18434','{21924}=10','UPS is Hardware Failure Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18436','{21927}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18437','{21928}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18438','{21929}=1','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery lifetime is not okay','','0','2','The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18439','{21930}=0','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status is not okay','','0','2','The battery cartridge status:
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18440','{21931} > {$BATTERY.TEMP.MAX.WARN}','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18441','{21932}=4','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18442','{21933}=2','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18443','{21934}=3','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18444','{21935}=4','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18445','{21936}=2','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18446','{21937}=3','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18447','{21938} > {$UPS.INPUT_VOLT.MAX.WARN} or {21939} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18448','{21940} > {$UPS.INPUT_VOLT.MAX.WARN} or {21941} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} output voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18449','{21942} < {$BATTERY.CAPACITY.MIN.WARN}','Battery has low capacity (below {$BATTERY.CAPACITY.MIN.WARN}%)','','0','4','',NULL,'0','0','0','','0','','0','Current capacity: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18450','{21943}=2','Battery needs replacement','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18451','{21944}=4','Battery has an internal error condition','','0','3','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18452','{21945}=3','Battery is Low','','0','3','The UPS will be unable to sustain the current load, and its services will be lost if power is not restored.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18453','{21946} > {$BATTERY.TEMP.MAX.WARN}','Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18457','{21950} > 0 and ({21950} > {$UPS.INPUT_FREQ.MAX.WARN} or {21951} < {$UPS.INPUT_FREQ.MIN.WARN})','Unacceptable input frequency (out of range {$UPS.INPUT_FREQ.MIN.WARN}-{$UPS.INPUT_FREQ.MAX.WARN}Hz for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current frequency: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18458','{21952} > 0 and ({21952} > {$UPS.INPUT_VOLT.MAX.WARN} or {21953} < {$UPS.INPUT_VOLT.MIN.WARN})','Unacceptable input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18459','{21954} > {$UPS.OUTPUT.MAX.WARN}','Output load is high (over {$UPS.OUTPUT.MAX.WARN}% for {$TIME.PERIOD})','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','Current load: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18460','{21955}=5','UPS is Timed Sleeping','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18461','{21956}=9','UPS is Switched Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18462','{21957}=6','UPS is Software Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18463','{21958}=11','UPS is Sleeping Until Power Return','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18464','{21959}=8','UPS is Rebooting','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18465','{21960}=12','UPS is On Smart Trim','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18466','{21961}=4','UPS is on Smart Boost','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18467','{21962}=3','UPS is on battery','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18468','{21963}=7','UPS is Off','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18469','{21964}=16','UPS is Emergency Static Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18470','{21965}=10','UPS is Hardware Failure Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18472','{21968}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18473','{21969}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18474','{21970}=1','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery lifetime is not okay','','0','2','The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18475','{21971}=0','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status is not okay','','0','2','The battery cartridge status:
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18476','{21972} > {$BATTERY.TEMP.MAX.WARN}','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18477','{21973}=4','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18478','{21974}=2','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18479','{21975}=3','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18480','{21976}=4','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18481','{21977}=2','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18482','{21978}=3','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18483','{21979} > {$UPS.INPUT_VOLT.MAX.WARN} or {21980} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18484','{21981} > {$UPS.INPUT_VOLT.MAX.WARN} or {21982} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} output voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18485','{21983} < {$BATTERY.CAPACITY.MIN.WARN}','Battery has low capacity (below {$BATTERY.CAPACITY.MIN.WARN}%)','','0','4','',NULL,'0','0','0','','0','','0','Current capacity: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18486','{21984}=0','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status is not okay','','0','2','The battery cartridge status:
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18487','{21985} > {$UPS.INPUT_VOLT.MAX.WARN} or {21986} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} output voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18488','{21987} < {$BATTERY.CAPACITY.MIN.WARN}','Battery has low capacity (below {$BATTERY.CAPACITY.MIN.WARN}%)','','0','4','',NULL,'0','0','0','','0','','0','Current capacity: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18489','{21988}=2','Battery needs replacement','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18490','{21989}=4','Battery has an internal error condition','','0','3','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18491','{21990}=3','Battery is Low','','0','3','The UPS will be unable to sustain the current load, and its services will be lost if power is not restored.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18492','{21991} > {$BATTERY.TEMP.MAX.WARN}','Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18496','{21995} > 0 and ({21995} > {$UPS.INPUT_FREQ.MAX.WARN} or {21996} < {$UPS.INPUT_FREQ.MIN.WARN})','Unacceptable input frequency (out of range {$UPS.INPUT_FREQ.MIN.WARN}-{$UPS.INPUT_FREQ.MAX.WARN}Hz for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current frequency: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18497','{21997} > 0 and ({21997} > {$UPS.INPUT_VOLT.MAX.WARN} or {21998} < {$UPS.INPUT_VOLT.MIN.WARN})','Unacceptable input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18498','{21999} > {$UPS.OUTPUT.MAX.WARN}','Output load is high (over {$UPS.OUTPUT.MAX.WARN}% for {$TIME.PERIOD})','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','Current load: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18499','{22000}=5','UPS is Timed Sleeping','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18500','{22001}=9','UPS is Switched Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18501','{22002}=6','UPS is Software Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18502','{22003}=11','UPS is Sleeping Until Power Return','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18503','{22004}=8','UPS is Rebooting','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18504','{22005}=12','UPS is On Smart Trim','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18505','{22006}=4','UPS is on Smart Boost','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18506','{22007}=3','UPS is on battery','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18507','{22008}=7','UPS is Off','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18508','{22009}=16','UPS is Emergency Static Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18509','{22010}=10','UPS is Hardware Failure Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18511','{22013}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18512','{22014}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18513','{22015}=1','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery lifetime is not okay','','0','2','The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18514','{22016}=0','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status is not okay','','0','2','The battery cartridge status:
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18515','{22017} > {$BATTERY.TEMP.MAX.WARN}','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18516','{22018}=4','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18517','{22019}=2','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18518','{22020}=3','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18519','{22021}=4','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18520','{22022}=2','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18521','{22023}=3','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18522','{22024} > {$UPS.INPUT_VOLT.MAX.WARN} or {22025} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18523','{22026} > {$UPS.INPUT_VOLT.MAX.WARN} or {22027} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} output voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18524','{22028} < {$BATTERY.CAPACITY.MIN.WARN}','Battery has low capacity (below {$BATTERY.CAPACITY.MIN.WARN}%)','','0','4','',NULL,'0','0','0','','0','','0','Current capacity: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18525','{22029}=2','Battery needs replacement','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18526','{22030}=4','Battery has an internal error condition','','0','3','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18527','{22031}=3','Battery is Low','','0','3','The UPS will be unable to sustain the current load, and its services will be lost if power is not restored.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18528','{22032} > {$BATTERY.TEMP.MAX.WARN}','Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18532','{22036} > 0 and ({22036} > {$UPS.INPUT_FREQ.MAX.WARN} or {22037} < {$UPS.INPUT_FREQ.MIN.WARN})','Unacceptable input frequency (out of range {$UPS.INPUT_FREQ.MIN.WARN}-{$UPS.INPUT_FREQ.MAX.WARN}Hz for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current frequency: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18533','{22038} > 0 and ({22038} > {$UPS.INPUT_VOLT.MAX.WARN} or {22039} < {$UPS.INPUT_VOLT.MIN.WARN})','Unacceptable input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18534','{22040} > {$UPS.OUTPUT.MAX.WARN}','Output load is high (over {$UPS.OUTPUT.MAX.WARN}% for {$TIME.PERIOD})','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','Current load: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18535','{22041}=5','UPS is Timed Sleeping','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18536','{22042}=9','UPS is Switched Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18537','{22043}=6','UPS is Software Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18538','{22044}=11','UPS is Sleeping Until Power Return','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18539','{22045}=8','UPS is Rebooting','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18540','{22046}=12','UPS is On Smart Trim','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18541','{22047}=4','UPS is on Smart Boost','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18542','{22048}=3','UPS is on battery','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18543','{22049}=7','UPS is Off','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18544','{22050}=16','UPS is Emergency Static Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18545','{22051}=10','UPS is Hardware Failure Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18547','{22054}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18548','{22055}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18549','{22056}=1','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery lifetime is not okay','','0','2','The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18550','{22057}=0','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status is not okay','','0','2','The battery cartridge status:
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18551','{22058} > {$BATTERY.TEMP.MAX.WARN}','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18552','{22059}=4','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18553','{22060}=2','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18554','{22061}=3','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18555','{22062}=4','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18556','{22063}=2','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18557','{22064}=3','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18558','{22065} > {$UPS.INPUT_VOLT.MAX.WARN} or {22066} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18559','{22067} > {$UPS.INPUT_VOLT.MAX.WARN} or {22068} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} output voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18560','{22069} < {$BATTERY.CAPACITY.MIN.WARN}','Battery has low capacity (below {$BATTERY.CAPACITY.MIN.WARN}%)','','0','4','',NULL,'0','0','0','','0','','0','Current capacity: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18561','{22070}=2','Battery needs replacement','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18562','{22071}=4','Battery has an internal error condition','','0','3','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18563','{22072}=3','Battery is Low','','0','3','The UPS will be unable to sustain the current load, and its services will be lost if power is not restored.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18564','{22073} > {$BATTERY.TEMP.MAX.WARN}','Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18568','{22077} > 0 and ({22077} > {$UPS.INPUT_FREQ.MAX.WARN} or {22078} < {$UPS.INPUT_FREQ.MIN.WARN})','Unacceptable input frequency (out of range {$UPS.INPUT_FREQ.MIN.WARN}-{$UPS.INPUT_FREQ.MAX.WARN}Hz for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current frequency: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18569','{22079} > 0 and ({22079} > {$UPS.INPUT_VOLT.MAX.WARN} or {22080} < {$UPS.INPUT_VOLT.MIN.WARN})','Unacceptable input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','0','0','','0','','0','Current voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18570','{22081} > {$UPS.OUTPUT.MAX.WARN}','Output load is high (over {$UPS.OUTPUT.MAX.WARN}% for {$TIME.PERIOD})','','0','4','A battery installed has an internal error condition.',NULL,'0','0','0','','0','','0','Current load: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18571','{22082}=5','UPS is Timed Sleeping','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18572','{22083}=9','UPS is Switched Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18573','{22084}=6','UPS is Software Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18574','{22085}=11','UPS is Sleeping Until Power Return','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18575','{22086}=8','UPS is Rebooting','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18576','{22087}=12','UPS is On Smart Trim','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18577','{22088}=4','UPS is on Smart Boost','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18578','{22089}=3','UPS is on battery','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18579','{22090}=7','UPS is Off','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18580','{22091}=16','UPS is Emergency Static Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18581','{22092}=10','UPS is Hardware Failure Bypass','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18583','{22095}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18584','{22096}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18585','{22097}=1','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery lifetime is not okay','','0','2','The battery cartridge health.
  bit 0 Battery lifetime okay
  bit 1 Battery lifetime near end, order replacement cartridge
  bit 2 Battery lifetime exceeded, replace battery
  bit 3 Battery lifetime near end acknowledged, order replacement cartridge
  bit 4 Battery lifetime exceeded acknowledged, replace battery
  bit 5 Battery measured lifetime near end, order replacement cartridge
  bit 6 Battery measured lifetime near end acknowledged, order replacement cartridge',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18586','{22098}=0','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery status is not okay','','0','2','The battery cartridge status:
bit 0 Disconnected
bit 1 Overvoltage
bit 2 NeedsReplacement
bit 3 OvertemperatureCritical
bit 4 Charger
bit 5 TemperatureSensor
bit 6 BusSoftStart
bit 7 OvertemperatureWarning
bit 8 GeneralError
bit 9 Communication
bit 10 DisconnectedFrame
bit 11 FirmwareMismatch',NULL,'0','2','0','','0','','0','Current bit set: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18587','{22099} > {$BATTERY.TEMP.MAX.WARN}','{#BATTERY_PACK}.{#CARTRIDGE_INDEX}: Battery has high temperature (over {$BATTERY.TEMP.MAX.WARN}℃ for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current temperature: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18588','{22100}=4','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18589','{22101}=2','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18590','{22102}=3','{#EXTERNAL_SENSOR1_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18591','{22103}=4','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Not Applicable','','0','1','The external sensor does not work or is not connected.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18592','{22104}=2','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Warning','','0','3','The external sensor has returned a value greater than the warning threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18593','{22105}=3','{#EXTERNAL_SENSOR2_NAME}: Sensor has status Critical','','0','4','The external sensor has returned a value greater than the critical threshold.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18594','{22106} > {$UPS.INPUT_VOLT.MAX.WARN} or {22107} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} input voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18595','{22108} > {$UPS.INPUT_VOLT.MAX.WARN} or {22109} < {$UPS.INPUT_VOLT.MIN.WARN}','{#PHASEINDEX}: Unacceptable phase {#PHASEINDEX} output voltage (out of range {$UPS.INPUT_VOLT.MIN.WARN}-{$UPS.INPUT_VOLT.MAX.WARN}V for {$TIME.PERIOD})','','0','4','',NULL,'0','2','0','','0','','0','Current phase {#PHASEINDEX} voltage: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18596','{22110}=1 and {22111}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18597','{22112}=1 and {22113}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18598','{22114}=1 and {22115}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18599','{22116}=1 and {22117}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18600','{22118}=1 and {22119}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18601','{22120}=1 and {22121}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18602','{22122}=1 and {22123}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18603','{22124}=1 and {22125}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18604','{22126}=1 and {22127}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18605','{22128}=1 and {22129}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18606','{22130}=1 and {22131}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18607','{22132}<10m','WildFly: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18608','{22133}=1 and {22134}>0','WildFly: Version has changed (new version: {ITEM.VALUE})','','0','1','WildFly version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18609','{22135}=1 and {22136}>0','WildFly domain: Server {#SERVER}: Server group has changed (new group: {ITEM.VALUE})','','0','1','Server group has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18610','{22137}=1 and {22138}>0','WildFly domain: Server {#SERVER}: Server status has changed (new status: {ITEM.VALUE})','','0','2','Server status has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18611','{22139}<10m','WildFly: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18612','{22140}=1','WildFly: Failed to fetch info data (or no data for 15m)','','0','2','Zabbix has not received data for items for the last 15 minutes',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18613','{22141}=1 and {22142}>0','WildFly: Version has changed (new version: {ITEM.VALUE})','','0','1','WildFly version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18614','{22143}=0','WildFly: Server needs to restart for configuration change.','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18615','{22144}=0','WildFly: Server controller is not in RUNNING state','','0','2','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18616','{22145}=0','WildFly {#JMX_DATA_SOURCE}: JDBC monitoring statistic is not enabled','','0','1','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18617','{22146}/{22147}*100>{$WILDFLY.CONN.USAGE.WARN.MAX}','WildFly {#JMX_DATA_SOURCE}: Connection usage is too high (over {$WILDFLY.CONN.USAGE.WARN.MAX} in 5m)','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18618','{22148}=0','WildFly {#JMX_DATA_SOURCE}: There are no active connections for 5m','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18619','{22149}=0','WildFly {#JMX_DATA_SOURCE}: Pools monitoring statistic is not enabled','','0','1','Zabbix has not received data for items for the last 15 minutes',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18620','{22150}>0','WildFly {#JMX_DATA_SOURCE}: There are timeout  connections','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18621','{22151}>{$WILDFLY.CONN.WAIT.MAX.WARN}','WildFly {#JMX_DATA_SOURCE}: Too many waiting connections (over {$WILDFLY.CONN.WAIT.MAX.WARN} for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18622','{22152}>0','WildFly listener {#HTTP_LISTENER}: There are 500 responses by this listener.','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18623','{22153}=1 and {22154}>0','WildFly deployment [{#DEPLOYMENT}]: Deployment status has changed (new status: {ITEM.VALUE})','','0','2','Deployment status has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18624','{22155}>{$MSSQL.WORK_FILES.MAX}','MSSQL: Number of work files created per second is high (over {$MSSQL.WORK_FILES.MAX} for 5m)','','0','3','Too many work files created per second to store temporary results for hash joins and hash aggregates.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18625','{22156}>{$MSSQL.WORK_TABLES.MAX}','MSSQL: Number of work tables created per second is high (over {$MSSQL.WORK_TABLES.MAX} for 5m)','','0','3','Too many work tables created per second to store temporary results for query spool, lob variables, XML variables, and cursors.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18626','{22157}>{$MSSQL.BACKUP_DIFF.CRIT:"{#DBNAME}"}','MSSQL DB ''{#DBNAME}'': Diff backup older than {$MSSQL.BACKUP_DIFF.CRIT:"{#DBNAME}"}','','0','4','The differential backup has not been executed for a long time.',NULL,'0','2','0','','0','','1','Time since last backup: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18627','{22158}>{$MSSQL.BACKUP_DIFF.WARN:"{#DBNAME}"}','MSSQL DB ''{#DBNAME}'': Diff backup older than {$MSSQL.BACKUP_DIFF.WARN:"{#DBNAME}"}','','0','2','The differential backup has not been executed for a long time.',NULL,'0','2','0','','0','','1','Time since last backup: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18628','{22159}>{$MSSQL.BACKUP_FULL.CRIT:"{#DBNAME}"}','MSSQL DB ''{#DBNAME}'': Full backup older than {$MSSQL.BACKUP_FULL.CRIT:"{#DBNAME}"}','','0','4','The full backup has not been executed for a long time.',NULL,'0','2','0','','0','','1','Time since last backup: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18629','{22160}>{$MSSQL.BACKUP_FULL.WARN:"{#DBNAME}"}','MSSQL DB ''{#DBNAME}'': Full backup older than {$MSSQL.BACKUP_FULL.WARN:"{#DBNAME}"}','','0','2','The full backup has not been executed for a long time.',NULL,'0','2','0','','0','','1','Time since last backup: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18630','{22161}>{$MSSQL.BACKUP_LOG.CRIT:"{#DBNAME}"}','MSSQL DB ''{#DBNAME}'': Log backup older than {$MSSQL.BACKUP_LOG.CRIT:"{#DBNAME}"}','','0','4','The log backup has not been executed for a long time.',NULL,'0','2','0','','0','','1','Time since last backup: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18631','{22162}>{$MSSQL.BACKUP_LOG.WARN:"{#DBNAME}"}','MSSQL DB ''{#DBNAME}'': Log backup older than {$MSSQL.BACKUP_LOG.WARN:"{#DBNAME}"}','','0','2','The log backup has not been executed for a long time.',NULL,'0','2','0','','0','','1','Time since last backup: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18632','{22163}>{$MSSQL.BACKUP_DURATION.WARN:"{#JOBNAME}"}','MSSQL Job ''{#JOBNAME}'': Job duration is greater than {$MSSQL.BACKUP_DURATION.WARN:"{#JOBNAME}"}','','0','2','The job is taking too long.',NULL,'0','2','0','','0','','1','Job duration: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18633','{22164}=0','MSSQL Job ''{#JOBNAME}'': Failed to run','','0','2','The last run of the job has failed.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18634','{22165}<{$MYSQL.BUFF_UTIL.MIN.WARN}','MySQL: Buffer pool utilization is too low (less than {$MYSQL.BUFF_UTIL.MIN.WARN}% for 5m)','','0','2','The buffer pool utilization is less than {$MYSQL.BUFF_UTIL.MIN.WARN}% in the last 5 minutes. This means that there is a lot of unused RAM allocated for the buffer pool, which you can easily reallocate at the moment.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18635','{22166}<{$MYSQL.BUFF_UTIL.MIN.WARN}','MySQL: Buffer pool utilization is too low (less than {$MYSQL.BUFF_UTIL.MIN.WARN}% for 5m)','','0','2','The buffer pool utilization is less than {$MYSQL.BUFF_UTIL.MIN.WARN}% in the last 5 minutes. This means that there is a lot of unused RAM allocated for the buffer pool, which you can easily reallocate at the moment.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18636','{22167}<{$MYSQL.BUFF_UTIL.MIN.WARN}','MySQL: Buffer pool utilization is too low (less than {$MYSQL.BUFF_UTIL.MIN.WARN}% for 5m)','','0','2','The buffer pool utilization is less than {$MYSQL.BUFF_UTIL.MIN.WARN}% in the last 5 minutes. This means that there is a lot of unused RAM allocated for the buffer pool, which you can easily reallocate at the moment.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18637','{22168}>75','Zabbix server: Utilization of alerter processes over 75%','','0','3','',NULL,'0','0','1','{22168}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18638','{22169}>75','Zabbix server: Utilization of alert manager processes over 75%','','0','3','',NULL,'0','0','1','{22169}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18639','{22170}>75','Zabbix server: Utilization of alert syncer processes over 75%','','0','3','',NULL,'0','0','1','{22170}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18641','{22172}>75','Zabbix server: Utilization of configuration syncer processes over 75%','','0','3','',NULL,'0','0','1','{22172}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18642','{22173}>75','Zabbix server: Utilization of discoverer processes over 75%','','0','3','',NULL,'0','0','1','{22173}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18643','{22174}>75','Zabbix server: Utilization of escalator processes over 75%','','0','3','',NULL,'0','0','1','{22174}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18645','{22176}>75','Zabbix server: Utilization of history syncer processes over 75%','','0','3','',NULL,'0','0','1','{22176}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18646','{22177}>75','Zabbix server: Utilization of housekeeper processes over 75%','','0','3','',NULL,'0','0','1','{22177}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18647','{22178}>75','Zabbix server: Utilization of http poller processes over 75%','','0','3','',NULL,'0','0','1','{22178}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18648','{22179}>75','Zabbix server: Utilization of icmp pinger processes over 75%','','0','3','',NULL,'0','0','1','{22179}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18649','{22180}>75','Zabbix server: Utilization of ipmi manager processes over 75%','','0','3','',NULL,'0','0','1','{22180}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18650','{22181}>75','Zabbix server: Utilization of ipmi poller processes over 75%','','0','3','',NULL,'0','0','1','{22181}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18651','{22182}>75','Zabbix server: Utilization of java poller processes over 75%','','0','3','',NULL,'0','0','1','{22182}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18652','{22183}>75','Zabbix server: Utilization of lld manager processes over 75%','','0','3','',NULL,'0','0','1','{22183}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18653','{22184}>75','Zabbix server: Utilization of lld worker processes over 75%','','0','3','',NULL,'0','0','1','{22184}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18654','{22185}>75','Zabbix server: Utilization of poller processes over 75%','','0','3','',NULL,'0','0','1','{22185}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18655','{22186}>75','Zabbix server: Utilization of preprocessing manager processes over 75%','','0','3','',NULL,'0','0','1','{22186}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18656','{22187}>75','Zabbix server: Utilization of preprocessing worker processes over 75%','','0','3','',NULL,'0','0','1','{22187}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18657','{22188}>75','Zabbix server: Utilization of proxy poller processes over 75%','','0','3','',NULL,'0','0','1','{22188}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18660','{22191}>75','Zabbix server: Utilization of self-monitoring processes over 75%','','0','3','',NULL,'0','0','1','{22191}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18661','{22192}>75','Zabbix server: Utilization of snmp trapper processes over 75%','','0','3','',NULL,'0','0','1','{22192}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18662','{22193}>75','Zabbix server: Utilization of task manager processes over 75%','','0','3','',NULL,'0','0','1','{22193}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18663','{22194}>75','Zabbix server: Utilization of timer processes over 75%','','0','3','',NULL,'0','0','1','{22194}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18664','{22195}>75','Zabbix server: Utilization of trapper processes over 75%','','0','3','',NULL,'0','0','1','{22195}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18665','{22196}>75','Zabbix server: Utilization of unreachable poller processes over 75%','','0','3','',NULL,'0','0','1','{22196}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18666','{22197}>75','Zabbix server: Utilization of vmware collector processes over 75%','','0','3','',NULL,'0','0','1','{22197}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18667','{22198}>100','Zabbix server: More than 100 items having missing data for more than 10 minutes','','0','2','zabbix[stats,{$IP},{$PORT},queue,10m] item is collecting data about how many items are missing data for more than 10 minutes',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18668','{22199}>75','Zabbix server: More than 75% used in the configuration cache','','0','3','Consider increasing CacheSize in the zabbix_server.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18669','{22200}>95','Zabbix server: More than 95% used in the value cache','','0','3','Consider increasing ValueCacheSize in the zabbix_server.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18670','{22201}=1','Zabbix server: Zabbix value cache working in low memory mode','','0','4','Once the low memory mode has been switched on, the value cache will remain in this state for 24 hours, even if the problem that triggered this mode is resolved sooner.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18671','{22202}=1 and {22203}>0','Zabbix server: Version has changed (new version: {ITEM.VALUE})','','0','1','Zabbix server version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18672','{22204}>75','Zabbix server: More than 75% used in the vmware cache','','0','3','Consider increasing VMwareCacheSize in the zabbix_server.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18673','{22205}>75','Zabbix server: More than 75% used in the history cache','','0','3','Consider increasing HistoryCacheSize in the zabbix_server.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18674','{22206}>75','Zabbix server: More than 75% used in the history index cache','','0','3','Consider increasing HistoryIndexCacheSize in the zabbix_server.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18675','{22207}>75','Zabbix server: More than 75% used in the trends cache','','0','3','Consider increasing TrendCacheSize in the zabbix_server.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18715','{22248}>75','Remote Zabbix server: Utilization of alerter processes over 75%','','0','3','',NULL,'0','0','1','{22248}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18716','{22249}>75','Remote Zabbix server: Utilization of alert manager processes over 75%','','0','3','',NULL,'0','0','1','{22249}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18717','{22250}>75','Remote Zabbix server: Utilization of alert syncer processes over 75%','','0','3','',NULL,'0','0','1','{22250}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18719','{22252}>75','Remote Zabbix server: Utilization of configuration syncer processes over 75%','','0','3','',NULL,'0','0','1','{22252}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18720','{22253}>75','Remote Zabbix server: Utilization of discoverer processes over 75%','','0','3','',NULL,'0','0','1','{22253}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18721','{22254}>75','Remote Zabbix server: Utilization of escalator processes over 75%','','0','3','',NULL,'0','0','1','{22254}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18723','{22256}>75','Remote Zabbix server: Utilization of history syncer processes over 75%','','0','3','',NULL,'0','0','1','{22256}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18724','{22257}>75','Remote Zabbix server: Utilization of housekeeper processes over 75%','','0','3','',NULL,'0','0','1','{22257}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18725','{22258}>75','Remote Zabbix server: Utilization of http poller processes over 75%','','0','3','',NULL,'0','0','1','{22258}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18726','{22259}>75','Remote Zabbix server: Utilization of icmp pinger processes over 75%','','0','3','',NULL,'0','0','1','{22259}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18727','{22260}>75','Remote Zabbix server: Utilization of ipmi manager processes over 75%','','0','3','',NULL,'0','0','1','{22260}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18728','{22261}>75','Remote Zabbix server: Utilization of ipmi poller processes over 75%','','0','3','',NULL,'0','0','1','{22261}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18729','{22262}>75','Remote Zabbix server: Utilization of java poller processes over 75%','','0','3','',NULL,'0','0','1','{22262}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18730','{22263}>75','Remote Zabbix server: Utilization of lld manager processes over 75%','','0','3','',NULL,'0','0','1','{22263}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18731','{22264}>75','Remote Zabbix server: Utilization of lld worker processes over 75%','','0','3','',NULL,'0','0','1','{22264}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18732','{22265}>75','Remote Zabbix server: Utilization of poller processes over 75%','','0','3','',NULL,'0','0','1','{22265}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18733','{22266}>75','Remote Zabbix server: Utilization of preprocessing manager processes over 75%','','0','3','',NULL,'0','0','1','{22266}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18734','{22267}>75','Remote Zabbix server: Utilization of preprocessing worker processes over 75%','','0','3','',NULL,'0','0','1','{22267}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18735','{22268}>75','Remote Zabbix server: Utilization of proxy poller processes over 75%','','0','3','',NULL,'0','0','1','{22268}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18738','{22271}>75','Remote Zabbix server: Utilization of self-monitoring processes over 75%','','0','3','',NULL,'0','0','1','{22271}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18739','{22272}>75','Remote Zabbix server: Utilization of snmp trapper processes over 75%','','0','3','',NULL,'0','0','1','{22272}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18740','{22273}>75','Remote Zabbix server: Utilization of task manager processes over 75%','','0','3','',NULL,'0','0','1','{22273}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18741','{22274}>75','Remote Zabbix server: Utilization of timer processes over 75%','','0','3','',NULL,'0','0','1','{22274}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18742','{22275}>75','Remote Zabbix server: Utilization of trapper processes over 75%','','0','3','',NULL,'0','0','1','{22275}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18743','{22276}>75','Remote Zabbix server: Utilization of unreachable poller processes over 75%','','0','3','',NULL,'0','0','1','{22276}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18744','{22277}>75','Remote Zabbix server: Utilization of vmware collector processes over 75%','','0','3','',NULL,'0','0','1','{22277}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18745','{22278}>75','Remote Zabbix server: More than 75% used in the configuration cache','','0','3','Consider increasing CacheSize in the zabbix_server.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18746','{22279}>95','Remote Zabbix server: More than 95% used in the value cache','','0','3','Consider increasing ValueCacheSize in the zabbix_server.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18747','{22280}=1','Remote Zabbix server: Zabbix value cache working in low memory mode','','0','4','Once the low memory mode has been switched on, the value cache will remain in this state for 24 hours, even if the problem that triggered this mode is resolved sooner.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18748','{22281}=1 and {22282}>0','Remote Zabbix server: Version has changed (new version: {ITEM.VALUE})','','0','1','Remote Zabbix server version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18749','{22283}>75','Remote Zabbix server: More than 75% used in the vmware cache','','0','3','Consider increasing VMwareCacheSize in the zabbix_server.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18750','{22284}>75','Remote Zabbix server: More than 75% used in the history cache','','0','3','Consider increasing HistoryCacheSize in the zabbix_server.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18751','{22285}>75','Remote Zabbix server: More than 75% used in the history index cache','','0','3','Consider increasing HistoryIndexCacheSize in the zabbix_server.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18752','{22286}>75','Remote Zabbix server: More than 75% used in the trends cache','','0','3','Consider increasing TrendCacheSize in the zabbix_server.conf configuration file',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18753','{22287}>100','Remote Zabbix server: More than 100 items having missing data for more than 10 minutes','','0','2','zabbix[stats,{$IP},{$PORT},queue,10m] item is collecting data about how many items are missing data for more than 10 minutes',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18754','{22288}=1','MongoDB: Node in ReplicaSet changed the state (new state: {ITEM.VALUE})','','0','2','Node in ReplicaSet  changed the state. Ack to close.',NULL,'0','2','2','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18755','{22289}=0','ZYXEL AAM1212-51 / IES-612: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18756','{22290}=1 and {22291}>0','ZYXEL AAM1212-51 / IES-612: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18757','{22292}<>"AAM1212-51 / IES-612"','ZYXEL AAM1212-51 / IES-612: Template does not match hardware','','0','1','This template is for Zyxel AAM1212-51 / IES-612, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18758','{22293}=1 and {22294}>0','ZYXEL AAM1212-51 / IES-612: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18759','{22295}=0','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX} alarm','','0','3','The slot reported an error.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18760','{22296}<10m','ZYXEL AAM1212-51 / IES-612: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18761','{22297}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL AAM1212-51 / IES-612: High the DSL line attenuation in Port {#SNMPINDEX} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18762','{22298}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL AAM1212-51 / IES-612: Low the DSL line noise margins in Port {#SNMPINDEX} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18763','{22299}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL AAM1212-51 / IES-612: High the DSL line attenuation in Port {#SNMPINDEX} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18764','{22300}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL AAM1212-51 / IES-612: Low the DSL line noise margins in Port {#SNMPINDEX} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18765','{22301}=2 and {22302}=1','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22301}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18766','{22303}=2 and {22304}=1','ZYXEL AAM1212-51 / IES-612: Port {#ZYXEL.IF.NAME}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22303}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18767','{22305}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL AAM1212-51 / IES-612: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18768','{22306}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL AAM1212-51 / IES-612: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18769','{22307}=0','ZYXEL ES3500-8PD: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18770','{22308}>{$CPU.UTIL.CRIT}','ZYXEL ES3500-8PD: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18771','{22309}=1 and {22310}>0','ZYXEL ES3500-8PD: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18772','{22311}<>"ES3500-8PD"','ZYXEL ES3500-8PD: Template does not match hardware','','0','1','This template is for Zyxel ES3500-8PD, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18773','{22312}=1 and {22313}>0','ZYXEL ES3500-8PD: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18774','{22314}<10m','ZYXEL ES3500-8PD: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18775','{22315}>{$MEMORY.UTIL.MAX}','ZYXEL ES3500-8PD: High memory utilization in "{#ZYXEL.MEMORY.NAME}" pool (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18776','{22316}=2 and {22317}=1','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22316}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18777','{22318} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL ES3500-8PD: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18778','{22319} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL ES3500-8PD: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18779','{22320}=1 and {22321}>0','ZYXEL ES3500-8PD: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18780','{22322}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL ES3500-8PD: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18781','{22323}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL ES3500-8PD: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18782','{22324}=0','ZYXEL GS-4012F: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18783','{22325}>{$CPU.UTIL.CRIT}','ZYXEL GS-4012F: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18784','{22326}=1 and {22327}>0','ZYXEL GS-4012F: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18785','{22328}<>"GS-4012F"','ZYXEL GS-4012F: Template does not match hardware','','0','1','This template is for Zyxel GS-4012F, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18786','{22329}=1 and {22330}>0','ZYXEL GS-4012F: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18787','{22331}<10m','ZYXEL GS-4012F: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18788','{22332}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL GS-4012F: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18789','{22333}=2 and {22334}=1','ZYXEL GS-4012F: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22333}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18790','{22335}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL GS-4012F: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18791','{22336}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL GS-4012F: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18792','{22337}=0','ZYXEL IES-500x: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18793','not({22338}="IES-5000" or {22338}="IES-5005")','ZYXEL IES-500x: Template does not match hardware','','0','1','This template is for Zyxel IES-500x, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18794','{22339}<10m','ZYXEL IES-500x: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18795','{22340}>{#ZYXEL.BUFFERHIGHTHRESH}','ZYXEL IES-500x: High Packet buffer utilization in Slot {#ZYXEL.SLOT.ID} (>{#ZYXEL.BUFFERHIGHTHRESH}% for 5m)','','0','3','The system is running out of free buffer.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18796','{22341}>{#ZYXEL.CPU.THRESH.HIGH}','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} high CPU utilization (over {#ZYXEL.CPU.THRESH.HIGH}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18797','{22342}<{#ZYXEL.FANRPM.THRESH.LOW} or {22342}>{#ZYXEL.FANRPM.THRESH.HIGH}','ZYXEL IES-500x: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18798','{22343}>{#ZYXEL.MEMORYHIGHTHRESH}','ZYXEL IES-500x: High memory utilization in Slot {#ZYXEL.SLOT.ID} pool (>{#ZYXEL.MEMORYHIGHTHRESH}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18799','{22344}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL IES-500x: High the DSL line attenuation in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18800','{22345}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL IES-500x: Low the DSL line noise margins in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18801','{22346}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL IES-500x: High the DSL line attenuation in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18802','{22347}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL IES-500x: Low the DSL line noise margins in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18803','{22348}=2 and {22349}=1','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22348}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18804','{22350}=2 and {22351}=1','ZYXEL IES-500x: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22350}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18805','{22352}=0','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} alarm','','0','3','The slot reported an error.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18806','{22353}=1 and {22354}>0','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: DSL modem code has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18807','{22355}=1 and {22356}>0','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Driver has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18808','{22357}=1 and {22358}>0','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18809','{22359}=1 and {22360}>0','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Hardware version has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18810','{22361}=1 and {22362}>0','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} has been replaced (new serial number received)','','0','1','Slot {#ZYXEL.SLOT.ID} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18811','{22363}<10m','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18812','{22364}>{#ZYXEL.TEMP.THRESH.HIGH} or {22364}<{#ZYXEL.TEMP.THRESH.LOW}','ZYXEL IES-500x: Temperature Slot {#ZYXEL.SLOT.ID} Sensor: {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18813','{22365}<{#ZYXEL.VOLT.THRESH.LOW} or {22365}>{#ZYXEL.VOLT.THRESH.HIGH}','ZYXEL IES-500x: Voltage Slot {#ZYXEL.SLOT.ID} {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18814','{22366}=0','ZYXEL IES-6000: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18815','{22367}<>"IES-6000"','ZYXEL IES-6000: Template does not match hardware','','0','1','This template is for Zyxel IES-6000, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18816','{22368}<10m','ZYXEL IES-6000: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18817','{22369}>{#ZYXEL.BUFFERHIGHTHRESH}','ZYXEL IES-6000: High Packet buffer utilization in Slot {#ZYXEL.SLOT.ID} (>{#ZYXEL.BUFFERHIGHTHRESH}% for 5m)','','0','3','The system is running out of free buffer.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18818','{22370}>{#ZYXEL.CPU.THRESH.HIGH}','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} high CPU utilization (over {#ZYXEL.CPU.THRESH.HIGH}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18819','{22371}<{#ZYXEL.FANRPM.THRESH.LOW} or {22371}>{#ZYXEL.FANRPM.THRESH.HIGH}','ZYXEL IES-6000: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18820','{22372}>{#ZYXEL.MEMORYHIGHTHRESH}','ZYXEL IES-6000: High memory utilization in Slot {#ZYXEL.SLOT.ID} pool (>{#ZYXEL.MEMORYHIGHTHRESH}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18821','{22373}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL IES-6000: High the DSL line attenuation in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18822','{22374}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL IES-6000: Low the DSL line noise margins in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18823','{22375}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL IES-6000: High the DSL line attenuation in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18824','{22376}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL IES-6000: Low the DSL line noise margins in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18825','{22377}=2 and {22378}=1','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22377}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18826','{22379}=2 and {22380}=1','ZYXEL IES-6000: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22379}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18827','{22381}=0','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} alarm','','0','3','The slot reported an error.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18828','{22382}=1 and {22383}>0','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: DSL modem code has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18829','{22384}=1 and {22385}>0','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Driver has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18830','{22386}=1 and {22387}>0','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18831','{22388}=1 and {22389}>0','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Hardware version has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18832','{22390}=1 and {22391}>0','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} has been replaced (new serial number received)','','0','1','Slot {#ZYXEL.SLOT.ID} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18833','{22392}<10m','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18834','{22393}>{#ZYXEL.TEMP.THRESH.HIGH} or {22393}<{#ZYXEL.TEMP.THRESH.LOW}','ZYXEL IES-6000: Temperature Slot {#ZYXEL.SLOT.ID} Sensor: {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18835','{22394}<{#ZYXEL.VOLT.THRESH.LOW} or {22394}>{#ZYXEL.VOLT.THRESH.HIGH}','ZYXEL IES-6000: Voltage Slot {#ZYXEL.SLOT.ID} {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18836','{22395}=0','ZYXEL IES1248-51: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18837','{22396}=1 and {22397}>0','ZYXEL IES1248-51: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18838','{22398}<>"IES1248-51"','ZYXEL IES1248-51: Template does not match hardware','','0','1','This template is for Zyxel IES1248-51, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18839','{22399}=1 and {22400}>0','ZYXEL IES1248-51: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18840','{22401}=0','ZYXEL IES1248-51: Port {#SNMPINDEX} alarm','','0','3','The slot reported an error.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18841','{22402}<10m','ZYXEL IES1248-51: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18842','{22403}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL IES1248-51: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18843','{22404}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL IES1248-51: High the DSL line attenuation in Port {#SNMPINDEX} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18844','{22405}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL IES1248-51: Low the DSL line noise margins in Port {#SNMPINDEX} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18845','{22406}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL IES1248-51: High the DSL line attenuation in Port {#SNMPINDEX} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18846','{22407}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL IES1248-51: Low the DSL line noise margins in Port {#SNMPINDEX} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18847','{22408}=2 and {22409}=1','ZYXEL IES1248-51: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22408}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18848','{22410}=2 and {22411}=1','ZYXEL IES1248-51: Port {#ZYXEL.IF.NAME}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22410}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18849','{22412}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL IES1248-51: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18850','{22413}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL IES1248-51: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18851','{22414}=0','ZYXEL MES-3528: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18852','{22415}>{$CPU.UTIL.CRIT}','ZYXEL MES-3528: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18853','{22416}=1 and {22417}>0','ZYXEL MES-3528: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18854','{22418}<>"MES-3528"','ZYXEL MES-3528: Template does not match hardware','','0','1','This template is for Zyxel MES-3528, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18855','{22419}=1 and {22420}>0','ZYXEL MES-3528: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18856','{22421}<10m','ZYXEL MES-3528: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18857','{22422}=2 and {22423}=1','ZYXEL MES-3528: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22422}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18858','{22424} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MES-3528: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18859','{22425} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MES-3528: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18860','{22426}=1 and {22427}>0','ZYXEL MES-3528: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18861','{22428}=0','ZYXEL MES3500-10: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18862','{22429}>{$CPU.UTIL.CRIT}','ZYXEL MES3500-10: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18863','{22430}=1 and {22431}>0','ZYXEL MES3500-10: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18864','{22432}<>"MES3500-10"','ZYXEL MES3500-10: Template does not match hardware','','0','1','This template is for Zyxel MES3500-10, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18865','{22433}=1 and {22434}>0','ZYXEL MES3500-10: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18866','{22435}<10m','ZYXEL MES3500-10: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18867','{22436}>{$MEMORY.UTIL.MAX}','ZYXEL MES3500-10: High memory utilization in "{#ZYXEL.MEMORY.NAME}" pool (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18868','{22437}=2 and {22438}=1','ZYXEL MES3500-10: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22437}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18869','{22439} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MES3500-10: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18870','{22440} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MES3500-10: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18871','{22441}=1 and {22442}>0','ZYXEL MES3500-10: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18872','{22443}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL MES3500-10: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18873','{22444}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL MES3500-10: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18874','{22445}=0','ZYXEL MES3500-24: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18875','{22446}>{$CPU.UTIL.CRIT}','ZYXEL MES3500-24: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18876','{22447}=1 and {22448}>0','ZYXEL MES3500-24: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18877','{22449}<>"MES3500-24"','ZYXEL MES3500-24: Template does not match hardware','','0','1','This template is for Zyxel MES3500-24, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18878','{22450}=1 and {22451}>0','ZYXEL MES3500-24: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18879','{22452}<10m','ZYXEL MES3500-24: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18880','{22453}>{$MEMORY.UTIL.MAX}','ZYXEL MES3500-24: High memory utilization in "{#ZYXEL.MEMORY.NAME}" pool (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18881','{22454}=2 and {22455}=1','ZYXEL MES3500-24: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22454}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18882','{22456} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MES3500-24: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18883','{22457} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MES3500-24: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18884','{22458}=1 and {22459}>0','ZYXEL MES3500-24: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18885','{22460}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL MES3500-24: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18886','{22461}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL MES3500-24: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18887','{22462}=0','ZYXEL MGS-3712: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18888','{22463}>{$CPU.UTIL.CRIT}','ZYXEL MGS-3712: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18889','{22464}=1 and {22465}>0','ZYXEL MGS-3712: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18890','{22466}<>"MGS-3712"','ZYXEL MGS-3712: Template does not match hardware','','0','1','This template is for Zyxel MGS-3712, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18891','{22467}=1 and {22468}>0','ZYXEL MGS-3712: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18892','{22469}<10m','ZYXEL MGS-3712: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18893','{22470}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL MGS-3712: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18894','{22471}=2 and {22472}=1','ZYXEL MGS-3712: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22471}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18895','{22473} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MGS-3712: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18896','{22474} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MGS-3712: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18897','{22475}=1 and {22476}>0','ZYXEL MGS-3712: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18898','{22477}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL MGS-3712: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18899','{22478}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL MGS-3712: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18900','{22479}=0','ZYXEL MGS-3712F: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18901','{22480}>{$CPU.UTIL.CRIT}','ZYXEL MGS-3712F: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18902','{22481}=1 and {22482}>0','ZYXEL MGS-3712F: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18903','{22483}<>"MGS-3712F"','ZYXEL MGS-3712F: Template does not match hardware','','0','1','This template is for Zyxel MGS-3712F, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18904','{22484}=1 and {22485}>0','ZYXEL MGS-3712F: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18905','{22486}<10m','ZYXEL MGS-3712F: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18906','{22487}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL MGS-3712F: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18907','{22488}=2 and {22489}=1','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22488}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18908','{22490} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MGS-3712F: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18909','{22491} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MGS-3712F: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18910','{22492}=1 and {22493}>0','ZYXEL MGS-3712F: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18911','{22494}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL MGS-3712F: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18912','{22495}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL MGS-3712F: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18913','{22496}=0','ZYXEL MES3500-24S: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18914','{22497}>{$CPU.UTIL.CRIT}','ZYXEL MES3500-24S: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18915','{22498}=1 and {22499}>0','ZYXEL MES3500-24S: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18916','{22500}>{$MEMORY.UTIL.MAX}','ZYXEL MES3500-24S: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18917','{22501}<>"MES3500-24S"','ZYXEL MES3500-24S: Template does not match hardware','','0','1','This template is for Zyxel MES3500-24S series, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18918','{22502}=1 and {22503}>0','ZYXEL MES3500-24S: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18919','{22504}<10m','ZYXEL MES3500-24S: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18920','{22505}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL MES3500-24S: {#ZYXEL.FAN.DESCRIPTION} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18921','{22506}=2 and {22507}=1','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22506}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18922','{22508} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MES3500-24S: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18923','{22509} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MES3500-24S: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18924','{22510}=1 and {22511}>0','ZYXEL MES3500-24S: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18925','{22512}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL MES3500-24S: Temperature {#ZYXEL.TEMPDESCRIPTION} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18926','{22513}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL MES3500-24S: Voltage {#ZYXEL.DESCRIPTION} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18927','{22514}=0','ZYXEL MGS3520-28x: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18928','{22515}>{$CPU.UTIL.CRIT}','ZYXEL MGS3520-28x: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18929','{22516}=1 and {22517}>0','ZYXEL MGS3520-28x: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18930','{22518}>{$MEMORY.UTIL.MAX}','ZYXEL MGS3520-28x: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18931','not({22519}="MGS3520-28" or {22519}="MGS3520-28F")','ZYXEL MGS3520-28x: Template does not match hardware','','0','1','This template is for Zyxel MGS3520-28x series, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18932','{22520}=1 and {22521}>0','ZYXEL MGS3520-28x: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18933','{22522}<10m','ZYXEL MGS3520-28x: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18934','{22523}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL MGS3520-28x: {#ZYXEL.FAN.DESCRIPTION} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18935','{22524}=2 and {22525}=1','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22524}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18936','{22526} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MGS3520-28x: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18937','{22527} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MGS3520-28x: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18938','{22528}=1 and {22529}>0','ZYXEL MGS3520-28x: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18939','{22530}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL MGS3520-28x: Temperature {#ZYXEL.TEMPDESCRIPTION} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18940','{22531}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL MGS3520-28x: Voltage {#ZYXEL.DESCRIPTION} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18941','{22532}=0','ZYXEL XGS-4728F: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18942','{22533}>{$CPU.UTIL.CRIT}','ZYXEL XGS-4728F: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18943','{22534}=1 and {22535}>0','ZYXEL XGS-4728F: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18944','{22536}<>"XGS-4728F"','ZYXEL XGS-4728F: Template does not match hardware','','0','1','This template is for Zyxel XGS-4728F, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18945','{22537}=1 and {22538}>0','ZYXEL XGS-4728F: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18946','{22539}<10m','ZYXEL XGS-4728F: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18947','{22540}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL XGS-4728F: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18948','{22541}>{$MEMORY.UTIL.MAX}','ZYXEL XGS-4728F: High memory utilization in "{#ZYXEL.MEMORY.NAME}" pool (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18949','{22542}=2 and {22543}=1','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22542}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18950','{22544} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL XGS-4728F: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18951','{22545} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL XGS-4728F: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18952','{22546}=1 and {22547}>0','ZYXEL XGS-4728F: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18953','{22548}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL XGS-4728F: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18954','{22549}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL XGS-4728F: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18955','{22550} > {$NGINX.DROP_RATE.MAX.WARN}','Nginx: High connections drop rate (more than {$NGINX.DROP_RATE.MAX.WARN} for 5m)','','0','2','The dropping rate connections is greater than {$NGINX.DROP_RATE.MAX.WARN} for the last 5 minutes.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18956','{22551}>0','Nginx: Server response error (text: {ITEM.VALUE})','','0','4','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18957','{22552}<10m','Nginx: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18958','{22553}=1','Nginx: Failed to fetch info data (or no data for 30m)','','0','2','Zabbix has not received data for metrics for the last 30 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18959','{22554}=1 and {22555}>0','Nginx: Version has changed (new version: {ITEM.VALUE})','','0','1','Nginx version has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18960','{22556} > ({22557}*({$NGINX.HTTP.UPSTREAM.4XX.MAX.WARN}/100))','Nginx: Too many HTTP requests with code 4xx (over {$NGINX.HTTP.UPSTREAM.4XX.MAX.WARN}% for 5m)','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18961','{22558} > ({22559}*({$NGINX.HTTP.UPSTREAM.5XX.MAX.WARN}/100))','Nginx: Too many HTTP requests with code 5xx (over {$NGINX.HTTP.UPSTREAM.5XX.MAX.WARN}% for 5m)','','0','4','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18962','{22560}=0 and {22561}=0','Nginx: HTTP upstream server is not in UP or DOWN state.','','0','2','',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18963','{22562}=0 and {22563}=0','Nginx: Stream upstream server is not in UP or DOWN state.','','0','2','',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18964','{22564} > 18000000','PostgreSQL: Oldest xid is too big','','0','3','',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18965','{22565}=1 and {22566}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18966','{22567}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18967','{22568}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18968','{22569}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT}','{#DISKARRAY_CACHE_LOCATION}: Disk array cache controller battery is in critical state!','','0','3','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18969','{22570}<>{$DISK.ARRAY.CACHE.BATTERY.STATUS.OK}','{#DISKARRAY_CACHE_LOCATION}: Disk array cache controller battery is not in optimal state','','0','2','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18970','{22571}={$DISK.ARRAY.STATUS.CRIT:"inoperable"}','{#DISKARRAY_LOCATION}: Disk array controller is in critical state','','0','4','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18971','{22572}={$DISK.ARRAY.STATUS.WARN:"degraded"}','{#DISKARRAY_LOCATION}: Disk array controller is in warning state','','0','3','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18972','{22573}>{$DISK.ARRAY.STATUS.OK:"operable"}','{#DISKARRAY_LOCATION}: Disk array controller is not in optimal state','','0','2','Please check the device for faults',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18973','{22574}={$FAN.STATUS.CRIT:"inoperable"}','{#FAN_LOCATION}: Fan is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18974','{22575}={$FAN.STATUS.WARN:"degraded"}','{#FAN_LOCATION}: Fan is in warning state','','0','2','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18975','{22576}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {22577}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate on {#IFNAME} ( > {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when value below {$IF.ERRORS.WARN:"{#IFNAME}"} threshold.',NULL,'0','2','0','','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18976','{$IFCONTROL:"{#IFNAME}"}=1 and ({22578}=2 and {22579}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{22578}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18977','{22580}=1 and {22581}>0','{#DISK_LOCATION}: Disk has been replaced (new serial number received)','','0','1','Disk serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18978','{22582}={$DISK.STATUS.FAIL:"failed"}','{#DISK_LOCATION}: Physical disk failed','','0','4','Please check physical disk for warnings or errors',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18979','{22583}={$DISK.STATUS.CRIT:"bad"} or {22583}={$DISK.STATUS.CRIT:"predictiveFailure"}','{#DISK_LOCATION}: Physical disk error','','0','3','Please check physical disk for warnings or errors',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18980','{22584}={$PSU.STATUS.CRIT:"inoperable"}','{#PSU_LOCATION}: Power supply is in critical state','','0','3','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18981','{22585}={$PSU.STATUS.WARN:"degraded"}','{#PSU_LOCATION}: Power supply is in warning state','','0','2','Please check the power supply unit for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18982','{22586}>{$TEMP.MAX.WARN:"CPU"}','{#SENSOR_LOCATION}: Temperature is above warning threshold: >{$TEMP.MAX.WARN:"CPU"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{22587}<{$TEMP.MAX.WARN:"CPU"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18983','{22588}>{$TEMP.MAX.CRIT:"CPU"}','{#SENSOR_LOCATION}: Temperature is above critical threshold: >{$TEMP.MAX.CRIT:"CPU"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{22589}<{$TEMP.MAX.CRIT:"CPU"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18984','{22590}>{$TEMP.MAX.WARN:"Ambient"}','{#SENSOR_LOCATION}.IOH: Temperature is above warning threshold: >{$TEMP.MAX.WARN:"Ambient"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{22591}<{$TEMP.MAX.WARN:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18985','{22592}>{$TEMP.MAX.CRIT:"Ambient"}','{#SENSOR_LOCATION}.IOH: Temperature is above critical threshold: >{$TEMP.MAX.CRIT:"Ambient"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{22593}<{$TEMP.MAX.CRIT:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18986','{22594}>{$TEMP.MAX.WARN:"Ambient"}','{#SENSOR_LOCATION}.Ambient: Temperature is above warning threshold: >{$TEMP.MAX.WARN:"Ambient"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{22595}<{$TEMP.MAX.WARN:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18987','{22596}>{$TEMP.MAX.CRIT:"Ambient"}','{#SENSOR_LOCATION}.Ambient: Temperature is above critical threshold: >{$TEMP.MAX.CRIT:"Ambient"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{22597}<{$TEMP.MAX.CRIT:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18988','{22598}>{$TEMP.MAX.WARN:"Ambient"}','{#SENSOR_LOCATION}.Front: Temperature is above warning threshold: >{$TEMP.MAX.WARN:"Ambient"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{22599}<{$TEMP.MAX.WARN:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18989','{22600}>{$TEMP.MAX.CRIT:"Ambient"}','{#SENSOR_LOCATION}.Front: Temperature is above critical threshold: >{$TEMP.MAX.CRIT:"Ambient"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{22601}<{$TEMP.MAX.CRIT:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18990','{22602}>{$TEMP.MAX.WARN:"Ambient"}','{#SENSOR_LOCATION}.Rear: Temperature is above warning threshold: >{$TEMP.MAX.WARN:"Ambient"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{22603}<{$TEMP.MAX.WARN:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18991','{22604}>{$TEMP.MAX.CRIT:"Ambient"}','{#SENSOR_LOCATION}.Rear: Temperature is above critical threshold: >{$TEMP.MAX.CRIT:"Ambient"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available',NULL,'0','2','1','{22605}<{$TEMP.MAX.CRIT:"Ambient"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18992','{22606}=1 and {22607}>0','{#UNIT_LOCATION}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18993','{22608}={$HEALTH.STATUS.CRIT:"computeFailed"} or {22608}={$HEALTH.STATUS.CRIT:"configFailure"} or {22608}={$HEALTH.STATUS.CRIT:"unconfigFailure"} or {22608}={$HEALTH.STATUS.CRIT:"inoperable"}','{#UNIT_LOCATION}: System status is in critical state','','0','4','Please check the device for errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18994','{22609}={$HEALTH.STATUS.WARN:"testFailed"} or {22609}={$HEALTH.STATUS.WARN:"thermalProblem"} or {22609}={$HEALTH.STATUS.WARN:"powerProblem"} or {22609}={$HEALTH.STATUS.WARN:"voltageProblem"} or {22609}={$HEALTH.STATUS.WARN:"diagnosticsFailed"}','{#UNIT_LOCATION}: System status is in warning state','','0','2','Please check the device for warnings',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18995','{22610}<>{$VDISK.STATUS.OK:"equipped"}','{#VDISK_LOCATION}: Virtual disk is not in OK state','','0','2','Please check virtual disk for warnings or errors',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19019','{22638}=1 and {22639}>0','Dell R720: Firmware has changed','','0','1','Firmware version has changed. Ack to close.',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19020','{22640}=1 and {22641}>0','Dell R720: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19021','{22642}=1 and {22643}>0','Dell R720: System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19022','{22644}={$HEALTH.STATUS.DISASTER}','Dell R720: System is in unrecoverable state','','0','5','Please check the device for faults.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19023','{22645}={$HEALTH.STATUS.CRIT}','Dell R720: System status is in critical state','','0','4','Please check the device for errors.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19024','{22646}={$HEALTH.STATUS.WARN}','Dell R720: System status is in warning state','','0','2','Please check the device for warnings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19025','{22647}=1 and {22648}>0','Dell R720: Operating system description has changed','','0','1','Operating system description has changed. Possibly, the system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19026','{22649}<10m','Dell R720: {HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19027','{22650}=0','Dell R720: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19028','{22651}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT}','Dell R720: {#BATTERY_NAME} is in critical state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19029','{22652}={$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN}','Dell R720: {#BATTERY_NAME} is in warning state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19030','{22653}<>{$DISK.ARRAY.CACHE.BATTERY.STATUS.OK}','Dell R720: {#BATTERY_NAME} is not in optimal state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19031','{22654}={$DISK.ARRAY.STATUS.FAIL}','Dell R720: {#CNTLR_NAME} is in unrecoverable state','','0','5','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19032','{22655}={$DISK.ARRAY.STATUS.CRIT}','Dell R720: {#CNTLR_NAME} is in critical state','','0','4','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19033','{22656}={$DISK.ARRAY.STATUS.WARN}','Dell R720: {#CNTLR_NAME} is in warning state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19034','{22657}={$FAN.STATUS.CRIT:"criticalUpper"} or {22657}={$FAN.STATUS.CRIT:"nonRecoverableUpper"} or {22657}={$FAN.STATUS.CRIT:"criticalLower"} or {22657}={$FAN.STATUS.CRIT:"nonRecoverableLower"} or {22657}={$FAN.STATUS.CRIT:"failed"}','Dell R720: {#FAN_DESCR} is in critical state','','0','3','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19035','{22658}={$FAN.STATUS.WARN:"nonCriticalUpper"} or {22658}={$FAN.STATUS.WARN:"nonCriticalLower"}','Dell R720: {#FAN_DESCR} is in warning state','','0','2','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19036','{22659}=1 and {22660}>0','Dell R720: {#DISK_NAME} has been replaced (new serial number received)','','0','1','{#DISK_NAME} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19037','{22661}={$DISK.SMART.STATUS.FAIL:"replaceDrive"} or {22661}={$DISK.SMART.STATUS.FAIL:"replaceDriveSSDWearOut"}','Dell R720: {#DISK_NAME} S.M.A.R.T. failed','','0','4','Disk probably requires replacement.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19038','{22662}={$DISK.STATUS.FAIL:"critical"} or {22662}={$DISK.STATUS.FAIL:"nonRecoverable"}','Dell R720: {#DISK_NAME} failed','','0','4','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19039','{22663}={$DISK.STATUS.WARN:"nonCritical"}','Dell R720: {#DISK_NAME} is in warning state','','0','2','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19040','{22664}={$PSU.STATUS.CRIT:"critical"} or {22664}={$PSU.STATUS.CRIT:"nonRecoverable"}','Dell R720: Power supply {#PSU_DESCR} is in critical state','','0','3','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19041','{22665}={$PSU.STATUS.WARN:"nonCritical"}','Dell R720: Power supply {#PSU_DESCR} is in warning state','','0','2','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19042','{22666}={$SENSOR.TEMP.STATUS.CRIT:"criticalUpper"} or {22666}={$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableUpper"} or {22666}={$SENSOR.TEMP.STATUS.CRIT:"criticalLower"} or {22666}={$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableLower"}','Dell R720: Probe {#SENSOR_LOCALE} is in critical status','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19043','{22667}={$SENSOR.TEMP.STATUS.WARN:"nonCriticalUpper"} or {22667}={$SENSOR.TEMP.STATUS.WARN:"nonCriticalLower"}','Dell R720: Probe {#SENSOR_LOCALE} is in warning status','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19044','{22668}<>{$SENSOR.TEMP.STATUS.OK}','Dell R720: Probe {#SENSOR_LOCALE} is not in optimal status','','0','1','Please check the device for faults.',NULL,'0','2','0','','0','','1','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19045','{22669}={$VDISK.STATUS.CRIT:"failed"}','Dell R720: {#DISK_NAME} failed','','0','4','Please check the virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19046','{22670}={$VDISK.STATUS.WARN:"degraded"}','Dell R720: {#DISK_NAME} is in warning state','','0','3','Please check the virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19070','{22698}=1 and {22699}>0','Dell R740: Firmware has changed','','0','1','Firmware version has changed. Ack to close.',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19071','{22700}=1 and {22701}>0','Dell R740: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19072','{22702}=1 and {22703}>0','Dell R740: System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19073','{22704}={$HEALTH.STATUS.DISASTER}','Dell R740: System is in unrecoverable state','','0','5','Please check the device for faults.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19074','{22705}={$HEALTH.STATUS.CRIT}','Dell R740: System status is in critical state','','0','4','Please check the device for errors.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19075','{22706}={$HEALTH.STATUS.WARN}','Dell R740: System status is in warning state','','0','2','Please check the device for warnings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19076','{22707}=1 and {22708}>0','Dell R740: Operating system description has changed','','0','1','Operating system description has changed. Possibly, the system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19077','{22709}<10m','Dell R740: {HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19078','{22710}=0','Dell R740: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19079','{22711}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT}','Dell R740: {#BATTERY_NAME} is in critical state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19080','{22712}={$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN}','Dell R740: {#BATTERY_NAME} is in warning state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19081','{22713}<>{$DISK.ARRAY.CACHE.BATTERY.STATUS.OK}','Dell R740: {#BATTERY_NAME} is not in optimal state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19082','{22714}={$DISK.ARRAY.STATUS.FAIL}','Dell R740: {#CNTLR_NAME} is in unrecoverable state','','0','5','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19083','{22715}={$DISK.ARRAY.STATUS.CRIT}','Dell R740: {#CNTLR_NAME} is in critical state','','0','4','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19084','{22716}={$DISK.ARRAY.STATUS.WARN}','Dell R740: {#CNTLR_NAME} is in warning state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19085','{22717}={$FAN.STATUS.CRIT:"criticalUpper"} or {22717}={$FAN.STATUS.CRIT:"nonRecoverableUpper"} or {22717}={$FAN.STATUS.CRIT:"criticalLower"} or {22717}={$FAN.STATUS.CRIT:"nonRecoverableLower"} or {22717}={$FAN.STATUS.CRIT:"failed"}','Dell R740: {#FAN_DESCR} is in critical state','','0','3','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19086','{22718}={$FAN.STATUS.WARN:"nonCriticalUpper"} or {22718}={$FAN.STATUS.WARN:"nonCriticalLower"}','Dell R740: {#FAN_DESCR} is in warning state','','0','2','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19087','{22719}=1 and {22720}>0','Dell R740: {#DISK_NAME} has been replaced (new serial number received)','','0','1','{#DISK_NAME} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19088','{22721}={$DISK.SMART.STATUS.FAIL:"replaceDrive"} or {22721}={$DISK.SMART.STATUS.FAIL:"replaceDriveSSDWearOut"}','Dell R740: {#DISK_NAME} S.M.A.R.T. failed','','0','4','Disk probably requires replacement.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19089','{22722}={$DISK.STATUS.FAIL:"critical"} or {22722}={$DISK.STATUS.FAIL:"nonRecoverable"}','Dell R740: {#DISK_NAME} failed','','0','4','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19090','{22723}={$DISK.STATUS.WARN:"nonCritical"}','Dell R740: {#DISK_NAME} is in warning state','','0','2','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19091','{22724}={$PSU.STATUS.CRIT:"critical"} or {22724}={$PSU.STATUS.CRIT:"nonRecoverable"}','Dell R740: Power supply {#PSU_DESCR} is in critical state','','0','3','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19092','{22725}={$PSU.STATUS.WARN:"nonCritical"}','Dell R740: Power supply {#PSU_DESCR} is in warning state','','0','2','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19093','{22726}={$SENSOR.TEMP.STATUS.CRIT:"criticalUpper"} or {22726}={$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableUpper"} or {22726}={$SENSOR.TEMP.STATUS.CRIT:"criticalLower"} or {22726}={$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableLower"}','Dell R740: Probe {#SENSOR_LOCALE} is in critical status','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19094','{22727}={$SENSOR.TEMP.STATUS.WARN:"nonCriticalUpper"} or {22727}={$SENSOR.TEMP.STATUS.WARN:"nonCriticalLower"}','Dell R740: Probe {#SENSOR_LOCALE} is in warning status','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19095','{22728}<>{$SENSOR.TEMP.STATUS.OK}','Dell R740: Probe {#SENSOR_LOCALE} is not in optimal status','','0','1','Please check the device for faults.',NULL,'0','2','0','','0','','1','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19096','{22729}={$VDISK.STATUS.CRIT:"failed"}','Dell R740: {#DISK_NAME} failed','','0','4','Please check the virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19097','{22730}={$VDISK.STATUS.WARN:"degraded"}','Dell R740: {#DISK_NAME} is in warning state','','0','3','Please check the virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19121','{22758}=1 and {22759}>0','Dell R820: Firmware has changed','','0','1','Firmware version has changed. Ack to close.',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19122','{22760}=1 and {22761}>0','Dell R820: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19123','{22762}=1 and {22763}>0','Dell R820: System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19124','{22764}={$HEALTH.STATUS.DISASTER}','Dell R820: System is in unrecoverable state','','0','5','Please check the device for faults.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19125','{22765}={$HEALTH.STATUS.CRIT}','Dell R820: System status is in critical state','','0','4','Please check the device for errors.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19126','{22766}={$HEALTH.STATUS.WARN}','Dell R820: System status is in warning state','','0','2','Please check the device for warnings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19127','{22767}=1 and {22768}>0','Dell R820: Operating system description has changed','','0','1','Operating system description has changed. Possibly, the system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19128','{22769}<10m','Dell R820: {HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19129','{22770}=0','Dell R820: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19130','{22771}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT}','Dell R820: {#BATTERY_NAME} is in critical state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19131','{22772}={$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN}','Dell R820: {#BATTERY_NAME} is in warning state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19132','{22773}<>{$DISK.ARRAY.CACHE.BATTERY.STATUS.OK}','Dell R820: {#BATTERY_NAME} is not in optimal state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19133','{22774}={$DISK.ARRAY.STATUS.FAIL}','Dell R820: {#CNTLR_NAME} is in unrecoverable state','','0','5','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19134','{22775}={$DISK.ARRAY.STATUS.CRIT}','Dell R820: {#CNTLR_NAME} is in critical state','','0','4','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19135','{22776}={$DISK.ARRAY.STATUS.WARN}','Dell R820: {#CNTLR_NAME} is in warning state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19136','{22777}={$FAN.STATUS.CRIT:"criticalUpper"} or {22777}={$FAN.STATUS.CRIT:"nonRecoverableUpper"} or {22777}={$FAN.STATUS.CRIT:"criticalLower"} or {22777}={$FAN.STATUS.CRIT:"nonRecoverableLower"} or {22777}={$FAN.STATUS.CRIT:"failed"}','Dell R820: {#FAN_DESCR} is in critical state','','0','3','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19137','{22778}={$FAN.STATUS.WARN:"nonCriticalUpper"} or {22778}={$FAN.STATUS.WARN:"nonCriticalLower"}','Dell R820: {#FAN_DESCR} is in warning state','','0','2','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19138','{22779}=1 and {22780}>0','Dell R820: {#DISK_NAME} has been replaced (new serial number received)','','0','1','{#DISK_NAME} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19139','{22781}={$DISK.SMART.STATUS.FAIL:"replaceDrive"} or {22781}={$DISK.SMART.STATUS.FAIL:"replaceDriveSSDWearOut"}','Dell R820: {#DISK_NAME} S.M.A.R.T. failed','','0','4','Disk probably requires replacement.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19140','{22782}={$DISK.STATUS.FAIL:"critical"} or {22782}={$DISK.STATUS.FAIL:"nonRecoverable"}','Dell R820: {#DISK_NAME} failed','','0','4','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19141','{22783}={$DISK.STATUS.WARN:"nonCritical"}','Dell R820: {#DISK_NAME} is in warning state','','0','2','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19142','{22784}={$PSU.STATUS.CRIT:"critical"} or {22784}={$PSU.STATUS.CRIT:"nonRecoverable"}','Dell R820: Power supply {#PSU_DESCR} is in critical state','','0','3','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19143','{22785}={$PSU.STATUS.WARN:"nonCritical"}','Dell R820: Power supply {#PSU_DESCR} is in warning state','','0','2','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19144','{22786}={$SENSOR.TEMP.STATUS.CRIT:"criticalUpper"} or {22786}={$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableUpper"} or {22786}={$SENSOR.TEMP.STATUS.CRIT:"criticalLower"} or {22786}={$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableLower"}','Dell R820: Probe {#SENSOR_LOCALE} is in critical status','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19145','{22787}={$SENSOR.TEMP.STATUS.WARN:"nonCriticalUpper"} or {22787}={$SENSOR.TEMP.STATUS.WARN:"nonCriticalLower"}','Dell R820: Probe {#SENSOR_LOCALE} is in warning status','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19146','{22788}<>{$SENSOR.TEMP.STATUS.OK}','Dell R820: Probe {#SENSOR_LOCALE} is not in optimal status','','0','1','Please check the device for faults.',NULL,'0','2','0','','0','','1','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19147','{22789}={$VDISK.STATUS.CRIT:"failed"}','Dell R820: {#DISK_NAME} failed','','0','4','Please check the virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19148','{22790}={$VDISK.STATUS.WARN:"degraded"}','Dell R820: {#DISK_NAME} is in warning state','','0','3','Please check the virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19172','{22818}=1 and {22819}>0','Dell R840: Firmware has changed','','0','1','Firmware version has changed. Ack to close.',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19173','{22820}=1 and {22821}>0','Dell R840: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19174','{22822}=1 and {22823}>0','Dell R840: System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19175','{22824}={$HEALTH.STATUS.DISASTER}','Dell R840: System is in unrecoverable state','','0','5','Please check the device for faults.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19176','{22825}={$HEALTH.STATUS.CRIT}','Dell R840: System status is in critical state','','0','4','Please check the device for errors.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19177','{22826}={$HEALTH.STATUS.WARN}','Dell R840: System status is in warning state','','0','2','Please check the device for warnings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19178','{22827}=1 and {22828}>0','Dell R840: Operating system description has changed','','0','1','Operating system description has changed. Possibly, the system has been updated or replaced. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19179','{22829}<10m','Dell R840: {HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19180','{22830}=0','Dell R840: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19181','{22831}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT}','Dell R840: {#BATTERY_NAME} is in critical state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19182','{22832}={$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN}','Dell R840: {#BATTERY_NAME} is in warning state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19183','{22833}<>{$DISK.ARRAY.CACHE.BATTERY.STATUS.OK}','Dell R840: {#BATTERY_NAME} is not in optimal state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19184','{22834}={$DISK.ARRAY.STATUS.FAIL}','Dell R840: {#CNTLR_NAME} is in unrecoverable state','','0','5','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19185','{22835}={$DISK.ARRAY.STATUS.CRIT}','Dell R840: {#CNTLR_NAME} is in critical state','','0','4','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19186','{22836}={$DISK.ARRAY.STATUS.WARN}','Dell R840: {#CNTLR_NAME} is in warning state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19187','{22837}={$FAN.STATUS.CRIT:"criticalUpper"} or {22837}={$FAN.STATUS.CRIT:"nonRecoverableUpper"} or {22837}={$FAN.STATUS.CRIT:"criticalLower"} or {22837}={$FAN.STATUS.CRIT:"nonRecoverableLower"} or {22837}={$FAN.STATUS.CRIT:"failed"}','Dell R840: {#FAN_DESCR} is in critical state','','0','3','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19188','{22838}={$FAN.STATUS.WARN:"nonCriticalUpper"} or {22838}={$FAN.STATUS.WARN:"nonCriticalLower"}','Dell R840: {#FAN_DESCR} is in warning state','','0','2','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19189','{22839}=1 and {22840}>0','Dell R840: {#DISK_NAME} has been replaced (new serial number received)','','0','1','{#DISK_NAME} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19190','{22841}={$DISK.SMART.STATUS.FAIL:"replaceDrive"} or {22841}={$DISK.SMART.STATUS.FAIL:"replaceDriveSSDWearOut"}','Dell R840: {#DISK_NAME} S.M.A.R.T. failed','','0','4','Disk probably requires replacement.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19191','{22842}={$DISK.STATUS.FAIL:"critical"} or {22842}={$DISK.STATUS.FAIL:"nonRecoverable"}','Dell R840: {#DISK_NAME} failed','','0','4','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19192','{22843}={$DISK.STATUS.WARN:"nonCritical"}','Dell R840: {#DISK_NAME} is in warning state','','0','2','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19193','{22844}={$PSU.STATUS.CRIT:"critical"} or {22844}={$PSU.STATUS.CRIT:"nonRecoverable"}','Dell R840: Power supply {#PSU_DESCR} is in critical state','','0','3','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19194','{22845}={$PSU.STATUS.WARN:"nonCritical"}','Dell R840: Power supply {#PSU_DESCR} is in warning state','','0','2','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19195','{22846}={$SENSOR.TEMP.STATUS.CRIT:"criticalUpper"} or {22846}={$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableUpper"} or {22846}={$SENSOR.TEMP.STATUS.CRIT:"criticalLower"} or {22846}={$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableLower"}','Dell R840: Probe {#SENSOR_LOCALE} is in critical status','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19196','{22847}={$SENSOR.TEMP.STATUS.WARN:"nonCriticalUpper"} or {22847}={$SENSOR.TEMP.STATUS.WARN:"nonCriticalLower"}','Dell R840: Probe {#SENSOR_LOCALE} is in warning status','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19197','{22848}<>{$SENSOR.TEMP.STATUS.OK}','Dell R840: Probe {#SENSOR_LOCALE} is not in optimal status','','0','1','Please check the device for faults.',NULL,'0','2','0','','0','','1','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19198','{22849}={$VDISK.STATUS.CRIT:"failed"}','Dell R840: {#DISK_NAME} failed','','0','4','Please check the virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19199','{22850}={$VDISK.STATUS.WARN:"degraded"}','Dell R840: {#DISK_NAME} is in warning state','','0','3','Please check the virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19200','{22851}=1 and {22852}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19201','{22853}=1 and {22854}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19202','{22855}={$HEALTH.STATUS.CRIT}','System status is in critical state','','0','4','Please check the device for errors.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19203','{22856}={$HEALTH.STATUS.WARN}','System status is in warning state','','0','2','Please check the device for warnings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19204','{22857}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19205','{22858}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19206','{22859}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"failed"} or {22859}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"capacitorFailed"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery is in critical state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19207','{22860}={$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN:"degraded"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery is in warning state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19208','{22861}={$DISK.ARRAY.CACHE.STATUS.CRIT:"cacheModCriticalFailure"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is in critical state!','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19209','{22862}={$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModDegradedFailsafeSpeed"} or {22862}={$DISK.ARRAY.CACHE.STATUS.WARN:"cacheReadCacheNotMapped"} or {22862}={$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModFlashMemNotAttached"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is in warning state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19210','{22863}<>{$DISK.ARRAY.CACHE.STATUS.OK:"enabled"} and {22863}<>{$DISK.ARRAY.CACHE.STATUS.WARN:"invalid"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is not in optimal state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19211','{22864}={$DISK.ARRAY.STATUS.CRIT}','{#CNTLR_LOCATION}: Disk array controller is in critical state','','0','4','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19212','{22865}={$DISK.ARRAY.STATUS.WARN}','{#CNTLR_LOCATION}: Disk array controller is in warning state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19213','{22866}={$FAN.STATUS.CRIT}','Fan {#SNMPINDEX}: Fan is in critical state','','0','3','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19214','{22867}={$FAN.STATUS.WARN}','Fan {#SNMPINDEX}: Fan is in warning state','','0','2','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19215','{22868}=3','{#ADAPTER_NAME} port {#ADAPTER_INDEX}: Adapter has failed','','0','4','Please check the physical adapter.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19216','{22869}=4','{#ADAPTER_NAME} port {#ADAPTER_INDEX}: Adapter has lost link','','0','3','Please check the cable connections to this adapter.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19217','{22870}=1 and {22871}>0','{#DISK_LOCATION}: Disk has been replaced (new serial number received)','','0','1','Disk serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19218','{22872}={$DISK.SMART.STATUS.FAIL:"replaceDrive"} or {22872}={$DISK.SMART.STATUS.FAIL:"replaceDriveSSDWearOut"}','{#DISK_LOCATION}: Physical disk S.M.A.R.T. failed','','0','4','Disk probably requires replacement.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19219','{22873}={$DISK.STATUS.FAIL}','{#DISK_LOCATION}: Physical disk failed','','0','4','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19220','{22874}={$DISK.STATUS.WARN}','{#DISK_LOCATION}: Physical disk is in warning state','','0','2','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19221','{22875}={$PSU.STATUS.CRIT}','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply is in critical state','','0','3','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19222','{22876}={$PSU.STATUS.WARN}','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply is in warning state','','0','2','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19223','{22877} = 1','Ambient: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19224','{22878} = 3','Ambient: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19225','{22879} = 4','Ambient: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19226','{22880} = 1','CPU-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19227','{22881} = 3','CPU-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19228','{22882} = 4','CPU-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19229','{22883} = 1','{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19230','{22884} = 3','{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19231','{22885} = 4','{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19232','{22886} = 1','I/O-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19233','{22887} = 3','I/O-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19234','{22888} = 4','I/O-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19235','{22889} = 1','Memory-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19236','{22890} = 3','Memory-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19237','{22891} = 4','Memory-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19238','{22892} = 1','PSU-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19239','{22893} = 3','PSU-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19240','{22894} = 4','PSU-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19241','{22895} = 1','System-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19242','{22896} = 3','System-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19243','{22897} = 4','System-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19244','{22898}={$VDISK.STATUS.CRIT}','Disk {#SNMPINDEX}({#DISK_NAME}): Virtual disk failed','','0','4','Please check virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19245','{22899}<>{$VDISK.STATUS.OK}','Disk {#SNMPINDEX}({#DISK_NAME}): Virtual disk is not in OK state','','0','2','Please check virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19246','{22900}=1 and {22901}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19247','{22902}=1 and {22903}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19248','{22904}={$HEALTH.STATUS.CRIT}','System status is in critical state','','0','4','Please check the device for errors.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19249','{22905}={$HEALTH.STATUS.WARN}','System status is in warning state','','0','2','Please check the device for warnings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19250','{22906}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19251','{22907}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19252','{22908}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"failed"} or {22908}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"capacitorFailed"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery is in critical state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19253','{22909}={$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN:"degraded"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery is in warning state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19254','{22910}={$DISK.ARRAY.CACHE.STATUS.CRIT:"cacheModCriticalFailure"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is in critical state!','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19255','{22911}={$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModDegradedFailsafeSpeed"} or {22911}={$DISK.ARRAY.CACHE.STATUS.WARN:"cacheReadCacheNotMapped"} or {22911}={$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModFlashMemNotAttached"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is in warning state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19256','{22912}<>{$DISK.ARRAY.CACHE.STATUS.OK:"enabled"} and {22912}<>{$DISK.ARRAY.CACHE.STATUS.WARN:"invalid"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is not in optimal state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19257','{22913}={$DISK.ARRAY.STATUS.CRIT}','{#CNTLR_LOCATION}: Disk array controller is in critical state','','0','4','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19258','{22914}={$DISK.ARRAY.STATUS.WARN}','{#CNTLR_LOCATION}: Disk array controller is in warning state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19259','{22915}={$FAN.STATUS.CRIT}','Fan {#SNMPINDEX}: Fan is in critical state','','0','3','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19260','{22916}={$FAN.STATUS.WARN}','Fan {#SNMPINDEX}: Fan is in warning state','','0','2','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19261','{22917}=3','{#ADAPTER_NAME} port {#ADAPTER_INDEX}: Adapter has failed','','0','4','Please check the physical adapter.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19262','{22918}=4','{#ADAPTER_NAME} port {#ADAPTER_INDEX}: Adapter has lost link','','0','3','Please check the cable connections to this adapter.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19263','{22919}=1 and {22920}>0','{#DISK_LOCATION}: Disk has been replaced (new serial number received)','','0','1','Disk serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19264','{22921}={$DISK.SMART.STATUS.FAIL:"replaceDrive"} or {22921}={$DISK.SMART.STATUS.FAIL:"replaceDriveSSDWearOut"}','{#DISK_LOCATION}: Physical disk S.M.A.R.T. failed','','0','4','Disk probably requires replacement.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19265','{22922}={$DISK.STATUS.FAIL}','{#DISK_LOCATION}: Physical disk failed','','0','4','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19266','{22923}={$DISK.STATUS.WARN}','{#DISK_LOCATION}: Physical disk is in warning state','','0','2','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19267','{22924}={$PSU.STATUS.CRIT}','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply is in critical state','','0','3','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19268','{22925}={$PSU.STATUS.WARN}','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply is in warning state','','0','2','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19269','{22926} = 1','Ambient: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19270','{22927} = 3','Ambient: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19271','{22928} = 4','Ambient: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19272','{22929} = 1','CPU-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19273','{22930} = 3','CPU-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19274','{22931} = 4','CPU-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19275','{22932} = 1','{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19276','{22933} = 3','{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19277','{22934} = 4','{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19278','{22935} = 1','I/O-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19279','{22936} = 3','I/O-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19280','{22937} = 4','I/O-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19281','{22938} = 1','Memory-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19282','{22939} = 3','Memory-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19283','{22940} = 4','Memory-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19284','{22941} = 1','PSU-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19285','{22942} = 3','PSU-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19286','{22943} = 4','PSU-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19287','{22944} = 1','System-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19288','{22945} = 3','System-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19289','{22946} = 4','System-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19290','{22947}={$VDISK.STATUS.CRIT}','Disk {#SNMPINDEX}({#DISK_NAME}): Virtual disk failed','','0','4','Please check virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19291','{22948}<>{$VDISK.STATUS.OK}','Disk {#SNMPINDEX}({#DISK_NAME}): Virtual disk is not in OK state','','0','2','Please check virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19292','{22949}=1 and {22950}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19293','{22951}=1 and {22952}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19294','{22953}={$HEALTH.STATUS.CRIT}','System status is in critical state','','0','4','Please check the device for errors.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19295','{22954}={$HEALTH.STATUS.WARN}','System status is in warning state','','0','2','Please check the device for warnings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19296','{22955}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19297','{22956}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19298','{22957}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"failed"} or {22957}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"capacitorFailed"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery is in critical state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19299','{22958}={$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN:"degraded"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery is in warning state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19300','{22959}={$DISK.ARRAY.CACHE.STATUS.CRIT:"cacheModCriticalFailure"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is in critical state!','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19301','{22960}={$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModDegradedFailsafeSpeed"} or {22960}={$DISK.ARRAY.CACHE.STATUS.WARN:"cacheReadCacheNotMapped"} or {22960}={$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModFlashMemNotAttached"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is in warning state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19302','{22961}<>{$DISK.ARRAY.CACHE.STATUS.OK:"enabled"} and {22961}<>{$DISK.ARRAY.CACHE.STATUS.WARN:"invalid"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is not in optimal state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19303','{22962}={$DISK.ARRAY.STATUS.CRIT}','{#CNTLR_LOCATION}: Disk array controller is in critical state','','0','4','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19304','{22963}={$DISK.ARRAY.STATUS.WARN}','{#CNTLR_LOCATION}: Disk array controller is in warning state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19305','{22964}={$FAN.STATUS.CRIT}','Fan {#SNMPINDEX}: Fan is in critical state','','0','3','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19306','{22965}={$FAN.STATUS.WARN}','Fan {#SNMPINDEX}: Fan is in warning state','','0','2','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19307','{22966}=3','{#ADAPTER_NAME} port {#ADAPTER_INDEX}: Adapter has failed','','0','4','Please check the physical adapter.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19308','{22967}=4','{#ADAPTER_NAME} port {#ADAPTER_INDEX}: Adapter has lost link','','0','3','Please check the cable connections to this adapter.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19309','{22968}=1 and {22969}>0','{#DISK_LOCATION}: Disk has been replaced (new serial number received)','','0','1','Disk serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19310','{22970}={$DISK.SMART.STATUS.FAIL:"replaceDrive"} or {22970}={$DISK.SMART.STATUS.FAIL:"replaceDriveSSDWearOut"}','{#DISK_LOCATION}: Physical disk S.M.A.R.T. failed','','0','4','Disk probably requires replacement.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19311','{22971}={$DISK.STATUS.FAIL}','{#DISK_LOCATION}: Physical disk failed','','0','4','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19312','{22972}={$DISK.STATUS.WARN}','{#DISK_LOCATION}: Physical disk is in warning state','','0','2','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19313','{22973}={$PSU.STATUS.CRIT}','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply is in critical state','','0','3','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19314','{22974}={$PSU.STATUS.WARN}','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply is in warning state','','0','2','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19315','{22975} = 1','Ambient: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19316','{22976} = 3','Ambient: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19317','{22977} = 4','Ambient: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19318','{22978} = 1','CPU-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19319','{22979} = 3','CPU-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19320','{22980} = 4','CPU-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19321','{22981} = 1','{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19322','{22982} = 3','{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19323','{22983} = 4','{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19324','{22984} = 1','I/O-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19325','{22985} = 3','I/O-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19326','{22986} = 4','I/O-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19327','{22987} = 1','Memory-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19328','{22988} = 3','Memory-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19329','{22989} = 4','Memory-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19330','{22990} = 1','PSU-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19331','{22991} = 3','PSU-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19332','{22992} = 4','PSU-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19333','{22993} = 1','System-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19334','{22994} = 3','System-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19335','{22995} = 4','System-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19336','{22996}={$VDISK.STATUS.CRIT}','Disk {#SNMPINDEX}({#DISK_NAME}): Virtual disk failed','','0','4','Please check virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19337','{22997}<>{$VDISK.STATUS.OK}','Disk {#SNMPINDEX}({#DISK_NAME}): Virtual disk is not in OK state','','0','2','Please check virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19338','{22998}=1 and {22999}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19339','{23000}=1 and {23001}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19340','{23002}={$HEALTH.STATUS.CRIT}','System status is in critical state','','0','4','Please check the device for errors.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19341','{23003}={$HEALTH.STATUS.WARN}','System status is in warning state','','0','2','Please check the device for warnings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19342','{23004}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19343','{23005}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19344','{23006}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"failed"} or {23006}={$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"capacitorFailed"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery is in critical state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19345','{23007}={$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN:"degraded"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller battery is in warning state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19346','{23008}={$DISK.ARRAY.CACHE.STATUS.CRIT:"cacheModCriticalFailure"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is in critical state!','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19347','{23009}={$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModDegradedFailsafeSpeed"} or {23009}={$DISK.ARRAY.CACHE.STATUS.WARN:"cacheReadCacheNotMapped"} or {23009}={$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModFlashMemNotAttached"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is in warning state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19348','{23010}<>{$DISK.ARRAY.CACHE.STATUS.OK:"enabled"} and {23010}<>{$DISK.ARRAY.CACHE.STATUS.WARN:"invalid"}','#{#CACHE_CNTRL_INDEX}: Disk array cache controller is not in optimal state','','0','2','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19349','{23011}={$DISK.ARRAY.STATUS.CRIT}','{#CNTLR_LOCATION}: Disk array controller is in critical state','','0','4','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19350','{23012}={$DISK.ARRAY.STATUS.WARN}','{#CNTLR_LOCATION}: Disk array controller is in warning state','','0','3','Please check the device for faults.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19351','{23013}={$FAN.STATUS.CRIT}','Fan {#SNMPINDEX}: Fan is in critical state','','0','3','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19352','{23014}={$FAN.STATUS.WARN}','Fan {#SNMPINDEX}: Fan is in warning state','','0','2','Please check the fan unit.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19353','{23015}=3','{#ADAPTER_NAME} port {#ADAPTER_INDEX}: Adapter has failed','','0','4','Please check the physical adapter.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19354','{23016}=4','{#ADAPTER_NAME} port {#ADAPTER_INDEX}: Adapter has lost link','','0','3','Please check the cable connections to this adapter.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19355','{23017}=1 and {23018}>0','{#DISK_LOCATION}: Disk has been replaced (new serial number received)','','0','1','Disk serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19356','{23019}={$DISK.SMART.STATUS.FAIL:"replaceDrive"} or {23019}={$DISK.SMART.STATUS.FAIL:"replaceDriveSSDWearOut"}','{#DISK_LOCATION}: Physical disk S.M.A.R.T. failed','','0','4','Disk probably requires replacement.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19357','{23020}={$DISK.STATUS.FAIL}','{#DISK_LOCATION}: Physical disk failed','','0','4','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current status: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19358','{23021}={$DISK.STATUS.WARN}','{#DISK_LOCATION}: Physical disk is in warning state','','0','2','Please check physical disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19359','{23022}={$PSU.STATUS.CRIT}','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply is in critical state','','0','3','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19360','{23023}={$PSU.STATUS.WARN}','Chassis {#CHASSIS_NUM}, bay {#BAY_NUM}: Power supply is in warning state','','0','2','Please check the power supply unit for errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19361','{23024} = 1','Ambient: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19362','{23025} = 3','Ambient: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19363','{23026} = 4','Ambient: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19364','{23027} = 1','CPU-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19365','{23028} = 3','CPU-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19366','{23029} = 4','CPU-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19367','{23030} = 1','{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19368','{23031} = 3','{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19369','{23032} = 4','{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19370','{23033} = 1','I/O-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19371','{23034} = 3','I/O-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19372','{23035} = 4','I/O-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19373','{23036} = 1','Memory-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19374','{23037} = 3','Memory-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19375','{23038} = 4','Memory-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19376','{23039} = 1','PSU-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19377','{23040} = 3','PSU-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19378','{23041} = 4','PSU-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19379','{23042} = 1','System-{#SNMPINDEX}: Temperature could not be determined','','0','1','Temperature could not be determined.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19380','{23043} = 3','System-{#SNMPINDEX}: The temperature sensor is outside of normal operating range','','0','2','If the cpqHeThermalDegradedAction is set to shutdown(3) the system will be shutdown if the degraded(3) condition occurs.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19381','{23044} = 4','System-{#SNMPINDEX}: The temperature sensor detects a condition that could permanently damage the system.','','0','4','The system will automatically shutdown if the failed(4) condition results, so it is unlikely that this value will ever be returned by the agent.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19382','{23045}={$VDISK.STATUS.CRIT}','Disk {#SNMPINDEX}({#DISK_NAME}): Virtual disk failed','','0','4','Please check virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19383','{23046}<>{$VDISK.STATUS.OK}','Disk {#SNMPINDEX}({#DISK_NAME}): Virtual disk is not in OK state','','0','2','Please check virtual disk for warnings or errors.',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19387','{23050}<>1','{#UNIT.NAME}: Service is not running','','0','2','',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19388','{23051}<10m','{#UNIT.NAME}: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19389','{23052}>={23053}','Cache group [{#JMXNAME}]: One or more backups are unavailable','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19390','{23054}=1 and {23055}>0','Cache group [{#JMXNAME}]: List of caches has changed','','0','1','List of caches has changed. Significant changes have occurred in the cluster. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19391','{23056}>0','Cache group [{#JMXNAME}]: Rebalance in progress','','0','1','Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19392','{23057}=0','Cache group [{#JMXNAME}]: There is no copy for partitions','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19393','{23058} > {$GRIDGAIN.THREAD.QUEUE.MAX.WARN:"{#JMXNAME}"}','Thread pool [{#JMXNAME}]: Too many messages in queue (over {$GRIDGAIN.THREAD.QUEUE.MAX.WARN:"{#JMXNAME}"} for 5 min)','','0','3','Number of messages in queue more than {$GRIDGAIN.THREAD.QUEUE.MAX.WARN:"{#JMXNAME}"}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19394','{23059}/{23060}*100>{$GRIDGAIN.CHECKPOINT.PUSED.MAX.HIGH}','Data region {#JMXNAME}: Checkpoint buffer utilization is too high (over {$GRIDGAIN.CHECKPOINT.PUSED.MAX.HIGH} in 5m)','','0','4','Checkpoint buffer utilization is high. Threads will be throttled to avoid buffer overflow. It can be caused by high disk utilization.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19395','{23061}/{23062}*100>{$GRIDGAIN.CHECKPOINT.PUSED.MAX.WARN}','Data region {#JMXNAME}: Checkpoint buffer utilization is too high (over {$GRIDGAIN.CHECKPOINT.PUSED.MAX.WARN} in 5m)','','0','2','Checkpoint buffer utilization is high. Threads will be throttled to avoid buffer overflow. It can be caused by high disk utilization.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19396','{23063}/{23064}*100>{$GRIDGAIN.DATA.REGION.PUSED.MAX.HIGH}','Data region {#JMXNAME}: Data region utilisation is too high (over {$GRIDGAIN.DATA.REGION.PUSED.MAX.HIGH} in 5m)','','0','4','Data region utilization is high. Increase data region size or delete any data.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19397','{23065}/{23066}*100>{$GRIDGAIN.DATA.REGION.PUSED.MAX.WARN}','Data region {#JMXNAME}: Data region utilisation is too high (over {$GRIDGAIN.DATA.REGION.PUSED.MAX.WARN} in 5m)','','0','2','Data region utilization is high. Increase data region size or delete any data.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19398','{23067}>0','Data region {#JMXNAME}: Node started to evict pages','','0','1','You store more data then region can accommodate. Data started to move to disk it can make requests work slower. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19399','{23068}>0','Data region {#JMXNAME}: Pages replace rate more than 0','','0','2','There is more data than DataRegionMaxSize. Cluster started to replace pages in memory. Page replacement can slow down operations.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19400','{23069} > {$GRIDGAIN.PME.DURATION.MAX.WARN}','GridGain [{#JMXIGNITEINSTANCENAME}]: PME duration is too long (over {$GRIDGAIN.PME.DURATION.MAX.WARN} for 5 min)','','0','2','PME duration is over {$GRIDGAIN.PME.DURATION.MAX.WARN}ms.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19401','{23070} > {$GRIDGAIN.PME.DURATION.MAX.HIGH}','GridGain [{#JMXIGNITEINSTANCENAME}]: PME duration is too long (over {$GRIDGAIN.PME.DURATION.MAX.HIGH} for 5 min)','','0','4','PME duration is over {$GRIDGAIN.PME.DURATION.MAX.HIGH}ms. Looks like PME is hung.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19402','{23071} > {$GRIDGAIN.THREADS.COUNT.MAX.WARN}','GridGain [{#JMXIGNITEINSTANCENAME}]: Number of running threads is too high (over {$GRIDGAIN.THREADS.COUNT.MAX.WARN} for 15 min)','','0','2','Number of running threads is over {$GRIDGAIN.THREADS.COUNT.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19403','{23072} > {$GRIDGAIN.JOBS.QUEUE.MAX.WARN}','GridGain [{#JMXIGNITEINSTANCENAME}]: Number of queued jobs is too high (over {$GRIDGAIN.JOBS.QUEUE.MAX.WARN} for 15 min)','','0','2','Number of queued jobs is over {$GRIDGAIN.JOBS.QUEUE.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19404','{23073}>{23074}','GridGain [{#JMXIGNITEINSTANCENAME}]: There are nodes is not in topology','','0','1','One or more server node left the topology. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19405','{23075}<0','GridGain [{#JMXIGNITEINSTANCENAME}]: Server node left the topology','','0','2','One or more server node left the topology. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19406','{23076}>0','GridGain [{#JMXIGNITEINSTANCENAME}]: Server node added to the topology','','0','1','One or more server node added to the topology. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19407','{23077}=1 and {23078}>0','GridGain [{#JMXIGNITEINSTANCENAME}]: Version has changed (new version: {ITEM.VALUE})','','0','1','GridGain [{#JMXIGNITEINSTANCENAME}] version has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19408','{23079}<10m','GridGain [{#JMXIGNITEINSTANCENAME}]: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19409','{23080}=1','GridGain [{#JMXIGNITEINSTANCENAME}]: Failed to fetch info data (or no data for 10m)','','0','2','Zabbix has not received data for items for the last 10 minutes.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19410','{23081}=1 and {23082}>0','GridGain [{#JMXIGNITEINSTANCENAME}]: Coordinator has changed','','0','2','GridGain [{#JMXIGNITEINSTANCENAME}] version has changed. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19411','{23083}={23084}','Cache group [{#JMXGROUP}]: All entries are in heap','','0','1','All entries are in heap. Possibly you use eager queries it may cause out of memory exceptions for big caches. Ack to close.',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19412','{23085} > {23086}','Cache group [{#JMXGROUP}]: Success transactions less than rollbacks for 5m','','0','2','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19413','{23087}>0 and {23088}=0','Cache group [{#JMXGROUP}]: There are no success transactions for cache for 5m','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19414','{23089}=1 and {23090}>0','F5 BIG-IP: Chassis has been replaced (new serial number received)','','0','1','Chassis serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19415','{23091}<10m','F5 BIG-IP: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19416','{23092}=0','F5 BIG-IP: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19417','{23093} + 86400 * {$BIGIP.CERT.MIN} < {23094}','F5 BIG-IP: Less than {$BIGIP.CERT.MIN} days left until the certificate expires ({#CERT.NAME})','','0','1','Please check certificate',NULL,'0','2','0','','0','','0','Expires: {ITEM.VALUE}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19418','{23095}=0','F5 BIG-IP: Fan[{#FAN.INDEX}] is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19419','{23096}=0','F5 BIG-IP: Power supply [{#POWER.INDEX}] is in critical state','','0','3','Please check the power supply unit',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19420','{23097}>{$BIGIP.CPU.UTIL.WARN.MAX}','F5 BIG-IP: High CPU utilization (over {$BIGIP.CPU.UTIL.WARN.MAX}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','1','{23097}<{$BIGIP.CPU.UTIL.WARN.MIN}','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19421','{23098}/{23099}*100<{$BIGIP.FS.FREE.WARN.MIN}','F5 BIG-IP: Low free space in file system [{#PART.NAME}] (less than {$BIGIP.FS.FREE.WARN.MIN}% for 5m)','','0','2','The system is running out of free space.',NULL,'0','2','1','{23098}/{23099}*100>{$BIGIP.FS.FREE.WARN.MAX}','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19422','{23100}/{23101}*100>{$BIGIP.MEMORY.UTIL.WARN.MAX}','F5 BIG-IP: High memory utilization in host [{#HOST.ID}] (over {$BIGIP.MEMORY.UTIL.WARN.MAX}% for 5m)','','0','2','The system is running out of free memory.',NULL,'0','2','1','{23100}/{23101}*100<{$BIGIP.MEMORY.UTIL.WARN.MIN}','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19423','{23102}/{23103}*100>{$BIGIP.SWAP.UTIL.WARN.MAX}','F5 BIG-IP: High swap utilization in host [{#HOST.ID}] (over {$BIGIP.SWAP.UTIL.WARN.MAX}% for 5m)','','0','2','The system is running out of free swap memory.',NULL,'0','2','1','{23102}/{23103}*100>{$BIGIP.SWAP.UTIL.WARN.MIN}','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19424','{23104}>{23105} or {23106}>{23107}','F5 BIG-IP: There are errors on the network interface ({#IF.NAME})','','0','3','',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19425','{23108}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {23109}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Node {#NODE}: port {#IFNAME} ({#TYPE}): High error rate (>{$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{23110}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {23111}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19426','({23112} - {23113}) / 86400 < {$CERT.EXPIRY.WARN}','Cert: SSL certificate expires soon (less than {$CERT.EXPIRY.WARN} days)','','0','2','The SSL certificate should be updated or it will become untrusted.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19427','{23114}=1','Cert: Fingerprint has changed (new version: {ITEM.VALUE})','','0','1','The SSL certificate fingerprint has changed. If you did not update the certificate, it may mean your certificate has been hacked. Ack to close.
There could be multiple valid certificates on some installations. In this case, the trigger will have a false positive. You can ignore it or disable the trigger.',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19428','{23115} = 1','Cert: SSL certificate is invalid','','0','4','SSL certificate has expired or it is issued for another domain.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19429','{23116}>{$HAPROXY.BACK_ERESP.MAX.WARN}','HAProxy backend {#PXNAME}: Number of responses with error is more than {$HAPROXY.BACK_ERESP.MAX.WARN} for 5m','','0','2','Number of requests on backend, whose responses yielded an error, is more than {$HAPROXY.BACK_ERESP.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19430','{23117}>{$HAPROXY.BACK_QCUR.MAX.WARN}','HAProxy backend {#PXNAME}: Current number of requests unassigned in queue is more than {$HAPROXY.BACK_QCUR.MAX.WARN} for 5m','','0','2','Current number of requests on backend unassigned in queue is more than {$HAPROXY.BACK_QCUR.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19431','{23118}>{$HAPROXY.BACK_QTIME.MAX.WARN}','HAProxy backend {#PXNAME}: Average time spent in queue is more than {$HAPROXY.BACK_QTIME.MAX.WARN} for 5m','','0','2','Average time spent in queue (in ms) for the last 1,024 requests is more than {$HAPROXY.BACK_QTIME.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19432','{23119}>{$HAPROXY.BACK_RTIME.MAX.WARN}','HAProxy backend {#PXNAME}: Average response time is more than {$HAPROXY.BACK_RTIME.MAX.WARN} for 5m','','0','2','Average backend response time (in ms) for the last 1,024 requests is more than {$HAPROXY.BACK_RTIME.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19433','{23120}=5','HAProxy backend {#PXNAME}: Server is DOWN','','0','3','Backend is not available.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19434','{23121}>{$HAPROXY.FRONT_DREQ.MAX.WARN}','HAProxy frontend {#PXNAME}: Number of requests denied is more than {$HAPROXY.FRONT_DREQ.MAX.WARN} for 5m','','0','2','Number of requests denied due to security concerns (ACL-restricted) is more than {$HAPROXY.FRONT_DREQ.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19435','{23122}>{$HAPROXY.FRONT_EREQ.MAX.WARN}','HAProxy frontend {#PXNAME}: Number of request errors is more than {$HAPROXY.FRONT_EREQ.MAX.WARN} for 5m','','0','2','Number of request errors is more than {$HAPROXY.FRONT_EREQ.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19436','{23123}>{$HAPROXY.FRONT_SUTIL.MAX.WARN}','HAProxy frontend {#PXNAME}: Session utilization is more than {$HAPROXY.FRONT_SUTIL.MAX.WARN}% for 5m','','0','2','Alerting on this metric is essential to ensure your server has sufficient capacity to handle all concurrent sessions. Unlike requests, upon reaching the session limit HAProxy will deny additional clients until resource consumption drops. Furthermore, if you find your session usage percentage to be hovering above 80%, it could be time to either modify HAProxy’s configuration to allow more sessions, or migrate your HAProxy server to a bigger box.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19437','{23124} = 0','HAProxy {#PXNAME} {#SVNAME}: Health check error','','0','2','Please check the server for faults.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19438','{23125}>{$HAPROXY.SERVER_ERESP.MAX.WARN}','HAProxy {#PXNAME} {#SVNAME}: Number of responses with error is more than {$HAPROXY.SERVER_ERESP.MAX.WARN} for 5m','','0','2','Number of requests on server, whose responses yielded an error, is more than {$HAPROXY.SERVER_ERESP.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19439','{23126}>{$HAPROXY.SERVER_QCUR.MAX.WARN}','HAProxy {#PXNAME} {#SVNAME}: Current number of requests unassigned in queue is more than {$HAPROXY.SERVER_QCUR.MAX.WARN} for 5m','','0','2','Current number of requests unassigned in queue is more than {$HAPROXY.SERVER_QCUR.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19440','{23127}>{$HAPROXY.SERVER_QTIME.MAX.WARN}','HAProxy {#PXNAME} {#SVNAME}: Average time spent in queue is more than {$HAPROXY.SERVER_QTIME.MAX.WARN} for 5m','','0','2','Average time spent in queue (in ms) for the last 1,024 requests is more than {$HAPROXY.SERVER_QTIME.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19441','{23128}>{$HAPROXY.SERVER_RTIME.MAX.WARN}','HAProxy {#PXNAME} {#SVNAME}: Average response time is more than {$HAPROXY.SERVER_RTIME.MAX.WARN} for 5m','','0','2','Average server response time (in ms) for the last 1,024 requests is more than {$HAPROXY.SERVER_RTIME.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19442','{23129}=5','HAProxy {#PXNAME} {#SVNAME}: Server is DOWN','','0','2','Server is not available.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19443','{23130}>{$HAPROXY.BACK_ERESP.MAX.WARN}','HAProxy backend {#PXNAME}: Number of responses with error is more than {$HAPROXY.BACK_ERESP.MAX.WARN} for 5m','','0','2','Number of requests on backend, whose responses yielded an error, is more than {$HAPROXY.BACK_ERESP.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19444','{23131}>{$HAPROXY.BACK_QCUR.MAX.WARN}','HAProxy backend {#PXNAME}: Current number of requests unassigned in queue is more than {$HAPROXY.BACK_QCUR.MAX.WARN} for 5m','','0','2','Current number of requests on backend unassigned in queue is more than {$HAPROXY.BACK_QCUR.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19445','{23132}>{$HAPROXY.BACK_QTIME.MAX.WARN}','HAProxy backend {#PXNAME}: Average time spent in queue is more than {$HAPROXY.BACK_QTIME.MAX.WARN} for 5m','','0','2','Average time spent in queue (in ms) for the last 1,024 requests is more than {$HAPROXY.BACK_QTIME.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19446','{23133}>{$HAPROXY.BACK_RTIME.MAX.WARN}','HAProxy backend {#PXNAME}: Average response time is more than {$HAPROXY.BACK_RTIME.MAX.WARN} for 5m','','0','2','Average backend response time (in ms) for the last 1,024 requests is more than {$HAPROXY.BACK_RTIME.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19447','{23134}=5','HAProxy backend {#PXNAME}: Server is DOWN','','0','3','Backend is not available.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19448','{23135}>{$HAPROXY.FRONT_DREQ.MAX.WARN}','HAProxy frontend {#PXNAME}: Number of requests denied is more than {$HAPROXY.FRONT_DREQ.MAX.WARN} for 5m','','0','2','Number of requests denied due to security concerns (ACL-restricted) is more than {$HAPROXY.FRONT_DREQ.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19449','{23136}>{$HAPROXY.FRONT_EREQ.MAX.WARN}','HAProxy frontend {#PXNAME}: Number of request errors is more than {$HAPROXY.FRONT_EREQ.MAX.WARN} for 5m','','0','2','Number of request errors is more than {$HAPROXY.FRONT_EREQ.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19450','{23137}>{$HAPROXY.FRONT_SUTIL.MAX.WARN}','HAProxy frontend {#PXNAME}: Session utilization is more than {$HAPROXY.FRONT_SUTIL.MAX.WARN}% for 5m','','0','2','Alerting on this metric is essential to ensure your server has sufficient capacity to handle all concurrent sessions. Unlike requests, upon reaching the session limit HAProxy will deny additional clients until resource consumption drops. Furthermore, if you find your session usage percentage to be hovering above 80%, it could be time to either modify HAProxy’s configuration to allow more sessions, or migrate your HAProxy server to a bigger box.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19451','{23138} = 0','HAProxy {#PXNAME} {#SVNAME}: Health check error','','0','2','Please check the server for faults.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19452','{23139}>{$HAPROXY.SERVER_ERESP.MAX.WARN}','HAProxy {#PXNAME} {#SVNAME}: Number of responses with error is more than {$HAPROXY.SERVER_ERESP.MAX.WARN} for 5m','','0','2','Number of requests on server, whose responses yielded an error, is more than {$HAPROXY.SERVER_ERESP.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19453','{23140}>{$HAPROXY.SERVER_QCUR.MAX.WARN}','HAProxy {#PXNAME} {#SVNAME}: Current number of requests unassigned in queue is more than {$HAPROXY.SERVER_QCUR.MAX.WARN} for 5m','','0','2','Current number of requests unassigned in queue is more than {$HAPROXY.SERVER_QCUR.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19454','{23141}>{$HAPROXY.SERVER_QTIME.MAX.WARN}','HAProxy {#PXNAME} {#SVNAME}: Average time spent in queue is more than {$HAPROXY.SERVER_QTIME.MAX.WARN} for 5m','','0','2','Average time spent in queue (in ms) for the last 1,024 requests is more than {$HAPROXY.SERVER_QTIME.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19455','{23142}>{$HAPROXY.SERVER_RTIME.MAX.WARN}','HAProxy {#PXNAME} {#SVNAME}: Average response time is more than {$HAPROXY.SERVER_RTIME.MAX.WARN} for 5m','','0','2','Average server response time (in ms) for the last 1,024 requests is more than {$HAPROXY.SERVER_RTIME.MAX.WARN}.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19456','{23143}=5','HAProxy {#PXNAME} {#SVNAME}: Server is DOWN','','0','2','Server is not available.',NULL,'0','2','0','','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19457','{23144}<10m','Cisco ASAv: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19458','{23145}=0','Cisco ASAv: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19459','{23146}>{$CPU.UTIL.CRIT}','Cisco ASAv: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19460','{23147}>{$MEMORY.UTIL.MAX}','Cisco ASAv: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19461','{23148}=2 and {23149}=1','Cisco ASAv: {#CISCO.IF.NAME} Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23148}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19462','{23150}=1 and {23151}>0','Cisco ASAv: {#CISCO.ASAV.PHYS.NAME} has been replaced (new serial number received)','','0','1','{#CISCO.ASAV.PHYS.NAME} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19463','{23152}=0','ZYXEL AAM1212-51 / IES-612: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19464','{23153}=1 and {23154}>0','ZYXEL AAM1212-51 / IES-612: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19465','{23155}<>"AAM1212-51 / IES-612"','ZYXEL AAM1212-51 / IES-612: Template does not match hardware','','0','1','This template is for Zyxel AAM1212-51 / IES-612, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19466','{23156}=1 and {23157}>0','ZYXEL AAM1212-51 / IES-612: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19467','{23158}=0','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX} alarm','','0','3','The slot reported an error.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19468','{23159}<10m','ZYXEL AAM1212-51 / IES-612: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19469','{23160}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL AAM1212-51 / IES-612: High the DSL line attenuation in Port {#SNMPINDEX} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19470','{23161}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL AAM1212-51 / IES-612: Low the DSL line noise margins in Port {#SNMPINDEX} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19471','{23162}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL AAM1212-51 / IES-612: High the DSL line attenuation in Port {#SNMPINDEX} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19472','{23163}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL AAM1212-51 / IES-612: Low the DSL line noise margins in Port {#SNMPINDEX} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19473','{23164}=2 and {23165}=1','ZYXEL AAM1212-51 / IES-612: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23164}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19474','{23166}=2 and {23167}=1','ZYXEL AAM1212-51 / IES-612: Port {#ZYXEL.IF.NAME}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23166}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19475','{23168}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL AAM1212-51 / IES-612: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19476','{23169}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL AAM1212-51 / IES-612: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19477','{23170}=0','ZYXEL ES3500-8PD: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19478','{23171}>{$CPU.UTIL.CRIT}','ZYXEL ES3500-8PD: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19479','{23172}=1 and {23173}>0','ZYXEL ES3500-8PD: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19480','{23174}<>"ES3500-8PD"','ZYXEL ES3500-8PD: Template does not match hardware','','0','1','This template is for Zyxel ES3500-8PD, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19481','{23175}=1 and {23176}>0','ZYXEL ES3500-8PD: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19482','{23177}<10m','ZYXEL ES3500-8PD: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19483','{23178}>{$MEMORY.UTIL.MAX}','ZYXEL ES3500-8PD: High memory utilization in "{#ZYXEL.MEMORY.NAME}" pool (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19484','{23179}=2 and {23180}=1','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23179}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19485','{23181} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL ES3500-8PD: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19486','{23182} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL ES3500-8PD: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19487','{23183}=1 and {23184}>0','ZYXEL ES3500-8PD: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19488','{23185}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL ES3500-8PD: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19489','{23186}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL ES3500-8PD: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19490','{23187}=0','ZYXEL GS-4012F: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19491','{23188}>{$CPU.UTIL.CRIT}','ZYXEL GS-4012F: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19492','{23189}=1 and {23190}>0','ZYXEL GS-4012F: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19493','{23191}<>"GS-4012F"','ZYXEL GS-4012F: Template does not match hardware','','0','1','This template is for Zyxel GS-4012F, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19494','{23192}=1 and {23193}>0','ZYXEL GS-4012F: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19495','{23194}<10m','ZYXEL GS-4012F: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19496','{23195}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL GS-4012F: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19497','{23196}=2 and {23197}=1','ZYXEL GS-4012F: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23196}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19498','{23198}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL GS-4012F: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19499','{23199}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL GS-4012F: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19500','{23200}=0','ZYXEL IES-500x: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19501','not({23201}="IES-5000" or {23201}="IES-5005")','ZYXEL IES-500x: Template does not match hardware','','0','1','This template is for Zyxel IES-500x, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19502','{23202}<10m','ZYXEL IES-500x: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19503','{23203}>{#ZYXEL.BUFFERHIGHTHRESH}','ZYXEL IES-500x: High Packet buffer utilization in Slot {#ZYXEL.SLOT.ID} (>{#ZYXEL.BUFFERHIGHTHRESH}% for 5m)','','0','3','The system is running out of free buffer.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19504','{23204}>{#ZYXEL.CPU.THRESH.HIGH}','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} high CPU utilization (over {#ZYXEL.CPU.THRESH.HIGH}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19505','{23205}<{#ZYXEL.FANRPM.THRESH.LOW} or {23205}>{#ZYXEL.FANRPM.THRESH.HIGH}','ZYXEL IES-500x: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19506','{23206}>{#ZYXEL.MEMORYHIGHTHRESH}','ZYXEL IES-500x: High memory utilization in Slot {#ZYXEL.SLOT.ID} pool (>{#ZYXEL.MEMORYHIGHTHRESH}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19507','{23207}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL IES-500x: High the DSL line attenuation in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19508','{23208}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL IES-500x: Low the DSL line noise margins in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19509','{23209}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL IES-500x: High the DSL line attenuation in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19510','{23210}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL IES-500x: Low the DSL line noise margins in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19511','{23211}=2 and {23212}=1','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23211}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19512','{23213}=2 and {23214}=1','ZYXEL IES-500x: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23213}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19513','{23215}=0','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} alarm','','0','3','The slot reported an error.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19514','{23216}=1 and {23217}>0','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: DSL modem code has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19515','{23218}=1 and {23219}>0','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Driver has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19516','{23220}=1 and {23221}>0','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19517','{23222}=1 and {23223}>0','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Hardware version has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19518','{23224}=1 and {23225}>0','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} has been replaced (new serial number received)','','0','1','Slot {#ZYXEL.SLOT.ID} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19519','{23226}<10m','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19520','{23227}>{#ZYXEL.TEMP.THRESH.HIGH} or {23227}<{#ZYXEL.TEMP.THRESH.LOW}','ZYXEL IES-500x: Temperature Slot {#ZYXEL.SLOT.ID} Sensor: {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19521','{23228}<{#ZYXEL.VOLT.THRESH.LOW} or {23228}>{#ZYXEL.VOLT.THRESH.HIGH}','ZYXEL IES-500x: Voltage Slot {#ZYXEL.SLOT.ID} {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19522','{23229}=0','ZYXEL IES-6000: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19523','{23230}<>"IES-6000"','ZYXEL IES-6000: Template does not match hardware','','0','1','This template is for Zyxel IES-6000, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19524','{23231}<10m','ZYXEL IES-6000: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19525','{23232}>{#ZYXEL.BUFFERHIGHTHRESH}','ZYXEL IES-6000: High Packet buffer utilization in Slot {#ZYXEL.SLOT.ID} (>{#ZYXEL.BUFFERHIGHTHRESH}% for 5m)','','0','3','The system is running out of free buffer.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19526','{23233}>{#ZYXEL.CPU.THRESH.HIGH}','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} high CPU utilization (over {#ZYXEL.CPU.THRESH.HIGH}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19527','{23234}<{#ZYXEL.FANRPM.THRESH.LOW} or {23234}>{#ZYXEL.FANRPM.THRESH.HIGH}','ZYXEL IES-6000: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19528','{23235}>{#ZYXEL.MEMORYHIGHTHRESH}','ZYXEL IES-6000: High memory utilization in Slot {#ZYXEL.SLOT.ID} pool (>{#ZYXEL.MEMORYHIGHTHRESH}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19529','{23236}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL IES-6000: High the DSL line attenuation in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19530','{23237}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL IES-6000: Low the DSL line noise margins in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19531','{23238}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL IES-6000: High the DSL line attenuation in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19532','{23239}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL IES-6000: Low the DSL line noise margins in Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19533','{23240}=2 and {23241}=1','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23240}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19534','{23242}=2 and {23243}=1','ZYXEL IES-6000: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23242}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19535','{23244}=0','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} alarm','','0','3','The slot reported an error.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19536','{23245}=1 and {23246}>0','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: DSL modem code has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19537','{23247}=1 and {23248}>0','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Driver has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19538','{23249}=1 and {23250}>0','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19539','{23251}=1 and {23252}>0','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Hardware version has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','2','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19540','{23253}=1 and {23254}>0','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} has been replaced (new serial number received)','','0','1','Slot {#ZYXEL.SLOT.ID} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19541','{23255}<10m','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19542','{23256}>{#ZYXEL.TEMP.THRESH.HIGH} or {23256}<{#ZYXEL.TEMP.THRESH.LOW}','ZYXEL IES-6000: Temperature Slot {#ZYXEL.SLOT.ID} Sensor: {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19543','{23257}<{#ZYXEL.VOLT.THRESH.LOW} or {23257}>{#ZYXEL.VOLT.THRESH.HIGH}','ZYXEL IES-6000: Voltage Slot {#ZYXEL.SLOT.ID} {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19544','{23258}=0','ZYXEL IES1248-51: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19545','{23259}=1 and {23260}>0','ZYXEL IES1248-51: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19546','{23261}<>"IES1248-51"','ZYXEL IES1248-51: Template does not match hardware','','0','1','This template is for Zyxel IES1248-51, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19547','{23262}=1 and {23263}>0','ZYXEL IES1248-51: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19548','{23264}=0','ZYXEL IES1248-51: Port {#SNMPINDEX} alarm','','0','3','The slot reported an error.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19549','{23265}<10m','ZYXEL IES1248-51: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19550','{23266}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL IES1248-51: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19551','{23267}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL IES1248-51: High the DSL line attenuation in Port {#SNMPINDEX} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19552','{23268}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL IES1248-51: Low the DSL line noise margins in Port {#SNMPINDEX} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19553','{23269}>{$ZYXEL.ADSL.ATN.MAX}','ZYXEL IES1248-51: High the DSL line attenuation in Port {#SNMPINDEX} (>{$ZYXEL.ADSL.ATN.MAX}dB for 5m)','','0','2','The reductions in amplitude of the downstream and upstream DSL signals.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19554','{23270}<{$ZYXEL.ADSL.SNR.MIN}','ZYXEL IES1248-51: Low the DSL line noise margins in Port {#SNMPINDEX} (<{$ZYXEL.ADSL.SNR.MIN}dB for 5m)','','0','2','Signal-to-noise margin (SNR Margin) which is the difference between the actual SNR and the SNR required to sync at a specific speed',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19555','{23271}=2 and {23272}=1','ZYXEL IES1248-51: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23271}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19556','{23273}=2 and {23274}=1','ZYXEL IES1248-51: Port {#ZYXEL.IF.NAME}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23273}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19557','{23275}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL IES1248-51: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19558','{23276}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL IES1248-51: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19559','{23277}=0','ZYXEL MES-3528: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19560','{23278}>{$CPU.UTIL.CRIT}','ZYXEL MES-3528: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19561','{23279}=1 and {23280}>0','ZYXEL MES-3528: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19562','{23281}<>"MES-3528"','ZYXEL MES-3528: Template does not match hardware','','0','1','This template is for Zyxel MES-3528, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19563','{23282}=1 and {23283}>0','ZYXEL MES-3528: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19564','{23284}<10m','ZYXEL MES-3528: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19565','{23285}=2 and {23286}=1','ZYXEL MES-3528: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23285}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19566','{23287} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MES-3528: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19567','{23288} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MES-3528: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19568','{23289}=1 and {23290}>0','ZYXEL MES-3528: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19569','{23291}=0','ZYXEL MES3500-10: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19570','{23292}>{$CPU.UTIL.CRIT}','ZYXEL MES3500-10: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19571','{23293}=1 and {23294}>0','ZYXEL MES3500-10: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19572','{23295}<>"MES3500-10"','ZYXEL MES3500-10: Template does not match hardware','','0','1','This template is for Zyxel MES3500-10, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19573','{23296}=1 and {23297}>0','ZYXEL MES3500-10: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19574','{23298}<10m','ZYXEL MES3500-10: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19575','{23299}>{$MEMORY.UTIL.MAX}','ZYXEL MES3500-10: High memory utilization in "{#ZYXEL.MEMORY.NAME}" pool (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19576','{23300}=2 and {23301}=1','ZYXEL MES3500-10: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23300}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19577','{23302} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MES3500-10: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19578','{23303} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MES3500-10: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19579','{23304}=1 and {23305}>0','ZYXEL MES3500-10: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19580','{23306}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL MES3500-10: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19581','{23307}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL MES3500-10: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19582','{23308}=0','ZYXEL MES3500-24: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19583','{23309}>{$CPU.UTIL.CRIT}','ZYXEL MES3500-24: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19584','{23310}=1 and {23311}>0','ZYXEL MES3500-24: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19585','{23312}<>"MES3500-24"','ZYXEL MES3500-24: Template does not match hardware','','0','1','This template is for Zyxel MES3500-24, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19586','{23313}=1 and {23314}>0','ZYXEL MES3500-24: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19587','{23315}<10m','ZYXEL MES3500-24: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19588','{23316}>{$MEMORY.UTIL.MAX}','ZYXEL MES3500-24: High memory utilization in "{#ZYXEL.MEMORY.NAME}" pool (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19589','{23317}=2 and {23318}=1','ZYXEL MES3500-24: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23317}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19590','{23319} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MES3500-24: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19591','{23320} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MES3500-24: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19592','{23321}=1 and {23322}>0','ZYXEL MES3500-24: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19593','{23323}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL MES3500-24: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19594','{23324}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL MES3500-24: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19595','{23325}=0','ZYXEL MGS-3712: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19596','{23326}>{$CPU.UTIL.CRIT}','ZYXEL MGS-3712: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19597','{23327}=1 and {23328}>0','ZYXEL MGS-3712: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19598','{23329}<>"MGS-3712"','ZYXEL MGS-3712: Template does not match hardware','','0','1','This template is for Zyxel MGS-3712, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19599','{23330}=1 and {23331}>0','ZYXEL MGS-3712: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19600','{23332}<10m','ZYXEL MGS-3712: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19601','{23333}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL MGS-3712: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19602','{23334}=2 and {23335}=1','ZYXEL MGS-3712: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23334}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19603','{23336} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MGS-3712: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19604','{23337} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MGS-3712: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19605','{23338}=1 and {23339}>0','ZYXEL MGS-3712: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19606','{23340}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL MGS-3712: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19607','{23341}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL MGS-3712: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19608','{23342}=0','ZYXEL MGS-3712F: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19609','{23343}>{$CPU.UTIL.CRIT}','ZYXEL MGS-3712F: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19610','{23344}=1 and {23345}>0','ZYXEL MGS-3712F: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19611','{23346}<>"MGS-3712F"','ZYXEL MGS-3712F: Template does not match hardware','','0','1','This template is for Zyxel MGS-3712F, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19612','{23347}=1 and {23348}>0','ZYXEL MGS-3712F: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19613','{23349}<10m','ZYXEL MGS-3712F: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19614','{23350}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL MGS-3712F: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19615','{23351}=2 and {23352}=1','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23351}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19616','{23353} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MGS-3712F: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19617','{23354} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MGS-3712F: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19618','{23355}=1 and {23356}>0','ZYXEL MGS-3712F: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19619','{23357}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL MGS-3712F: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19620','{23358}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL MGS-3712F: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19621','{23359}=0','ZYXEL MES3500-24S: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19622','{23360}>{$CPU.UTIL.CRIT}','ZYXEL MES3500-24S: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19623','{23361}=1 and {23362}>0','ZYXEL MES3500-24S: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19624','{23363}>{$MEMORY.UTIL.MAX}','ZYXEL MES3500-24S: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19625','{23364}<>"MES3500-24S"','ZYXEL MES3500-24S: Template does not match hardware','','0','1','This template is for Zyxel MES3500-24S series, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19626','{23365}=1 and {23366}>0','ZYXEL MES3500-24S: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19627','{23367}<10m','ZYXEL MES3500-24S: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19628','{23368}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL MES3500-24S: {#ZYXEL.FAN.DESCRIPTION} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19629','{23369}=2 and {23370}=1','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23369}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19630','{23371} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MES3500-24S: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19631','{23372} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MES3500-24S: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19632','{23373}=1 and {23374}>0','ZYXEL MES3500-24S: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19633','{23375}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL MES3500-24S: Temperature {#ZYXEL.TEMPDESCRIPTION} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19634','{23376}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL MES3500-24S: Voltage {#ZYXEL.DESCRIPTION} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19635','{23377}=0','ZYXEL MGS3520-28x: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19636','{23378}>{$CPU.UTIL.CRIT}','ZYXEL MGS3520-28x: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19637','{23379}=1 and {23380}>0','ZYXEL MGS3520-28x: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19638','{23381}>{$MEMORY.UTIL.MAX}','ZYXEL MGS3520-28x: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19639','not({23382}="MGS3520-28" or {23382}="MGS3520-28F")','ZYXEL MGS3520-28x: Template does not match hardware','','0','1','This template is for Zyxel MGS3520-28x series, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19640','{23383}=1 and {23384}>0','ZYXEL MGS3520-28x: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19641','{23385}<10m','ZYXEL MGS3520-28x: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19642','{23386}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL MGS3520-28x: {#ZYXEL.FAN.DESCRIPTION} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19643','{23387}=2 and {23388}=1','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23387}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19644','{23389} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL MGS3520-28x: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19645','{23390} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL MGS3520-28x: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19646','{23391}=1 and {23392}>0','ZYXEL MGS3520-28x: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19647','{23393}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL MGS3520-28x: Temperature {#ZYXEL.TEMPDESCRIPTION} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19648','{23394}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL MGS3520-28x: Voltage {#ZYXEL.DESCRIPTION} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19649','{23395}=0','ZYXEL XGS-4728F: No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.',NULL,'0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19650','{23396}>{$CPU.UTIL.CRIT}','ZYXEL XGS-4728F: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.',NULL,'0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19651','{23397}=1 and {23398}>0','ZYXEL XGS-4728F: Firmware has changed','','0','1','Firmware version has changed. Ack to close',NULL,'0','0','0','','0','','1','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19652','{23399}<>"XGS-4728F"','ZYXEL XGS-4728F: Template does not match hardware','','0','1','This template is for Zyxel XGS-4728F, but connected to {ITEM.VALUE}',NULL,'0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19653','{23400}=1 and {23401}>0','ZYXEL XGS-4728F: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19654','{23402}<10m','ZYXEL XGS-4728F: has been restarted (uptime < 10m)','','0','1','Uptime is less than 10 minutes',NULL,'0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19655','{23403}<{#ZYXEL.FANRPM.THRESH.LOW}','ZYXEL XGS-4728F: FAN{#SNMPINDEX} is in critical state','','0','3','Please check the fan unit',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19656','{23404}>{$MEMORY.UTIL.MAX}','ZYXEL XGS-4728F: High memory utilization in "{#ZYXEL.MEMORY.NAME}" pool (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19657','{23405}=2 and {23406}=1','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23405}<>2','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19658','{23407} > {#ZYXEL.SFP.WARN.MAX}','ZYXEL XGS-4728F: SFP {#ZYXEL.SFP.PORT}: High {#ZYXEL.SFP.DESCRIPTION} (over {#ZYXEL.SFP.WARN.MAX}{#ZYXEL.SFP.UNIT})','','0','2','The upper threshold value of the parameter is exceeded',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19659','{23408} < {#ZYXEL.SFP.WARN.MIN}','ZYXEL XGS-4728F: SFP {#ZYXEL.SFP.PORT}: Low {#ZYXEL.SFP.DESCRIPTION} (less than {#ZYXEL.SFP.WARN.MIN}{#ZYXEL.SFP.UNIT})','','0','2','The parameter values are less than the lower threshold',NULL,'0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19660','{23409}=1 and {23410}>0','ZYXEL XGS-4728F: SFP {#SNMPINDEX} has been replaced (new serial number received)','','0','1','SFP {#SNMPINDEX} serial number has changed. Ack to close',NULL,'0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19661','{23411}>{#ZYXEL.TEMP.THRESH.HIGH}','ZYXEL XGS-4728F: Temperature {#ZYXEL.TEMP.ID} is in critical state','','0','3','Please check the temperature',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19662','{23412}<{#ZYXEL.VOLT.THRESH.LOW}','ZYXEL XGS-4728F: Voltage {#ZYXEL.VOLT.NOMINAL} is in critical state','','0','3','Please check the power supply',NULL,'0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19663','{23413}<0 and
{23414}>0 and
{23415}=2','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','0','','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19664','({23416}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{23417} or
{23418}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{23417}) and
{23417}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (>{$IF.UTIL.MAX:"{#IFNAME}"}%)','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{23416}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{23417} and
{23418}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{23417}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19665','{23419}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {23420}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (>{$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{23421}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {23422}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19666','{$IFCONTROL:"{#IFNAME}"}=1 and ({23423}<>2 and {23424}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:\"{#IFNAME}\"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important.
    No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status is different from Connected(2).

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23423}=2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19671','{23437}<0 and
{23438}>0 and
{23439}=2','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.',NULL,'0','2','0','','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19672','({23440}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{23441} or
{23442}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{23441}) and
{23441}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (>{$IF.UTIL.MAX:"{#IFNAME}"}%)','','0','2','The network interface utilization is close to its estimated maximum bandwidth.',NULL,'0','2','1','{23440}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{23441} and
{23442}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{23441}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19673','{23443}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {23444}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (>{$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold',NULL,'0','2','1','{23445}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {23446}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19674','{$IFCONTROL:"{#IFNAME}"}=1 and ({23447}<>2 and {23448}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:\"{#IFNAME}\"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important.
    No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status is different from Connected(2).

WARNING: if closed manually - won''t fire again on next poll, because of .diff.',NULL,'0','2','1','{23447}=2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14293','{14468}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14251','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14294','{14469}>{$ICMP_LOSS_WARN} and {14469}<100','High ICMP ping loss','','0','2','','14252','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14295','{14470}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14253','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14411','{14672}=1 and {14673}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close','14409','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14413','{14676}=1 and {14677}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close','14409','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14428','{14698}=1 and {14699}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close','14417','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14430','{14702}=1 and {14703}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close','14417','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14942','{15732}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14943','{15733}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14944','{15734}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14945','{15735}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14946','{15736}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14947','{15737}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14948','{15738}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14949','{15739}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14950','{15740}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14951','{15741}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14953','{15743}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15208','{16445}=1 and {16446}>0','Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close','14409','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15209','{16447}=1 and {16448}>0','{#ENT_NAME}: Device has been replaced (new serial number received)','','0','1','Device serial number has changed. Ack to close','14417','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15354','{16866}=1 or {16867}=1','{#SENSOR_INFO}: Power supply is in critical state','','0','3','Please check the power supply unit for errors','15344','0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15355','{16868}=1 or {16869}=1','{#SENSOR_INFO}: Power supply is in critical state','','0','3','Please check the power supply unit for errors','15344','0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15356','{16870}=1 or {16871}=1','{#SENSOR_INFO}: Power supply is in critical state','','0','3','Please check the power supply unit for errors','15344','0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15357','{16872}=1 or {16873}=1','{#SENSOR_INFO}: Power supply is in warning state','','0','2','Please check the power supply unit for errors','15345','0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15358','{16874}=1 or {16875}=1','{#SENSOR_INFO}: Power supply is in warning state','','0','2','Please check the power supply unit for errors','15345','0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15359','{16876}=1 or {16877}=1','{#SENSOR_INFO}: Power supply is in warning state','','0','2','Please check the power supply unit for errors','15345','0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15360','{16878}=1 or {16879}=1','{#SENSOR_INFO}: Fan is in critical state','','0','3','Please check the fan unit','15346','0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15361','{16880}=1 or {16881}=1','{#SENSOR_INFO}: Fan is in critical state','','0','3','Please check the fan unit','15346','0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15362','{16882}=1 or {16883}=1','{#SENSOR_INFO}: Fan is in critical state','','0','3','Please check the fan unit','15346','0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15363','{16884}=1 or {16885}=1','{#SENSOR_INFO}: Fan is in warning state','','0','2','Please check the fan unit','15347','0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15364','{16886}=1 or {16887}=1','{#SENSOR_INFO}: Fan is in warning state','','0','2','Please check the fan unit','15347','0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15365','{16888}=1 or {16889}=1','{#SENSOR_INFO}: Fan is in warning state','','0','2','Please check the fan unit','15347','0','2','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15672','{17697}<0 and {17698}>0
and (
{17699}=6 or
{17699}=7 or
{17699}=11 or
{17699}=62 or
{17699}=69 or
{17699}=117
)
and
({17700}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17697}>0 and {17701}>0) or
({17700}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15673','{17702}<0 and {17703}>0
and (
{17704}=6 or
{17704}=7 or
{17704}=11 or
{17704}=62 or
{17704}=69 or
{17704}=117
)
and
({17705}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17702}>0 and {17706}>0) or
({17705}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15674','{17707}<0 and {17708}>0
and (
{17709}=6 or
{17709}=7 or
{17709}=11 or
{17709}=62 or
{17709}=69 or
{17709}=117
)
and
({17710}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17707}>0 and {17711}>0) or
({17710}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15675','{17712}<0 and {17713}>0
and (
{17714}=6 or
{17714}=7 or
{17714}=11 or
{17714}=62 or
{17714}=69 or
{17714}=117
)
and
({17715}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17712}>0 and {17716}>0) or
({17715}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15676','{17717}<0 and {17718}>0
and (
{17719}=6 or
{17719}=7 or
{17719}=11 or
{17719}=62 or
{17719}=69 or
{17719}=117
)
and
({17720}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17717}>0 and {17721}>0) or
({17720}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15677','{17722}<0 and {17723}>0
and (
{17724}=6 or
{17724}=7 or
{17724}=11 or
{17724}=62 or
{17724}=69 or
{17724}=117
)
and
({17725}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17722}>0 and {17726}>0) or
({17725}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15678','{17727}<0 and {17728}>0
and (
{17729}=6 or
{17729}=7 or
{17729}=11 or
{17729}=62 or
{17729}=69 or
{17729}=117
)
and
({17730}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17727}>0 and {17731}>0) or
({17730}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15679','{17732}<0 and {17733}>0
and (
{17734}=6 or
{17734}=7 or
{17734}=11 or
{17734}=62 or
{17734}=69 or
{17734}=117
)
and
({17735}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17732}>0 and {17736}>0) or
({17735}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15680','{17737}<0 and {17738}>0
and (
{17739}=6 or
{17739}=7 or
{17739}=11 or
{17739}=62 or
{17739}=69 or
{17739}=117
)
and
({17740}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17737}>0 and {17741}>0) or
({17740}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15681','{17742}<0 and {17743}>0
and (
{17744}=6 or
{17744}=7 or
{17744}=11 or
{17744}=62 or
{17744}=69 or
{17744}=117
)
and
({17745}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17742}>0 and {17746}>0) or
({17745}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15682','{17747}<0 and {17748}>0
and (
{17749}=6 or
{17749}=7 or
{17749}=11 or
{17749}=62 or
{17749}=69 or
{17749}=117
)
and
({17750}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17747}>0 and {17751}>0) or
({17750}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15683','{17752}<0 and {17753}>0
and (
{17754}=6 or
{17754}=7 or
{17754}=11 or
{17754}=62 or
{17754}=69 or
{17754}=117
)
and
({17755}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17752}>0 and {17756}>0) or
({17755}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15684','{17757}<0 and {17758}>0
and (
{17759}=6 or
{17759}=7 or
{17759}=11 or
{17759}=62 or
{17759}=69 or
{17759}=117
)
and
({17760}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17757}>0 and {17761}>0) or
({17760}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15685','{17762}<0 and {17763}>0
and (
{17764}=6 or
{17764}=7 or
{17764}=11 or
{17764}=62 or
{17764}=69 or
{17764}=117
)
and
({17765}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17762}>0 and {17766}>0) or
({17765}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15686','{17767}<0 and {17768}>0
and (
{17769}=6 or
{17769}=7 or
{17769}=11 or
{17769}=62 or
{17769}=69 or
{17769}=117
)
and
({17770}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17767}>0 and {17771}>0) or
({17770}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15687','{17772}<0 and {17773}>0
and (
{17774}=6 or
{17774}=7 or
{17774}=11 or
{17774}=62 or
{17774}=69 or
{17774}=117
)
and
({17775}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17772}>0 and {17776}>0) or
({17775}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15689','{17782}<0 and {17783}>0
and (
{17784}=6 or
{17784}=7 or
{17784}=11 or
{17784}=62 or
{17784}=69 or
{17784}=117
)
and
({17785}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17782}>0 and {17786}>0) or
({17785}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15691','{17792}<0 and {17793}>0
and (
{17794}=6 or
{17794}=7 or
{17794}=11 or
{17794}=62 or
{17794}=69 or
{17794}=117
)
and
({17795}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17792}>0 and {17796}>0) or
({17795}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15694','{17807}<0 and {17808}>0
and (
{17809}=6 or
{17809}=7 or
{17809}=11 or
{17809}=62 or
{17809}=69 or
{17809}=117
)
and
({17810}<>2)','Interface {#IFDESCR}: Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15695','0','2','1','({17807}>0 and {17811}>0) or
({17810}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15696','{17817}<0 and {17818}>0
and (
{17819}=6 or
{17819}=7 or
{17819}=11 or
{17819}=62 or
{17819}=69 or
{17819}=117
)
and
({17820}<>2)','Interface {#IFDESCR}: Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15695','0','2','1','({17817}>0 and {17821}>0) or
({17820}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15697','{17822}<0 and {17823}>0
and (
{17824}=6 or
{17824}=7 or
{17824}=11 or
{17824}=62 or
{17824}=69 or
{17824}=117
)
and
({17825}<>2)','Interface {#IFDESCR}: Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15695','0','2','1','({17822}>0 and {17826}>0) or
({17825}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15700','{17837}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15708','{17848}<0 and {17849}>0
and (
{17850}=6 or
{17850}=7 or
{17850}=11 or
{17850}=62 or
{17850}=69 or
{17850}=117
)
and
({17851}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({17848}>0 and {17852}>0) or
({17851}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15989','{18223}=2','Interface {#IFNAME}({#IFALIAS}): In half-duplex mode','','0','2','Please check autonegotiation settings and cabling','14941','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15997','{18234}<0 and {18235}>0
and (
{18236}=6 or
{18236}=7 or
{18236}=11 or
{18236}=62 or
{18236}=69 or
{18236}=117
)
and
({18237}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15671','0','2','1','({18234}>0 and {18238}>0) or
({18237}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16012','{18266}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16007','0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16013','{18267}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({18268}-{18269})<5G or {18270}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.','16008','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16014','{18271}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({18272}-{18273})<10G or {18274}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.','16009','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16015','{18275}<{$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}%)','','0','3','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.','16010','0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16016','{18276}<{$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}%)','','0','2','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.','16011','0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16028','{18291}<0 and {18292}>0
and (
{18293}=6 or
{18293}=7 or
{18293}=11 or
{18293}=62 or
{18293}=69 or
{18293}=117
)
and
({18294}<>2)','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','15698','0','2','1','({18291}>0 and {18295}>0) or
({18294}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16045','{18321}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16031','0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16053','{18333}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','The host uptime is less than 10 minutes','16035','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16055','{18335}=0','System time is out of sync (diff with Zabbix server > {$SYSTEM.FUZZYTIME.MAX}s)','','0','2','The host system time is different from the Zabbix server time.','16036','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16059','{18341}<{$KERNEL.MAXFILES.MIN}','Configured max number of open filedescriptors is too low (< {$KERNEL.MAXFILES.MIN})','','0','1','','16038','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16061','{18343}<{$KERNEL.MAXPROC.MIN}','Configured max number of processes is too low (< {$KERNEL.MAXPROC.MIN})','','0','1','','16039','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16063','{18345}/{18346}*100>80','Getting closer to process limit (over 80% used)','','0','2','','16040','0','0','0','','0','','0','{ITEM.LASTVALUE1} active, {ITEM.LASTVALUE2} limit.','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16065','{18349}>0','/etc/passwd has been changed','','0','1','','16041','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16067','{18351}=1 and {18352}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.','16042','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16077','{18376}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({18377}-{18378})<5G or {18379}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.','16069','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16079','{18384}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({18385}-{18386})<10G or {18387}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.','16070','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16081','{18392}<{$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}%)','','0','3','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.','16071','0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16083','{18394}<{$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}%)','','0','2','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.','16072','0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16091','{18410}<0 and {18411}>0
and
({18411}=6
or {18411}=1)
and
({18412}<>2)','Interface {#IFNAME}: Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','16076','0','2','1','({18410}>0 and {18413}>0) or
({18412}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16110','{18442}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16097','0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16114','{18448}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','The host uptime is less than 10 minutes','16101','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16115','{18449}=0','System time is out of sync (diff with Zabbix server > {$SYSTEM.FUZZYTIME.MAX}s)','','0','2','The host system time is different from the Zabbix server time.','16102','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16117','{18452}<{$KERNEL.MAXFILES.MIN}','Configured max number of open filedescriptors is too low (< {$KERNEL.MAXFILES.MIN})','','0','1','','16104','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16118','{18453}<{$KERNEL.MAXPROC.MIN}','Configured max number of processes is too low (< {$KERNEL.MAXPROC.MIN})','','0','1','','16105','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16119','{18454}/{18455}*100>80','Getting closer to process limit (over 80% used)','','0','2','','16106','0','0','0','','0','','0','{ITEM.LASTVALUE1} active, {ITEM.LASTVALUE2} limit.','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16120','{18456}>0','/etc/passwd has been changed','','0','1','','16107','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16121','{18457}=1 and {18458}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.','16108','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16130','{18480}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({18481}-{18482})<5G or {18483}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.','16122','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16131','{18484}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({18485}-{18486})<10G or {18487}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.','16123','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16132','{18488}<{$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}%)','','0','3','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.','16124','0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16133','{18489}<{$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}%)','','0','2','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.','16125','0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16137','{18497}<0 and {18498}>0
and
({18498}=6
or {18498}=1)
and
({18499}<>2)','Interface {#IFNAME}: Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','16129','0','2','1','({18497}>0 and {18500}>0) or
({18499}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16171','{18561}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16160','0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16172','{18562}>{$CPU.INTERRUPT.CRIT.MAX}','CPU interrupt time is too high (over {$CPU.INTERRUPT.CRIT.MAX}% for 5m)','','0','2','"The CPU Interrupt Time in the last 5 minutes exceeds {$CPU.INTERRUPT.CRIT.MAX}%."
The Processor Information\% Interrupt Time is the time the processor spends receiving and servicing 
hardware interrupts during sample intervals. This value is an indirect indicator of the activity of 
devices that generate interrupts, such as the system clock, the mouse, disk drivers, data communication 
lines, network interface cards and other peripheral devices. This is an easy way to identify a potential 
hardware failure. This should never be higher than 20%.','16161','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16173','{18563}>{$CPU.PRIV.CRIT.MAX}','CPU privileged time is too high (over {$CPU.PRIV.CRIT.MAX}% for 5m)','','0','2','The CPU privileged time in the last 5 minutes exceeds {$CPU.PRIV.CRIT.MAX}%.','16162','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16177','{18568}<{$MEM.PAGE_TABLE_CRIT.MIN}','Number of free system page table entries is too low (less {$MEM.PAGE_TABLE_CRIT.MIN} for 5m)','','0','2','The Memory Free System Page Table Entries is less than {$MEM.PAGE_TABLE_CRIT.MIN} for 5 minutes. If the number is less than 5,000, there may well be a memory leak.','16166','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16178','{18569}>{$MEM.PAGE_SEC.CRIT.MAX}','The Memory Pages/sec is too high (over {$MEM.PAGE_SEC.CRIT.MAX} for 5m)','','0','2','The Memory Pages/sec in the last 5 minutes exceeds {$MEM.PAGE_SEC.CRIT.MAX}. If the value is greater than 1,000, as a result of excessive paging, there may be a memory leak.','16167','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16179','{18570}<10m','Host has been restarted (uptime < 10m)','','0','2','The device uptime is less than 10 minutes.','16168','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16180','{18571}=0','System time is out of sync (diff with Zabbix server > {$SYSTEM.FUZZYTIME.MAX}s)','','0','2','The host system time is different from the Zabbix server time.','16169','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16189','{18597}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({18598}-{18599})<5G or {18600}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.','16182','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16190','{18601}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({18602}-{18603})<10G or {18604}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.','16183','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16198','{18622}=0','Zabbix agent is not available (for {$AGENT.TIMEOUT})','','0','3','For passive only agents, host availability is used with {$AGENT.TIMEOUT} as time threshold.','16196','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16200','{18624}=0','Zabbix agent is not available (for {$AGENT.TIMEOUT})','','0','3','For passive only agents, host availability is used with {$AGENT.TIMEOUT} as time threshold.','16196','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16201','{18625}=0','Zabbix agent is not available (for {$AGENT.TIMEOUT})','','0','3','For passive only agents, host availability is used with {$AGENT.TIMEOUT} as time threshold.','16196','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16202','{18626}=0','Zabbix agent is not available (for {$AGENT.TIMEOUT})','','0','3','For passive only agents, host availability is used with {$AGENT.TIMEOUT} as time threshold.','16196','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16203','{18627}=0','Zabbix agent is not available (for {$AGENT.TIMEOUT})','','0','3','For passive only agents, host availability is used with {$AGENT.TIMEOUT} as time threshold.','16196','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16204','{18628}=0','Zabbix agent is not available (for {$AGENT.TIMEOUT})','','0','3','For passive only agents, host availability is used with {$AGENT.TIMEOUT} as time threshold.','16196','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16205','{18629}=0','Zabbix agent is not available (for {$AGENT.TIMEOUT})','','0','3','For passive only agents, host availability is used with {$AGENT.TIMEOUT} as time threshold.','16196','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16206','{18630}=0','Zabbix agent is not available (for {$AGENT.TIMEOUT})','','0','3','For passive only agents, host availability is used with {$AGENT.TIMEOUT} as time threshold.','16196','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16208','{18632}=1','Zabbix agent is not available (or nodata for {$AGENT.NODATA_TIMEOUT})','','0','3','For active agents, nodata() with agent.ping is used with {$AGENT.NODATA_TIMEOUT} as time threshold.','16197','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16220','{18646}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16209','0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16221','{18647}>{$CPU.INTERRUPT.CRIT.MAX}','CPU interrupt time is too high (over {$CPU.INTERRUPT.CRIT.MAX}% for 5m)','','0','2','"The CPU Interrupt Time in the last 5 minutes exceeds {$CPU.INTERRUPT.CRIT.MAX}%."
The Processor Information\% Interrupt Time is the time the processor spends receiving and servicing 
hardware interrupts during sample intervals. This value is an indirect indicator of the activity of 
devices that generate interrupts, such as the system clock, the mouse, disk drivers, data communication 
lines, network interface cards and other peripheral devices. This is an easy way to identify a potential 
hardware failure. This should never be higher than 20%.','16210','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16222','{18648}>{$CPU.PRIV.CRIT.MAX}','CPU privileged time is too high (over {$CPU.PRIV.CRIT.MAX}% for 5m)','','0','2','The CPU privileged time in the last 5 minutes exceeds {$CPU.PRIV.CRIT.MAX}%.','16211','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16226','{18653}<{$MEM.PAGE_TABLE_CRIT.MIN}','Number of free system page table entries is too low (less {$MEM.PAGE_TABLE_CRIT.MIN} for 5m)','','0','2','The Memory Free System Page Table Entries is less than {$MEM.PAGE_TABLE_CRIT.MIN} for 5 minutes. If the number is less than 5,000, there may well be a memory leak.','16215','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16227','{18654}>{$MEM.PAGE_SEC.CRIT.MAX}','The Memory Pages/sec is too high (over {$MEM.PAGE_SEC.CRIT.MAX} for 5m)','','0','2','The Memory Pages/sec in the last 5 minutes exceeds {$MEM.PAGE_SEC.CRIT.MAX}. If the value is greater than 1,000, as a result of excessive paging, there may be a memory leak.','16216','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16228','{18655}<10m','Host has been restarted (uptime < 10m)','','0','2','The device uptime is less than 10 minutes.','16217','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16229','{18656}=0','System time is out of sync (diff with Zabbix server > {$SYSTEM.FUZZYTIME.MAX}s)','','0','2','The host system time is different from the Zabbix server time.','16218','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16238','{18682}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({18683}-{18684})<5G or {18685}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.','16231','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16239','{18686}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({18687}-{18688})<10G or {18689}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.','16232','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16279','{18742}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16285','{18751}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16290','{18757}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16291','{18758}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16292','{18759}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16293','{18760}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16294','{18761}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16295','{18762}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16296','{18763}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16297','{18764}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16298','{18765}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16299','{18766}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16300','{18767}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16301','{18768}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16302','{18769}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16303','{18770}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16304','{18771}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16305','{18772}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16306','{18773}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16307','{18774}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16308','{18775}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16309','{18776}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16311','{18778}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16312','{18779}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16313','{18780}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16314','{18781}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16315','{18782}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16316','{18783}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16317','{18784}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16318','{18785}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16348','{18844}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16349','{18845}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16350','{18846}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16351','{18847}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16352','{18848}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16353','{18849}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16354','{18850}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16355','{18851}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16356','{18852}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16357','{18853}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16358','{18854}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16359','{18855}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16360','{18856}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16361','{18857}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16362','{18858}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16363','{18859}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16364','{18860}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16365','{18861}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16366','{18862}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16367','{18863}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16369','{18865}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16370','{18866}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16371','{18867}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16372','{18868}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16373','{18869}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16374','{18870}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16375','{18871}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16376','{18872}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16441','{19092}=1','Zabbix agent is not available (or nodata for {$AGENT.NODATA_TIMEOUT})','','0','3','For active agents, nodata() with agent.ping is used with {$AGENT.NODATA_TIMEOUT} as time threshold.','16197','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16457','{19111}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16458','{19112}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16500','{19181}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16498','0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16501','{19182}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16498','0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16509','{19194}=1 and {19195}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.','16507','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16510','{19196}=1 and {19197}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.','16507','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16511','{19198}=1 and {19199}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.','16507','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16512','{19200}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16508','0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16519','{19207}>{$CPU.UTIL.CRIT}','{#SNMPVALUE}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16514','0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16520','{19208}>{$CPU.UTIL.CRIT}','#{#SNMPINDEX}: High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16515','0','2','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16564','{19273}/{19274}>{$LOAD_AVG_PER_CPU.MAX.WARN}
and {19275}>0
and {19276}>0','Load average is too high (per CPU load over {$LOAD_AVG_PER_CPU.MAX.WARN} for 5m)','','0','3','Per CPU load average is too high. Your system may be slow to respond.','16563','0','0','0','','0','','0','Load averages(1m 5m 15m): ({ITEM.LASTVALUE1} {ITEM.LASTVALUE3} {ITEM.LASTVALUE4}), # of CPUs: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16570','{19291}/{19292}>{$LOAD_AVG_PER_CPU.MAX.WARN}
and {19293}>0
and {19294}>0','Load average is too high (per CPU load over {$LOAD_AVG_PER_CPU.MAX.WARN} for 5m)','','0','3','Per CPU load average is too high. Your system may be slow to respond.','16569','0','0','0','','0','','0','Load averages(1m 5m 15m): ({ITEM.LASTVALUE1} {ITEM.LASTVALUE3} {ITEM.LASTVALUE4}), # of CPUs: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16576','{19309}/{19310}>{$LOAD_AVG_PER_CPU.MAX.WARN}
and {19311}>0
and {19312}>0','Load average is too high (per CPU load over {$LOAD_AVG_PER_CPU.MAX.WARN} for 5m)','','0','3','Per CPU load average is too high. Your system may be slow to respond.','16575','0','0','0','','0','','0','Load averages(1m 5m 15m): ({ITEM.LASTVALUE1} {ITEM.LASTVALUE3} {ITEM.LASTVALUE4}), # of CPUs: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16580','{19318}=1 and {19319}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16579','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16583','{19324}=1 and {19325}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16582','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16586','{19330}=1 and {19331}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16585','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16588','{19334}=1 and {19335}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16587','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16591','{19340}=1 and {19341}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16594','{19346}=1 and {19347}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16595','{19348}=1 and {19349}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16596','{19350}=1 and {19351}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16597','{19352}=1 and {19353}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16598','{19354}=1 and {19355}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16599','{19356}=1 and {19357}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16600','{19358}=1 and {19359}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16601','{19360}=1 and {19361}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16602','{19362}=1 and {19363}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16603','{19364}=1 and {19365}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16604','{19366}=1 and {19367}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16605','{19368}=1 and {19369}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16606','{19370}=1 and {19371}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16607','{19372}=1 and {19373}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16608','{19374}=1 and {19375}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16609','{19376}=1 and {19377}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16610','{19378}=1 and {19379}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16611','{19380}=1 and {19381}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16612','{19382}=1 and {19383}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16613','{19384}=1 and {19385}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16615','{19388}=1 and {19389}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16616','{19390}=1 and {19391}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16617','{19392}=1 and {19393}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16618','{19394}=1 and {19395}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16619','{19396}=1 and {19397}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16620','{19398}=1 and {19399}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16621','{19400}=1 and {19401}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16622','{19402}=1 and {19403}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16623','{19404}=1 and {19405}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16625','{19407}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16624','0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16636','{19424}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({19425}-{19426})<5G or {19427}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.','16630','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16640','{19440}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({19441}-{19442})<10G or {19443}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.','16631','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16714','{19553}<>0','"{#SERVICE.NAME}" ({#SERVICE.DISPLAYNAME}) is not running (startup type {#SERVICE.STARTUPNAME})','','0','3','The service has a state other than "Running" for the last three times.','16713','0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16718','{19557}<>0','"{#SERVICE.NAME}" ({#SERVICE.DISPLAYNAME}) is not running (startup type {#SERVICE.STARTUPNAME})','','0','3','The service has a state other than "Running" for the last three times.','16717','0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16842','{$IFCONTROL:"{#IFNAME}"}=1 and ({19696}=2 and {19697}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19696}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16843','{$IFCONTROL:"{#IFNAME}"}=1 and ({19698}=2 and {19699}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19698}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16844','{$IFCONTROL:"{#IFNAME}"}=1 and ({19700}=2 and {19701}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19700}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16845','{$IFCONTROL:"{#IFNAME}"}=1 and ({19702}=2 and {19703}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19702}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16846','{$IFCONTROL:"{#IFNAME}"}=1 and ({19704}=2 and {19705}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19704}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16847','{$IFCONTROL:"{#IFNAME}"}=1 and ({19706}=2 and {19707}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19706}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16848','{$IFCONTROL:"{#IFNAME}"}=1 and ({19708}=2 and {19709}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19708}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16849','{$IFCONTROL:"{#IFNAME}"}=1 and ({19710}=2 and {19711}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19710}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16850','{$IFCONTROL:"{#IFNAME}"}=1 and ({19712}=2 and {19713}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19712}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16851','{$IFCONTROL:"{#IFNAME}"}=1 and ({19714}=2 and {19715}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19714}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16852','{$IFCONTROL:"{#IFNAME}"}=1 and ({19716}=2 and {19717}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19716}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16853','{$IFCONTROL:"{#IFNAME}"}=1 and ({19718}=2 and {19719}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19718}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16854','{$IFCONTROL:"{#IFNAME}"}=1 and ({19720}=2 and {19721}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19720}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16855','{$IFCONTROL:"{#IFNAME}"}=1 and ({19722}=2 and {19723}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19722}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16856','{$IFCONTROL:"{#IFNAME}"}=1 and ({19724}=2 and {19725}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19724}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16857','{$IFCONTROL:"{#IFNAME}"}=1 and ({19726}=2 and {19727}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19726}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16858','{$IFCONTROL:"{#IFNAME}"}=1 and ({19728}=2 and {19729}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19728}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16860','{$IFCONTROL:"{#IFNAME}"}=1 and ({19732}=2 and {19733}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19732}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16861','{$IFCONTROL:"{#IFNAME}"}=1 and ({19734}=2 and {19735}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19734}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16862','{$IFCONTROL:"{#IFNAME}"}=1 and ({19736}=2 and {19737}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16841','0','2','1','{19736}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16864','{$IFCONTROL:"{#IFNAME}"}=1 and ({19740}=2 and {19741}=1)','Interface {#IFDESCR}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16863','0','2','1','{19740}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16865','{$IFCONTROL:"{#IFNAME}"}=1 and ({19742}=2 and {19743}=1)','Interface {#IFDESCR}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16863','0','2','1','{19742}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16867','{$IFCONTROL:"{#IFNAME}"}=1 and ({19746}=2 and {19747}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16866','0','2','1','{19746}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16868','{$IFCONTROL:"{#IFNAME}"}=1 and ({19748}=2 and {19749}=1)','Interface {#IFDESCR}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16863','0','2','1','{19748}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16878','{19776}<{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','','0','3','','16871','0','2','1','{19777}>{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16879','{19778}<{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','','0','3','','16871','0','2','1','{19779}>{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16880','{19780}<{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','{#SNMPVALUE}: Temperature is too low: <{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}','','0','3','','16871','0','2','1','{19781}>{$TEMP_CRIT_LOW:"{#SNMPVALUE}"}+3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16995','{19921} > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"} or {19922} > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk read/write request responses are too high (read > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"} ms for 15m or write > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"} ms for 15m)','','0','2','This trigger might indicate disk {#DEVNAME} saturation.','16993','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16997','{$IFCONTROL:"{#IFNAME}"}=1 and ({19925}=2 and {19926}=1)','Interface {#IFNAME}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16994','0','2','1','{19925}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17003','{19935} > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"} or {19936} > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk read/write request responses are too high (read > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"} ms for 15m or write > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"} ms for 15m)','','0','2','This trigger might indicate disk {#DEVNAME} saturation.','17001','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17004','{$IFCONTROL:"{#IFNAME}"}=1 and ({19937}=2 and {19938}=1)','Interface {#IFNAME}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','17002','0','2','1','{19937}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17007','{19943} - {19944} * 2 > {$CPU.QUEUE.CRIT.MAX}','CPU queue length is too high (over {$CPU.QUEUE.CRIT.MAX} for 5m)','','0','2','The CPU Queue Length in the last 5 minutes exceeds {$CPU.QUEUE.CRIT.MAX}. According to actual observations, PQL should not exceed the number of cores * 2. To fine-tune the conditions, use the macro {$CPU.QUEUE.CRIT.MAX }.','17005','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17010','{19948}>{$VFS.DEV.UTIL.MAX.WARN}','{#DEVNAME}: Disk is overloaded (util > {$VFS.DEV.UTIL.MAX.WARN}% for 15m)','','0','2','The disk appears to be under heavy load','17009','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17013','{19953} - {19954} * 2 > {$CPU.QUEUE.CRIT.MAX}','CPU queue length is too high (over {$CPU.QUEUE.CRIT.MAX} for 5m)','','0','2','The CPU Queue Length in the last 5 minutes exceeds {$CPU.QUEUE.CRIT.MAX}. According to actual observations, PQL should not exceed the number of cores * 2. To fine-tune the conditions, use the macro {$CPU.QUEUE.CRIT.MAX }.','17011','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17016','{19958}>{$VFS.DEV.UTIL.MAX.WARN}','{#DEVNAME}: Disk is overloaded (util > {$VFS.DEV.UTIL.MAX.WARN}% for 15m)','','0','2','The disk appears to be under heavy load','17015','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17197','{20225}>{$TEMP_CRIT:"{#SNMPVALUE}"}
or
{20226}={$TEMP_CRIT_STATUS}
or
{20226}={$TEMP_DISASTER_STATUS}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:"{#SNMPVALUE}"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available','17195','0','2','1','{20227}<{$TEMP_CRIT:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17198','{20228}>{$TEMP_CRIT:"{#SNMPVALUE}"}
or
{20229}={$TEMP_CRIT_STATUS}
or
{20229}={$TEMP_DISASTER_STATUS}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:"{#SNMPVALUE}"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available','17195','0','2','1','{20230}<{$TEMP_CRIT:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17199','{20231}>{$TEMP_CRIT:"{#SNMPVALUE}"}
or
{20232}={$TEMP_CRIT_STATUS}
or
{20232}={$TEMP_DISASTER_STATUS}','{#SNMPVALUE}: Temperature is above critical threshold: >{$TEMP_CRIT:"{#SNMPVALUE}"}','','0','4','This trigger uses temperature sensor values as well as temperature sensor status if available','17195','0','2','1','{20233}<{$TEMP_CRIT:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17200','{20234}>{$TEMP_WARN:"{#SNMPVALUE}"}
or
{20235}={$TEMP_WARN_STATUS}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:"{#SNMPVALUE}"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available','17196','0','2','1','{20236}<{$TEMP_WARN:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17201','{20237}>{$TEMP_WARN:"{#SNMPVALUE}"}
or
{20238}={$TEMP_WARN_STATUS}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:"{#SNMPVALUE}"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available','17196','0','2','1','{20239}<{$TEMP_WARN:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17202','{20240}>{$TEMP_WARN:"{#SNMPVALUE}"}
or
{20241}={$TEMP_WARN_STATUS}','{#SNMPVALUE}: Temperature is above warning threshold: >{$TEMP_WARN:"{#SNMPVALUE}"}','','0','2','This trigger uses temperature sensor values as well as temperature sensor status if available','17196','0','2','1','{20242}<{$TEMP_WARN:"{#SNMPVALUE}"}-3','0','','0','Current value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17663','{20756} > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk write request responses are too high (write > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}s for 15m)','','0','2','This trigger might indicate disk {#DEVNAME} saturation.','17661','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17664','{20757} > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk read request responses are too high (read > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"}s for 15m','','0','2','This trigger might indicate disk {#DEVNAME} saturation.','17662','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17667','{20760} > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk write request responses are too high (write > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}s for 15m)','','0','2','This trigger might indicate disk {#DEVNAME} saturation.','17665','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17668','{20761} > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk read request responses are too high (read > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"}s for 15m','','0','2','This trigger might indicate disk {#DEVNAME} saturation.','17666','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17723','{20824}=1 and {20825}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17724','{20826}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17725','{20827}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17794','{20921}>{$MEMORY.UTIL.MAX}','{#MEMNAME}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17793','0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17800','({20932}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20933} or
{20934}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20933}) and
{20933}>0','Interface {#IFDESCR}: High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17798','0','2','1','{20932}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20933} and
{20934}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20933}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17801','({20935}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20936} or
{20937}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20936}) and
{20936}>0','Interface {#IFDESCR}: High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17798','0','2','1','{20935}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20936} and
{20937}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20936}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17802','({20938}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20939} or
{20940}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20939}) and
{20939}>0','Interface {#IFDESCR}: High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17798','0','2','1','{20938}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20939} and
{20940}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20939}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17803','{20941}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {20942}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFDESCR}: High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17799','0','2','1','{20943}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {20944}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17804','{20945}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {20946}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFDESCR}: High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17799','0','2','1','{20947}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {20948}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17805','{20949}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {20950}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFDESCR}: High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17799','0','2','1','{20951}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {20952}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17808','({20960}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20961} or
{20962}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20961}) and
{20961}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20960}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20961} and
{20962}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20961}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17809','({20963}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20964} or
{20965}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20964}) and
{20964}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20963}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20964} and
{20965}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20964}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17810','({20966}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20967} or
{20968}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20967}) and
{20967}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20966}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20967} and
{20968}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20967}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17811','({20969}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20970} or
{20971}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20970}) and
{20970}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20969}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20970} and
{20971}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20970}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17812','({20972}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20973} or
{20974}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20973}) and
{20973}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20972}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20973} and
{20974}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20973}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17813','({20975}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20976} or
{20977}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20976}) and
{20976}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20975}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20976} and
{20977}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20976}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17814','({20978}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20979} or
{20980}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20979}) and
{20979}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20978}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20979} and
{20980}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20979}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17815','({20981}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20982} or
{20983}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20982}) and
{20982}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20981}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20982} and
{20983}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20982}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17816','({20984}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20985} or
{20986}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20985}) and
{20985}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20984}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20985} and
{20986}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20985}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17817','({20987}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20988} or
{20989}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20988}) and
{20988}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20987}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20988} and
{20989}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20988}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17818','({20990}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20991} or
{20992}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20991}) and
{20991}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20990}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20991} and
{20992}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20991}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17819','({20993}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20994} or
{20995}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20994}) and
{20994}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20993}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20994} and
{20995}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20994}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17820','({20996}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20997} or
{20998}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{20997}) and
{20997}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20996}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20997} and
{20998}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{20997}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17821','({20999}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21000} or
{21001}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21000}) and
{21000}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{20999}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21000} and
{21001}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21000}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17822','({21002}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21003} or
{21004}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21003}) and
{21003}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{21002}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21003} and
{21004}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21003}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17823','({21005}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21006} or
{21007}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21006}) and
{21006}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{21005}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21006} and
{21007}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21006}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17824','({21008}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21009} or
{21010}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21009}) and
{21009}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{21008}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21009} and
{21010}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21009}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17826','({21014}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21015} or
{21016}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21015}) and
{21015}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{21014}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21015} and
{21016}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21015}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17827','({21017}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21018} or
{21019}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21018}) and
{21018}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{21017}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21018} and
{21019}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21018}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17828','({21020}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21021} or
{21022}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21021}) and
{21021}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17806','0','2','1','{21020}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21021} and
{21022}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21021}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17829','{21023}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21024}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21025}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21026}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17830','{21027}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21028}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21029}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21030}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17831','{21031}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21032}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21033}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21034}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17832','{21035}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21036}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21037}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21038}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17833','{21039}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21040}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21041}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21042}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17834','{21043}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21044}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21045}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21046}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17835','{21047}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21048}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21049}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21050}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17836','{21051}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21052}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21053}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21054}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17837','{21055}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21056}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21057}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21058}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17838','{21059}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21060}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21061}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21062}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17839','{21063}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21064}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21065}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21066}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17840','{21067}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21068}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21069}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21070}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17841','{21071}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21072}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21073}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21074}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17842','{21075}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21076}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21077}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21078}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17843','{21079}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21080}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21081}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21082}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17844','{21083}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21084}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21085}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21086}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17845','{21087}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21088}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21089}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21090}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17847','{21095}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21096}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21097}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21098}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17848','{21099}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21100}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21101}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21102}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17849','{21103}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21104}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17807','0','2','1','{21105}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21106}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17852','({21114}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21115} or
{21116}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{21115}) and
{21115}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (> {$IF.UTIL.MAX:"{#IFNAME}"}% )','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','17850','0','2','1','{21114}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21115} and
{21116}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{21115}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17853','{21117}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21118}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17851','0','2','1','{21119}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21120}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17869','{21138}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17868','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17870','{21139}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17868','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17872','{21141}>{$MEMORY.UTIL.MAX}','{#SNMPVALUE}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17871','0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17873','{21142}>{$MEMORY.UTIL.MAX}','{#SNMPVALUE}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17871','0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17874','{21143}>{$MEMORY.UTIL.MAX}','{#SNMPVALUE}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17871','0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17891','{21162}<{$SWAP.PFREE.MIN.WARN} and {21163}>0','High swap space usage (less than {$SWAP.PFREE.MIN.WARN}% free)','','0','2','This trigger is ignored, if there is no swap configured','17888','0','0','0','','0','','0','Free: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17892','{21164}<{$MEMORY.AVAILABLE.MIN} and {21165}>0','Lack of available memory (< {$MEMORY.AVAILABLE.MIN} of {ITEM.VALUE2})','','0','3','','17889','0','0','0','','0','','0','Available: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17893','{21166}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17890','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17898','{21176}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21177}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}: High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17897','0','2','1','{21178}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21179}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17903','{21189}<{$SWAP.PFREE.MIN.WARN} and {21190}>0','High swap space usage (less than {$SWAP.PFREE.MIN.WARN}% free)','','0','2','This trigger is ignored, if there is no swap configured','17900','0','0','0','','0','','0','Free: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17904','{21191}<{$MEMORY.AVAILABLE.MIN} and {21192}>0','Lack of available memory (< {$MEMORY.AVAILABLE.MIN} of {ITEM.VALUE2})','','0','3','','17901','0','0','0','','0','','0','Available: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17905','{21193}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17902','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17907','{21198}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21199}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}: High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17906','0','2','1','{21200}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21201}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17916','{21219}<{$SWAP.PFREE.MIN.WARN} and {21220}>0','High swap space usage (less than {$SWAP.PFREE.MIN.WARN}% free)','','0','2','This trigger is ignored, if there is no swap configured','17913','0','0','0','','0','','0','Free: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17917','{21221}<{$MEMORY.AVAILABLE.MIN} and {21222}>0','Lack of available memory (< {$MEMORY.AVAILABLE.MIN} of {ITEM.VALUE2})','','0','3','','17914','0','0','0','','0','','0','Available: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17918','{21223}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17915','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17921','{21227}<{$SWAP.PFREE.MIN.WARN} and {21228}>0','High swap space usage (less than {$SWAP.PFREE.MIN.WARN}% free)','','0','2','This trigger is ignored, if there is no swap configured','17919','0','0','0','','0','','0','Free: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17922','{21229}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17920','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17929','{21247}<{$SWAP.PFREE.MIN.WARN} and {21248}>0','High swap space usage (less than {$SWAP.PFREE.MIN.WARN}% free)','','0','2','This trigger is ignored, if there is no swap configured','17927','0','0','0','','0','','0','Free: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17930','{21249}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17928','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17938','{21267}=1 and {21268}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16593','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17939','{21269}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','Uptime is less than 10 minutes','16287','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17940','{21270}=0','No SNMP data collection','','0','2','SNMP is not available for polling. Please check device connectivity and SNMP settings.','16289','0','0','0','','0','','0','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18676','{22208}>75','Zabbix server: Utilization of alerter processes over 75%','','0','3','','18637','0','0','1','{22208}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18677','{22209}>75','Zabbix server: Utilization of alert manager processes over 75%','','0','3','','18638','0','0','1','{22209}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18678','{22210}>75','Zabbix server: Utilization of alert syncer processes over 75%','','0','3','','18639','0','0','1','{22210}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18680','{22212}>75','Zabbix server: Utilization of configuration syncer processes over 75%','','0','3','','18641','0','0','1','{22212}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18681','{22213}>75','Zabbix server: Utilization of discoverer processes over 75%','','0','3','','18642','0','0','1','{22213}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18682','{22214}>75','Zabbix server: Utilization of escalator processes over 75%','','0','3','','18643','0','0','1','{22214}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18684','{22216}>75','Zabbix server: Utilization of history syncer processes over 75%','','0','3','','18645','0','0','1','{22216}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18685','{22217}>75','Zabbix server: Utilization of housekeeper processes over 75%','','0','3','','18646','0','0','1','{22217}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18686','{22218}>75','Zabbix server: Utilization of http poller processes over 75%','','0','3','','18647','0','0','1','{22218}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18687','{22219}>75','Zabbix server: Utilization of icmp pinger processes over 75%','','0','3','','18648','0','0','1','{22219}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18688','{22220}>75','Zabbix server: Utilization of ipmi manager processes over 75%','','0','3','','18649','0','0','1','{22220}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18689','{22221}>75','Zabbix server: Utilization of ipmi poller processes over 75%','','0','3','','18650','0','0','1','{22221}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18690','{22222}>75','Zabbix server: Utilization of java poller processes over 75%','','0','3','','18651','0','0','1','{22222}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18691','{22223}>75','Zabbix server: Utilization of lld manager processes over 75%','','0','3','','18652','0','0','1','{22223}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18692','{22224}>75','Zabbix server: Utilization of lld worker processes over 75%','','0','3','','18653','0','0','1','{22224}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18693','{22225}>75','Zabbix server: Utilization of poller processes over 75%','','0','3','','18654','0','0','1','{22225}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18694','{22226}>75','Zabbix server: Utilization of preprocessing manager processes over 75%','','0','3','','18655','0','0','1','{22226}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18695','{22227}>75','Zabbix server: Utilization of preprocessing worker processes over 75%','','0','3','','18656','0','0','1','{22227}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18696','{22228}>75','Zabbix server: Utilization of proxy poller processes over 75%','','0','3','','18657','0','0','1','{22228}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18699','{22231}>75','Zabbix server: Utilization of self-monitoring processes over 75%','','0','3','','18660','0','0','1','{22231}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18700','{22232}>75','Zabbix server: Utilization of snmp trapper processes over 75%','','0','3','','18661','0','0','1','{22232}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18701','{22233}>75','Zabbix server: Utilization of task manager processes over 75%','','0','3','','18662','0','0','1','{22233}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18702','{22234}>75','Zabbix server: Utilization of timer processes over 75%','','0','3','','18663','0','0','1','{22234}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18703','{22235}>75','Zabbix server: Utilization of trapper processes over 75%','','0','3','','18664','0','0','1','{22235}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18704','{22236}>75','Zabbix server: Utilization of unreachable poller processes over 75%','','0','3','','18665','0','0','1','{22236}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18705','{22237}>75','Zabbix server: Utilization of vmware collector processes over 75%','','0','3','','18666','0','0','1','{22237}<65','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18706','{22238}>100','Zabbix server: More than 100 items having missing data for more than 10 minutes','','0','2','zabbix[stats,{$IP},{$PORT},queue,10m] item is collecting data about how many items are missing data for more than 10 minutes','18667','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18707','{22239}>75','Zabbix server: More than 75% used in the configuration cache','','0','3','Consider increasing CacheSize in the zabbix_server.conf configuration file','18668','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18708','{22240}>95','Zabbix server: More than 95% used in the value cache','','0','3','Consider increasing ValueCacheSize in the zabbix_server.conf configuration file','18669','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18709','{22241}=1','Zabbix server: Zabbix value cache working in low memory mode','','0','4','Once the low memory mode has been switched on, the value cache will remain in this state for 24 hours, even if the problem that triggered this mode is resolved sooner.','18670','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18710','{22242}=1 and {22243}>0','Zabbix server: Version has changed (new version: {ITEM.VALUE})','','0','1','Zabbix server version has changed. Ack to close.','18671','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18711','{22244}>75','Zabbix server: More than 75% used in the vmware cache','','0','3','Consider increasing VMwareCacheSize in the zabbix_server.conf configuration file','18672','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18712','{22245}>75','Zabbix server: More than 75% used in the history cache','','0','3','Consider increasing HistoryCacheSize in the zabbix_server.conf configuration file','18673','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18713','{22246}>75','Zabbix server: More than 75% used in the history index cache','','0','3','Consider increasing HistoryIndexCacheSize in the zabbix_server.conf configuration file','18674','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('18714','{22247}>75','Zabbix server: More than 75% used in the trends cache','','0','3','Consider increasing TrendCacheSize in the zabbix_server.conf configuration file','18675','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19667','{23425}<0 and
{23426}>0 and
{23427}=2','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','19663','0','2','0','','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19668','({23428}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{23429} or
{23430}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{23429}) and
{23429}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (>{$IF.UTIL.MAX:"{#IFNAME}"}%)','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','19664','0','2','1','{23428}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{23429} and
{23430}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{23429}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19669','{23431}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {23432}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (>{$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','19665','0','2','1','{23433}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {23434}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19670','{$IFCONTROL:"{#IFNAME}"}=1 and ({23435}<>2 and {23436}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:\"{#IFNAME}\"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important.
    No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status is different from Connected(2).

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','19666','0','2','1','{23435}=2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19675','{23449}<0 and
{23450}>0 and
{23451}=2','Interface {#IFNAME}({#IFALIAS}): Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','19671','0','2','0','','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19676','({23452}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{23453} or
{23454}>({$IF.UTIL.MAX:"{#IFNAME}"}/100)*{23453}) and
{23453}>0','Interface {#IFNAME}({#IFALIAS}): High bandwidth usage (>{$IF.UTIL.MAX:"{#IFNAME}"}%)','','0','2','The network interface utilization is close to its estimated maximum bandwidth.','19672','0','2','1','{23452}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{23453} and
{23454}<(({$IF.UTIL.MAX:"{#IFNAME}"}-3)/100)*{23453}','0','','1','In: {ITEM.LASTVALUE1}, out: {ITEM.LASTVALUE3}, speed: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19677','{23455}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {23456}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}({#IFALIAS}): High error rate (>{$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','19673','0','2','1','{23457}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {23458}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('19678','{$IFCONTROL:"{#IFNAME}"}=1 and ({23459}<>2 and {23460}=1)','Interface {#IFNAME}({#IFALIAS}): Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:\"{#IFNAME}\"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important.
    No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status is different from Connected(2).

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','19674','0','2','1','{23459}=2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14311','{14508}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14312','{14509}>{$ICMP_LOSS_WARN} and {14509}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14313','{14510}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14327','{14536}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14328','{14537}>{$ICMP_LOSS_WARN} and {14537}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14329','{14538}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14347','{14570}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14348','{14571}>{$ICMP_LOSS_WARN} and {14571}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14349','{14572}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14356','{14587}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14357','{14588}>{$ICMP_LOSS_WARN} and {14588}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14358','{14589}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14389','{14641}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14390','{14642}>{$ICMP_LOSS_WARN} and {14642}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14391','{14643}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14403','{14663}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14404','{14664}>{$ICMP_LOSS_WARN} and {14664}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14405','{14665}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14451','{14747}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14452','{14748}>{$ICMP_LOSS_WARN} and {14748}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14453','{14749}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14468','{14776}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14469','{14777}>{$ICMP_LOSS_WARN} and {14777}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14470','{14778}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14486','{14806}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14487','{14807}>{$ICMP_LOSS_WARN} and {14807}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14488','{14808}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14505','{14838}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14506','{14839}>{$ICMP_LOSS_WARN} and {14839}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14507','{14840}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14534','{14889}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14535','{14890}>{$ICMP_LOSS_WARN} and {14890}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14536','{14891}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14544','{14907}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14545','{14908}>{$ICMP_LOSS_WARN} and {14908}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14546','{14909}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14582','{14972}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14583','{14973}>{$ICMP_LOSS_WARN} and {14973}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14584','{14974}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14598','{15000}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14599','{15001}>{$ICMP_LOSS_WARN} and {15001}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14600','{15002}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14615','{15032}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14616','{15033}>{$ICMP_LOSS_WARN} and {15033}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14617','{15034}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14652','{15094}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14653','{15095}>{$ICMP_LOSS_WARN} and {15095}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14654','{15096}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14673','{15131}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14674','{15132}>{$ICMP_LOSS_WARN} and {15132}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14675','{15133}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14691','{15163}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14692','{15164}>{$ICMP_LOSS_WARN} and {15164}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14693','{15165}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14704','{15186}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14705','{15187}>{$ICMP_LOSS_WARN} and {15187}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14706','{15188}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14717','{15209}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14718','{15210}>{$ICMP_LOSS_WARN} and {15210}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14719','{15211}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14906','{15678}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14907','{15679}>{$ICMP_LOSS_WARN} and {15679}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('14908','{15680}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15220','{16472}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15221','{16473}>{$ICMP_LOSS_WARN} and {16473}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15222','{16474}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15701','{17838}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15702','{17839}>{$ICMP_LOSS_WARN} and {17839}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15703','{17840}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15723','{17874}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15724','{17875}>{$ICMP_LOSS_WARN} and {17875}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15725','{17876}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15755','{17926}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15756','{17927}>{$ICMP_LOSS_WARN} and {17927}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15757','{17928}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15819','{18026}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15820','{18027}>{$ICMP_LOSS_WARN} and {18027}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15821','{18028}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15840','{18057}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15841','{18058}>{$ICMP_LOSS_WARN} and {18058}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15842','{18059}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15990','{18224}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15991','{18225}>{$ICMP_LOSS_WARN} and {18225}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('15992','{18226}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16017','{18277}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16018','{18278}>{$ICMP_LOSS_WARN} and {18278}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16019','{18279}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16046','{18322}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16045','0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16054','{18334}<10m','{HOST.NAME} has been restarted (uptime < 10m)','','0','2','The host uptime is less than 10 minutes','16053','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16056','{18336}=0','System time is out of sync (diff with Zabbix server > {$SYSTEM.FUZZYTIME.MAX}s)','','0','2','The host system time is different from the Zabbix server time.','16055','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16060','{18342}<{$KERNEL.MAXFILES.MIN}','Configured max number of open filedescriptors is too low (< {$KERNEL.MAXFILES.MIN})','','0','1','','16059','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16062','{18344}<{$KERNEL.MAXPROC.MIN}','Configured max number of processes is too low (< {$KERNEL.MAXPROC.MIN})','','0','1','','16061','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16064','{18347}/{18348}*100>80','Getting closer to process limit (over 80% used)','','0','2','','16063','0','0','0','','0','','0','{ITEM.LASTVALUE1} active, {ITEM.LASTVALUE2} limit.','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16066','{18350}>0','/etc/passwd has been changed','','0','1','','16065','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16068','{18353}=1 and {18354}>0','Operating system description has changed','','0','1','Operating system description has changed. Possible reasons that system has been updated or replaced. Ack to close.','16067','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16078','{18380}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({18381}-{18382})<5G or {18383}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.','16077','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16080','{18388}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({18389}-{18390})<10G or {18391}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.','16079','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16082','{18393}<{$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.CRIT:"{#FSNAME}"}%)','','0','3','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.','16081','0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16084','{18395}<{$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}','{#FSNAME}: Running out of free inodes (free < {$VFS.FS.INODE.PFREE.MIN.WARN:"{#FSNAME}"}%)','','0','2','It may become impossible to write to disk if there are no index nodes left.
As symptoms, ''No space left on device'' or ''Disk is full'' errors may be seen even though free space is available.','16083','0','2','0','','0','','0','Free inodes: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16092','{18414}<0 and {18415}>0
and
({18415}=6
or {18415}=1)
and
({18416}<>2)','Interface {#IFNAME}: Ethernet has changed to lower speed than it was before','','0','1','This Ethernet connection has transitioned down from its known maximum speed. This might be a sign of autonegotiation issues. Ack to close.','16091','0','2','1','({18414}>0 and {18417}>0) or
({18416}=2)','0','','1','Current reported speed: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16199','{18623}=0','Zabbix agent is not available (for {$AGENT.TIMEOUT})','','0','3','For passive only agents, host availability is used with {$AGENT.TIMEOUT} as time threshold.','16198','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16453','{19106}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16454','{19107}>{$ICMP_LOSS_WARN} and {19107}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16455','{19108}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16565','{19277}/{19278}>{$LOAD_AVG_PER_CPU.MAX.WARN}
and {19279}>0
and {19280}>0','Load average is too high (per CPU load over {$LOAD_AVG_PER_CPU.MAX.WARN} for 5m)','','0','3','Per CPU load average is too high. Your system may be slow to respond.','16564','0','0','0','','0','','0','Load averages(1m 5m 15m): ({ITEM.LASTVALUE1} {ITEM.LASTVALUE3} {ITEM.LASTVALUE4}), # of CPUs: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16581','{19320}=1 and {19321}>0','System name has changed (new name: {ITEM.VALUE})','','0','1','System name has changed. Ack to close.','16580','0','0','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16627','{19409}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16625','0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16628','{19410}>{$CPU.UTIL.CRIT}','High CPU utilization (over {$CPU.UTIL.CRIT}% for 5m)','','0','2','CPU utilization is too high. The system might be slow to respond.','16625','0','0','0','','0','','0','Current utilization: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16638','{19432}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({19433}-{19434})<5G or {19435}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.','16636','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16639','{19436}>{$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"} and
(({19437}-{19438})<5G or {19439}<1d)','{#FSNAME}: Disk space is critically low (used > {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}%)','','0','3','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.CRIT:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 5G.
 - The disk will be full in less than 24 hours.','16636','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16642','{19448}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({19449}-{19450})<10G or {19451}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.','16640','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16643','{19452}>{$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"} and
(({19453}-{19454})<10G or {19455}<1d)','{#FSNAME}: Disk space is low (used > {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}%)','','0','2','Two conditions should match: First, space utilization should be above {$VFS.FS.PUSED.MAX.WARN:"{#FSNAME}"}.
 Second condition should be one of the following:
 - The disk free space is less than 10G.
 - The disk will be full in less than 24 hours.','16640','0','2','0','','0','','1','Space used: {ITEM.LASTVALUE3} of {ITEM.LASTVALUE2} ({ITEM.LASTVALUE1})','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16996','{19923} > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"} or {19924} > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"}','{#DEVNAME}: Disk read/write request responses are too high (read > {$VFS.DEV.READ.AWAIT.WARN:"{#DEVNAME}"} ms for 15m or write > {$VFS.DEV.WRITE.AWAIT.WARN:"{#DEVNAME}"} ms for 15m)','','0','2','This trigger might indicate disk {#DEVNAME} saturation.','16995','0','2','0','','0','','1','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('16998','{$IFCONTROL:"{#IFNAME}"}=1 and ({19927}=2 and {19928}=1)','Interface {#IFNAME}: Link down','','0','3','This trigger expression works as follows:
1. Can be triggered if operations status is down.
2. {$IFCONTROL:"{#IFNAME}"}=1 - user can redefine Context macro to value - 0. That marks this interface as not important. No new trigger will be fired if this interface is down.
3. {TEMPLATE_NAME:METRIC.diff()}=1) - trigger fires only if operational status was up(1) sometime before. (So, do not fire ''ethernal off'' interfaces.)

WARNING: if closed manually - won''t fire again on next poll, because of .diff.','16997','0','2','1','{19927}<>2 or {$IFCONTROL:"{#IFNAME}"}=0','0','','1','Current state: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17720','{20821}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17721','{20822}>{$ICMP_LOSS_WARN} and {20822}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17722','{20823}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17796','{20923}>{$MEMORY.UTIL.MAX}','{#MEMNAME}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17794','0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17797','{20924}>{$MEMORY.UTIL.MAX}','{#MEMNAME}: High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17794','0','2','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17894','{21167}<{$SWAP.PFREE.MIN.WARN} and {21168}>0','High swap space usage (less than {$SWAP.PFREE.MIN.WARN}% free)','','0','2','This trigger is ignored, if there is no swap configured','17891','0','0','0','','0','','0','Free: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17895','{21169}<{$MEMORY.AVAILABLE.MIN} and {21170}>0','Lack of available memory (< {$MEMORY.AVAILABLE.MIN} of {ITEM.VALUE2})','','0','3','','17892','0','0','0','','0','','0','Available: {ITEM.LASTVALUE1}, total: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17896','{21171}>{$MEMORY.UTIL.MAX}','High memory utilization (>{$MEMORY.UTIL.MAX}% for 5m)','','0','3','The system is running out of free memory.','17893','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17899','{21180}>{$IF.ERRORS.WARN:"{#IFNAME}"}
or {21181}>{$IF.ERRORS.WARN:"{#IFNAME}"}','Interface {#IFNAME}: High error rate (> {$IF.ERRORS.WARN:"{#IFNAME}"} for 5m)','','0','2','Recovers when below 80% of {$IF.ERRORS.WARN:"{#IFNAME}"} threshold','17898','0','2','1','{21182}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8
and {21183}<{$IF.ERRORS.WARN:"{#IFNAME}"}*0.8','0','','1','errors in: {ITEM.LASTVALUE1}, errors out: {ITEM.LASTVALUE2}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17935','{21264}=0','Unavailable by ICMP ping','','0','4','Last three attempts returned timeout.  Please check device connectivity.','14293','0','0','0','','0','','0','','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17936','{21265}>{$ICMP_LOSS_WARN} and {21265}<100','High ICMP ping loss','','0','2','','14294','0','0','0','','0','','0','Loss: {ITEM.LASTVALUE1}','0');
INSERT INTO triggers (triggerid,expression,description,url,status,priority,comments,templateid,type,flags,recovery_mode,recovery_expression,correlation_mode,correlation_tag,manual_close,opdata,discover) values ('17937','{21266}>{$ICMP_RESPONSE_TIME_WARN}','High ICMP ping response time','','0','2','','14295','0','0','0','','0','','0','Value: {ITEM.LASTVALUE1}','0');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('10546','15978','15983');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('10547','15980','15979');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('10548','15986','15987');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('10549','15988','15987');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('21337','16257','16255');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('21338','16257','16256');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('21339','16256','16255');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('21340','16251','16255');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('21341','16251','16256');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('21342','16443','16255');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('21343','16443','16256');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('21344','16270','16269');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('21345','16448','16269');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('21346','16265','16269');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27731','17682','17683');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27732','17684','17685');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27733','17686','17687');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27734','15944','15947');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27735','15944','15943');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27736','15943','15947');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27737','16888','15947');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27738','16888','15943');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27739','15948','15949');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27740','15950','15949');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27741','17219','17218');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27742','17222','17221');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27743','19426','19428');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27744','16743','16744');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27745','16784','16785');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27746','16790','16791');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27747','16892','16900');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27748','16894','16900');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27749','17267','17275');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27750','17272','17276');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27751','17273','17275');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27752','17274','17276');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27753','17279','17277');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27754','17282','17280');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27755','16646','16647');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27756','19437','19442');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27757','16809','16810');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27758','19451','19456');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27759','16902','16904');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27760','16904','16905');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27761','16909','16906');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27762','16910','16912');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27763','16912','16913');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27764','16917','16914');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27765','16752','16753');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27766','15955','15957');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27767','15955','15954');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27768','15954','15957');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27769','15956','15957');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27770','15956','15954');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27771','16678','15957');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27772','16678','15954');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27773','15961','15960');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27774','15962','15960');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27775','16679','15960');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27776','17225','17231');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27777','17228','17231');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27778','17236','17233');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27779','17966','17968');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27780','17966','17967');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27781','17967','17968');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27782','17973','17968');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27783','17973','17967');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27784','17975','17968');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27785','17975','17967');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27786','17985','17986');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27787','17987','17986');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27788','17992','17986');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27789','17081','17083');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27790','17082','17081');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27791','17082','17083');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27792','17082','17084');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27793','17084','17083');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27794','18615','18614');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27795','17117','17127');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27796','17118','17117');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27797','17118','17127');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27798','17119','17127');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27799','17120','17119');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27800','17120','17127');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27801','17122','17121');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27802','17123','17127');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27803','17124','17123');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27804','17124','17127');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27805','17126','17125');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27806','17128','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27807','17129','17128');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27808','17129','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27809','17130','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27810','17131','17130');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27811','17131','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27812','17132','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27813','17133','17132');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27814','17133','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27815','17134','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27816','17135','17134');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27817','17135','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27818','17136','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27819','17137','17136');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27820','17137','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27821','17139','17138');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27822','17140','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27823','17141','17140');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27824','17141','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27825','17142','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27826','17143','17142');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27827','17143','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27828','17145','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27829','17146','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27830','17146','17145');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27831','17147','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27832','17148','17144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27833','17148','17147');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27834','17306','17307');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27835','16920','16921');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27836','16833','16920');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27837','19395','19394');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27838','19397','19396');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27839','19400','19401');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27840','19402','19401');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27841','19412','19413');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27842','17748','17747');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27843','17750','17749');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27844','17753','17754');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27845','17755','17754');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27846','17765','17766');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27847','18007','18005');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27848','18019','18017');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27849','16929','16928');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27850','16940','17153');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27851','18627','18626');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27852','18629','18628');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27853','18631','18630');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27854','16719','16721');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27855','16975','16723');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27856','16729','16728');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27857','16730','16728');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27858','16756','16758');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27859','16979','16759');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27860','16765','16764');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27861','16766','16764');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27862','16734','16736');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27863','16983','16732');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27864','16741','16740');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27865','16742','16740');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27866','17173','17172');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27867','17175','17176');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27868','17180','17179');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27869','17711','17712');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27870','17713','17714');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27871','15928','15933');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27872','15931','15933');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27873','16683','16687');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27874','14252','14251');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27875','14294','14293');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27876','14312','14311');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27877','14328','14327');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27878','14348','14347');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27879','14357','14356');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27880','14390','14389');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27881','14404','14403');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27882','14452','14451');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27883','14469','14468');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27884','14487','14486');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27885','14506','14505');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27886','14535','14534');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27887','14545','14544');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27888','14583','14582');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27889','14599','14598');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27890','14616','14615');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27891','14653','14652');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27892','14674','14673');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27893','14692','14691');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27894','14705','14704');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27895','14718','14717');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27896','14907','14906');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27897','15221','15220');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27898','15702','15701');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27899','15724','15723');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27900','15756','15755');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27901','15820','15819');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27902','15841','15840');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27903','15991','15990');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27904','16018','16017');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27905','16454','16453');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27906','17721','17720');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27907','17936','17935');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27908','14253','14252');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27909','14295','14294');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27910','14313','14312');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27911','14329','14328');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27912','14349','14348');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27913','14358','14357');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27914','14391','14390');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27915','14405','14404');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27916','14453','14452');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27917','14470','14469');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27918','14488','14487');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27919','14507','14506');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27920','14536','14535');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27921','14546','14545');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27922','14584','14583');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27923','14600','14599');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27924','14617','14616');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27925','14654','14653');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27926','14675','14674');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27927','14693','14692');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27928','14706','14705');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27929','14719','14718');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27930','14908','14907');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27931','15222','15221');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27932','15703','15702');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27933','15725','15724');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27934','15757','15756');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27935','15821','15820');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27936','15842','15841');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27937','15992','15991');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27938','16019','16018');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27939','16455','16454');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27940','17722','17721');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27941','17937','17936');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27942','14253','14251');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27943','14295','14293');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27944','14313','14311');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27945','14329','14327');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27946','14349','14347');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27947','14358','14356');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27948','14391','14389');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27949','14405','14403');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27950','14453','14451');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27951','14470','14468');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27952','14488','14486');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27953','14507','14505');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27954','14536','14534');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27955','14546','14544');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27956','14584','14582');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27957','14600','14598');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27958','14617','14615');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27959','14654','14652');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27960','14675','14673');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27961','14693','14691');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27962','14706','14704');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27963','14719','14717');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27964','14908','14906');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27965','15222','15220');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27966','15703','15701');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27967','15725','15723');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27968','15757','15755');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27969','15821','15819');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27970','15842','15840');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27971','15992','15990');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27972','16019','16017');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27973','16455','16453');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27974','17722','17720');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27975','17937','17935');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27976','16287','16289');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27977','16279','16285');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27978','16290','16348');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27979','16291','16349');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27980','16292','16350');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27981','16293','16351');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27982','16294','16352');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27983','16295','16353');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27984','16296','16354');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27985','16297','16355');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27986','16298','16356');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27987','16299','16357');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27988','16300','16358');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27989','16301','16359');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27990','16302','16360');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27991','16303','16361');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27992','16304','16362');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27993','16305','16363');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27994','16306','16364');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27995','16307','16365');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27996','16308','16366');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27997','16309','16367');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27998','16311','16369');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('27999','16312','16370');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28000','16313','16371');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28001','16314','16372');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28002','16315','16373');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28003','16316','16374');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28004','16317','16375');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28005','16318','16376');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28006','16457','16458');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28007','17724','17725');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28008','17939','17940');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28009','16289','14293');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28010','16285','14717');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28011','16348','14311');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28012','16349','14327');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28013','16350','14347');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28014','16351','14356');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28015','16352','14389');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28016','16353','14403');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28017','16354','14451');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28018','16355','14468');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28019','16356','14486');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28020','16357','14505');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28021','16358','14534');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28022','16359','14544');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28023','16360','14582');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28024','16361','14598');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28025','16362','14615');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28026','16363','14652');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28027','16364','14673');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28028','16365','14691');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28029','16366','14704');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28030','16367','14906');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28031','16369','15220');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28032','16370','15701');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28033','16371','15723');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28034','16372','15755');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28035','16373','15819');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28036','16374','15840');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28037','16375','15990');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28038','16376','16017');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28039','16458','16453');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28040','17725','17720');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28041','17940','17935');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28042','16631','16630');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28043','16640','16636');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28044','16642','16638');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28045','16643','16639');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28046','15695','16863');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28047','17798','16863');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28048','17799','16863');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28049','15694','16868');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28050','15696','16864');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28051','15697','16865');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28052','17800','16864');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28053','17801','16865');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28054','17802','16868');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28055','17803','16864');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28056','17804','16865');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28057','17805','16868');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28058','15671','16841');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28059','17806','16841');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28060','17807','16841');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28061','15672','16842');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28062','15673','16843');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28063','15674','16844');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28064','15675','16845');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28065','15676','16846');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28066','15677','16847');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28067','15678','16848');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28068','15679','16849');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28069','15680','16850');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28070','15681','16851');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28071','15682','16852');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28072','15683','16853');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28073','15684','16854');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28074','15685','16855');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28075','15686','16856');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28076','15687','16857');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28077','15689','16858');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28078','15691','16860');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28079','15708','16861');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28080','15997','16862');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28081','17808','16842');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28082','17809','16843');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28083','17810','16844');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28084','17811','16845');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28085','17812','16846');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28086','17813','16847');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28087','17814','16848');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28088','17815','16849');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28089','17816','16850');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28090','17817','16851');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28091','17818','16852');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28092','17819','16853');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28093','17820','16854');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28094','17821','16855');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28095','17822','16856');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28096','17823','16857');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28097','17824','16858');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28098','17826','16860');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28099','17827','16861');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28100','17828','16862');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28101','17829','16842');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28102','17830','16843');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28103','17831','16844');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28104','17832','16845');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28105','17833','16846');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28106','17834','16847');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28107','17835','16848');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28108','17836','16849');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28109','17837','16850');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28110','17838','16851');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28111','17839','16852');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28112','17840','16853');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28113','17841','16854');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28114','17842','16855');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28115','17843','16856');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28116','17844','16857');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28117','17845','16858');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28118','17847','16860');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28119','17848','16861');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28120','17849','16862');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28121','15698','16866');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28122','17850','16866');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28123','17851','16866');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28124','16028','16867');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28125','17852','16867');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28126','17853','16867');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28127','17857','17858');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28128','17863','17864');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28129','14318','14319');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28130','17311','15717');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28131','17311','17312');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28132','17312','15717');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28133','17313','15717');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28134','17313','17314');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28135','17314','15717');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28136','17315','17316');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28137','17317','17318');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28138','17319','17320');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28139','17321','17322');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28140','15721','15720');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28141','15394','15393');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28142','15392','15391');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28143','17194','14339');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28144','15382','15381');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28145','15380','15379');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28146','16504','16505');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28147','14372','14373');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28148','15386','15385');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28149','15384','15383');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28150','14380','14381');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28151','18024','18023');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28152','18025','18024');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28153','18025','18023');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28154','18028','18027');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28155','18034','18033');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28156','18036','18041');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28157','18037','18041');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28158','18038','18041');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28159','18039','18041');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28160','18040','18041');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28161','18044','18043');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28162','18046','18045');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28163','18048','18047');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28164','18051','18050');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28165','18052','18051');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28166','18052','18050');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28167','18055','18054');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28168','18061','18060');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28169','18063','18068');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28170','18064','18068');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28171','18065','18068');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28172','18066','18068');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28173','18067','18068');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28174','18071','18070');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28175','18073','18072');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28176','18075','18074');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28177','18078','18077');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28178','18079','18078');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28179','18079','18077');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28180','18082','18081');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28181','18088','18087');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28182','18090','18095');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28183','18091','18095');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28184','18092','18095');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28185','18093','18095');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28186','18094','18095');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28187','18098','18097');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28188','18100','18099');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28189','18102','18101');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28190','18105','18104');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28191','18106','18105');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28192','18106','18104');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28193','18109','18108');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28194','18115','18114');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28195','18117','18122');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28196','18118','18122');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28197','18119','18122');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28198','18120','18122');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28199','18121','18122');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28200','18125','18124');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28201','18127','18126');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28202','18129','18128');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28203','18132','18131');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28204','18133','18132');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28205','18133','18131');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28206','18136','18135');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28207','18142','18141');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28208','18144','18149');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28209','18145','18149');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28210','18146','18149');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28211','18147','18149');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28212','18148','18149');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28213','18152','18151');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28214','18154','18153');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28215','18156','18155');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28216','15347','15346');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28217','15345','15344');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28218','17196','17195');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28219','15363','15360');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28220','15364','15361');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28221','15365','15362');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28222','15357','15354');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28223','15358','15355');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28224','15359','15356');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28225','17200','17197');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28226','17201','17198');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28227','17202','17199');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28228','15334','15333');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28229','15332','15331');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28230','14460','14461');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28231','14476','14477');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28232','14495','14496');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28233','14511','17203');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28234','14551','14552');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28235','15374','15373');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28236','15376','15375');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28237','14914','14915');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28238','14589','14590');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28239','15338','15337');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28240','17205','17204');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28241','14624','14625');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28242','18159','18158');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28243','18160','18159');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28244','18160','18158');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28245','18163','18164');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28246','18164','18158');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28247','18166','18169');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28248','18167','18169');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28249','18168','18169');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28250','18171','18172');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28251','18175','18174');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28252','14664','14665');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28253','17207','17208');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28254','16547','16546');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28255','17323','17324');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28256','17325','17326');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28257','17374','17375');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28258','17376','17377');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28259','17378','17379');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28260','17380','17381');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28261','17382','17383');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28262','17384','17385');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28263','17432','17433');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28264','17434','17435');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28265','17436','17437');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28266','17438','17439');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28267','17440','17441');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28268','17442','17443');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28269','17476','17477');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28270','17478','17479');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28271','17480','17481');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28272','17482','17483');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28273','17484','17485');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28274','17500','17501');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28275','17502','17503');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28276','17504','17505');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28277','17565','17566');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28278','17567','17568');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28279','17569','17570');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28280','17571','17572');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28281','17573','17574');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28282','17606','17607');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28283','17608','17609');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28284','17610','17611');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28285','17612','17613');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28286','17645','17646');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28287','17647','17648');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28288','17649','17650');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28289','17651','17652');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28290','17653','17654');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28291','17655','17656');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28292','17212','17211');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28293','16551','16552');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28294','17888','17890');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28295','17891','17893');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28296','17894','17896');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28297','17888','17889');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28298','17891','17892');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28299','17894','17895');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28300','16031','16563');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28301','16045','16564');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28302','16046','16565');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28303','16039','16040');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28304','16061','16063');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28305','16062','16064');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28306','16042','16579');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28307','16067','16580');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28308','16068','16581');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28309','16041','16042');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28310','16065','16067');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28311','16066','16068');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28312','16041','16579');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28313','16065','16580');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28314','16066','16581');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28315','17890','17889');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28316','17893','17892');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28317','17896','17895');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28318','16070','16069');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28319','16072','16071');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28320','16076','16994');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28321','17897','16994');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28322','16079','16077');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28323','16080','16078');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28324','16083','16081');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28325','16084','16082');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28326','16091','16997');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28327','16092','16998');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28328','17898','16997');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28329','17899','16998');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28330','17900','17902');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28331','17903','17905');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28332','17900','17901');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28333','17903','17904');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28334','16097','16569');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28335','16110','16570');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28336','16105','16106');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28337','16118','16119');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28338','16108','16582');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28339','16121','16583');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28340','16107','16108');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28341','16120','16121');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28342','16107','16582');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28343','16120','16583');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28344','17902','17901');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28345','17905','17904');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28346','16123','16122');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28347','16125','16124');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28348','16129','17002');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28349','17906','17002');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28350','16131','16130');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28351','16133','16132');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28352','16137','17004');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28353','17907','17004');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28354','17908','17910');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28355','17908','17909');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28356','16141','16142');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28357','16146','16573');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28358','16143','16584');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28359','17910','17909');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28360','16152','16883');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28361','16153','16883');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28362','17911','16883');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28363','17912','16883');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28364','16156','16155');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28365','16158','16157');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28366','17913','17915');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28367','17916','17918');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28368','17913','17914');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28369','17916','17917');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28370','17915','17914');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28371','17918','17917');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28372','16009','16008');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28373','16011','16010');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28374','16014','16013');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28375','16016','16015');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28376','17005','16160');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28377','17007','16171');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28378','17919','17920');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28379','17921','17922');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28380','16161','16160');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28381','16172','16171');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28382','16162','16161');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28383','16173','16172');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28384','16162','16160');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28385','16173','16171');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28386','16166','17920');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28387','16177','17922');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28388','16167','17920');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28389','16178','17922');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28390','16183','16182');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28391','19663','19666');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28392','19664','19666');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28393','19665','19666');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28394','17009','17662');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28395','17009','17661');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28396','16190','16189');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28397','19667','19670');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28398','19668','19670');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28399','19669','19670');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28400','17010','17664');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28401','17010','17663');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28402','17011','16209');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28403','17013','16220');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28404','17927','17928');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28405','17929','17930');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28406','16210','16209');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28407','16221','16220');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28408','16211','16210');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28409','16222','16221');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28410','16211','16209');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28411','16222','16220');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28412','16215','17928');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28413','16226','17930');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28414','16216','17928');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28415','16227','17930');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28416','16232','16231');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28417','19671','19674');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28418','19672','19674');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28419','19673','19674');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28420','17015','17666');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28421','17015','17665');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28422','16239','16238');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28423','19675','19678');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28424','19676','19678');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28425','19677','19678');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28426','17016','17668');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28427','17016','17667');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28428','18256','18257');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28429','18292','18293');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28430','18328','18329');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28431','18364','18365');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28432','18400','18401');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28433','18436','18437');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28434','18472','18473');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28435','18199','18200');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28436','18511','18512');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28437','18547','18548');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28438','18583','18584');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28439','16768','16769');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28440','16768','16770');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28441','16769','16770');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28442','16771','16772');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28443','16771','16773');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28444','16772','16773');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28445','18966','18967');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28446','18969','18968');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28447','18971','18970');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28448','18972','18970');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28449','18972','18971');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28450','18974','18973');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28451','18975','18976');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28452','18979','18978');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28453','18981','18980');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28454','18982','18983');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28455','18984','18987');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28456','18984','18989');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28457','18984','18985');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28458','18984','18991');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28459','18986','18987');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28460','18986','18989');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28461','18986','18985');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28462','18986','18991');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28463','18988','18987');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28464','18988','18989');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28465','18988','18985');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28466','18988','18991');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28467','18990','18987');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28468','18990','18989');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28469','18990','18985');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28470','18990','18991');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28471','18994','18993');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28472','16488','16487');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28473','16485','16484');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28474','16486','16484');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28475','16486','16485');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28476','16480','16479');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28477','16482','16481');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28478','16475','16474');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28479','16471','16472');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28480','16468','16469');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28481','16459','16460');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28482','16462','16463');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28483','16465','16466');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28484','16477','16476');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28485','19024','19023');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28486','19029','19028');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28487','19030','19028');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28488','19030','19029');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28489','19032','19031');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28490','19033','19032');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28491','19033','19031');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28492','19035','19034');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28493','19037','19038');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28494','19039','19038');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28495','19041','19040');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28496','19043','19042');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28497','19044','19042');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28498','19044','19043');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28499','19046','19045');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28500','19075','19074');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28501','19080','19079');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28502','19081','19079');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28503','19081','19080');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28504','19083','19082');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28505','19084','19083');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28506','19084','19082');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28507','19086','19085');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28508','19088','19089');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28509','19090','19089');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28510','19092','19091');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28511','19094','19093');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28512','19095','19093');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28513','19095','19094');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28514','19097','19096');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28515','19126','19125');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28516','19131','19130');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28517','19132','19130');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28518','19132','19131');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28519','19134','19133');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28520','19135','19134');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28521','19135','19133');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28522','19137','19136');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28523','19139','19140');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28524','19141','19140');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28525','19143','19142');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28526','19145','19144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28527','19146','19144');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28528','19146','19145');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28529','19148','19147');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28530','19177','19176');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28531','19182','19181');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28532','19183','19181');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28533','19183','19182');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28534','19185','19184');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28535','19186','19185');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28536','19186','19184');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28537','19188','19187');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28538','19190','19191');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28539','19192','19191');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28540','19194','19193');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28541','19196','19195');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28542','19197','19195');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28543','19197','19196');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28544','19199','19198');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28545','15729','15728');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28546','15730','15728');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28547','15730','15729');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28548','15752','15754');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28549','15753','15754');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28550','15753','15752');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28551','15742','15741');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28552','15750','15749');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28553','15751','15750');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28554','15751','15749');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28555','15746','15743');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28556','15744','15743');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28557','15740','15739');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28558','17214','17213');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28559','17216','17215');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28560','15748','15747');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28561','19203','19202');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28562','19207','19206');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28563','19209','19208');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28564','19210','19208');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28565','19210','19209');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28566','19212','19211');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28567','19214','19213');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28568','19216','19215');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28569','19218','19219');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28570','19220','19219');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28571','19222','19221');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28572','19245','19244');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28573','19249','19248');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28574','19253','19252');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28575','19255','19254');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28576','19256','19254');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28577','19256','19255');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28578','19258','19257');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28579','19260','19259');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28580','19262','19261');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28581','19264','19265');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28582','19266','19265');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28583','19268','19267');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28584','19291','19290');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28585','19295','19294');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28586','19299','19298');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28587','19301','19300');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28588','19302','19300');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28589','19302','19301');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28590','19304','19303');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28591','19306','19305');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28592','19308','19307');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28593','19310','19311');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28594','19312','19311');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28595','19314','19313');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28596','19337','19336');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28597','19341','19340');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28598','19345','19344');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28599','19347','19346');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28600','19348','19346');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28601','19348','19347');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28602','19350','19349');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28603','19352','19351');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28604','19354','19353');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28605','19356','19357');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28606','19358','19357');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28607','19360','19359');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28608','19383','19382');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28609','16440','16439');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28610','17768','15790');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28611','17769','15787');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28612','17770','15787');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28613','17770','17769');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28614','15786','15785');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28615','15784','15783');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28616','15794','15792');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28617','15793','15792');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28618','15782','15781');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28619','15797','15796');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28620','15825','15824');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28621','15826','15824');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28622','15826','15825');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28623','15828','15829');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28624','15831','15832');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28625','15834','15835');
INSERT INTO trigger_depends (triggerdepid,triggerid_down,triggerid_up) values ('28626','15845','15846');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12723','22853','13336','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12725','22858','13338','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12726','22859','13339','change','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12727','22861','13340','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12739','22893','13352','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12741','22898','13354','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12742','22899','13355','change','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12743','22901','13356','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12755','22933','13368','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12757','22938','13370','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12758','22939','13371','change','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12759','22941','13372','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12771','22973','13384','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12773','22978','13386','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12775','22981','13388','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12787','23013','13400','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12789','23018','13402','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12790','23019','13403','change','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12791','23021','13404','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12803','23053','13416','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12805','23058','13418','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12806','23059','13419','change','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12807','23061','13420','diff','0');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12946','23357','13517','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12947','23342','13518','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12948','23341','13519','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12949','23359','13520','min','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12994','23644','13544','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12995','23645','13545','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12996','23646','13546','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12997','23647','13547','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('12998','23648','13548','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13068','23115','13367','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13069','22922','13366','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13070','22918','13365','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13071','22917','13364','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13072','22882','13350','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13073','22878','13349','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13074','22877','13348','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13075','22962','13382','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13086','23042','13414','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13087','22842','13334','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13088','22838','13333','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13089','22837','13332','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13090','23007','13399','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13091','23002','13398','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13092','22998','13397','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13093','22997','13396','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13152','23651','13551','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13154','23649','13549','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13156','23650','13550','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13157','23652','13552','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13158','23653','13553','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13159','23654','13285','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13206','23347','13521','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13207','23360','13534','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13208','23352','13522','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13209','23351','13535','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13210','23350','13523','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13211','23353','13524','avg','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13212','23354','13525','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13213','23356','13526','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13214','23355','13527','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13215','23349','13528','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13216','23348','13529','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13217','23343','13530','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13218','23344','13531','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13219','23345','13532','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13220','23346','13533','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13224','25368','13564','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('13225','25369','13565','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14378','27067','14251','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14379','27066','14252','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14380','27065','14253','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14468','27149','14293','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14469','27150','14294','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14470','27151','14295','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14508','27192','14311','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14509','27193','14312','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14510','27194','14313','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14515','27212','14318','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14516','27212','14318','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14517','27212','14319','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14518','27212','14319','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14519','27212','14320','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14520','27212','14320','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14522','27214','14322','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14523','27214','14322','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14536','27225','14327','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14537','27226','14328','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14538','27227','14329','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14545','27237','14336','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14546','27237','14336','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14547','27236','14337','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14548','27236','14337','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14552','27247','14339','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14553','27247','14339','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14554','27247','14340','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14555','27247','14340','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14570','27261','14347','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14571','27262','14348','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14572','27263','14349','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14587','27282','14356','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14588','27283','14357','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14589','27284','14358','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14594','27296','14363','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14595','27296','14363','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14596','27295','14364','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14597','27295','14364','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14598','27297','14365','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14599','27297','14365','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14606','27314','14372','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14607','27314','14372','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14608','27314','14373','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14609','27314','14373','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14610','27314','14374','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14611','27314','14374','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14620','27318','14380','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14621','27318','14380','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14622','27318','14381','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14623','27318','14381','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14624','27318','14382','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14625','27318','14382','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14626','27320','14383','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14627','27320','14383','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14641','27333','14389','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14642','27334','14390','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14643','27335','14391','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14663','27365','14403','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14664','27366','14404','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14665','27367','14405','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14669','27378','14409','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14670','27378','14409','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14672','27385','14411','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14673','27385','14411','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14676','27382','14413','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14677','27382','14413','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14681','27419','14417','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14682','27419','14417','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14698','27428','14428','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14699','27428','14428','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14702','27445','14430','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14703','27445','14430','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14747','27462','14451','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14748','27463','14452','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14749','27464','14453','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14756','27485','14460','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14757','27485','14460','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14758','27485','14461','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14759','27485','14461','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14760','27485','14462','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14761','27485','14462','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14762','27483','14463','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14763','27483','14463','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14776','27496','14468','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14777','27497','14469','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14778','27498','14470','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14782','27509','14474','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14783','27509','14474','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14785','27517','14476','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14786','27517','14476','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14787','27517','14477','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14788','27517','14477','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14789','27517','14478','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14790','27517','14478','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14806','27532','14486','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14807','27533','14487','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14808','27534','14488','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14812','27545','14492','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14813','27545','14492','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14814','27544','14493','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14815','27544','14493','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14817','27553','14495','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14818','27553','14495','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14819','27553','14496','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14820','27553','14496','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14821','27553','14497','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14822','27553','14497','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14838','27568','14505','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14839','27569','14506','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14840','27570','14507','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14844','27584','14511','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14845','27584','14511','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14849','27584','14513','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14850','27584','14513','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14851','27582','14514','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14852','27582','14514','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14853','27579','14515','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14854','27579','14515','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14889','27631','14534','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14890','27632','14535','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14891','27633','14536','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14907','27654','14544','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14908','27655','14545','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14909','27656','14546','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14914','27672','14551','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14915','27672','14551','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14916','27672','14552','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14917','27672','14552','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14918','27672','14553','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14919','27672','14553','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14922','27678','14556','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14923','27678','14556','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14924','27677','14557','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14925','27677','14557','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14972','27734','14582','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14973','27735','14583','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14974','27736','14584','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14979','27751','14589','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14980','27751','14589','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14981','27751','14590','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14982','27751','14590','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14983','27751','14591','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14984','27751','14591','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14985','27750','14592','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('14986','27750','14592','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15000','27766','14598','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15001','27767','14599','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15002','27768','14600','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15005','27777','14603','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15006','27777','14603','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15013','27784','14606','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15014','27784','14606','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15015','27785','14607','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15016','27785','14607','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15032','27800','14615','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15033','27801','14616','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15034','27802','14617','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15038','27813','14621','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15039','27813','14621','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15042','27821','14624','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15043','27821','14624','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15044','27821','14625','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15045','27821','14625','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15046','27821','14626','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15047','27821','14626','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15094','27882','14652','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15095','27883','14653','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15096','27884','14654','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15106','27894','14661','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15107','27894','14661','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15108','27895','14662','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15109','27895','14662','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15111','27905','14664','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15112','27905','14664','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15113','27905','14665','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15114','27905','14665','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15115','27905','14666','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15116','27905','14666','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15131','27919','14673','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15132','27920','14674','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15133','27921','14675','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15138','27931','14680','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15139','27931','14680','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15146','27941','14683','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15147','27941','14683','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15163','27956','14691','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15164','27957','14692','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15165','27958','14693','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15170','27970','14698','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15171','27970','14698','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15172','27967','14699','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15173','27967','14699','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15186','27986','14704','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15187','27987','14705','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15188','27988','14706','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15191','27999','14709','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15192','27999','14709','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15193','27998','14710','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15194','27998','14710','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15209','28015','14717','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15210','28016','14718','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15211','28017','14719','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15216','28027','14724','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15217','28027','14724','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15678','28130','14906','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15679','28131','14907','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15680','28132','14908','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15684','28142','14912','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15685','28142','14912','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15686','28141','14913','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15687','28141','14913','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15688','28150','14914','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15689','28150','14914','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15690','28150','14915','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15691','28150','14915','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15692','28150','14916','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15693','28150','14916','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15726','28204','14937','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15727','28204','14937','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15731','27032','14941','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15732','27191','14942','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15733','27332','14943','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15734','27461','14944','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15735','27531','14945','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15736','27567','14946','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15737','27630','14947','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15738','27653','14948','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15739','27733','14949','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15740','27799','14950','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15741','27955','14951','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('15743','28129','14953','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16445','28210','15208','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16446','28210','15208','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16447','28208','15209','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16448','28208','15209','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16472','28233','15220','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16473','28234','15221','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16474','28235','15222','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16818','27213','15330','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16819','27479','15331','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16820','27479','15332','count','#1,{$PSU_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16821','27480','15333','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16822','27480','15334','count','#1,{$FAN_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16829','27786','15337','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16830','27786','15338','count','#1,{$PSU_WARN_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16831','27787','15339','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16832','27554','15340','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16833','27555','15341','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16840','27422','15344','count','#1,{$PSU_CRIT_STATUS:"critical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16841','27422','15344','count','#1,{$PSU_CRIT_STATUS:"shutdown"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16842','27422','15345','count','#1,{$PSU_WARN_STATUS:"warning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16843','27422','15345','count','#1,{$PSU_WARN_STATUS:"notFunctioning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16844','27423','15346','count','#1,{$FAN_CRIT_STATUS:"critical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16845','27423','15346','count','#1,{$FAN_CRIT_STATUS:"shutdown"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16846','27423','15347','count','#1,{$FAN_WARN_STATUS:"warning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16847','27423','15347','count','#1,{$FAN_WARN_STATUS:"notFunctioning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16866','27431','15354','count','#1,{$PSU_CRIT_STATUS:"critical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16867','27431','15354','count','#1,{$PSU_CRIT_STATUS:"shutdown"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16868','27448','15355','count','#1,{$PSU_CRIT_STATUS:"critical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16869','27448','15355','count','#1,{$PSU_CRIT_STATUS:"shutdown"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16870','28216','15356','count','#1,{$PSU_CRIT_STATUS:"critical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16871','28216','15356','count','#1,{$PSU_CRIT_STATUS:"shutdown"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16872','27431','15357','count','#1,{$PSU_WARN_STATUS:"warning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16873','27431','15357','count','#1,{$PSU_WARN_STATUS:"notFunctioning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16874','27448','15358','count','#1,{$PSU_WARN_STATUS:"warning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16875','27448','15358','count','#1,{$PSU_WARN_STATUS:"notFunctioning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16876','28216','15359','count','#1,{$PSU_WARN_STATUS:"warning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16877','28216','15359','count','#1,{$PSU_WARN_STATUS:"notFunctioning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16878','27432','15360','count','#1,{$FAN_CRIT_STATUS:"critical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16879','27432','15360','count','#1,{$FAN_CRIT_STATUS:"shutdown"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16880','27449','15361','count','#1,{$FAN_CRIT_STATUS:"critical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16881','27449','15361','count','#1,{$FAN_CRIT_STATUS:"shutdown"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16882','28215','15362','count','#1,{$FAN_CRIT_STATUS:"critical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16883','28215','15362','count','#1,{$FAN_CRIT_STATUS:"shutdown"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16884','27432','15363','count','#1,{$FAN_WARN_STATUS:"warning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16885','27432','15363','count','#1,{$FAN_WARN_STATUS:"notFunctioning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16886','27449','15364','count','#1,{$FAN_WARN_STATUS:"warning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16887','27449','15364','count','#1,{$FAN_WARN_STATUS:"notFunctioning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16888','28215','15365','count','#1,{$FAN_WARN_STATUS:"warning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16889','28215','15365','count','#1,{$FAN_WARN_STATUS:"notFunctioning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16890','27518','15366','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16891','27519','15367','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16895','27593','15369','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16896','27595','15370','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16897','27673','15371','count','#1,{$FAN_CRIT_STATUS:"fanError"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16898','27673','15371','count','#1,{$FAN_CRIT_STATUS:"hardwareFaulty"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16899','27674','15372','count','#1,{$PSU_CRIT_STATUS:"psuError"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16900','27674','15372','count','#1,{$PSU_CRIT_STATUS:"rpsError"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16901','27674','15372','count','#1,{$PSU_CRIT_STATUS:"hardwareFaulty"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16902','28154','15373','count','#1,{$FAN_CRIT_STATUS:"bad"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16903','28154','15374','count','#1,{$FAN_WARN_STATUS:"warning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16904','28155','15375','count','#1,{$PSU_CRIT_STATUS:"bad"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16905','28155','15376','count','#1,{$PSU_WARN_STATUS:"warning"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16906','27822','15377','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16907','27823','15378','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16908','27312','15379','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16909','27312','15380','count','#1,{$PSU_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16910','27313','15381','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16911','27313','15382','count','#1,{$FAN_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16912','27316','15383','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16913','27316','15384','count','#1,{$PSU_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16914','27317','15385','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16915','27317','15386','count','#1,{$FAN_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16924','27248','15391','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16925','27248','15392','count','#1,{$PSU_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16926','27250','15393','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16927','27250','15394','count','#1,{$FAN_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16928','27755','15395','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16935','27942','15398','count','#1,{$FAN_CRIT_STATUS:"failed"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('16936','27943','15399','count','#1,{$PSU_CRIT_STATUS:"failed"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17243','28013','15493','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17244','28013','15493','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17657','28251','15640','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17658','28250','15641','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17692','27101','15671','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17693','27101','15671','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17694','27100','15671','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17695','27107','15671','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17696','27101','15671','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17697','27187','15672','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17698','27187','15672','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17699','27189','15672','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17700','27188','15672','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17701','27187','15672','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17702','27222','15673','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17703','27222','15673','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17704','27224','15673','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17705','27223','15673','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17706','27222','15673','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17707','27258','15674','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17708','27258','15674','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17709','27260','15674','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17710','27259','15674','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17711','27258','15674','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17712','27279','15675','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17713','27279','15675','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17714','27281','15675','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17715','27280','15675','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17716','27279','15675','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17717','27328','15676','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17718','27328','15676','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17719','27330','15676','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17720','27329','15676','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17721','27328','15676','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17722','27457','15677','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17723','27457','15677','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17724','27459','15677','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17725','27458','15677','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17726','27457','15677','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17727','27493','15678','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17728','27493','15678','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17729','27495','15678','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17730','27494','15678','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17731','27493','15678','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17732','27527','15679','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17733','27527','15679','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17734','27529','15679','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17735','27528','15679','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17736','27527','15679','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17737','27563','15680','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17738','27563','15680','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17739','27565','15680','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17740','27564','15680','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17741','27563','15680','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17742','27649','15681','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17743','27649','15681','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17744','27651','15681','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17745','27650','15681','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17746','27649','15681','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17747','27729','15682','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17748','27729','15682','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17749','27731','15682','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17750','27730','15682','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17751','27729','15682','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17752','27763','15683','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17753','27763','15683','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17754','27765','15683','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17755','27764','15683','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17756','27763','15683','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17757','27795','15684','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17758','27795','15684','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17759','27797','15684','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17760','27796','15684','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17761','27795','15684','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17762','27879','15685','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17763','27879','15685','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17764','27881','15685','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17765','27880','15685','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17766','27879','15685','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17767','27916','15686','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17768','27916','15686','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17769','27918','15686','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17770','27917','15686','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17771','27916','15686','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17772','27951','15687','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17773','27951','15687','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17774','27953','15687','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17775','27952','15687','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17776','27951','15687','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17782','28125','15689','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17783','28125','15689','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17784','28127','15689','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17785','28126','15689','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17786','28125','15689','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17792','28230','15691','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17793','28230','15691','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17794','28232','15691','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17795','28231','15691','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17796','28230','15691','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17807','28012','15694','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17808','28012','15694','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17809','28014','15694','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17810','28013','15694','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17811','28012','15694','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17812','27081','15695','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17813','27081','15695','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17814','27080','15695','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17815','27087','15695','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17816','27081','15695','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17817','27626','15696','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17818','27626','15696','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17819','27628','15696','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17820','27627','15696','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17821','27626','15696','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17822','27983','15697','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17823','27983','15697','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17824','27985','15697','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17825','27984','15697','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17826','27983','15697','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17827','27121','15698','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17828','27121','15698','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17829','27120','15698','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17830','27127','15698','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17831','27121','15698','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17837','28281','15700','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17838','28282','15701','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17839','28283','15702','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17840','28284','15703','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17848','28300','15708','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17849','28300','15708','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17850','28302','15708','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17851','28301','15708','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17852','28300','15708','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17866','28326','15717','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17867','28328','15718','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17868','28328','15718','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17869','28329','15719','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17870','27238','15720','count','#1,{$HEALTH_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17871','27238','15721','count','#1,{$HEALTH_WARN_STATUS:"offline"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17872','27238','15721','count','#1,{$HEALTH_WARN_STATUS:"testing"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17873','27814','15722','count','#1,{$HEALTH_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17874','28330','15723','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17875','28331','15724','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17876','28332','15725','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17879','28341','15728','count','#1,{$HEALTH_DISASTER_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17880','28341','15729','count','#1,{$HEALTH_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17881','28341','15730','count','#1,{$HEALTH_WARN_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17882','28344','15731','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17883','28344','15731','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17884','28345','15732','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17885','28345','15732','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17892','28354','15735','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17893','28354','15735','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17900','28356','15738','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17901','28356','15738','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17902','28358','15739','count','#1,{$PSU_CRIT_STATUS:"critical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17903','28358','15739','count','#1,{$PSU_CRIT_STATUS:"nonRecoverable"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17904','28358','15740','count','#1,{$PSU_WARN_STATUS:"nonCritical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17905','28359','15741','count','#1,{$FAN_CRIT_STATUS:"criticalUpper"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17906','28359','15741','count','#1,{$FAN_CRIT_STATUS:"nonRecoverableUpper"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17907','28359','15741','count','#1,{$FAN_CRIT_STATUS:"criticalLower"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17908','28359','15741','count','#1,{$FAN_CRIT_STATUS:"nonRecoverableLower"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17909','28359','15741','count','#1,{$FAN_CRIT_STATUS:"failed"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17910','28359','15742','count','#1,{$FAN_WARN_STATUS:"nonCriticalUpper"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17911','28359','15742','count','#1,{$FAN_WARN_STATUS:"nonCriticalLower"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17912','28361','15743','count','#1,{$DISK_FAIL_STATUS:"critical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17913','28361','15743','count','#1,{$DISK_FAIL_STATUS:"nonRecoverable"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17914','28361','15744','count','#1,{$DISK_WARN_STATUS:"nonCritical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17915','28362','15745','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17916','28362','15745','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17917','28363','15746','count','#1,{$DISK_SMART_FAIL_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17918','28373','15747','count','#1,{$VDISK_CRIT_STATUS:"failed"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17919','28373','15748','count','#1,{$VDISK_WARN_STATUS:"degraded"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17920','28374','15749','count','#1,{$DISK_ARRAY_FAIL_STATUS:"nonRecoverable"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17921','28374','15750','count','#1,{$DISK_ARRAY_CRIT_STATUS:"critical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17922','28374','15751','count','#1,{$DISK_ARRAY_WARN_STATUS:"nonCritical"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17923','28376','15752','count','#1,{$DISK_ARRAY_CACHE_BATTERY_WARN_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17924','28376','15753','count','#1,{$DISK_ARRAY_CACHE_BATTERY_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17925','28376','15754','count','#1,{$DISK_ARRAY_CACHE_BATTERY_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17926','28377','15755','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17927','28378','15756','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17928','28379','15757','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17933','28391','15762','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17934','28391','15762','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17971','28411','15781','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17972','28411','15782','count','#1,{$PSU_WARN_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17973','28412','15783','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17974','28412','15784','count','#1,{$FAN_WARN_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17975','28413','15785','count','#1,{$DISK_ARRAY_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17976','28413','15786','count','#1,{$DISK_ARRAY_WARN_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17977','28415','15787','count','#1,{$DISK_ARRAY_CACHE_CRIT_STATUS:"cacheModCriticalFailure"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17983','28416','15790','count','#1,{$DISK_ARRAY_CACHE_BATTERY_CRIT_STATUS:"failed"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17984','28416','15790','count','#1,{$DISK_ARRAY_CACHE_BATTERY_CRIT_STATUS:"capacitorFailed"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17987','28417','15792','count','#1,{$DISK_FAIL_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17988','28417','15793','count','#1,{$DISK_WARN_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17989','28418','15794','count','#1,{$DISK_SMART_FAIL_STATUS:"replaceDrive"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17990','28418','15794','count','#1,{$DISK_SMART_FAIL_STATUS:"replaceDriveSSDWearOut"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17991','28419','15795','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17992','28419','15795','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17993','28423','15796','count','#1,{$VDISK_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('17994','28423','15797','count','#1,{$VDISK_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18026','28454','15819','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18027','28455','15820','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18028','28456','15821','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18031','28465','15824','count','#1,{$HEALTH_DISASTER_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18032','28465','15825','count','#1,{$HEALTH_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18033','28465','15826','count','#1,{$HEALTH_WARN_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18034','28467','15827','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18035','28467','15827','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18036','28474','15828','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18037','28474','15828','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18038','28474','15829','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18039','28474','15829','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18040','28474','15830','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18041','28474','15830','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18042','28475','15831','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18043','28475','15831','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18044','28475','15832','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18045','28475','15832','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18046','28475','15833','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18047','28475','15833','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18048','28476','15834','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18049','28476','15834','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18050','28476','15835','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18051','28476','15835','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18052','28476','15836','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18053','28476','15836','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18054','28477','15837','count','#1,{$PSU_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18055','28478','15838','count','#1,{$FAN_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18056','28480','15839','count','#1,{$DISK_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18057','28482','15840','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18058','28483','15841','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18059','28484','15842','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18062','28495','15845','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18063','28495','15845','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18064','28495','15846','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18065','28495','15846','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18066','28495','15847','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18067','28495','15847','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18113','28599','15890','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18114','28597','15891','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18115','28596','15892','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18116','28598','15893','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18117','28587','15894','min','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18118','28600','15895','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18119','28601','15896','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18120','28615','15897','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18121','28614','15898','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18122','28613','15899','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18123','28612','15900','avg','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18124','28611','15901','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18125','28610','15902','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18126','28609','15903','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18127','28608','15904','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18128','28607','15905','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18129','28606','15906','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18130','28605','15907','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18131','28604','15908','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18132','28603','15909','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18133','28602','15910','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18134','28616','15911','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18135','28588','15912','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18136','28618','15913','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18137','28619','15914','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18150','28681','15926','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18151','28680','15927','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18152','28680','15927','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18153','28682','15928','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18154','28679','15929','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18155','28699','15930','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18156','28673','15931','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18157','28684','15932','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18158','28674','15933','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18159','28677','15934','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18160','28709','15935','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18161','28685','15936','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18162','28685','15936','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18164','28716','15938','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18165','28715','15939','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18166','28724','15940','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18167','28741','15941','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18169','28743','15943','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18170','28748','15944','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18174','28746','15947','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18175','28775','15948','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18176','28776','15949','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18177','28777','15950','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18178','28791','15951','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18179','28790','15952','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18180','28790','15952','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18183','28810','15954','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18184','28805','15955','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18185','28816','15956','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18186','28809','15957','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18187','28820','15958','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18188','28820','15958','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18191','28822','15960','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18192','28823','15961','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18193','28827','15962','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18194','28833','15963','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18195','28833','15963','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18211','28913','15978','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18212','28941','15979','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18213','28939','15980','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18214','28922','15981','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18215','28927','15982','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18216','28910','15983','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18217','28909','15984','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18218','28909','15984','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18219','28952','15985','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18220','28953','15986','count','#1,"Yes",ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18221','28953','15987','count','#1,"No",eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18222','28954','15988','count','#1,"No",eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18223','28956','15989','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18224','28957','15990','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18225','28958','15991','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18226','28959','15992','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18234','28975','15997','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18235','28975','15997','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18236','28977','15997','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18237','28976','15997','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18238','28975','15997','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18255','29048','16007','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18256','29029','16008','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18257','29028','16008','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18258','29027','16008','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18259','29029','16008','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18260','29029','16009','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18261','29028','16009','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18262','29027','16009','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18263','29029','16009','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18264','29030','16010','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18265','29030','16011','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18266','29049','16012','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18267','29046','16013','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18268','29045','16013','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18269','29044','16013','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18270','29046','16013','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18271','29046','16014','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18272','29045','16014','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18273','29044','16014','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18274','29046','16014','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18275','29047','16015','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18276','29047','16016','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18277','29050','16017','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18278','29051','16018','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18279','29052','16019','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18291','29084','16028','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18292','29084','16028','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18293','29086','16028','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18294','29085','16028','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18295','29084','16028','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18300','29198','16031','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18306','29110','16035','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18307','29112','16036','fuzzytime','{$SYSTEM.FUZZYTIME.MAX}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18310','29116','16038','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18311','29117','16039','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18312','29118','16040','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18313','29117','16040','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18314','29120','16041','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18315','29121','16042','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18316','29121','16042','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18321','29199','16045','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18322','29200','16046','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18333','29147','16053','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18334','29184','16054','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18335','29149','16055','fuzzytime','{$SYSTEM.FUZZYTIME.MAX}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18336','29186','16056','fuzzytime','{$SYSTEM.FUZZYTIME.MAX}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18341','29153','16059','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18342','29190','16060','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18343','29154','16061','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18344','29191','16062','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18345','29155','16063','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18346','29154','16063','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18347','29192','16064','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18348','29191','16064','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18349','29157','16065','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18350','29194','16066','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18351','29158','16067','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18352','29158','16067','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18353','29195','16068','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18354','29195','16068','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18355','29212','16069','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18356','29211','16069','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18357','29210','16069','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18358','29212','16069','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18359','29212','16070','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18360','29211','16070','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18361','29210','16070','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18362','29212','16070','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18363','29213','16071','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18364','29213','16072','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18372','29223','16076','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18373','29223','16076','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18374','29222','16076','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18375','29223','16076','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18376','29226','16077','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18377','29225','16077','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18378','29224','16077','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18379','29226','16077','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18380','29240','16078','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18381','29239','16078','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18382','29238','16078','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18383','29240','16078','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18384','29226','16079','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18385','29225','16079','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18386','29224','16079','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18387','29226','16079','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18388','29240','16080','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18389','29239','16080','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18390','29238','16080','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18391','29240','16080','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18392','29227','16081','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18393','29241','16082','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18394','29227','16083','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18395','29241','16084','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18410','29237','16091','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18411','29237','16091','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18412','29236','16091','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18413','29237','16091','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18414','29251','16092','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18415','29251','16092','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18416','29250','16092','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18417','29251','16092','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18423','29347','16097','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18429','29296','16101','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18430','29298','16102','fuzzytime','{$SYSTEM.FUZZYTIME.MAX}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18433','29302','16104','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18434','29303','16105','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18435','29304','16106','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18436','29303','16106','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18437','29306','16107','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18438','29307','16108','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18439','29307','16108','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18442','29348','16110','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18448','29333','16114','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18449','29335','16115','fuzzytime','{$SYSTEM.FUZZYTIME.MAX}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18452','29339','16117','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18453','29340','16118','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18454','29341','16119','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18455','29340','16119','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18456','29343','16120','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18457','29344','16121','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18458','29344','16121','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18459','29357','16122','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18460','29356','16122','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18461','29355','16122','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18462','29357','16122','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18463','29357','16123','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18464','29356','16123','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18465','29355','16123','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18466','29357','16123','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18467','29358','16124','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18468','29358','16125','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18476','29368','16129','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18477','29368','16129','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18478','29367','16129','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18479','29368','16129','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18480','29371','16130','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18481','29370','16130','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18482','29369','16130','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18483','29371','16130','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18484','29371','16131','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18485','29370','16131','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18486','29369','16131','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18487','29371','16131','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18488','29372','16132','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18489','29372','16133','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18497','29382','16137','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18498','29382','16137','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18499','29381','16137','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18500','29382','16137','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18501','29395','16138','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18502','29398','16139','fuzzytime','{$SYSTEM.FUZZYTIME.MAX}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18505','29424','16141','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18506','29423','16142','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18507','29424','16142','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18508','29428','16143','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18509','29428','16143','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18510','29421','16144','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18513','29427','16146','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18526','29442','16152','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18527','29442','16152','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18528','29443','16152','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18529','29444','16152','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18530','29442','16152','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18531','29443','16153','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18532','29443','16153','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18533','29444','16153','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18534','29443','16153','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18537','29433','16155','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18538','29446','16155','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18539','29432','16155','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18540','29433','16155','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18541','29433','16156','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18542','29446','16156','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18543','29432','16156','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18544','29433','16156','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18545','29447','16157','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18546','29447','16158','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18548','29454','16160','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18549','29455','16161','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18550','29457','16162','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18555','29467','16166','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18556','29469','16167','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18557','29472','16168','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18558','29473','16169','fuzzytime','{$SYSTEM.FUZZYTIME.MAX}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18561','29480','16171','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18562','29481','16172','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18563','29483','16173','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18568','29493','16177','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18569','29495','16178','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18570','29498','16179','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18571','29499','16180','fuzzytime','{$SYSTEM.FUZZYTIME.MAX}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18574','29514','16182','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18575','29513','16182','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18576','29512','16182','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18577','29514','16182','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18578','29514','16183','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18579','29513','16183','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18580','29512','16183','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18581','29514','16183','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18597','29523','16189','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18598','29522','16189','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18599','29521','16189','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18600','29523','16189','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18601','29523','16190','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18602','29522','16190','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18603','29521','16190','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18604','29523','16190','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18620','29544','16196','max','{$AGENT.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18621','29547','16197','nodata','{$AGENT.NODATA_TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18622','29548','16198','max','{$AGENT.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18623','29557','16199','max','{$AGENT.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18624','29549','16200','max','{$AGENT.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18625','29550','16201','max','{$AGENT.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18626','29551','16202','max','{$AGENT.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18627','29552','16203','max','{$AGENT.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18628','29553','16204','max','{$AGENT.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18629','29554','16205','max','{$AGENT.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18630','29555','16206','max','{$AGENT.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18632','29559','16208','nodata','{$AGENT.NODATA_TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18633','29561','16209','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18634','29562','16210','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18635','29564','16211','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18640','29574','16215','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18641','29576','16216','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18642','29579','16217','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18643','29580','16218','fuzzytime','{$SYSTEM.FUZZYTIME.MAX}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18646','29587','16220','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18647','29588','16221','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18648','29590','16222','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18653','29600','16226','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18654','29602','16227','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18655','29605','16228','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18656','29606','16229','fuzzytime','{$SYSTEM.FUZZYTIME.MAX}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18659','29621','16231','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18660','29620','16231','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18661','29619','16231','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18662','29621','16231','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18663','29621','16232','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18664','29620','16232','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18665','29619','16232','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18666','29621','16232','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18682','29630','16238','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18683','29629','16238','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18684','29628','16238','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18685','29630','16238','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18686','29630','16239','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18687','29629','16239','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18688','29628','16239','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18689','29630','16239','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18711','29696','16250','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18712','29695','16251','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18715','29692','16254','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18716','29659','16255','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18717','29655','16256','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18718','29660','16257','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18719','29720','16258','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18720','29738','16259','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18726','29771','16264','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18727','29775','16265','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18730','29772','16268','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18731','29742','16269','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18732','29743','16270','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18733','29803','16271','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18742','29834','16279','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18751','28025','16285','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18753','29844','16287','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18756','27154','16289','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18757','29849','16290','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18758','29854','16291','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18759','29859','16292','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18760','29864','16293','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18761','29869','16294','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18762','29874','16295','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18763','29879','16296','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18764','29884','16297','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18765','29889','16298','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18766','29894','16299','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18767','29899','16300','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18768','29904','16301','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18769','29909','16302','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18770','29914','16303','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18771','29919','16304','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18772','29924','16305','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18773','29929','16306','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18774','29934','16307','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18775','29939','16308','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18776','29944','16309','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18778','29954','16311','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18779','29959','16312','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18780','29964','16313','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18781','29969','16314','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18782','29974','16315','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18783','29979','16316','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18784','29984','16317','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18785','29989','16318','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18844','27202','16348','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18845','27235','16349','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18846','27271','16350','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18847','27292','16351','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18848','27343','16352','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18849','27375','16353','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18850','27472','16354','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18851','27506','16355','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18852','27542','16356','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18853','27578','16357','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18854','27641','16358','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18855','27664','16359','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18856','27744','16360','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18857','27776','16361','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18858','27810','16362','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18859','27892','16363','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18860','27929','16364','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18861','27966','16365','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18862','27996','16366','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18863','28140','16367','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18865','28243','16369','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18866','28292','16370','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18867','28340','16371','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18868','28387','16372','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18869','28464','16373','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18870','28492','16374','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18871','28967','16375','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('18872','29060','16376','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19090','29994','16439','count','#1,{$HEALTH_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19091','29994','16440','count','#1,{$HEALTH_WARN_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19092','29996','16441','nodata','{$AGENT.NODATA_TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19093','29998','16442','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19094','29654','16443','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19095','29662','16444','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19096','30025','16445','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19097','30025','16445','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19098','29693','16446','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19099','29688','16447','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19100','29741','16448','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19101','29744','16449','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19102','30045','16450','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19103','30045','16450','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19104','29774','16451','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19105','29773','16452','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19106','30046','16453','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19107','30047','16454','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19108','30048','16455','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19111','30055','16457','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19112','30056','16458','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19113','30066','16459','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19114','30066','16459','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19115','30066','16460','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19116','30066','16460','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19117','30066','16461','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19118','30066','16461','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19119','30067','16462','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19120','30067','16462','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19121','30067','16463','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19122','30067','16463','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19123','30067','16464','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19124','30067','16464','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19125','30068','16465','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19126','30068','16465','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19127','30068','16466','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19128','30068','16466','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19129','30068','16467','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19130','30068','16467','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19131','30069','16468','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19132','30069','16468','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19133','30069','16469','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19134','30069','16469','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19135','30069','16470','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19136','30069','16470','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19137','30070','16471','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19138','30070','16471','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19139','30070','16472','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19140','30070','16472','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19141','30070','16473','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19142','30070','16473','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19143','30071','16474','count','#1,{$PSU_CRIT_STATUS:"inoperable"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19144','30071','16475','count','#1,{$PSU_WARN_STATUS:"degraded"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19145','30072','16476','count','#1,{$HEALTH_CRIT_STATUS:"computeFailed"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19146','30072','16476','count','#1,{$HEALTH_CRIT_STATUS:"configFailure"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19147','30072','16476','count','#1,{$HEALTH_CRIT_STATUS:"unconfigFailure"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19148','30072','16476','count','#1,{$HEALTH_CRIT_STATUS:"inoperable"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19149','30072','16477','count','#1,{$HEALTH_WARN_STATUS:"testFailed"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19150','30072','16477','count','#1,{$HEALTH_WARN_STATUS:"thermalProblem"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19151','30072','16477','count','#1,{$HEALTH_WARN_STATUS:"powerProblem"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19152','30072','16477','count','#1,{$HEALTH_WARN_STATUS:"voltageProblem"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19153','30072','16477','count','#1,{$HEALTH_WARN_STATUS:"diagnosticsFailed"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19154','30074','16478','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19155','30074','16478','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19156','30075','16479','count','#1,{$FAN_CRIT_STATUS:"inoperable"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19157','30075','16480','count','#1,{$FAN_WARN_STATUS:"degraded"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19158','30076','16481','count','#1,{$DISK_FAIL_STATUS:"failed"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19159','30076','16482','count','#1,{$DISK_CRIT_STATUS:"bad"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19160','30076','16482','count','#1,{$DISK_CRIT_STATUS:"predictiveFailure"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19161','30080','16483','count','#1,{$VDISK_OK_STATUS:"equipped"},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19162','30083','16484','count','#1,{$DISK_ARRAY_CRIT_STATUS:"inoperable"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19163','30083','16485','count','#1,{$DISK_ARRAY_WARN_STATUS:"degraded"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19164','30083','16486','count','#1,{$DISK_ARRAY_OK_STATUS:"operable"},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19165','30085','16487','count','#1,{$DISK_ARRAY_CACHE_BATTERY_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19166','30085','16488','count','#1,{$DISK_ARRAY_CACHE_BATTERY_OK_STATUS},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19171','27208','16491','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19172','30086','16492','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19173','30086','16492','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19175','30091','16494','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19176','30092','16495','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19177','27240','16496','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19179','27294','16498','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19181','27299','16500','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19182','27301','16501','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19185','27315','16504','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19186','27315','16504','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19187','27315','16505','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19188','27315','16505','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19189','27315','16506','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19190','27315','16506','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19191','30097','16507','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19192','30097','16507','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19193','27376','16508','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19194','30098','16509','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19195','30098','16509','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19196','30099','16510','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19197','30099','16510','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19198','30100','16511','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19199','30100','16511','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19200','27380','16512','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19202','28246','16514','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19203','27417','16515','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19207','28247','16519','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19208','27427','16520','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19209','27478','16521','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19211','27481','16523','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19212','27481','16523','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19213','27511','16524','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19214','30106','16525','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19215','30106','16525','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19217','27547','16527','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19219','27586','16529','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19220','30109','16530','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19221','30109','16530','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19223','27675','16532','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19224','27675','16532','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19225','27671','16533','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19227','28143','16535','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19229','27753','16537','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19230','27749','16538','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19231','27749','16538','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19233','30117','16540','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19234','30117','16540','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19235','28894','16541','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19237','30119','16543','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19238','30119','16543','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19240','27904','16545','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19241','27906','16546','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19242','27907','16546','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19243','27908','16546','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19244','27906','16546','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19245','27906','16547','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19246','27907','16547','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19247','27908','16547','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19248','27906','16547','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19249','27936','16548','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19250','30121','16549','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19251','30121','16549','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19253','30124','16551','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19254','30124','16551','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19255','30124','16552','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19256','30124','16552','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19257','30124','16553','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19258','30124','16553','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19259','27975','16554','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19260','30125','16555','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19261','30125','16555','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19263','30129','16557','count','#1,{$FAN_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19264','30130','16558','count','#1,{$PSU_CRIT_STATUS},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19265','28003','16559','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19267','28031','16561','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19269','29096','16563','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19270','29087','16563','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19271','29101','16563','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19272','29100','16563','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19273','29133','16564','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19274','29124','16564','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19275','29138','16564','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19276','29137','16564','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19277','29170','16565','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19278','29161','16565','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19279','29175','16565','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19280','29174','16565','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19287','29282','16569','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19288','29273','16569','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19289','29287','16569','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19290','29286','16569','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19291','29319','16570','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19292','29310','16570','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19293','29324','16570','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19294','29323','16570','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19299','29420','16573','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19300','29417','16573','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19301','29419','16573','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19302','29418','16573','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19305','28987','16575','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19306','28990','16575','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19307','28988','16575','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19308','28989','16575','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19309','29002','16576','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19310','29005','16576','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19311','29003','16576','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19312','29004','16576','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19313','30141','16577','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19314','30141','16577','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19316','29113','16579','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19317','29113','16579','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19318','29150','16580','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19319','29150','16580','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19320','29187','16581','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19321','29187','16581','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19322','29299','16582','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19323','29299','16582','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19324','29336','16583','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19325','29336','16583','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19326','29414','16584','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19327','29414','16584','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19328','29474','16585','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19329','29474','16585','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19330','29500','16586','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19331','29500','16586','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19332','29581','16587','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19333','29581','16587','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19334','29607','16588','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19335','29607','16588','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19340','28022','16591','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19341','28022','16591','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19344','27152','16593','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19345','27152','16593','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19346','27199','16594','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19347','27199','16594','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19348','27232','16595','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19349','27232','16595','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19350','27268','16596','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19351','27268','16596','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19352','27289','16597','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19353','27289','16597','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19354','27340','16598','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19355','27340','16598','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19356','27372','16599','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19357','27372','16599','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19358','27469','16600','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19359','27469','16600','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19360','27503','16601','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19361','27503','16601','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19362','27539','16602','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19363','27539','16602','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19364','27575','16603','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19365','27575','16603','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19366','27638','16604','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19367','27638','16604','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19368','27661','16605','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19369','27661','16605','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19370','27741','16606','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19371','27741','16606','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19372','27773','16607','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19373','27773','16607','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19374','27807','16608','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19375','27807','16608','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19376','27889','16609','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19377','27889','16609','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19378','27926','16610','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19379','27926','16610','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19380','27963','16611','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19381','27963','16611','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19382','27993','16612','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19383','27993','16612','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19384','28137','16613','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19385','28137','16613','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19388','28240','16615','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19389','28240','16615','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19390','28289','16616','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19391','28289','16616','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19392','28337','16617','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19393','28337','16617','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19394','28384','16618','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19395','28384','16618','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19396','28461','16619','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19397','28461','16619','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19398','28489','16620','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19399','28489','16620','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19400','28964','16621','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19401','28964','16621','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19402','29057','16622','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19403','29057','16622','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19404','30053','16623','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19405','30053','16623','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19406','30142','16624','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19407','30143','16625','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19409','30145','16627','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19410','30146','16628','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19412','30160','16630','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19413','30161','16630','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19414','30162','16630','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19415','30160','16630','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19416','30160','16631','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19417','30161','16631','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19418','30162','16631','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19419','30160','16631','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19424','30166','16636','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19425','30167','16636','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19426','30168','16636','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19427','30166','16636','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19432','30178','16638','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19433','30179','16638','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19434','30180','16638','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19435','30178','16638','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19436','30184','16639','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19437','30185','16639','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19438','30186','16639','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19439','30184','16639','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19440','30166','16640','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19441','30167','16640','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19442','30168','16640','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19443','30166','16640','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19448','30178','16642','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19449','30179','16642','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19450','30180','16642','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19451','30178','16642','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19452','30184','16643','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19453','30185','16643','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19454','30186','16643','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19455','30184','16643','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19456','30191','16644','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19457','30192','16645','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19458','30192','16645','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19459','30187','16646','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19460','30188','16647','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19474','30234','16661','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19475','30235','16662','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19476','30235','16662','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19492','28804','16678','str','"HTTP/1.1 200"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19493','28804','16678','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19494','28821','16679','str','"HTTP/1.1 200"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19495','28821','16679','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19496','28729','16680','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19497','30322','16681','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19498','30312','16681','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19499','30275','16682','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19500','30275','16682','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19501','30276','16683','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19502','30317','16684','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19503','30326','16685','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19504','30333','16686','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19505','30273','16687','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19506','30306','16688','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19507','30286','16689','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19508','30286','16689','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19509','30283','16690','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19510','30283','16690','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19511','30281','16691','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19512','30274','16692','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19513','30298','16693','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19514','30347','16694','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19517','30398','16696','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19548','29434','16710','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19549','29435','16710','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19552','30425','16713','min','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19553','30426','16714','min','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19556','30429','16717','min','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19557','30430','16718','min','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19558','30470','16719','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19560','30454','16721','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19562','30432','16723','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19563','30445','16724','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19564','30450','16725','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19565','30431','16726','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19566','30431','16726','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19567','30476','16727','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19568','30477','16728','count','#1,"No",eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19569','30477','16729','count','#1,"Yes",ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19570','30478','16730','count','#1,"No",eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19572','30481','16732','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19573','30480','16733','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19574','30480','16733','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19575','30505','16734','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19577','30514','16736','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19578','30495','16737','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19579','30519','16738','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19580','30524','16739','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19581','30525','16740','count','#1,"No",eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19582','30525','16741','count','#1,"Yes",ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19583','30526','16742','count','#1,"No",eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19584','30537','16743','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19585','30530','16744','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19586','30547','16745','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19587','30547','16745','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19588','30599','16746','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19589','30604','16746','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19590','30598','16747','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19591','30598','16747','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19592','30614','16748','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19593','30634','16748','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19594','30633','16749','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19595','30632','16749','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19596','30631','16750','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19597','30628','16751','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19598','30627','16752','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19599','30611','16753','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19600','30615','16754','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19601','30636','16755','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19602','30636','16755','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19603','30676','16756','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19605','30660','16758','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19606','30638','16759','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19607','30651','16760','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19608','30656','16761','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19609','30637','16762','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19610','30637','16762','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19611','30682','16763','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19612','30683','16764','count','#1,"No",eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19613','30683','16765','count','#1,"Yes",ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19614','30684','16766','count','#1,"No",eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19615','30688','16767','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19616','30689','16768','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19617','30689','16769','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19618','30689','16770','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19619','30689','16771','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19620','30689','16772','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19621','30689','16773','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19622','30697','16774','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19623','30698','16774','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19624','30709','16774','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19625','30710','16775','min','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19626','30708','16776','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19627','30708','16777','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19628','30705','16778','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19629','30705','16779','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19630','30705','16780','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19631','30712','16781','min','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19632','30699','16782','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19633','30696','16783','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19634','30692','16784','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19635','30690','16785','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19636','30715','16786','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19637','30716','16787','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19638','30717','16788','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19639','30714','16789','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19640','30724','16790','min','1h');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19641','30724','16791','min','1h');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19642','30725','16792','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19643','30729','16793','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19644','30733','16794','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19645','30758','16795','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19659','30789','16809','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19660','30790','16810','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19674','30854','16824','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19675','30858','16825','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19676','30864','16826','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19677','30862','16827','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19679','30827','16829','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19680','30837','16830','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19681','30829','16831','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19682','30829','16831','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19683','30846','16832','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19684','30846','16833','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19685','30822','16834','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19686','30822','16834','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19687','30843','16835','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19688','30880','16836','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19689','30891','16836','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19690','30883','16837','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19691','30884','16838','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19692','30885','16839','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19693','30890','16840','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19694','27107','16841','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19695','27107','16841','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19696','27188','16842','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19697','27188','16842','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19698','27223','16843','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19699','27223','16843','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19700','27259','16844','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19701','27259','16844','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19702','27280','16845','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19703','27280','16845','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19704','27329','16846','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19705','27329','16846','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19706','27458','16847','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19707','27458','16847','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19708','27494','16848','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19709','27494','16848','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19710','27528','16849','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19711','27528','16849','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19712','27564','16850','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19713','27564','16850','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19714','27650','16851','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19715','27650','16851','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19716','27730','16852','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19717','27730','16852','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19718','27764','16853','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19719','27764','16853','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19720','27796','16854','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19721','27796','16854','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19722','27880','16855','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19723','27880','16855','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19724','27917','16856','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19725','27917','16856','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19726','27952','16857','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19727','27952','16857','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19728','28126','16858','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19729','28126','16858','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19732','28231','16860','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19733','28231','16860','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19734','28301','16861','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19735','28301','16861','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19736','28976','16862','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19737','28976','16862','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19738','27087','16863','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19739','27087','16863','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19740','27627','16864','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19741','27627','16864','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19742','27984','16865','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19743','27984','16865','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19744','27127','16866','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19745','27127','16866','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19746','29085','16867','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19747','29085','16867','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19748','28013','16868','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19749','28013','16868','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19756','27421','16871','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19757','27421','16871','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19776','27430','16878','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19777','27430','16878','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19778','27447','16879','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19779','27447','16879','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19780','28218','16880','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19781','28218','16880','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19786','29444','16883','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19787','29444','16883','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19792','30912','16886','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19793','30911','16887','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19794','30911','16887','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19795','30896','16888','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19796','30927','16889','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19797','30944','16889','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19798','30943','16890','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19799','30943','16890','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19800','30945','16891','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19801','30924','16892','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19802','30954','16893','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19803','30956','16894','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19804','30960','16895','delta','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19805','30930','16896','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19806','30931','16897','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19807','30937','16898','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19808','30937','16898','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19809','30939','16899','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19810','30923','16900','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19811','30963','16901','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19812','30968','16902','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19813','30975','16903','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19814','30984','16904','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19815','31004','16905','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19816','31006','16906','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19817','31007','16907','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19818','31008','16908','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19819','31009','16909','min','{$IIS.QUEUE.MAX.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19820','31010','16910','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19821','31017','16911','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19822','31026','16912','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19823','31046','16913','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19824','31048','16914','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19825','31049','16915','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19826','31050','16916','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19827','31051','16917','min','{$IIS.QUEUE.MAX.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19828','31052','16918','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19829','31052','16918','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19832','30821','16920','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19833','31054','16920','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19834','31054','16921','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19841','31092','16925','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19842','31095','16925','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19845','31056','16927','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19846','31096','16928','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19847','31096','16929','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19848','31106','16930','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19849','31114','16931','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19850','31115','16932','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19851','31116','16933','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19852','31118','16934','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19853','31062','16935','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19854','31064','16936','max','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19855','31066','16937','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19856','31068','16938','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19857','31082','16939','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19858','31082','16940','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19859','31085','16941','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19860','31085','16941','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19863','31088','16944','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19865','31133','16946','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19866','31135','16947','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19867','31136','16948','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19868','31136','16949','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19869','31142','16950','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19870','31143','16951','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19873','31148','16954','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19874','31149','16955','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19875','31152','16956','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19876','31153','16957','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19877','31153','16958','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19878','31157','16959','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19879','31157','16960','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19880','31157','16961','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19881','31158','16962','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19888','31161','16965','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19889','31166','16965','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19890','31164','16966','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19891','31164','16967','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19892','31164','16968','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19893','31165','16969','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19894','31167','16970','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19895','31167','16971','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19896','31169','16972','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19897','31170','16973','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19898','31171','16974','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19899','30450','16975','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19900','31173','16976','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19901','31174','16977','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19902','31175','16978','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19903','30656','16979','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19904','31177','16980','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19905','31179','16981','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19906','31178','16982','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19907','30519','16983','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19908','31235','16984','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19910','31188','16986','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19911','31193','16987','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19912','31263','16988','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19913','31262','16989','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19917','31276','16993','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19918','31277','16993','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19919','29222','16994','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19920','29222','16994','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19921','31279','16995','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19922','31280','16995','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19923','31282','16996','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19924','31283','16996','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19925','29236','16997','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19926','29236','16997','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19927','29250','16998','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19928','29250','16998','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19931','31307','17001','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19932','31308','17001','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19933','29367','17002','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19934','29367','17002','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19935','31310','17003','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19936','31311','17003','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19937','29381','17004','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19938','29381','17004','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19939','29459','17005','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19940','31325','17005','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19943','29485','17007','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19944','31328','17007','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19947','31335','17009','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19948','31339','17010','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19949','29566','17011','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19950','31343','17011','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19953','29592','17013','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19954','31346','17013','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19957','31353','17015','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('19958','31357','17016','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20054','31532','17063','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20055','31538','17063','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20056','31536','17064','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20057','31534','17064','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20058','31528','17065','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20059','31542','17065','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20060','31546','17066','min','{$JMX.HEAP.MEM.USAGE.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20061','31545','17066','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20062','31549','17067','min','{$JMX.NONHEAP.MEM.USAGE.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20063','31548','17067','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20064','31541','17068','min','{$JMX.MP.USAGE.TIME:"CMS Old Gen"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20065','31552','17068','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20066','31525','17069','min','{$JMX.MP.USAGE.TIME:"CMS Perm Gen"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20067','31513','17069','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20068','31503','17070','min','{$JMX.MP.USAGE.TIME:"Code Cache"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20069','31502','17070','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20070','31506','17071','min','{$JMX.MP.USAGE.TIME:"Perm Gen"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20071','31505','17071','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20072','31509','17072','min','{$JMX.MP.USAGE.TIME:"PS Old Gen"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20073','31508','17072','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20074','31500','17073','min','{$JMX.MP.USAGE.TIME:"PS Perm Gen"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20075','31511','17073','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20076','31515','17074','min','{$JMX.MP.USAGE.TIME:"Tenured Gen"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20077','31514','17074','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20078','31517','17075','min','{$JMX.FILE.DESCRIPTORS.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20079','31516','17075','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20080','31530','17076','str','Client');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20081','31518','17077','min','{$JMX.CPU.LOAD.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20082','31519','17078','nodata','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20083','31520','17079','str','Server');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20084','31575','17080','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20085','31581','17081','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20086','31581','17082','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20087','31580','17083','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20088','31580','17084','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20089','31579','17085','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20096','22942','17089','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20097','22952','17090','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20098','22949','17091','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20099','22875','17092','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20100','22876','17093','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20101','22902','17094','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20102','22896','17095','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20103','22912','17096','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20104','22909','17097','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20105','22982','17098','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20106','22992','17099','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20107','22989','17100','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20108','23035','17101','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20109','23036','17102','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20110','23062','17103','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20111','23072','17104','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20112','23069','17105','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20113','22835','17106','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20114','22836','17107','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20115','22862','17108','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20116','22856','17109','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20117','22872','17110','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20118','22869','17111','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20119','22996','17112','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20120','23022','17113','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20121','23016','17114','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20122','23032','17115','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20123','23029','17116','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20124','26932','17117','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20125','26932','17118','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20126','26930','17119','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20127','26930','17120','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20128','26931','17121','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20129','26931','17122','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20130','26929','17123','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20131','26929','17124','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20132','26928','17125','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20133','26928','17126','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20134','26925','17127','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20135','26943','17128','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20136','26943','17129','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20137','26939','17130','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20138','26939','17131','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20139','26940','17132','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20140','26940','17133','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20141','26941','17134','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20142','26941','17135','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20143','26942','17136','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20144','26942','17137','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20145','26938','17138','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20146','26938','17139','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20147','26937','17140','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20148','26937','17141','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20149','26933','17142','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20150','26933','17143','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20151','26934','17144','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20152','26935','17145','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20153','26935','17146','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20154','26936','17147','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20155','26936','17148','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20156','31070','17149','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20157','31066','17149','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20158','31626','17150','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20159','31628','17151','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20160','31627','17152','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20161','31057','17153','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20162','31632','17154','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20163','31655','17154','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20164','31650','17155','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20165','31653','17155','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20166','31630','17156','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20167','31683','17156','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20168','31668','17157','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20169','31702','17157','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20170','31693','17158','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20171','31693','17158','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20172','31694','17159','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20173','31694','17159','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20174','31629','17160','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20175','31640','17161','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20177','31654','17163','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20178','31657','17164','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20179','31663','17165','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20180','31669','17166','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20181','31669','17167','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20182','31641','17168','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20183','31705','17169','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20184','31705','17169','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20185','31713','17170','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20186','31714','17171','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20187','31715','17171','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20188','31716','17172','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20189','31716','17173','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20190','31717','17174','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20191','31720','17175','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20192','31720','17176','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20193','31721','17177','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20194','31721','17178','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20195','31725','17179','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20196','31725','17180','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20216','27247','17194','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20217','27246','17194','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20218','27247','17194','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20219','27421','17195','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20220','27420','17195','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20221','27421','17195','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20222','27421','17196','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20223','27420','17196','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20224','27421','17196','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20225','27430','17197','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20226','27429','17197','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20227','27430','17197','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20228','27447','17198','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20229','27446','17198','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20230','27447','17198','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20231','28218','17199','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20232','28217','17199','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20233','28218','17199','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20234','27430','17200','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20235','27429','17200','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20236','27430','17200','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20237','27447','17201','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20238','27446','17201','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20239','27447','17201','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20240','28218','17202','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20241','28217','17202','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20242','28218','17202','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20243','27584','17203','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20244','27585','17203','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20245','27584','17203','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20246','27784','17204','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20247','27783','17204','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20248','27784','17204','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20249','27784','17205','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20250','27783','17205','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20251','27784','17205','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20255','31790','17207','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20256','31790','17207','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20257','31790','17208','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20258','31790','17208','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20259','31790','17209','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20260','31790','17209','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20261','31799','17210','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20262','27941','17211','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20263','27940','17211','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20264','27941','17211','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20265','27941','17212','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20266','27940','17212','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20267','27941','17212','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20268','28356','17213','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20269','28357','17213','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20270','28356','17213','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20271','28356','17214','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20272','28357','17214','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20273','28356','17214','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20274','28354','17215','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20275','28355','17215','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20276','28354','17215','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20277','28354','17216','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20278','28355','17216','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20279','28354','17216','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20280','31848','17217','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20281','31848','17217','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20282','31849','17218','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20283','31849','17219','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20284','31803','17220','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20285','31853','17221','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20286','31836','17221','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20287','31853','17222','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20288','31843','17222','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20289','31858','17223','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20290','31871','17224','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20291','31885','17225','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20292','31885','17225','nodata','3m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20293','31884','17226','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20294','31875','17227','min','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20295','31877','17228','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20296','31877','17229','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20297','31876','17230','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20298','31876','17230','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20299','31870','17231','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20300','31891','17232','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20301','31901','17233','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20302','31901','17233','nodata','3m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20303','31903','17234','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20304','31898','17235','min','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20305','31896','17236','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20306','31896','17237','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20307','31909','17238','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20308','31909','17238','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20311','31943','17240','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20312','31930','17240','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20313','31932','17240','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20314','31943','17241','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20315','31931','17241','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20316','31932','17241','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20317','31910','17242','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20318','31945','17243','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20319','31934','17244','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20320','31963','17245','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20321','31963','17245','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20322','31965','17246','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20323','31966','17247','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20324','31967','17248','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20325','31968','17249','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20340','32020','17263','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20341','32034','17264','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20342','32041','17265','max','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20343','32045','17266','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20344','32045','17267','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20345','32035','17268','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20346','32033','17269','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20347','32027','17270','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20348','32025','17271','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20349','32025','17272','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20350','32016','17273','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20351','32015','17274','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20352','32014','17275','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20353','32018','17276','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20354','32056','17277','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20355','32058','17278','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20356','32058','17279','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20357','32067','17280','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20358','32068','17281','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20359','32068','17282','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20360','32102','17283','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20361','32105','17284','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20362','32110','17285','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20363','32074','17286','max','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20364','32074','17287','nodata','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20365','32075','17288','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20366','32076','17289','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20367','32076','17289','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20368','32072','17290','max','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20369','32092','17291','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20370','32093','17292','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20371','32095','17293','regexp','"CONNECTED"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20372','28511','17294','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20373','28511','17294','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20374','32144','17295','str','off');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20375','32156','17296','min','{$TOMCAT.THREADS.MAX.TIME:"{#JMXNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20376','32157','17296','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20377','32165','17297','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20378','32175','17297','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20379','32161','17298','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20380','32170','17299','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20381','32170','17299','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20382','32172','17300','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20383','32172','17301','nodata','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20384','32173','17302','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20385','32173','17302','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20386','32204','17303','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20387','32203','17303','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20388','32202','17304','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20389','32241','17305','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20390','32241','17305','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20391','32270','17306','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20392','32270','17307','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20393','32258','17308','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20394','32240','17309','nodata','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20395','32238','17310','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20396','28325','17311','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20397','28325','17312','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20398','28325','17313','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20399','28325','17314','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20400','28323','17315','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20401','28323','17316','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20402','28323','17317','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20403','28323','17318','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20404','32307','17319','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20405','32307','17320','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20406','32307','17321','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20407','32307','17322','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20408','32323','17323','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20409','32323','17324','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20410','32309','17325','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20411','32309','17326','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20412','32316','17327','count','#3,"rtsShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20413','32316','17328','count','#3,"rtsDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20414','32316','17329','count','#3,"heatsinkTempSensorOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20415','32316','17330','count','#3,"heatsinkTempSensorShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20416','32316','17331','count','#3,"heatsinkTempLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20417','32316','17332','count','#3,"inductorTempSensorOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20418','32316','17333','count','#3,"inductorTempSensorShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20419','32316','17334','count','#3,"inductorTempLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20420','32316','17335','count','#3,"currentLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20421','32316','17336','count','#3,"currentMeasurementError","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20422','32316','17337','count','#3,"batterySenseOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20423','32316','17338','count','#3,"batterySenseDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20424','32316','17339','count','#3,"uncalibrated","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20425','32316','17340','count','#3,"tb5v","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20426','32316','17341','count','#3,"fp10SupplyOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20427','32316','17342','count','#3,"mosfetOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20428','32316','17343','count','#3,"arrayCurrentOffset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20429','32316','17344','count','#3,"loadCurrentOffset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20430','32316','17345','count','#3,"p33SupplyOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20431','32316','17346','count','#3,"p12SupplyOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20432','32316','17347','count','#3,"hightInputVoltageLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20433','32316','17348','count','#3,"controllerReset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20434','32316','17349','count','#3,"loadLvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20435','32316','17350','count','#3,"logTimeout","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20436','32316','17351','count','#3,"eepromAccessFailure","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20437','32315','17352','count','#3,"overcurrent","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20438','32315','17353','count','#3,"mosfetSShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20439','32315','17354','count','#3,"software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20440','32315','17355','count','#3,"batteryHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20441','32315','17356','count','#3,"arrayHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20442','32315','17357','count','#3,"customSettingsEdit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20443','32315','17358','count','#3,"rtsShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20444','32315','17359','count','#3,"rtsNoLongerValid","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20445','32315','17360','count','#3,"localTempSensorDamaged","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20446','32315','17361','count','#3,"batteryLowVoltageDisconnect","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20447','32315','17362','count','#3,"slaveTimeout","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20448','32315','17363','count','#3,"dipSwitchChanged","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20449','32314','17364','count','#3,"externalShortCircuit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20450','32314','17365','count','#3,"overcurrent","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20451','32314','17366','count','#3,"mosfetShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20452','32314','17367','count','#3,"software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20453','32314','17368','count','#3,"loadHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20454','32314','17369','count','#3,"highTempDisconnect","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20455','32314','17370','count','#3,"dipSwitchChanged","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20456','32314','17371','count','#3,"customSettingsEdit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20457','32313','17372','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20458','32313','17373','nodata','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20459','32310','17374','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20460','32310','17375','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20461','32310','17376','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20462','32310','17377','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20463','32330','17378','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20464','32330','17379','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20465','32330','17380','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20466','32330','17381','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20467','32346','17382','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20468','32346','17383','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20469','32341','17384','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20470','32341','17385','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20471','32332','17386','count','#3,"rtsShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20472','32332','17387','count','#3,"rtsDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20473','32332','17388','count','#3,"heatsinkTempSensorOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20474','32332','17389','count','#3,"heatsinkTempSensorShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20475','32332','17390','count','#3,"heatsinkTempLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20476','32332','17391','count','#3,"currentLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20477','32332','17392','count','#3,"currentMeasurementError","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20478','32332','17393','count','#3,"batterySenseOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20479','32332','17394','count','#3,"batterySenseDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20480','32332','17395','count','#3,"uncalibrated","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20481','32332','17396','count','#3,"batteryTempOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20482','32332','17397','count','#3,"fp10SupplyOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20483','32332','17398','count','#3,"mosfetOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20484','32332','17399','count','#3,"arrayCurrentOffset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20485','32332','17400','count','#3,"loadCurrentOffset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20486','32332','17401','count','#3,"p33SupplyOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20487','32332','17402','count','#3,"p12SupplyOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20488','32332','17403','count','#3,"hightInputVoltageLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20489','32332','17404','count','#3,"controllerReset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20490','32332','17405','count','#3,"loadLvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20491','32332','17406','count','#3,"logTimeout","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20492','32332','17407','count','#3,"eepromAccessFailure","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20493','32338','17408','count','#3,"overcurrent","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20494','32338','17409','count','#3,"mosfetSShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20495','32338','17410','count','#3,"software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20496','32338','17411','count','#3,"batteryHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20497','32338','17412','count','#3,"arrayHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20498','32338','17413','count','#3,"customSettingsEdit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20499','32338','17414','count','#3,"rtsShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20500','32338','17415','count','#3,"rtsNoLongerValid","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20501','32338','17416','count','#3,"localTempSensorDamaged","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20502','32338','17417','count','#3,"batteryLowVoltageDisconnect","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20503','32338','17418','count','#3,"slaveTimeout","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20504','32338','17419','count','#3,"dipSwitchChanged","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20505','32338','17420','count','#3,"p3Fault","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20506','32337','17421','count','#3,"externalShortCircuit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20507','32337','17422','count','#3,"overcurrent","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20508','32337','17423','count','#3,"mosfetShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20509','32337','17424','count','#3,"software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20510','32337','17425','count','#3,"loadHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20511','32337','17426','count','#3,"highTempDisconnect","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20512','32337','17427','count','#3,"dipSwitchChanged","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20513','32337','17428','count','#3,"customSettingsEdit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20514','32337','17429','count','#3,"p3Fault","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20515','32336','17430','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20516','32336','17431','nodata','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20517','32333','17432','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20518','32333','17433','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20519','32333','17434','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20520','32333','17435','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20521','32350','17436','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20522','32350','17437','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20523','32350','17438','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20524','32350','17439','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20525','32366','17440','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20526','32366','17441','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20527','32352','17442','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20528','32352','17443','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20529','32359','17444','count','#3,"rtsShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20530','32359','17445','count','#3,"rtsDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20531','32359','17446','count','#3,"heatsinkTempSensorOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20532','32359','17447','count','#3,"heatsinkTempSensorShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20533','32359','17448','count','#3,"sspptHot","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20534','32359','17449','count','#3,"currentLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20535','32359','17450','count','#3,"currentOffset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20536','32359','17451','count','#3,"uncalibrated","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20537','32359','17452','count','#3,"rtsMiswire","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20538','32359','17453','count','#3,"systemMiswire","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20539','32359','17454','count','#3,"mosfetSOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20540','32359','17455','count','#3,"p12VoltageReferenceOff","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20541','32359','17456','count','#3,"highVaCurrentLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20542','32358','17457','count','#3,"overcurrent","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20543','32358','17458','count','#3,"mosfetSShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20544','32358','17459','count','#3,"softwareFault","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20545','32358','17460','count','#3,"batteryHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20546','32358','17461','count','#3,"arrayHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20547','32358','17462','count','#3,"customSettingsEdit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20548','32358','17463','count','#3,"rtsShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20549','32358','17464','count','#3,"rtsNoLongerValid","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20550','32358','17465','count','#3,"localTempSensorDamaged","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20551','32357','17466','count','#3,"externalShortCircuit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20552','32357','17467','count','#3,"overcurrent","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20553','32357','17468','count','#3,"mosfetShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20554','32357','17469','count','#3,"software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20555','32357','17470','count','#3,"loadHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20556','32357','17471','count','#3,"highTempDisconnect","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20557','32357','17472','count','#3,"customSettingsEdit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20558','32357','17473','count','#3,"unknownLoadFault","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20559','32356','17474','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20560','32356','17475','nodata','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20561','32353','17476','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20562','32353','17477','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20563','32353','17478','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20564','32353','17479','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20565','32373','17480','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20566','32373','17481','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20567','32373','17482','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20568','32373','17483','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20569','32376','17484','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20570','32376','17485','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20571','32377','17486','count','#3,"heatsinkTempSensorOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20572','32377','17487','count','#3,"heatsinkTempSensorShort","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20573','32377','17488','count','#3,"unknownAlarm","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20574','32377','17489','count','#3,"suresineHot","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20575','32378','17490','count','#3,"reset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20576','32378','17491','count','#3,"overcurrent","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20577','32378','17492','count','#3,"unknownFault","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20578','32378','17493','count','#3,"software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20579','32378','17494','count','#3,"highVoltageDisconnect","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20580','32378','17495','count','#3,"suresineHot","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20581','32378','17496','count','#3,"dipSwitchChanged","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20582','32378','17497','count','#3,"customSettingsEdit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20583','32379','17498','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20584','32379','17499','nodata','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20585','32382','17500','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20586','32382','17501','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20587','32382','17502','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20588','32382','17503','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20589','32391','17504','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20590','32391','17505','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20591','32389','17506','count','#3,"rtsShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20592','32389','17507','count','#3,"rtsDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20593','32389','17508','count','#3,"heatsinkTempSensorOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20594','32389','17509','count','#3,"heatsinkTempSensorShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20595','32389','17510','count','#3,"highTemperatureCurrentLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20596','32389','17511','count','#3,"currentLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20597','32389','17512','count','#3,"currentOffset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20598','32389','17513','count','#3,"batterySense","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20599','32389','17514','count','#3,"batterySenseDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20600','32389','17515','count','#3,"uncalibrated","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20601','32389','17516','count','#3,"rtsMiswire","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20602','32389','17517','count','#3,"highVoltageDisconnect","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20603','32389','17518','count','#3,"systemMiswire","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20604','32389','17519','count','#3,"mosfetSOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20605','32389','17520','count','#3,"p12VoltageOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20606','32389','17521','count','#3,"highArrayVCurrentLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20607','32389','17522','count','#3,"maxAdcValueReached","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20608','32389','17523','count','#3,"controllerWasReset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20609','32389','17524','count','#3,"alarm21Internal","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20610','32389','17525','count','#3,"p3VoltageOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20611','32389','17526','count','#3,"derateLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20612','32389','17527','count','#3,"arrayCurrentOffset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20613','32389','17528','count','#3,"ee-i2cRetryLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20614','32389','17529','count','#3,"ethernetAlarm","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20615','32389','17530','count','#3,"lvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20616','32389','17531','count','#3,"software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20617','32389','17532','count','#3,"fp12VoltageOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20618','32389','17533','count','#3,"extflashFault","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20619','32389','17534','count','#3,"slaveControlFault","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20620','32388','17535','count','#3,"overcurrent","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20621','32388','17536','count','#3,"fetShort","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20622','32388','17537','count','#3,"softwareFault","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20623','32388','17538','count','#3,"batteryHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20624','32388','17539','count','#3,"arrayHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20625','32388','17540','count','#3,"dipSwitchChange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20626','32388','17541','count','#3,"customSettingsEdit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20627','32388','17542','count','#3,"rtsShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20628','32388','17543','count','#3,"rtsDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20629','32388','17544','count','#3,"eepromRetryLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20630','32388','17545','count','#3,"controllerWasReset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20631','32388','17546','count','#3,"chargeSlaveControlTimeout","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20632','32388','17547','count','#3,"rs232SerialToMeterBridge","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20633','32388','17548','count','#3,"batteryLvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20634','32388','17549','count','#3,"powerboardCommunicationFault","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20635','32388','17550','count','#3,"fault16Software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20636','32388','17551','count','#3,"fault17Software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20637','32388','17552','count','#3,"fault18Software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20638','32388','17553','count','#3,"fault19Software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20639','32388','17554','count','#3,"fault20Software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20640','32388','17555','count','#3,"fault21Software","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20641','32388','17556','count','#3,"fpgaVersion","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20642','32388','17557','count','#3,"currentSensorReferenceOutOfRange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20643','32388','17558','count','#3,"ia-refSlaveModeTimeout","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20644','32388','17559','count','#3,"blockbusBoot","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20645','32388','17560','count','#3,"hscommMaster","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20646','32388','17561','count','#3,"hscomm","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20647','32388','17562','count','#3,"slave","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20648','32387','17563','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20649','32387','17564','nodata','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20650','32385','17565','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20651','32385','17566','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20652','32385','17567','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20653','32385','17568','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20654','32401','17569','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20655','32401','17570','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20656','32401','17571','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20657','32401','17572','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20658','32410','17573','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20659','32410','17574','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20660','32408','17575','count','#3,"rtsShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20661','32408','17576','count','#3,"rtsDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20662','32408','17577','count','#3,"heatsinkTempSensorOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20663','32408','17578','count','#3,"heatsinkTempSensorShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20664','32408','17579','count','#3,"highTemperatureCurrentLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20665','32408','17580','count','#3,"currentLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20666','32408','17581','count','#3,"currentOffset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20667','32408','17582','count','#3,"batterySense","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20668','32408','17583','count','#3,"batterySenseDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20669','32408','17584','count','#3,"uncalibrated","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20670','32408','17585','count','#3,"rtsMiswire","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20671','32408','17586','count','#3,"highVoltageDisconnect","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20672','32408','17587','count','#3,"systemMiswire","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20673','32408','17588','count','#3,"mosfetSOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20674','32408','17589','count','#3,"p12VoltageReferenceOff","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20675','32408','17590','count','#3,"highArrayVCurrentLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20676','32408','17591','count','#3,"maxAdcValueReached","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20677','32408','17592','count','#3,"controllerWasReset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20678','32407','17593','count','#3,"overcurrent","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20679','32407','17594','count','#3,"fetShort","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20680','32407','17595','count','#3,"softwareFault","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20681','32407','17596','count','#3,"batteryHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20682','32407','17597','count','#3,"arrayHvd","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20683','32407','17598','count','#3,"dipSwitchChange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20684','32407','17599','count','#3,"customSettingsEdit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20685','32407','17600','count','#3,"rtsShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20686','32407','17601','count','#3,"rtsDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20687','32407','17602','count','#3,"eepromRetryLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20688','32407','17603','count','#3,"slaveControlTimeout","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20689','32406','17604','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20690','32406','17605','nodata','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20691','32404','17606','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20692','32404','17607','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20693','32404','17608','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20694','32404','17609','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20695','32420','17610','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20696','32420','17611','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20697','32420','17612','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20698','32420','17613','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20699','32425','17614','count','#3,"rtsShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20700','32425','17615','count','#3,"rtsDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20701','32425','17616','count','#3,"heatsinkTempSensorOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20702','32425','17617','count','#3,"heatsinkTempSensorShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20703','32425','17618','count','#3,"tristarHot","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20704','32425','17619','count','#3,"currentLimit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20705','32425','17620','count','#3,"currentOffset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20706','32425','17621','count','#3,"batterySense","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20707','32425','17622','count','#3,"batterySenseDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20708','32425','17623','count','#3,"uncalibrated","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20709','32425','17624','count','#3,"rtsMiswire","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20710','32425','17625','count','#3,"highVoltageDisconnect","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20711','32425','17626','count','#3,"diversionLoadNearMax","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20712','32425','17627','count','#3,"systemMiswire","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20713','32425','17628','count','#3,"mosfetSOpen","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20714','32425','17629','count','#3,"p12VoltageReferenceOff","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20715','32425','17630','count','#3,"loadDisconnectState","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20716','32426','17631','count','#3,"externalShort","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20717','32426','17632','count','#3,"overcurrent","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20718','32426','17633','count','#3,"mosfetSShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20719','32426','17634','count','#3,"softwareFault","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20720','32426','17635','count','#3,"highVoltageDisconnect","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20721','32426','17636','count','#3,"tristarHot","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20722','32426','17637','count','#3,"dipSwitchChange","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20723','32426','17638','count','#3,"customSettingsEdit","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20724','32426','17639','count','#3,"reset","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20725','32426','17640','count','#3,"systemMiswire","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20726','32426','17641','count','#3,"rtsShorted","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20727','32426','17642','count','#3,"rtsDisconnected","like"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20728','32427','17643','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20729','32427','17644','nodata','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20730','32428','17645','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20731','32428','17646','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20732','32428','17647','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20733','32428','17648','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20734','32436','17649','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20735','32436','17650','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20736','32436','17651','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20737','32436','17652','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20738','32437','17653','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20739','32437','17654','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20740','32444','17655','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20741','32444','17656','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20754','32447','17661','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20755','32446','17662','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20756','32451','17663','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20757','32450','17664','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20758','32455','17665','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20759','32454','17666','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20760','32459','17667','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20761','32458','17668','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20766','32467','17673','max','{$ACTIVEMQ.DESTINATION.CONSUMERS.MIN.TIME:"{#JMXDESTINATIONNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20767','32465','17673','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20768','32467','17673','min','{$ACTIVEMQ.DESTINATION.CONSUMERS.MIN.TIME:"{#JMXDESTINATIONNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20771','32472','17675','max','{$ACTIVEMQ.DESTINATION.PRODUCERS.MIN.TIME:"{#JMXDESTINATIONNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20772','32466','17675','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20773','32472','17675','min','{$ACTIVEMQ.DESTINATION.PRODUCERS.MIN.TIME:"{#JMXDESTINATIONNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20775','32471','17677','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20776','32471','17678','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20779','32474','17681','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20780','32474','17681','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20781','32476','17682','min','{$ACTIVEMQ.MEM.TIME:"{#JMXBROKERNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20782','32476','17683','min','{$ACTIVEMQ.MEM.TIME:"{#JMXBROKERNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20783','32478','17684','min','{$ACTIVEMQ.STORE.TIME:"{#JMXBROKERNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20784','32478','17685','min','{$ACTIVEMQ.STORE.TIME:"{#JMXBROKERNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20785','32480','17686','min','{$ACTIVEMQ.TEMP.TIME:"{#JMXBROKERNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20786','32480','17687','min','{$ACTIVEMQ.TEMP.TIME:"{#JMXBROKERNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20787','32481','17688','max','{$ACTIVEMQ.BROKER.CONSUMERS.MIN.TIME:"{#JMXBROKERNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20788','32484','17689','max','{$ACTIVEMQ.BROKER.PRODUCERS.MIN.TIME:"{#JMXBROKERNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20789','32485','17690','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20790','32498','17691','min','{$MS.EXCHANGE.LDAP.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20791','32499','17692','min','{$MS.EXCHANGE.LDAP.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20792','32510','17693','avg','{$MS.EXCHANGE.DB.PASSIVE.WRITE.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20793','32507','17693','avg','{$MS.EXCHANGE.DB.PASSIVE.WRITE.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20794','32502','17694','min','{$MS.EXCHANGE.DB.FAULTS.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20795','32503','17695','avg','{$MS.EXCHANGE.LOG.STALLS.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20796','32506','17696','min','{$MS.EXCHANGE.DB.ACTIVE.READ.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20797','32507','17697','min','{$MS.EXCHANGE.DB.PASSIVE.READ.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20798','32509','17698','min','{$MS.EXCHANGE.DB.ACTIVE.WRITE.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20799','32513','17699','min','{$MS.EXCHANGE.RPC.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20800','32515','17700','min','{$MS.EXCHANGE.RPC.COUNT.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20801','32528','17701','min','{$MS.EXCHANGE.LDAP.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20802','32529','17702','min','{$MS.EXCHANGE.LDAP.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20803','32540','17703','avg','{$MS.EXCHANGE.DB.PASSIVE.WRITE.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20804','32537','17703','avg','{$MS.EXCHANGE.DB.PASSIVE.WRITE.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20805','32532','17704','min','{$MS.EXCHANGE.DB.FAULTS.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20806','32533','17705','avg','{$MS.EXCHANGE.LOG.STALLS.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20807','32536','17706','min','{$MS.EXCHANGE.DB.ACTIVE.READ.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20808','32537','17707','min','{$MS.EXCHANGE.DB.PASSIVE.READ.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20809','32539','17708','min','{$MS.EXCHANGE.DB.ACTIVE.WRITE.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20810','32543','17709','min','{$MS.EXCHANGE.RPC.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20811','32545','17710','min','{$MS.EXCHANGE.RPC.COUNT.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20812','32589','17711','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20813','32589','17712','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20814','31726','17713','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20815','31726','17714','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20821','32601','17720','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20822','32602','17721','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20823','32603','17722','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20824','32608','17723','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20825','32608','17723','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20826','32610','17724','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20827','32611','17725','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20828','32612','17726','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20829','32613','17726','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20830','32623','17727','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20831','32624','17727','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20832','32621','17728','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20833','32622','17728','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20834','32625','17729','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20835','32626','17730','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20836','32629','17731','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20837','32631','17732','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20838','32632','17733','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20839','32633','17734','min','{$FAS3220.FS.TIME:"{#FSNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20840','32638','17735','max','{$FAS3220.FS.TIME:"{#FSNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20841','32639','17736','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20842','32640','17737','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20843','32640','17738','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20848','32649','17740','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20849','32652','17740','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20850','32648','17741','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20851','32647','17741','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20854','32664','17743','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20855','32664','17743','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20856','32665','17744','max','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20857','32670','17745','max','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20858','32675','17746','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20859','32686','17747','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20860','32677','17747','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20861','32686','17748','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20862','32677','17748','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20863','32682','17749','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20864','32681','17749','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20865','32682','17750','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20866','32681','17750','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20867','32679','17751','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20868','32684','17752','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20869','32689','17753','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20870','32689','17754','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20871','32691','17755','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20872','32692','17756','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20873','32701','17757','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20874','32698','17757','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20875','32701','17758','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20876','32701','17759','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20877','32702','17760','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20878','32702','17760','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20879','32704','17761','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20880','32704','17762','nodata','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20881','32709','17763','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20882','32709','17763','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20883','32727','17764','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20884','32730','17764','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20885','32729','17765','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20886','32728','17765','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20887','32729','17766','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20888','32728','17766','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20889','30318','17767','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20890','30369','17767','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20891','28416','17768','count','#1,{$DISK_ARRAY_CACHE_BATTERY_WARN_STATUS:"degraded"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20892','28415','17769','count','#1,{$DISK_ARRAY_CACHE_WARN_STATUS:"cacheModDegradedFailsafeSpeed"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20893','28415','17769','count','#1,{$DISK_ARRAY_CACHE_WARN_STATUS:"cacheReadCacheNotMapped"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20894','28415','17769','count','#1,{$DISK_ARRAY_CACHE_WARN_STATUS:"cacheModFlashMemNotAttached"},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20895','28415','17770','count','#1,{$DISK_ARRAY_CACHE_OK_STATUS:"enabled"},ne');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20896','28415','17770','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20897','32732','17771','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20898','32732','17772','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20899','32732','17773','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20900','32733','17774','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20901','32733','17775','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20902','32733','17776','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20903','32734','17777','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20904','32734','17778','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20905','32734','17779','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20906','32735','17780','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20907','32735','17781','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20908','32735','17782','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20909','32737','17783','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20910','32737','17784','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20911','32737','17785','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20912','32738','17786','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20913','32738','17787','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20914','32738','17788','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20915','32739','17789','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20916','32739','17790','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20917','32739','17791','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20918','32663','17792','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20919','32670','17792','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20920','30159','17793','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20921','30165','17794','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20923','30177','17796','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20924','30183','17797','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20925','27084','17798','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20926','27081','17798','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20927','27085','17798','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20928','27086','17799','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20929','27083','17799','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20930','27086','17799','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20931','27083','17799','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20932','27622','17800','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20933','27626','17800','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20934','27625','17800','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20935','27979','17801','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20936','27983','17801','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20937','27982','17801','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20938','28008','17802','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20939','28012','17802','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20940','28011','17802','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20941','27621','17803','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20942','27624','17803','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20943','27621','17803','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20944','27624','17803','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20945','27978','17804','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20946','27981','17804','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20947','27978','17804','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20948','27981','17804','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20949','28007','17805','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20950','28010','17805','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20951','28007','17805','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20952','28010','17805','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20953','27104','17806','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20954','27101','17806','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20955','27105','17806','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20956','27106','17807','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20957','27103','17807','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20958','27106','17807','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20959','27103','17807','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20960','27183','17808','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20961','27187','17808','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20962','27186','17808','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20963','27218','17809','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20964','27222','17809','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20965','27221','17809','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20966','27254','17810','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20967','27258','17810','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20968','27257','17810','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20969','27275','17811','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20970','27279','17811','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20971','27278','17811','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20972','27324','17812','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20973','27328','17812','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20974','27327','17812','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20975','27453','17813','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20976','27457','17813','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20977','27456','17813','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20978','27489','17814','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20979','27493','17814','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20980','27492','17814','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20981','27523','17815','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20982','27527','17815','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20983','27526','17815','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20984','27559','17816','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20985','27563','17816','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20986','27562','17816','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20987','27645','17817','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20988','27649','17817','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20989','27648','17817','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20990','27725','17818','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20991','27729','17818','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20992','27728','17818','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20993','27759','17819','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20994','27763','17819','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20995','27762','17819','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20996','27791','17820','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20997','27795','17820','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20998','27794','17820','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('20999','27875','17821','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21000','27879','17821','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21001','27878','17821','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21002','27912','17822','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21003','27916','17822','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21004','27915','17822','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21005','27947','17823','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21006','27951','17823','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21007','27950','17823','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21008','28121','17824','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21009','28125','17824','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21010','28124','17824','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21014','28226','17826','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21015','28230','17826','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21016','28229','17826','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21017','28296','17827','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21018','28300','17827','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21019','28299','17827','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21020','28971','17828','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21021','28975','17828','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21022','28974','17828','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21023','27182','17829','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21024','27185','17829','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21025','27182','17829','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21026','27185','17829','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21027','27217','17830','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21028','27220','17830','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21029','27217','17830','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21030','27220','17830','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21031','27253','17831','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21032','27256','17831','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21033','27253','17831','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21034','27256','17831','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21035','27274','17832','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21036','27277','17832','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21037','27274','17832','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21038','27277','17832','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21039','27323','17833','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21040','27326','17833','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21041','27323','17833','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21042','27326','17833','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21043','27452','17834','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21044','27455','17834','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21045','27452','17834','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21046','27455','17834','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21047','27488','17835','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21048','27491','17835','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21049','27488','17835','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21050','27491','17835','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21051','27522','17836','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21052','27525','17836','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21053','27522','17836','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21054','27525','17836','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21055','27558','17837','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21056','27561','17837','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21057','27558','17837','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21058','27561','17837','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21059','27644','17838','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21060','27647','17838','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21061','27644','17838','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21062','27647','17838','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21063','27724','17839','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21064','27727','17839','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21065','27724','17839','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21066','27727','17839','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21067','27758','17840','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21068','27761','17840','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21069','27758','17840','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21070','27761','17840','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21071','27790','17841','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21072','27793','17841','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21073','27790','17841','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21074','27793','17841','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21075','27874','17842','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21076','27877','17842','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21077','27874','17842','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21078','27877','17842','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21079','27911','17843','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21080','27914','17843','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21081','27911','17843','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21082','27914','17843','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21083','27946','17844','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21084','27949','17844','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21085','27946','17844','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21086','27949','17844','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21087','28120','17845','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21088','28123','17845','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21089','28120','17845','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21090','28123','17845','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21095','28225','17847','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21096','28228','17847','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21097','28225','17847','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21098','28228','17847','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21099','28295','17848','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21100','28298','17848','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21101','28295','17848','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21102','28298','17848','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21103','28970','17849','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21104','28973','17849','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21105','28970','17849','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21106','28973','17849','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21107','27124','17850','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21108','27121','17850','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21109','27125','17850','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21110','27126','17851','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21111','27123','17851','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21112','27126','17851','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21113','27123','17851','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21114','29080','17852','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21115','29084','17852','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21116','29083','17852','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21117','29079','17853','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21118','29082','17853','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21119','29079','17853','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21120','29082','17853','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21121','32744','17854','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21122','32749','17855','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21123','32750','17856','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21124','32750','17856','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21125','32751','17857','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21126','32751','17858','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21127','32752','17859','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21128','32756','17860','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21129','32761','17861','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21130','32762','17862','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21131','32762','17862','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21132','32763','17863','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21133','32763','17864','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21134','32764','17865','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21135','30089','17866','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21136','30093','17867','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21137','30094','17868','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21138','30095','17869','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21139','30096','17870','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21140','30101','17871','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21141','30102','17872','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21142','30103','17873','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21143','30104','17874','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21144','30105','17875','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21145','30107','17876','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21146','30108','17877','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21147','30111','17878','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21148','30112','17879','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21149','30115','17880','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21150','30116','17881','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21151','30118','17882','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21152','30120','17883','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21153','30123','17884','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21154','30126','17885','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21155','30131','17886','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21156','30136','17887','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21157','29108','17888','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21158','29106','17888','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21159','29105','17889','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21160','29104','17889','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21161','31270','17890','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21162','29145','17891','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21163','29143','17891','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21164','29142','17892','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21165','29141','17892','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21166','31271','17893','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21167','29182','17894','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21168','29180','17894','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21169','29179','17895','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21170','29178','17895','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21171','31272','17896','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21172','29219','17897','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21173','29218','17897','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21174','29219','17897','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21175','29218','17897','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21176','29233','17898','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21177','29232','17898','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21178','29233','17898','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21179','29232','17898','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21180','29247','17899','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21181','29246','17899','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21182','29247','17899','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21183','29246','17899','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21184','29294','17900','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21185','29292','17900','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21186','29291','17901','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21187','29290','17901','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21188','31303','17902','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21189','29331','17903','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21190','29329','17903','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21191','29328','17904','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21192','29327','17904','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21193','31304','17905','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21194','29364','17906','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21195','29363','17906','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21196','29364','17906','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21197','29363','17906','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21198','29378','17907','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21199','29377','17907','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21200','29378','17907','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21201','29377','17907','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21202','29397','17908','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21203','29401','17908','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21204','29402','17909','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21205','29403','17909','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21206','29396','17910','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21207','29436','17911','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21208','29442','17911','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21209','29437','17911','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21210','29439','17912','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21211','29438','17912','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21212','29439','17912','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21213','29438','17912','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21214','28986','17913','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21215','28984','17913','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21216','28983','17914','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21217','28982','17914','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21218','28978','17915','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21219','29001','17916','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21220','28999','17916','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21221','28998','17917','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21222','28997','17917','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21223','28993','17918','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21224','31331','17919','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21225','29466','17919','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21226','29462','17920','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21227','31332','17921','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21228','29492','17921','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21229','29488','17922','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21244','31349','17927','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21245','29573','17927','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21246','29569','17928','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21247','31350','17929','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21248','29599','17929','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21249','29595','17930','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21264','32765','17935','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21265','32766','17936','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21266','32767','17937','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21267','32772','17938','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21268','32772','17938','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21269','32774','17939','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21270','32775','17940','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21271','32779','17941','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21272','32779','17941','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21273','32788','17942','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21274','32789','17943','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21275','32790','17944','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21276','32791','17945','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21277','32792','17946','min','{$HUAWEI.5300.MEM.MAX.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21278','32793','17947','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21279','32794','17948','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21280','32796','17949','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21281','32797','17950','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21282','32798','17951','min','{$HUAWEI.5300.DISK.TEMP.MAX.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21283','32799','17952','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21284','32800','17953','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21285','32801','17954','min','{$HUAWEI.5300.TEMP.MAX.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21286','32802','17955','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21287','32803','17956','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21288','32804','17957','min','{$HUAWEI.5300.LUN.IO.TIME.MAX.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21289','32814','17958','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21290','32815','17959','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21291','32816','17960','min','{$HUAWEI.5300.NODE.IO.DELAY.MAX.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21292','32824','17961','min','{$HUAWEI.5300.POOL.CAPACITY.THRESH.TIME}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21293','32825','17962','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21294','32826','17963','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21299','32829','17965','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21300','32831','17966','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21301','32832','17967','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21302','32836','17968','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21303','32877','17969','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21304','32874','17970','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21305','32869','17971','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21306','32869','17971','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21307','32870','17972','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21308','32864','17973','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21309','32865','17974','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21310','32834','17975','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21311','32884','17976','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21312','32885','17977','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21313','32886','17978','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21314','32887','17979','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21315','32888','17980','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21316','32889','17981','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21317','32890','17982','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21318','32912','17983','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21319','32926','17984','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21320','32927','17985','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21321','32931','17986','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21322','32928','17987','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21323','32968','17988','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21324','32965','17989','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21325','32956','17990','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21326','32956','17990','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21327','32961','17991','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21328','32960','17992','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21329','32970','17993','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21330','32976','17994','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21331','32977','17995','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21332','32978','17996','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21333','32979','17997','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21334','32980','17998','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21335','32981','17999','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21336','32982','18000','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21337','33004','18001','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21338','33054','18002','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21339','33053','18002','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21340','33054','18002','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21341','33051','18003','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21342','33039','18004','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21343','33019','18005','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21344','33037','18006','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21345','33037','18007','nodata','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21346','33060','18008','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21347','33060','18008','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21348','33103','18009','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21349','33121','18009','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21350','33116','18010','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21352','33128','18012','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21353','33125','18013','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21354','33165','18014','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21355','33161','18015','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21356','33160','18016','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21357','33141','18017','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21358','33154','18018','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21359','33154','18019','nodata','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21360','33172','18020','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21361','33172','18020','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21362','33195','18021','last','#1');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21363','33195','18021','last','#2');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21364','33195','18021','last','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21365','33196','18022','last','#1');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21366','33196','18022','last','#2');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21367','33196','18022','last','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21368','33197','18023','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21369','33198','18024','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21370','33199','18025','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21371','33204','18026','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21372','33204','18026','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21373','33206','18027','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21374','33206','18027','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21375','33208','18028','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21376','33208','18028','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21377','33209','18029','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21378','33210','18030','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21379','33219','18031','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21380','33220','18032','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21381','33220','18032','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21382','33221','18033','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21383','33221','18034','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21384','33224','18035','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21385','33231','18036','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21386','33231','18036','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21387','33233','18036','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21388','33232','18036','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21389','33231','18036','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21390','33227','18037','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21391','33231','18037','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21392','33230','18038','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21393','33231','18038','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21394','33226','18039','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21395','33226','18039','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21396','33229','18040','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21397','33229','18040','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21398','33232','18041','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21399','33234','18042','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21400','33235','18043','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21401','33235','18043','last','4');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21402','33235','18044','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21403','33236','18045','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21404','33236','18046','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21405','33237','18047','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21406','33237','18047','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21407','33237','18048','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21408','33237','18048','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21409','33237','18049','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21410','33237','18049','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21411','33238','18050','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21412','33239','18051','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21413','33240','18052','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21414','33245','18053','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21415','33245','18053','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21416','33247','18054','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21417','33247','18054','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21418','33249','18055','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21419','33249','18055','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21420','33250','18056','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21421','33251','18057','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21422','33260','18058','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21423','33261','18059','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21424','33261','18059','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21425','33262','18060','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21426','33262','18061','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21427','33265','18062','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21428','33272','18063','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21429','33272','18063','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21430','33274','18063','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21431','33273','18063','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21432','33272','18063','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21433','33268','18064','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21434','33272','18064','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21435','33271','18065','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21436','33272','18065','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21437','33267','18066','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21438','33267','18066','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21439','33270','18067','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21440','33270','18067','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21441','33273','18068','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21442','33275','18069','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21443','33276','18070','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21444','33276','18070','last','4');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21445','33276','18071','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21446','33277','18072','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21447','33277','18073','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21448','33278','18074','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21449','33278','18074','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21450','33278','18075','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21451','33278','18075','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21452','33278','18076','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21453','33278','18076','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21454','33279','18077','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21455','33280','18078','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21456','33281','18079','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21457','33286','18080','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21458','33286','18080','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21459','33288','18081','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21460','33288','18081','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21461','33290','18082','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21462','33290','18082','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21463','33291','18083','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21464','33292','18084','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21465','33301','18085','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21466','33302','18086','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21467','33302','18086','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21468','33303','18087','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21469','33303','18088','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21470','33306','18089','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21471','33313','18090','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21472','33313','18090','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21473','33315','18090','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21474','33314','18090','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21475','33313','18090','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21476','33309','18091','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21477','33313','18091','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21478','33312','18092','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21479','33313','18092','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21480','33308','18093','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21481','33308','18093','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21482','33311','18094','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21483','33311','18094','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21484','33314','18095','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21485','33316','18096','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21486','33317','18097','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21487','33317','18097','last','4');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21488','33317','18098','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21489','33318','18099','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21490','33318','18100','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21491','33319','18101','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21492','33319','18101','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21493','33319','18102','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21494','33319','18102','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21495','33319','18103','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21496','33319','18103','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21497','33320','18104','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21498','33321','18105','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21499','33322','18106','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21500','33327','18107','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21501','33327','18107','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21502','33329','18108','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21503','33329','18108','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21504','33331','18109','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21505','33331','18109','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21506','33332','18110','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21507','33333','18111','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21508','33342','18112','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21509','33343','18113','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21510','33343','18113','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21511','33344','18114','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21512','33344','18115','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21513','33347','18116','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21514','33354','18117','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21515','33354','18117','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21516','33356','18117','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21517','33355','18117','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21518','33354','18117','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21519','33350','18118','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21520','33354','18118','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21521','33353','18119','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21522','33354','18119','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21523','33349','18120','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21524','33349','18120','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21525','33352','18121','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21526','33352','18121','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21527','33355','18122','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21528','33357','18123','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21529','33358','18124','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21530','33358','18124','last','4');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21531','33358','18125','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21532','33359','18126','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21533','33359','18127','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21534','33360','18128','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21535','33360','18128','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21536','33360','18129','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21537','33360','18129','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21538','33360','18130','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21539','33360','18130','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21540','33361','18131','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21541','33362','18132','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21542','33363','18133','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21543','33368','18134','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21544','33368','18134','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21545','33370','18135','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21546','33370','18135','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21547','33372','18136','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21548','33372','18136','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21549','33373','18137','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21550','33374','18138','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21551','33383','18139','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21552','33384','18140','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21553','33384','18140','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21554','33385','18141','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21555','33385','18142','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21556','33388','18143','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21557','33395','18144','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21558','33395','18144','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21559','33397','18144','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21560','33396','18144','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21561','33395','18144','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21562','33391','18145','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21563','33395','18145','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21564','33394','18146','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21565','33395','18146','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21566','33390','18147','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21567','33390','18147','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21568','33393','18148','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21569','33393','18148','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21570','33396','18149','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21571','33398','18150','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21572','33399','18151','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21573','33399','18151','last','4');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21574','33399','18152','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21575','33400','18153','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21576','33400','18154','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21577','33401','18155','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21578','33401','18155','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21579','33401','18156','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21580','33401','18156','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21581','33401','18157','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21582','33401','18157','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21583','33402','18158','max','#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21584','33403','18159','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21585','33404','18160','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21586','33407','18161','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21587','33410','18162','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21588','33410','18162','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21589','33412','18163','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21590','33413','18164','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21591','28202','18165','count','#1,{$FAN.STATUS.CRIT},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21592','33423','18166','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21593','33423','18166','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21594','33425','18166','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21595','33424','18166','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21596','33423','18166','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21597','33419','18167','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21598','33423','18167','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21599','33422','18167','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21600','33418','18168','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21601','33421','18168','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21602','33418','18168','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21603','33421','18168','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21604','33424','18169','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21605','33424','18169','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21606','28206','18170','count','#1,{$PSU.STATUS.CRIT},eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21607','28201','18171','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21608','28200','18171','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21609','28201','18171','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21610','28201','18172','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21611','28201','18172','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21612','28201','18173','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21613','28201','18173','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21614','33426','18174','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21615','33427','18174','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21616','33428','18174','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21617','33426','18174','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21618','33426','18175','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21619','33427','18175','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21620','33428','18175','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21621','33426','18175','timeleft','1h,,100');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21622','33431','18176','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21623','33457','18177','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21624','33455','18178','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21625','33455','18179','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21626','33454','18180','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21630','33448','18184','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21631','33448','18184','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21632','33447','18185','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21633','33447','18185','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21634','33433','18186','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21635','33444','18187','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21636','33444','18188','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21637','33444','18189','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21638','33444','18190','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21639','33444','18191','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21640','33444','18192','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21641','33444','18193','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21642','33444','18194','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21643','33444','18195','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21644','33444','18196','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21645','33444','18197','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21648','33434','18199','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21649','33459','18200','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21650','33467','18201','regexp','"^(0)[0|1]{15}$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21652','33469','18203','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21653','33472','18204','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21654','33472','18205','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21655','33472','18206','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21656','33475','18207','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21657','33475','18208','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21658','33475','18209','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21659','33478','18210','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21660','33478','18210','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21661','33493','18211','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21662','33501','18212','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21663','33501','18212','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21664','33526','18213','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21665','33526','18213','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21666','33527','18214','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21667','33527','18214','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21668','33528','18215','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21669','33528','18215','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21670','33531','18216','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21671','33531','18216','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21672','33532','18217','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21673','33532','18217','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21674','33533','18218','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21675','33533','18218','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21676','33534','18219','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21677','33537','18220','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21678','33538','18221','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21679','33539','18222','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21680','33539','18222','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21681','33541','18223','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21682','33541','18223','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21683','33543','18224','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21684','33543','18224','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21685','33563','18225','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21686','33563','18225','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21687','32469','18226','avg','{$ACTIVEMQ.MSG.RATE.WARN.TIME:"{#JMXDESTINATIONNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21688','32468','18226','avg','{$ACTIVEMQ.MSG.RATE.WARN.TIME:"{#JMXDESTINATIONNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21689','32470','18227','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21690','32473','18228','min','{$ACTIVEMQ.QUEUE.TIME:"{#JMXDESTINATIONNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21691','32483','18229','avg','{$ACTIVEMQ.MSG.RATE.WARN.TIME:"{#JMXBROKERNAME}"}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21692','31933','18230','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21693','31922','18230','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21694','31649','18231','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21696','33568','18233','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21697','33593','18234','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21698','33591','18235','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21699','33591','18236','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21700','33590','18237','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21704','33584','18241','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21705','33584','18241','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21706','33583','18242','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21707','33583','18242','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21708','33569','18243','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21709','33580','18244','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21710','33580','18245','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21711','33580','18246','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21712','33580','18247','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21713','33580','18248','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21714','33580','18249','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21715','33580','18250','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21716','33580','18251','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21717','33580','18252','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21718','33580','18253','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21719','33580','18254','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21722','33570','18256','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21723','33595','18257','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21724','33604','18258','regexp','"^(0)[0|1]{15}$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21725','33605','18259','regexp','"^(0{16})$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21726','33606','18260','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21727','33609','18261','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21728','33609','18262','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21729','33609','18263','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21730','33612','18264','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21731','33612','18265','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21732','33612','18266','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21733','33615','18267','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21734','33615','18267','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21735','33618','18268','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21736','33618','18268','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21737','33619','18269','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21738','33644','18270','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21739','33642','18271','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21740','33642','18272','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21741','33641','18273','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21745','33635','18277','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21746','33635','18277','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21747','33634','18278','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21748','33634','18278','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21749','33620','18279','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21750','33631','18280','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21751','33631','18281','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21752','33631','18282','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21753','33631','18283','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21754','33631','18284','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21755','33631','18285','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21756','33631','18286','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21757','33631','18287','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21758','33631','18288','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21759','33631','18289','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21760','33631','18290','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21763','33621','18292','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21764','33646','18293','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21765','33655','18294','regexp','"^(0)[0|1]{15}$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21766','33656','18295','regexp','"^(0{16})$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21767','33657','18296','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21768','33660','18297','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21769','33660','18298','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21770','33660','18299','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21771','33663','18300','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21772','33663','18301','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21773','33663','18302','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21774','33666','18303','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21775','33666','18303','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21776','33669','18304','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21777','33669','18304','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21778','33670','18305','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21779','33695','18306','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21780','33693','18307','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21781','33693','18308','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21782','33692','18309','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21786','33686','18313','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21787','33686','18313','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21788','33685','18314','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21789','33685','18314','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21790','33671','18315','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21791','33682','18316','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21792','33682','18317','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21793','33682','18318','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21794','33682','18319','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21795','33682','18320','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21796','33682','18321','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21797','33682','18322','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21798','33682','18323','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21799','33682','18324','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21800','33682','18325','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21801','33682','18326','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21804','33672','18328','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21805','33697','18329','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21806','33706','18330','regexp','"^(0)[0|1]{15}$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21807','33707','18331','regexp','"^(0{16})$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21808','33708','18332','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21809','33711','18333','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21810','33711','18334','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21811','33711','18335','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21812','33714','18336','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21813','33714','18337','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21814','33714','18338','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21815','33717','18339','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21816','33717','18339','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21817','33720','18340','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21818','33720','18340','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21819','33721','18341','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21820','33746','18342','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21821','33744','18343','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21822','33744','18344','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21823','33743','18345','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21827','33737','18349','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21828','33737','18349','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21829','33736','18350','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21830','33736','18350','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21831','33722','18351','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21832','33733','18352','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21833','33733','18353','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21834','33733','18354','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21835','33733','18355','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21836','33733','18356','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21837','33733','18357','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21838','33733','18358','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21839','33733','18359','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21840','33733','18360','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21841','33733','18361','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21842','33733','18362','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21845','33723','18364','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21846','33748','18365','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21847','33757','18366','regexp','"^(0)[0|1]{15}$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21848','33758','18367','regexp','"^(0{16})$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21849','33759','18368','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21850','33762','18369','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21851','33762','18370','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21852','33762','18371','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21853','33765','18372','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21854','33765','18373','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21855','33765','18374','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21856','33768','18375','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21857','33768','18375','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21858','33771','18376','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21859','33771','18376','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21860','33772','18377','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21861','33797','18378','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21862','33795','18379','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21863','33795','18380','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21864','33794','18381','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21868','33788','18385','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21869','33788','18385','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21870','33787','18386','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21871','33787','18386','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21872','33773','18387','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21873','33784','18388','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21874','33784','18389','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21875','33784','18390','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21876','33784','18391','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21877','33784','18392','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21878','33784','18393','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21879','33784','18394','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21880','33784','18395','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21881','33784','18396','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21882','33784','18397','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21883','33784','18398','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21886','33774','18400','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21887','33799','18401','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21888','33808','18402','regexp','"^(0)[0|1]{15}$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21889','33809','18403','regexp','"^(0{16})$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21890','33810','18404','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21891','33813','18405','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21892','33813','18406','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21893','33813','18407','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21894','33816','18408','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21895','33816','18409','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21896','33816','18410','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21897','33819','18411','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21898','33819','18411','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21899','33822','18412','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21900','33822','18412','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21901','33823','18413','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21902','33848','18414','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21903','33846','18415','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21904','33846','18416','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21905','33845','18417','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21909','33839','18421','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21910','33839','18421','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21911','33838','18422','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21912','33838','18422','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21913','33824','18423','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21914','33835','18424','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21915','33835','18425','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21916','33835','18426','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21917','33835','18427','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21918','33835','18428','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21919','33835','18429','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21920','33835','18430','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21921','33835','18431','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21922','33835','18432','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21923','33835','18433','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21924','33835','18434','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21927','33825','18436','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21928','33850','18437','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21929','33859','18438','regexp','"^(0)[0|1]{15}$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21930','33860','18439','regexp','"^(0{16})$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21931','33861','18440','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21932','33864','18441','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21933','33864','18442','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21934','33864','18443','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21935','33867','18444','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21936','33867','18445','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21937','33867','18446','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21938','33870','18447','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21939','33870','18447','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21940','33873','18448','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21941','33873','18448','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21942','33874','18449','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21943','33899','18450','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21944','33897','18451','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21945','33897','18452','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21946','33896','18453','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21950','33890','18457','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21951','33890','18457','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21952','33889','18458','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21953','33889','18458','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21954','33875','18459','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21955','33886','18460','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21956','33886','18461','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21957','33886','18462','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21958','33886','18463','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21959','33886','18464','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21960','33886','18465','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21961','33886','18466','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21962','33886','18467','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21963','33886','18468','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21964','33886','18469','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21965','33886','18470','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21968','33876','18472','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21969','33901','18473','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21970','33910','18474','regexp','"^(0)[0|1]{15}$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21971','33911','18475','regexp','"^(0{16})$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21972','33912','18476','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21973','33915','18477','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21974','33915','18478','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21975','33915','18479','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21976','33918','18480','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21977','33918','18481','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21978','33918','18482','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21979','33921','18483','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21980','33921','18483','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21981','33924','18484','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21982','33924','18484','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21983','33925','18485','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21984','33468','18486','regexp','"^(0{16})$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21985','33929','18487','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21986','33929','18487','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21987','33930','18488','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21988','33955','18489','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21989','33953','18490','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21990','33953','18491','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21991','33952','18492','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21995','33946','18496','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21996','33946','18496','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21997','33945','18497','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21998','33945','18497','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('21999','33931','18498','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22000','33942','18499','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22001','33942','18500','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22002','33942','18501','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22003','33942','18502','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22004','33942','18503','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22005','33942','18504','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22006','33942','18505','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22007','33942','18506','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22008','33942','18507','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22009','33942','18508','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22010','33942','18509','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22013','33932','18511','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22014','33957','18512','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22015','33966','18513','regexp','"^(0)[0|1]{15}$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22016','33967','18514','regexp','"^(0{16})$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22017','33968','18515','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22018','33971','18516','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22019','33971','18517','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22020','33971','18518','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22021','33974','18519','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22022','33974','18520','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22023','33974','18521','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22024','33977','18522','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22025','33977','18522','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22026','33980','18523','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22027','33980','18523','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22028','33981','18524','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22029','34006','18525','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22030','34004','18526','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22031','34004','18527','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22032','34003','18528','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22036','33997','18532','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22037','33997','18532','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22038','33996','18533','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22039','33996','18533','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22040','33982','18534','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22041','33993','18535','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22042','33993','18536','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22043','33993','18537','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22044','33993','18538','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22045','33993','18539','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22046','33993','18540','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22047','33993','18541','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22048','33993','18542','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22049','33993','18543','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22050','33993','18544','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22051','33993','18545','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22054','33983','18547','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22055','34008','18548','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22056','34017','18549','regexp','"^(0)[0|1]{15}$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22057','34018','18550','regexp','"^(0{16})$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22058','34019','18551','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22059','34022','18552','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22060','34022','18553','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22061','34022','18554','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22062','34025','18555','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22063','34025','18556','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22064','34025','18557','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22065','34028','18558','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22066','34028','18558','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22067','34031','18559','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22068','34031','18559','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22069','34032','18560','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22070','34057','18561','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22071','34055','18562','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22072','34055','18563','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22073','34054','18564','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22077','34048','18568','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22078','34048','18568','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22079','34047','18569','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22080','34047','18569','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22081','34033','18570','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22082','34044','18571','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22083','34044','18572','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22084','34044','18573','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22085','34044','18574','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22086','34044','18575','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22087','34044','18576','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22088','34044','18577','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22089','34044','18578','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22090','34044','18579','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22091','34044','18580','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22092','34044','18581','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22095','34034','18583','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22096','34059','18584','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22097','34068','18585','regexp','"^(0)[0|1]{15}$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22098','34069','18586','regexp','"^(0{16})$"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22099','34070','18587','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22100','34073','18588','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22101','34073','18589','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22102','34073','18590','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22103','34076','18591','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22104','34076','18592','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22105','34076','18593','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22106','34079','18594','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22107','34079','18594','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22108','34082','18595','min','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22109','34082','18595','max','{$TIME.PERIOD}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22110','34083','18596','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22111','34083','18596','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22112','34084','18597','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22113','34084','18597','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22114','34085','18598','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22115','34085','18598','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22116','34086','18599','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22117','34086','18599','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22118','34087','18600','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22119','34087','18600','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22120','34088','18601','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22121','34088','18601','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22122','34089','18602','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22123','34089','18602','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22124','34090','18603','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22125','34090','18603','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22126','34091','18604','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22127','34091','18604','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22128','34092','18605','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22129','34092','18605','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22130','34093','18606','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22131','34093','18606','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22132','34094','18607','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22133','34098','18608','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22134','34098','18608','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22135','34102','18609','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22136','34102','18609','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22137','34103','18610','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22138','34103','18610','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22139','34106','18611','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22140','34106','18612','nodata','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22141','34119','18613','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22142','34119','18613','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22143','34118','18614','str','ok');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22144','34117','18615','str','running');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22145','34151','18616','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22146','34153','18617','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22147','34149','18617','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22148','34134','18618','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22149','34151','18619','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22150','34150','18620','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22151','34148','18621','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22152','34166','18622','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22153','34172','18623','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22154','34172','18623','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22155','31086','18624','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22156','31087','18625','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22157','34177','18626','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22158','34177','18627','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22159','34180','18628','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22160','34180','18629','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22161','34178','18630','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22162','34178','18631','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22163','34185','18632','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22164','34186','18633','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22165','30434','18634','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22166','30640','18635','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22167','30483','18636','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22168','22424','18637','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22169','25370','18638','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22170','29822','18639','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22172','22412','18641','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22173','22430','18642','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22174','22422','18643','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22176','22406','18645','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22177','22408','18646','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22178','22402','18647','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22179','22418','18648','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22180','25366','18649','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22181','22416','18650','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22182','22689','18651','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22183','28535','18652','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22184','28537','18653','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22185','22399','18654','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22186','25665','18655','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22187','25666','18656','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22188','22420','18657','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22191','22414','18660','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22192','23171','18661','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22193','23663','18662','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22194','22426','18663','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22195','22404','18664','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22196','22400','18665','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22197','22401','18666','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22198','22219','18667','min','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22199','22189','18668','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22200','22191','18669','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22201','23661','18670','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22202','34189','18671','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22203','34189','18671','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22204','23634','18672','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22205','22183','18673','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22206','22396','18674','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22207','22185','18675','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22208','23252','18676','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22209','25371','18677','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22210','29823','18678','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22212','23253','18680','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22213','23255','18681','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22214','23256','18682','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22216','23257','18684','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22217','23258','18685','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22218','23259','18686','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22219','23260','18687','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22220','25367','18688','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22221','23261','18689','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22222','23262','18690','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22223','28536','18691','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22224','28538','18692','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22225','23264','18693','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22226','25667','18694','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22227','25668','18695','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22228','23265','18696','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22231','23266','18699','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22232','23267','18700','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22233','23664','18701','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22234','23268','18702','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22235','23269','18703','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22236','23270','18704','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22237','23328','18705','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22238','23271','18706','min','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22239','23273','18707','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22240','23620','18708','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22241','23662','18709','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22242','34196','18710','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22243','34196','18710','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22244','23635','18711','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22245','23274','18712','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22246','23275','18713','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22247','23276','18714','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22248','28561','18715','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22249','28563','18716','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22250','29821','18717','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22252','28564','18719','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22253','28565','18720','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22254','28566','18721','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22256','28567','18723','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22257','28568','18724','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22258','28569','18725','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22259','28570','18726','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22260','28562','18727','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22261','28571','18728','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22262','28573','18729','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22263','28582','18730','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22264','28583','18731','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22265','28574','18732','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22266','28575','18733','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22267','28576','18734','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22268','28577','18735','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22271','28578','18738','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22272','28579','18739','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22273','28580','18740','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22274','28572','18741','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22275','28581','18742','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22276','28552','18743','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22277','28559','18744','avg','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22278','28543','18745','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22279','28544','18746','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22280','28547','18747','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22281','31053','18748','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22282','31053','18748','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22283','28548','18749','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22284','28549','18750','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22285','28542','18751','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22286','28551','18752','max','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22287','28541','18753','min','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22288','33105','18754','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22289','34207','18755','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22290','34209','18756','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22291','34209','18756','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22292','34212','18757','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22293','34214','18758','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22294','34214','18758','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22295','34215','18759','str','"moduleNoDefect"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22296','34216','18760','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22297','34222','18761','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22298','34224','18762','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22299','34225','18763','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22300','34227','18764','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22301','34230','18765','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22302','34230','18765','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22303','34235','18766','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22304','34235','18766','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22305','34237','18767','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22306','34238','18768','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22307','34239','18769','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22308','34241','18770','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22309','34242','18771','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22310','34242','18771','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22311','34245','18772','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22312','34247','18773','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22313','34247','18773','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22314','34248','18774','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22315','34255','18775','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22316','34263','18776','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22317','34263','18776','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22318','34273','18777','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22319','34273','18778','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22320','34277','18779','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22321','34277','18779','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22322','34281','18780','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22323','34282','18781','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22324','34283','18782','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22325','34285','18783','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22326','34286','18784','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22327','34286','18784','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22328','34289','18785','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22329','34291','18786','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22330','34291','18786','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22331','34292','18787','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22332','34297','18788','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22333','34305','18789','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22334','34305','18789','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22335','34315','18790','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22336','34316','18791','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22337','34317','18792','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22338','34321','18793','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22339','34323','18794','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22340','34333','18795','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22341','34334','18796','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22342','34335','18797','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22343','34336','18798','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22344','34346','18799','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22345','34352','18800','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22346','34351','18801','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22347','34349','18802','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22348','34342','18803','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22349','34342','18803','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22350','34364','18804','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22351','34364','18804','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22352','34370','18805','str','"moduleNoDefect"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22353','34371','18806','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22354','34371','18806','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22355','34373','18807','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22356','34373','18807','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22357','34374','18808','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22358','34374','18808','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22359','34375','18809','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22360','34375','18809','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22361','34378','18810','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22362','34378','18810','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22363','34381','18811','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22364','34382','18812','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22365','34383','18813','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22366','34384','18814','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22367','34388','18815','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22368','34390','18816','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22369','34400','18817','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22370','34401','18818','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22371','34402','18819','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22372','34403','18820','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22373','34413','18821','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22374','34419','18822','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22375','34418','18823','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22376','34416','18824','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22377','34409','18825','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22378','34409','18825','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22379','34431','18826','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22380','34431','18826','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22381','34437','18827','str','"moduleNoDefect"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22382','34438','18828','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22383','34438','18828','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22384','34440','18829','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22385','34440','18829','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22386','34441','18830','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22387','34441','18830','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22388','34442','18831','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22389','34442','18831','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22390','34445','18832','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22391','34445','18832','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22392','34448','18833','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22393','34449','18834','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22394','34450','18835','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22395','34451','18836','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22396','34453','18837','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22397','34453','18837','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22398','34456','18838','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22399','34458','18839','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22400','34458','18839','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22401','34459','18840','str','"moduleNoDefect"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22402','34460','18841','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22403','34466','18842','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22404','34468','18843','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22405','34470','18844','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22406','34471','18845','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22407','34473','18846','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22408','34476','18847','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22409','34476','18847','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22410','34481','18848','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22411','34481','18848','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22412','34483','18849','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22413','34484','18850','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22414','34485','18851','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22415','34487','18852','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22416','34488','18853','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22417','34488','18853','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22418','34491','18854','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22419','34493','18855','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22420','34493','18855','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22421','34494','18856','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22422','34505','18857','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22423','34505','18857','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22424','34515','18858','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22425','34515','18859','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22426','34519','18860','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22427','34519','18860','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22428','34523','18861','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22429','34525','18862','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22430','34526','18863','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22431','34526','18863','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22432','34529','18864','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22433','34531','18865','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22434','34531','18865','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22435','34532','18866','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22436','34539','18867','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22437','34547','18868','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22438','34547','18868','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22439','34557','18869','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22440','34557','18870','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22441','34561','18871','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22442','34561','18871','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22443','34565','18872','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22444','34566','18873','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22445','34567','18874','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22446','34569','18875','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22447','34570','18876','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22448','34570','18876','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22449','34573','18877','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22450','34575','18878','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22451','34575','18878','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22452','34576','18879','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22453','34583','18880','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22454','34591','18881','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22455','34591','18881','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22456','34601','18882','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22457','34601','18883','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22458','34605','18884','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22459','34605','18884','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22460','34609','18885','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22461','34610','18886','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22462','34611','18887','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22463','34613','18888','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22464','34614','18889','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22465','34614','18889','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22466','34617','18890','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22467','34619','18891','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22468','34619','18891','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22469','34620','18892','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22470','34627','18893','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22471','34635','18894','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22472','34635','18894','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22473','34645','18895','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22474','34645','18896','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22475','34649','18897','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22476','34649','18897','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22477','34653','18898','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22478','34654','18899','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22479','34655','18900','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22480','34657','18901','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22481','34658','18902','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22482','34658','18902','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22483','34661','18903','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22484','34663','18904','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22485','34663','18904','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22486','34664','18905','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22487','34671','18906','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22488','34679','18907','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22489','34679','18907','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22490','34689','18908','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22491','34689','18909','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22492','34693','18910','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22493','34693','18910','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22494','34697','18911','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22495','34698','18912','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22496','34699','18913','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22497','34701','18914','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22498','34702','18915','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22499','34702','18915','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22500','34705','18916','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22501','34706','18917','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22502','34708','18918','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22503','34708','18918','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22504','34709','18919','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22505','34716','18920','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22506','34724','18921','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22507','34724','18921','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22508','34734','18922','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22509','34734','18923','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22510','34738','18924','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22511','34738','18924','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22512','34742','18925','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22513','34743','18926','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22514','34744','18927','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22515','34746','18928','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22516','34747','18929','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22517','34747','18929','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22518','34750','18930','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22519','34751','18931','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22520','34753','18932','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22521','34753','18932','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22522','34754','18933','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22523','34761','18934','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22524','34769','18935','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22525','34769','18935','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22526','34779','18936','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22527','34779','18937','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22528','34783','18938','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22529','34783','18938','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22530','34787','18939','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22531','34788','18940','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22532','34789','18941','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22533','34791','18942','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22534','34792','18943','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22535','34792','18943','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22536','34795','18944','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22537','34797','18945','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22538','34797','18945','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22539','34798','18946','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22540','34806','18947','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22541','34807','18948','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22542','34815','18949','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22543','34815','18949','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22544','34825','18950','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22545','34825','18951','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22546','34829','18952','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22547','34829','18952','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22548','34833','18953','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22549','34834','18954','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22550','34850','18955','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22551','34856','18956','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22552','34858','18957','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22553','34858','18958','nodata','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22554','34853','18959','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22555','34853','18959','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22556','34894','18960','sum','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22557','34892','18960','sum','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22558','34893','18961','sum','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22559','34892','18961','sum','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22560','34890','18962','str','up');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22561','34890','18962','str','down');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22562','34940','18963','str','up');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22563','34940','18963','str','down');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22564','34945','18964','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22565','34949','18965','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22566','34949','18965','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22567','34951','18966','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22568','34953','18967','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22569','34964','18968','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22570','34964','18969','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22571','34966','18970','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22572','34966','18971','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22573','34966','18972','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22574','34967','18973','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22575','34967','18974','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22576','34971','18975','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22577','34976','18975','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22578','34980','18976','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22579','34980','18976','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22580','34984','18977','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22581','34984','18977','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22582','34986','18978','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22583','34986','18979','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22584','34987','18980','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22585','34987','18981','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22586','34988','18982','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22587','34988','18982','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22588','34988','18983','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22589','34988','18983','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22590','34989','18984','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22591','34989','18984','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22592','34989','18985','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22593','34989','18985','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22594','34990','18986','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22595','34990','18986','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22596','34990','18987','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22597','34990','18987','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22598','34991','18988','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22599','34991','18988','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22600','34991','18989','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22601','34991','18989','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22602','34992','18990','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22603','34992','18990','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22604','34992','18991','avg','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22605','34992','18991','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22606','34994','18992','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22607','34994','18992','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22608','34995','18993','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22609','34995','18994','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22610','34998','18995','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22638','35043','19019','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22639','35043','19019','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22640','35045','19020','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22641','35045','19020','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22642','35047','19021','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22643','35047','19021','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22644','35049','19022','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22645','35049','19023','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22646','35049','19024','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22647','35050','19025','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22648','35050','19025','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22649','35051','19026','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22650','35053','19027','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22651','35061','19028','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22652','35061','19029','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22653','35061','19030','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22654','35063','19031','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22655','35063','19032','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22656','35063','19033','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22657','35065','19034','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22658','35065','19035','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22659','35068','19036','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22660','35068','19036','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22661','35070','19037','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22662','35071','19038','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22663','35071','19039','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22664','35072','19040','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22665','35072','19041','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22666','35073','19042','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22667','35073','19043','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22668','35073','19044','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22669','35079','19045','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22670','35079','19046','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22698','35125','19070','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22699','35125','19070','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22700','35127','19071','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22701','35127','19071','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22702','35129','19072','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22703','35129','19072','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22704','35131','19073','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22705','35131','19074','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22706','35131','19075','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22707','35132','19076','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22708','35132','19076','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22709','35133','19077','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22710','35135','19078','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22711','35143','19079','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22712','35143','19080','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22713','35143','19081','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22714','35145','19082','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22715','35145','19083','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22716','35145','19084','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22717','35147','19085','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22718','35147','19086','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22719','35150','19087','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22720','35150','19087','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22721','35152','19088','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22722','35153','19089','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22723','35153','19090','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22724','35154','19091','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22725','35154','19092','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22726','35155','19093','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22727','35155','19094','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22728','35155','19095','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22729','35161','19096','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22730','35161','19097','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22758','35207','19121','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22759','35207','19121','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22760','35209','19122','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22761','35209','19122','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22762','35211','19123','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22763','35211','19123','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22764','35213','19124','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22765','35213','19125','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22766','35213','19126','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22767','35214','19127','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22768','35214','19127','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22769','35215','19128','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22770','35217','19129','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22771','35225','19130','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22772','35225','19131','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22773','35225','19132','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22774','35227','19133','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22775','35227','19134','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22776','35227','19135','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22777','35229','19136','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22778','35229','19137','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22779','35232','19138','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22780','35232','19138','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22781','35234','19139','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22782','35235','19140','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22783','35235','19141','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22784','35236','19142','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22785','35236','19143','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22786','35237','19144','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22787','35237','19145','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22788','35237','19146','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22789','35243','19147','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22790','35243','19148','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22818','35289','19172','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22819','35289','19172','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22820','35291','19173','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22821','35291','19173','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22822','35293','19174','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22823','35293','19174','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22824','35295','19175','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22825','35295','19176','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22826','35295','19177','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22827','35296','19178','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22828','35296','19178','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22829','35297','19179','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22830','35299','19180','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22831','35307','19181','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22832','35307','19182','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22833','35307','19183','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22834','35309','19184','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22835','35309','19185','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22836','35309','19186','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22837','35311','19187','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22838','35311','19188','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22839','35314','19189','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22840','35314','19189','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22841','35316','19190','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22842','35317','19191','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22843','35317','19192','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22844','35318','19193','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22845','35318','19194','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22846','35319','19195','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22847','35319','19196','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22848','35319','19197','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22849','35325','19198','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22850','35325','19199','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22851','35330','19200','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22852','35330','19200','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22853','35332','19201','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22854','35332','19201','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22855','35335','19202','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22856','35335','19203','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22857','35336','19204','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22858','35338','19205','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22859','35353','19206','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22860','35353','19207','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22861','35354','19208','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22862','35354','19209','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22863','35354','19210','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22864','35356','19211','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22865','35356','19212','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22866','35357','19213','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22867','35357','19214','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22868','35358','19215','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22869','35358','19216','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22870','35361','19217','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22871','35361','19217','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22872','35363','19218','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22873','35364','19219','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22874','35364','19220','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22875','35365','19221','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22876','35365','19222','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22877','35366','19223','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22878','35366','19224','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22879','35366','19225','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22880','35368','19226','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22881','35368','19227','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22882','35368','19228','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22883','35370','19229','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22884','35370','19230','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22885','35370','19231','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22886','35373','19232','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22887','35373','19233','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22888','35373','19234','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22889','35375','19235','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22890','35375','19236','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22891','35375','19237','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22892','35377','19238','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22893','35377','19239','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22894','35377','19240','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22895','35379','19241','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22896','35379','19242','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22897','35379','19243','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22898','35383','19244','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22899','35383','19245','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22900','35387','19246','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22901','35387','19246','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22902','35389','19247','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22903','35389','19247','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22904','35392','19248','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22905','35392','19249','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22906','35393','19250','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22907','35395','19251','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22908','35410','19252','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22909','35410','19253','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22910','35411','19254','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22911','35411','19255','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22912','35411','19256','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22913','35413','19257','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22914','35413','19258','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22915','35414','19259','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22916','35414','19260','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22917','35415','19261','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22918','35415','19262','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22919','35418','19263','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22920','35418','19263','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22921','35420','19264','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22922','35421','19265','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22923','35421','19266','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22924','35422','19267','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22925','35422','19268','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22926','35423','19269','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22927','35423','19270','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22928','35423','19271','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22929','35425','19272','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22930','35425','19273','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22931','35425','19274','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22932','35427','19275','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22933','35427','19276','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22934','35427','19277','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22935','35430','19278','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22936','35430','19279','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22937','35430','19280','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22938','35432','19281','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22939','35432','19282','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22940','35432','19283','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22941','35434','19284','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22942','35434','19285','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22943','35434','19286','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22944','35436','19287','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22945','35436','19288','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22946','35436','19289','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22947','35440','19290','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22948','35440','19291','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22949','35444','19292','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22950','35444','19292','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22951','35446','19293','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22952','35446','19293','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22953','35449','19294','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22954','35449','19295','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22955','35450','19296','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22956','35452','19297','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22957','35467','19298','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22958','35467','19299','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22959','35468','19300','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22960','35468','19301','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22961','35468','19302','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22962','35470','19303','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22963','35470','19304','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22964','35471','19305','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22965','35471','19306','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22966','35472','19307','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22967','35472','19308','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22968','35475','19309','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22969','35475','19309','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22970','35477','19310','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22971','35478','19311','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22972','35478','19312','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22973','35479','19313','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22974','35479','19314','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22975','35480','19315','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22976','35480','19316','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22977','35480','19317','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22978','35482','19318','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22979','35482','19319','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22980','35482','19320','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22981','35484','19321','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22982','35484','19322','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22983','35484','19323','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22984','35487','19324','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22985','35487','19325','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22986','35487','19326','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22987','35489','19327','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22988','35489','19328','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22989','35489','19329','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22990','35491','19330','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22991','35491','19331','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22992','35491','19332','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22993','35493','19333','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22994','35493','19334','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22995','35493','19335','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22996','35497','19336','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22997','35497','19337','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22998','35501','19338','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('22999','35501','19338','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23000','35503','19339','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23001','35503','19339','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23002','35506','19340','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23003','35506','19341','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23004','35507','19342','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23005','35509','19343','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23006','35524','19344','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23007','35524','19345','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23008','35525','19346','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23009','35525','19347','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23010','35525','19348','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23011','35527','19349','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23012','35527','19350','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23013','35528','19351','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23014','35528','19352','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23015','35529','19353','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23016','35529','19354','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23017','35532','19355','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23018','35532','19355','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23019','35534','19356','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23020','35535','19357','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23021','35535','19358','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23022','35536','19359','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23023','35536','19360','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23024','35537','19361','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23025','35537','19362','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23026','35537','19363','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23027','35539','19364','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23028','35539','19365','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23029','35539','19366','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23030','35541','19367','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23031','35541','19368','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23032','35541','19369','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23033','35544','19370','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23034','35544','19371','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23035','35544','19372','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23036','35546','19373','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23037','35546','19374','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23038','35546','19375','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23039','35548','19376','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23040','35548','19377','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23041','35548','19378','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23042','35550','19379','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23043','35550','19380','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23044','35550','19381','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23045','35554','19382','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23046','35554','19383','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23050','35562','19387','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23051','35565','19388','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23052','35578','19389','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23053','35585','19389','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23054','35579','19390','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23055','35579','19390','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23056','35580','19391','max','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23057','35585','19392','max','30m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23058','35590','19393','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23059','35601','19394','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23060','35592','19394','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23061','35601','19395','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23062','35592','19395','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23063','35597','19396','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23064','35596','19396','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23065','35597','19397','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23066','35596','19397','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23067','35594','19398','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23068','35599','19399','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23069','35604','19400','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23070','35604','19401','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23071','35606','19402','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23072','35607','19403','min','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23073','35616','19404','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23074','35613','19404','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23075','35616','19405','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23076','35616','19406','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23077','35617','19407','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23078','35617','19407','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23079','35619','19408','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23080','35619','19409','nodata','10m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23081','35624','19410','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23082','35624','19410','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23083','35642','19411','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23084','35645','19411','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23085','35644','19412','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23086','35643','19412','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23087','35644','19413','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23088','35643','19413','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23089','35654','19414','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23090','35654','19414','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23091','35648','19415','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23092','35663','19416','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23093','35682','19417','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23094','35682','19417','now','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23095','35684','19418','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23096','35685','19419','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23097','35692','19420','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23098','35718','19421','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23099','35720','19421','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23100','35727','19422','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23101','35724','19422','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23102','35726','19423','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23103','35723','19423','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23104','35735','19424','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23105','35735','19424','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23106','35741','19424','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23107','35741','19424','prev','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23108','32642','19425','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23109','32645','19425','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23110','32642','19425','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23111','32645','19425','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23112','35776','19426','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23113','35776','19426','now','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23114','35780','19427','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23115','35783','19428','str','"invalid"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23116','35801','19429','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23117','35795','19430','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23118','35794','19431','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23119','35793','19432','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23120','35792','19433','count','#5,"DOWN",eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23121','35809','19434','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23122','35810','19435','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23123','35786','19436','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23124','35840','19437','regexp','"(?:L[4-7]OK|^$)",#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23125','35837','19438','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23126','35830','19439','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23127','35828','19440','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23128','35827','19441','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23129','35826','19442','count','#5,"DOWN",eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23130','35860','19443','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23131','35854','19444','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23132','35853','19445','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23133','35852','19446','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23134','35851','19447','count','#5,"DOWN",eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23135','35868','19448','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23136','35869','19449','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23137','35845','19450','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23138','35899','19451','regexp','"(?:L[4-7]OK|^$)",#3');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23139','35896','19452','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23140','35889','19453','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23141','35887','19454','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23142','35886','19455','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23143','35885','19456','count','#5,"DOWN",eq');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23144','35907','19457','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23145','35908','19458','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23146','35914','19459','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23147','35917','19460','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23148','35927','19461','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23149','35927','19461','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23150','35939','19462','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23151','35939','19462','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23152','35951','19463','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23153','35953','19464','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23154','35953','19464','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23155','35956','19465','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23156','35958','19466','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23157','35958','19466','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23158','35959','19467','str','"moduleNoDefect"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23159','35960','19468','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23160','35966','19469','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23161','35968','19470','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23162','35969','19471','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23163','35971','19472','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23164','35974','19473','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23165','35974','19473','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23166','35979','19474','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23167','35979','19474','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23168','35981','19475','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23169','35982','19476','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23170','35983','19477','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23171','35985','19478','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23172','35986','19479','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23173','35986','19479','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23174','35989','19480','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23175','35991','19481','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23176','35991','19481','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23177','35992','19482','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23178','35999','19483','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23179','36007','19484','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23180','36007','19484','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23181','36017','19485','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23182','36017','19486','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23183','36021','19487','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23184','36021','19487','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23185','36025','19488','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23186','36026','19489','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23187','36027','19490','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23188','36029','19491','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23189','36030','19492','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23190','36030','19492','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23191','36033','19493','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23192','36035','19494','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23193','36035','19494','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23194','36036','19495','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23195','36041','19496','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23196','36049','19497','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23197','36049','19497','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23198','36059','19498','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23199','36060','19499','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23200','36061','19500','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23201','36065','19501','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23202','36067','19502','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23203','36077','19503','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23204','36078','19504','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23205','36079','19505','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23206','36080','19506','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23207','36090','19507','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23208','36096','19508','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23209','36095','19509','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23210','36093','19510','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23211','36086','19511','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23212','36086','19511','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23213','36108','19512','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23214','36108','19512','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23215','36114','19513','str','"moduleNoDefect"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23216','36115','19514','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23217','36115','19514','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23218','36117','19515','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23219','36117','19515','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23220','36118','19516','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23221','36118','19516','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23222','36119','19517','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23223','36119','19517','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23224','36122','19518','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23225','36122','19518','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23226','36125','19519','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23227','36126','19520','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23228','36127','19521','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23229','36128','19522','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23230','36132','19523','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23231','36134','19524','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23232','36144','19525','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23233','36145','19526','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23234','36146','19527','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23235','36147','19528','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23236','36157','19529','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23237','36163','19530','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23238','36162','19531','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23239','36160','19532','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23240','36153','19533','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23241','36153','19533','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23242','36175','19534','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23243','36175','19534','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23244','36181','19535','str','"moduleNoDefect"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23245','36182','19536','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23246','36182','19536','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23247','36184','19537','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23248','36184','19537','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23249','36185','19538','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23250','36185','19538','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23251','36186','19539','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23252','36186','19539','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23253','36189','19540','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23254','36189','19540','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23255','36192','19541','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23256','36193','19542','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23257','36194','19543','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23258','36195','19544','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23259','36197','19545','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23260','36197','19545','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23261','36200','19546','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23262','36202','19547','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23263','36202','19547','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23264','36203','19548','str','"moduleNoDefect"');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23265','36204','19549','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23266','36210','19550','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23267','36212','19551','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23268','36214','19552','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23269','36215','19553','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23270','36217','19554','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23271','36220','19555','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23272','36220','19555','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23273','36225','19556','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23274','36225','19556','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23275','36227','19557','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23276','36228','19558','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23277','36229','19559','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23278','36231','19560','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23279','36232','19561','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23280','36232','19561','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23281','36235','19562','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23282','36237','19563','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23283','36237','19563','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23284','36238','19564','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23285','36249','19565','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23286','36249','19565','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23287','36259','19566','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23288','36259','19567','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23289','36263','19568','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23290','36263','19568','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23291','36267','19569','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23292','36269','19570','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23293','36270','19571','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23294','36270','19571','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23295','36273','19572','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23296','36275','19573','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23297','36275','19573','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23298','36276','19574','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23299','36283','19575','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23300','36291','19576','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23301','36291','19576','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23302','36301','19577','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23303','36301','19578','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23304','36305','19579','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23305','36305','19579','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23306','36309','19580','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23307','36310','19581','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23308','36311','19582','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23309','36313','19583','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23310','36314','19584','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23311','36314','19584','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23312','36317','19585','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23313','36319','19586','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23314','36319','19586','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23315','36320','19587','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23316','36327','19588','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23317','36335','19589','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23318','36335','19589','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23319','36345','19590','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23320','36345','19591','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23321','36349','19592','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23322','36349','19592','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23323','36353','19593','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23324','36354','19594','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23325','36355','19595','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23326','36357','19596','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23327','36358','19597','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23328','36358','19597','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23329','36361','19598','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23330','36363','19599','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23331','36363','19599','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23332','36364','19600','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23333','36371','19601','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23334','36379','19602','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23335','36379','19602','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23336','36389','19603','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23337','36389','19604','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23338','36393','19605','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23339','36393','19605','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23340','36397','19606','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23341','36398','19607','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23342','36399','19608','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23343','36401','19609','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23344','36402','19610','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23345','36402','19610','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23346','36405','19611','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23347','36407','19612','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23348','36407','19612','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23349','36408','19613','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23350','36415','19614','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23351','36423','19615','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23352','36423','19615','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23353','36433','19616','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23354','36433','19617','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23355','36437','19618','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23356','36437','19618','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23357','36441','19619','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23358','36442','19620','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23359','36443','19621','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23360','36445','19622','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23361','36446','19623','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23362','36446','19623','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23363','36449','19624','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23364','36450','19625','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23365','36452','19626','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23366','36452','19626','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23367','36453','19627','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23368','36460','19628','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23369','36468','19629','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23370','36468','19629','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23371','36478','19630','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23372','36478','19631','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23373','36482','19632','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23374','36482','19632','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23375','36486','19633','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23376','36487','19634','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23377','36488','19635','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23378','36490','19636','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23379','36491','19637','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23380','36491','19637','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23381','36494','19638','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23382','36495','19639','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23383','36497','19640','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23384','36497','19640','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23385','36498','19641','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23386','36505','19642','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23387','36513','19643','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23388','36513','19643','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23389','36523','19644','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23390','36523','19645','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23391','36527','19646','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23392','36527','19646','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23393','36531','19647','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23394','36532','19648','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23395','36533','19649','max','{$SNMP.TIMEOUT}');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23396','36535','19650','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23397','36536','19651','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23398','36536','19651','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23399','36539','19652','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23400','36541','19653','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23401','36541','19653','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23402','36542','19654','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23403','36550','19655','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23404','36551','19656','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23405','36559','19657','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23406','36559','19657','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23407','36569','19658','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23408','36569','19659','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23409','36573','19660','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23410','36573','19660','strlen','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23411','36577','19661','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23412','36578','19662','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23413','36595','19663','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23414','36595','19663','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23415','36596','19663','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23416','36585','19664','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23417','36595','19664','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23418','36588','19664','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23419','36584','19665','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23420','36587','19665','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23421','36584','19665','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23422','36587','19665','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23423','36596','19666','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23424','36596','19666','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23425','36598','19667','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23426','36598','19667','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23427','36599','19667','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23428','36591','19668','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23429','36598','19668','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23430','36594','19668','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23431','36590','19669','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23432','36593','19669','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23433','36590','19669','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23434','36593','19669','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23435','36599','19670','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23436','36599','19670','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23437','36617','19671','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23438','36617','19671','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23439','36618','19671','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23440','36607','19672','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23441','36617','19672','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23442','36610','19672','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23443','36606','19673','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23444','36609','19673','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23445','36606','19673','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23446','36609','19673','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23447','36618','19674','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23448','36618','19674','diff','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23449','36620','19675','change','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23450','36620','19675','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23451','36621','19675','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23452','36613','19676','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23453','36620','19676','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23454','36616','19676','avg','15m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23455','36612','19677','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23456','36615','19677','min','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23457','36612','19677','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23458','36615','19677','max','5m');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23459','36621','19678','last','');
INSERT INTO functions (functionid,itemid,triggerid,name,parameter) values ('23460','36621','19678','diff','');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('456','CPU utilization','900','200','0','100',NULL,'1','0','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('457','CPU load','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('458','Swap usage','600','340','0','100',NULL,'0','0','2','1','1','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('459','CPU jumps','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('461','Disk space usage {#FSNAME}','600','340','0','100',NULL,'0','0','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('462','CPU utilization','900','200','0','100',NULL,'1','0','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('463','CPU load','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('464','Swap usage','600','340','0','100',NULL,'0','0','2','1','1','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('465','CPU jumps','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('467','Disk space usage {#FSNAME}','600','340','0','100',NULL,'0','0','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('469','CPU load','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('471','CPU jumps','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('472','Network traffic on {#IFNAME}','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('473','Disk space usage {#FSNAME}','600','340','0','100',NULL,'0','0','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('474','CPU utilization','900','200','0','100',NULL,'1','0','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('475','CPU load','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('478','Network traffic on {#IFNAME}','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('479','Disk space usage {#FSNAME}','600','340','0','100',NULL,'0','0','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('480','CPU utilization','900','200','0','100',NULL,'1','0','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('481','CPU load','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('482','Swap usage','600','340','0','100',NULL,'0','0','2','1','1','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('483','CPU jumps','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('484','Network traffic on {#IFNAME}','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('485','Disk space usage {#FSNAME}','600','340','0','100',NULL,'0','0','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('487','CPU load','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('491','Disk space usage {#FSNAME}','600','340','0','100',NULL,'0','0','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('492','Network traffic on {#IFNAME}','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('493','Network traffic on {#IFNAME}','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('494','Network traffic on en0','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('498','CPU utilization','900','200','0','100',NULL,'1','0','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('529','Zabbix cache usage, % used','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('530','Zabbix data gathering process busy %','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('531','Zabbix internal process busy %','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('532','Zabbix proxy performance','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('540','Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','2',NULL,'22943','0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('541','Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','2',NULL,'22903','0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('542','Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','2',NULL,'22983','0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('543','Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','2',NULL,'23063','0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('544','Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','2',NULL,'22863','0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('545','Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','2',NULL,'23023','0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('651','Fan speed and ambient temperature','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('652','Voltage','900','200','0','5.5',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('653','Fan speed and temperature','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('654','Voltage','900','200','0','5.5',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('668','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('671','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('675','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('687','#{#SNMPINDEX}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('691','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('694','#{#SNMPINDEX}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('698','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('701','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('704','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('708','{#MODULE_NAME}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('714','{#ENT_NAME}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('724','#{#SNMPINDEX}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('727','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('730','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('733','#{#SNMPVALUE}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('736','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('741','Interface {#IFDESCR}: Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('745','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('766','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('775','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('786','{#SNMPVALUE}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('803','Zabbix cache usage, % free','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('804','Zabbix data gathering process busy %','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('805','Zabbix internal process busy %','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('806','Zabbix proxy performance','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('807','Zabbix internal queues','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('814','DB {#DBNAME}: Block hit/read','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('815','DB {#DBNAME}: Database size','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('816','DB {#DBNAME}: Events','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('817','DB {#DBNAME}: Locks','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('818','DB {#DBNAME}: Queries','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('819','DB {#DBNAME}: Slow queries','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('820','DB {#DBNAME}: Temp files','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('821','DB {#DBNAME}: Tuples','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('822','PostgreSQL bgwriter','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('823','PostgreSQL checkpoints','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('824','PostgreSQL connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('825','PostgreSQL ping','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('826','PostgreSQL replication lag','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('827','PostgreSQL transactions','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('828','PostgreSQL uptime','900','200','0','100',NULL,'1','0','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('829','PostgreSQL WAL','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('835','Apache: Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('836','Apache: Current async connections{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('837','Apache: Current async processes{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('838','Apache: Requests per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('839','Apache: Workers total','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('840','Apache: Worker states','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('841','Nginx: Connections by state','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('842','Nginx: Connections per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('843','Nginx: Requests per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('844','Nginx: Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('845','Nginx: Connections by state','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('846','Nginx: Connections per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('847','Nginx: Requests per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('856','{#SNMPVALUE}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('859','MySQL bandwidth','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('860','MySQL connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('861','MySQL InnoDB buffer pool','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('862','MySQL operations','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('863','MySQL queries','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('864','MySQL threads','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('866','{#DEVNAME}: Disk read/write rates','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('868','CPU usage{#SINGLETON}','900','200','0','100',NULL,'1','1','1','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('870','CPU utilization{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('872','{#FSNAME}: Disk space usage','600','340','0','100',NULL,'1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('874','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('876','Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('878','Swap usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('880','System load','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('882','CPU jumps','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('887','{#FSNAME}: Disk space usage','600','340','0','100',NULL,'1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('899','Interface {#IFNAME}: Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('902','System load','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('905','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('908','CPU usage','900','200','0','100',NULL,'1','1','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('911','CPU jumps','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('914','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('917','Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('920','Swap usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('923','Processes','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('926','{#FSNAME}: Disk space usage','600','340','0','100',NULL,'1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('934','Interface {#IFNAME}: Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('936','System load','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('938','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('940','CPU usage','900','200','0','100',NULL,'1','1','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('942','CPU jumps','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('944','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('946','Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('948','Swap usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('950','Processes','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('952','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('953','{#FSNAME}: Disk space usage','600','340','0','100',NULL,'1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('954','{#DEVNAME}: Disk read/write rates','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('955','{#DEVNAME}: Disk average waiting time','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('956','{#DEVNAME}: Disk utilization and queue','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('957','System load','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('958','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('959','CPU usage','900','200','0','100',NULL,'1','1','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('960','CPU jumps','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('961','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('962','Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('963','Swap usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('964','{#FSNAME}: Disk space usage','600','340','0','100',NULL,'1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('972','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('974','CPU jumps','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('976','CPU usage','900','200','0','100',NULL,'1','1','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('978','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('980','Swap usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('982','{#FSNAME}: Disk space usage','600','340','0','100',NULL,'1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('990','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('992','CPU jumps','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('994','CPU usage','900','200','0','100',NULL,'1','1','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('996','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('998','Swap usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1000','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages status','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1001','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1007','RabbitMQ: File descriptors','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1008','RabbitMQ: Disk free','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1009','RabbitMQ: Memory used','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1010','RabbitMQ: Sockets','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1011','RabbitMQ: Node status','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1012','RabbitMQ: Uptime','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1013','RabbitMQ: Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1014','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages status','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1015','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1016','RabbitMQ: Connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1017','RabbitMQ: Queues','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1018','RabbitMQ: Messages','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1019','RabbitMQ: Messages status','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1020','RabbitMQ: Messages per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1021','RabbitMQ: File descriptors','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1022','RabbitMQ: Disk free','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1023','RabbitMQ: Memory used','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1024','RabbitMQ: Sockets','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1025','RabbitMQ: Node status','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1026','RabbitMQ: Uptime','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1027','RabbitMQ: Connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1028','RabbitMQ: Queues','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1029','RabbitMQ: Messages','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1030','RabbitMQ: Messages status','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1031','RabbitMQ: Messages per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1032','Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1033','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1034','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1035','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1038','{#SNMPVALUE}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1042','#{#SNMPINDEX}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1043','{#SNMPINDEX}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1044','#{#SNMPVALUE}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1045','#{#SNMPVALUE}: Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1046','#{#SNMPVALUE}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1047','{#MODULE_NAME}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1048','#{#SNMPVALUE}: Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1049','#{#SNMPVALUE}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1050','{#ENT_NAME}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1051','{#SNMPVALUE}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1052','Disk-{#SNMPINDEX}: Disk space usage','600','340','0','100',NULL,'1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1053','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1054','Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1055','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1056','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1057','#{#SNMPVALUE}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1058','Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1060','{#MEMNAME}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1065','{#FSNAME}: Disk space usage','600','340','0','100',NULL,'1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1070','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1087','Redis: Memory usage{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1088','DB {#DB}: Keys','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1089','Redis slave {#SLAVE_IP}:{#SLAVE_PORT}: Replication lag bytes','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1090','Redis: Replication lag time{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1091','Redis: Clients','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1092','Redis: Commands','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1093','Redis: CPU','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1094','Redis: Expired keys','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1095','Redis: Keyspace','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1096','Redis: Memory','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1097','Redis: Memory fragmentation','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1098','Redis: Network','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1099','Redis: Persistence','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1100','Redis: Slaves','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1101','Redis: Slowlog','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1102','Redis: Uptime','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1109','MySQL: Bandwidth','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1110','MySQL: Connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1111','MySQL: InnoDB buffer pool','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1112','MySQL: Operations','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1113','MySQL: Queries','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1114','MySQL: Threads','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1115','MySQL: Bandwidth','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1116','MySQL: Connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1117','MySQL: InnoDB buffer pool','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1118','MySQL: Operations','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1119','MySQL: Queries','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1120','MySQL: Threads','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1121','Container {#NAME}: CPU usage','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1122','Container {#NAME}: Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1123','Container {#NAME}: Network packets','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1124','Container {#NAME}: Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1125','Docker: Containers','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1126','Docker: Goroutines','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1127','Docker: Images','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1128','Docker: Memory total','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1129','Docker: Size','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1130','Memcached: Commands','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1131','Memcached: Connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1132','Memcached: Connections rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1133','Memcached: Keyspace','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1134','Memcached: Network','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1135','Memcached: Uptime','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1136','MySQL: Bandwidth','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1137','MySQL: Connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1138','MySQL: InnoDB buffer pool','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1139','MySQL: Operations','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1140','MySQL: Queries','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1141','MySQL: Threads','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1142','IPMI: {#SENSOR_ID}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1143','ES {#ES.NODE}: Latency','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1144','ES {#ES.NODE}: Query load','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1145','ES {#ES.NODE}: Refresh thread pool','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1146','ES {#ES.NODE}: Search thread pool','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1147','ES {#ES.NODE}: Write thread pool','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1148','ES: Cluster health','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1159','ClickHouse: {#DB}.{#TABLE}: Replica log activity','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1160','ClickHouse: {#DB}.{#TABLE}: Replica queues','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1161','ClickHouse: Current activity','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1162','ClickHouse: Current connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1163','ClickHouse: Distributed','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1164','ClickHouse: Insert/Merge bytes rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1165','ClickHouse: Insert/Merge rows rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1166','ClickHouse: Memory Usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1167','ClickHouse: Memory Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1168','ClickHouse: Queries rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1169','ClickHouse: Syscalls in fly','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1170','ClickHouse: Uptime','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1172','Apache: Current async connections{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1173','Apache: Current async processes{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1174','Apache: Requests per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1175','Apache: Worker states','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1176','Apache: Workers total','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1177','Etcd: File descriptors','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1178','Etcd: gRPC client traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1179','Etcd: gRPC requests rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1180','Etcd: HTTP requests rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1181','Etcd: Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1182','Etcd: Proposals rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1183','Etcd: Read/Write rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1184','IIS: Cache hits percentage','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1185','IIS: Cache misses','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1186','IIS: Requests rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1187','IIS: Cache hits percentage','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1188','IIS: Cache misses','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1189','IIS: Requests rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1190','MSSQL DB ''{#DBNAME}'': Log size','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1191','MSSQL DB ''{#DBNAME}'': Size','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1192','MSSQL Mirroring ''{#DBNAME}'': States','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1193','MSSQL: Access methods','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1194','MSSQL: Auto-params','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1195','MSSQL: Cache objects','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1196','MSSQL: Compilations','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1197','MSSQL: Database pages','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1198','MSSQL: Errors','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1199','MSSQL: Locks','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1200','MSSQL: Logins per second and Logouts per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1201','MSSQL: Memory/cache load','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1202','MSSQL: Memory grants outstanding and pending','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1203','MSSQL: Page life expectancy','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1204','MSSQL: Pages','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1205','MSSQL: Processes blocked','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1206','MSSQL: Server memory','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1207','MSSQL: Transactions','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1208','MSSQL: Waits per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1209','MSSQL: Wait times','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1210','DB {#DBNAME}: Locks','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1211','DB {#DBNAME}: Number of bloating tables','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1212','DB {#DBNAME}: pg_stat_database metrics','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1213','DB {#DBNAME}: Size','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1214','{#DEVNAME}: Disk average waiting time','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1217','{#DEVNAME}: Disk read/write rates','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1220','{#DEVNAME}: Disk utilization and queue','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1223','{#DEVNAME}: Disk average waiting time','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1225','{#DEVNAME}: Disk read/write rates','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1227','{#DEVNAME}: Disk utilization and queue','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1229','{#DEVNAME}: Disk read/write rates','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1231','{#DEVNAME}: Disk utilization and queue','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1233','{#DEVNAME}: Disk read/write rates','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1235','{#DEVNAME}: Disk utilization and queue','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1250','ClassLoading: Class Loader','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1251','GarbageCollector: Garbage Collector collections per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1252','MemoryPool: Memory Pool CMS Old Gen','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1253','MemoryPool: Memory Pool CMS Perm Gen','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1254','MemoryPool: Memory Pool Code Cache','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1255','MemoryPool: Memory Pool Perm Gen','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1256','MemoryPool: Memory Pool PS Old Gen','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1257','MemoryPool: Memory Pool PS Perm Gen','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1258','MemoryPool: Memory Pool Tenured Gen','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1259','OperatingSystem: File Descriptors','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1260','Threading: Threads','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1261','MSSQL DB ''{#DBNAME}'': Number of Log changes','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1262','ASM ''{#DG_NAME}'': ASM disk group ''{#DG_NAME}''','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1263','Oracle TBS ''{#TABLESPACE}'': Tablespace ''{#TABLESPACE}''','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1264','Oracle: Datafiles','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1265','Oracle: PGA','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1266','Oracle: Physical Read\Write Rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1267','Oracle: Physical Read\Write Rate, Bytes','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1268','Oracle: Processes','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1269','Oracle: Sessions','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1270','Oracle: SGA Memory Usage','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1278','Ceph: [osd.{#OSDNAME}] OSD latency','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1282','Ceph: Cluster bandwidth','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1283','Ceph: Cluster I/O','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1284','Ceph: Free space','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1285','Ceph: Overall OSD latency','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1286','Ceph: Overall OSD utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1287','PHP-FPM: Process','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1288','PHP-FPM: Queue','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1289','PHP-FPM: Process','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1290','PHP-FPM: Queue','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1291','Squid: DNS lookup statistics','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1292','Squid: Domain name (FQDN) cache ctatistics','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1293','Squid: File descriptor usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1294','Squid: HTTP Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1295','Squid: IP address cache statistics','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1296','Squid: Memory','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1297','Squid: Objects cache statistics','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1298','Squid: Service timing statistics','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1299','Interface {#IFNAME}({#IFALIAS}): Modem Signal. {#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1304','Ceph: [{#POOLNAME}] Pool bandwidth','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1305','Ceph: [{#POOLNAME}] Pool I/O','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1306','Ceph: [{#POOLNAME}] Pool Usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1307','{#HOSTNAME}: DataNode {#HOSTNAME} DFS size','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1308','Kafka: Broker throughput','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1309','Kafka: ISR shrinks/expands rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1310','Kafka: Leader electoin rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1311','Kafka: Pending deletes','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1312','Kafka: Purgatory size','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1313','Kafka: Requests failed rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1314','Kafka: Requests performance','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1315','Kafka: Temporary memory size','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1316','Kafka: ZooKeeper connections rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1317','{#JMXNAME}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1318','{#JMXHOST}{#JMXCONTEXT}: Sessions','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1319','{#JMXNAME}: Worker threads','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1320','Zookeeper client {#TYPE} [{#CLIENT}]: Latency','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1321','Zookeeper client {#TYPE} [{#CLIENT}]: Packets','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1322','Zookeeper: File descriptors usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1323','Zookeeper: Latency','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1324','Zookeeper: Nodes','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1325','Zookeeper: Packets','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1326','{#JMXKEYSPACE}.{#JMXSCOPE}: Read\Write latency','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1327','{#JMXKEYSPACE}.{#JMXSCOPE}: Requests rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1328','Client connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1329','Client requests rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1330','Client requests Read\Write latency','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1331','Dropped Messages','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1332','KeyCache Hit rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1333','Nodes state','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1334','Tables Read\Write latency','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1335','Voltage: Battery/Load{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1336','Array: Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1337','Current: Charge/Load','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1338','Temperature: Ambient/Battery/Heatsink','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1339','Voltage: Battery/Load{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1340','Array: Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1341','Current: Charge/Load','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1342','Temperature: Ambient/Battery/Heatsink','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1343','Voltage: Battery/Load{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1344','Array: Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1345','Current: Charge/Load','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1346','Temperature: Ambient/Battery/Heatsink','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1347','Voltage: Battery{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1348','Current: A/C Load','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1349','Temperature: Heatsink','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1350','Battery: Voltage{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1351','Array: Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1352','Battery: Current','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1353','Battery: Output Power (Watts)','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1354','Temperature: Battery/Heatsink','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1355','Battery: Voltage{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1356','Array: Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1357','Battery: Current','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1358','Battery: Output Power (Watts)','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1359','Temperature: Battery/Heatsink','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1360','Battery: Voltage{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1361','Array: Voltage{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1362','Battery: Charge Current{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1363','Load: Current{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1364','Load: Voltage{#SINGLETON}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1365','Temperature: Battery/Heatsink','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1366','{#DEVNAME}: Disk average queue length','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1368','{#DEVNAME}: Disk average waiting time','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1370','{#DEVNAME}: Disk average queue length','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1372','{#DEVNAME}: Disk average waiting time','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1374','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1375','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Messages rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1376','{#JMXBROKERNAME}: {#JMXDESTINATIONTYPE} {#JMXDESTINATIONNAME}: Producers and consumers','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1377','Broker {#JMXBROKERNAME}: Messages rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1378','Broker {#JMXBROKERNAME}: Producers and consumers','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1379','Broker {#JMXBROKERNAME}: Resources usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1380','Domain Controller [{#INSTANCE}]: Timings','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1381','Database Counters [{#INSTANCE}]: Read and write stats','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1382','MS Exchange [Client Access Server]: Request rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1383','Domain Controller [{#INSTANCE}]: Timings','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1384','Database Counters [{#INSTANCE}]: Read and write stats','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1385','MS Exchange [Client Access Server]: Request rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1386','Application {#APPLICATION}: Replication lag','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1387','Node {#NODE.NAME}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1388','{#VSERVER}{#FSNAME}: Free space','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1389','Node {#NODE}: port {#IFNAME} ({#TYPE}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1390','Cache group [{#JMXNAME}]: Partitions','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1391','Thread pool [{#JMXNAME}]: Thread pool size','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1392','Data region {#JMXNAME}: Checkpoint buffer utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1393','Data region {#JMXNAME}: DataRegion utilisation','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1394','Ignite [{#JMXIGNITEINSTANCENAME}]: Jobs current state','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1395','Ignite [{#JMXIGNITEINSTANCENAME}]: Jobs rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1396','Ignite [{#JMXIGNITEINSTANCENAME}]: Communication messages rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1397','Ignite [{#JMXIGNITEINSTANCENAME}]: Discovery messages rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1398','Ignite [{#JMXIGNITEINSTANCENAME}]: Transactions','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1399','Ignite [{#JMXIGNITEINSTANCENAME}]: Transactions rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1400','Cache group [{#JMXGROUP}]: Cache hits','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1401','Cache group [{#JMXGROUP}]: Cache ops','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1402','Cache group [{#JMXGROUP}]: Cache transactions','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1403','Controller {#ID}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1404','LUN {#NAME}: LUN I/O','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1405','LUN {#NAME}: LUN I/O latency','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1406','LUN {#NAME}: LUN traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1407','Node {#NODE}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1408','Node {#NODE}: Node I/O','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1409','Node {#NODE}: Node traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1410','Pool {#NAME}: Capacity','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1411','OceanStor 5300 V5: Capacity','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1412','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1413','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages status','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1414','RabbitMQ: Connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1415','RabbitMQ: Disk free','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1416','RabbitMQ: File descriptors','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1417','RabbitMQ: Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1418','RabbitMQ: Memory used','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1419','RabbitMQ: Messages','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1420','RabbitMQ: Messages per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1421','RabbitMQ: Messages status','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1422','RabbitMQ: Node status','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1423','RabbitMQ: Queues','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1424','RabbitMQ: Sockets','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1425','RabbitMQ: Uptime','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1426','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1427','RabbitMQ: Queue {#VHOST}/{#QUEUE}: Messages status','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1428','RabbitMQ: Connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1429','RabbitMQ: Disk free','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1430','RabbitMQ: File descriptors','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1431','RabbitMQ: Memory used','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1432','RabbitMQ: Messages','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1433','RabbitMQ: Messages per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1434','RabbitMQ: Messages status','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1435','RabbitMQ: Node status','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1436','RabbitMQ: Queues','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1437','RabbitMQ: Sockets','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1438','RabbitMQ: Uptime','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1439','MongoDB {#DBNAME}.{#COLLECTION}: Locks','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1440','MongoDB {#DBNAME}.{#COLLECTION}: Locks time','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1441','MongoDB {#DBNAME}.{#COLLECTION}: Operations','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1442','MongoDB {#DBNAME}.{#COLLECTION}: Operations time','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1443','MongoDB {#DBNAME}: Collections stats','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1444','MongoDB {#DBNAME}: Disk usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1445','MongoDB: Replication lag time [{#RS_NAME}]','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1446','MongoDB: Active clients','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1447','MongoDB: Activity','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1448','MongoDB: Connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1449','MongoDB: Cursors','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1450','MongoDB: Documents','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1451','MongoDB: Memory usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1452','MongoDB: Network','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1453','MongoDB: Operations','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1454','MongoDB: Queued operations','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1455','MongoDB {#DBNAME}: Disk usage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1456','MongoDB cluster: Connection pool','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1457','MongoDB cluster: Connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1458','MongoDB cluster: Cursors','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1459','MongoDB cluster: Network','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1460','MongoDB cluster: Operations rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1461','#{#SNMPINDEX}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1462','{#SNMPVALUE}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1463','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1464','#{#SNMPINDEX}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1465','{#SNMPVALUE}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1466','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1467','#{#SNMPINDEX}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1468','{#SNMPVALUE}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1469','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1470','#{#SNMPINDEX}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1471','{#SNMPVALUE}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1472','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1473','#{#SNMPINDEX}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1474','{#SNMPVALUE}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1475','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1476','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1477','{#FSNAME}: Disk space usage','600','340','0','100',NULL,'1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1478','{#MEMNAME}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1479','CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1481','Output','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1482','Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1483','{#VOLUMENAME}: Volume latency','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1484','{#VOLUMENAME}: Volume size','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1485','Cluster IOPS','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1486','Cluster latency','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1487','Cluster throughput','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1488','ClickHouse: Zookeeper exceptions rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1489','Capacity of the UPS batteries','900','200','0','100',NULL,'1','1','2','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1490','Output','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1491','Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1492','Capacity of the UPS batteries','900','200','0','100',NULL,'1','1','2','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1493','Output','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1494','Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1495','Capacity of the UPS batteries','900','200','0','100',NULL,'1','1','2','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1496','Output','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1497','Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1498','Capacity of the UPS batteries','900','200','0','100',NULL,'1','1','2','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1499','Output','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1500','Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1501','Capacity of the UPS batteries','900','200','0','100',NULL,'1','1','2','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1502','Output','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1503','Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1504','Capacity of the UPS batteries','900','200','0','100',NULL,'1','1','2','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1505','Output','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1506','Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1507','Capacity of the UPS batteries','900','200','0','100',NULL,'1','1','2','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1508','Output','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1509','Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1510','Capacity of the UPS batteries','900','200','0','100',NULL,'1','1','2','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1511','Capacity of the UPS batteries','900','200','0','100',NULL,'1','1','2','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1512','Output','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1513','Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1514','Capacity of the UPS batteries','900','200','0','100',NULL,'1','1','2','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1515','Output','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1516','Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1517','Capacity of the UPS batteries','900','200','0','100',NULL,'1','1','2','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1518','Output','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1519','Voltage','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1520','WildFly {#JMX_DATA_SOURCE}: Cache operations','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1521','WildFly {#JMX_DATA_SOURCE}: Connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1522','WildFly listener {#HTTP_LISTENER}: Requests','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1523','WildFly listener {#HTTP_LISTENER}: Throughput','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1524','WildFly: Transactions','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1525','Zabbix server: Data gathering processes','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1527','Zabbix server: Data handling processes','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1529','Zabbix server: Internal processes','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1531','Zabbix server: Reporting processes','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1535','Zabbix server: Value cache effectiveness','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1537','Zabbix server: Zabbix cache usage, % free','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1539','Zabbix server: Zabbix data gathering process busy %','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1541','Zabbix server: Zabbix internal process busy %','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1543','Zabbix server: Zabbix internal queues','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1545','Zabbix server: Zabbix server performance','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1547','Remote Zabbix server: Data gathering processes','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1548','Remote Zabbix server: Data handling processes','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1549','Remote Zabbix server: Internal processes','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1550','Remote Zabbix server: Reporting processes','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1552','Remote Zabbix server: Value cache effectiveness','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1553','Remote Zabbix server: Zabbix cache usage, % free','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1554','Remote Zabbix server: Zabbix data gathering process busy %','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1555','Remote Zabbix server: Zabbix internal process busy %','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1556','Remote Zabbix server: Zabbix internal queues','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1557','Remote Zabbix server: Zabbix server performance','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1558','ZYXEL AAM1212-51 / IES-612: ADSL port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1559','ZYXEL AAM1212-51 / IES-612: Ethernet port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1560','ZYXEL AAM1212-51 / IES-612: "Temperature {#ZYXEL.TEMP.ID}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1561','ZYXEL AAM1212-51 / IES-612: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1562','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1563','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1564','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1565','ZYXEL ES3500-8PD: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1566','ZYXEL ES3500-8PD: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1567','ZYXEL ES3500-8PD: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1568','ZYXEL ES3500-8PD: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1569','ZYXEL GS-4012F: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1570','ZYXEL GS-4012F: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1571','ZYXEL GS-4012F: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1572','ZYXEL GS-4012F: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1573','ZYXEL GS-4012F: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1574','ZYXEL GS-4012F: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1575','ZYXEL GS-4012F: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1576','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Packet buffer utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1577','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1578','ZYXEL IES-500x: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1579','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1580','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1581','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1582','ZYXEL IES-500x: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1583','ZYXEL IES-500x: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1584','ZYXEL IES-500x: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1585','ZYXEL IES-500x: "Temperature Slot {#ZYXEL.SLOT.ID} Sensor: {#ZYXEL.TEMP.ID}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1586','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1587','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Packet buffer utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1588','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1589','ZYXEL IES-6000: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1590','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1591','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1592','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1593','ZYXEL IES-6000: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1594','ZYXEL IES-6000: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1595','ZYXEL IES-6000: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1596','ZYXEL IES-6000: "Temperature Slot {#ZYXEL.SLOT.ID} Sensor: {#ZYXEL.TEMP.ID}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1597','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1598','ZYXEL IES1248-51: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1599','ZYXEL IES1248-51: ADSL port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1600','ZYXEL IES1248-51: Ethernet port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1601','ZYXEL IES1248-51: "Temperature {#ZYXEL.TEMP.ID}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1602','ZYXEL IES1248-51: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1603','ZYXEL MES-3528: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1604','ZYXEL MES-3528: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1605','ZYXEL MES-3528: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1606','ZYXEL MES-3528: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1607','ZYXEL MES-3528: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1608','ZYXEL MES3500-10: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1609','ZYXEL MES3500-10: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1610','ZYXEL MES3500-10: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1611','ZYXEL MES3500-10: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1612','ZYXEL MES3500-10: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1613','ZYXEL MES3500-10: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1614','ZYXEL MES3500-10: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1615','ZYXEL MES3500-24: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1616','ZYXEL MES3500-24: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1617','ZYXEL MES3500-24: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1618','ZYXEL MES3500-24: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1619','ZYXEL MES3500-24: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1620','ZYXEL MES3500-24: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1621','ZYXEL MES3500-24: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1622','ZYXEL MGS-3712: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1623','ZYXEL MGS-3712: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1624','ZYXEL MGS-3712: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1625','ZYXEL MGS-3712: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1626','ZYXEL MGS-3712: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1627','ZYXEL MGS-3712: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1628','ZYXEL MGS-3712: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1629','ZYXEL MGS-3712: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1630','ZYXEL MGS-3712F: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1631','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1632','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1633','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1634','ZYXEL MGS-3712F: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1635','ZYXEL MGS-3712F: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1636','ZYXEL MGS-3712F: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1637','ZYXEL MGS-3712F: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1638','ZYXEL MES3500-24S: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1639','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1640','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1641','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1642','ZYXEL MES3500-24S: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1643','ZYXEL MES3500-24S: Temperature "{#ZYXEL.TEMPDESCRIPTION}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1644','ZYXEL MES3500-24S: Nominal "{#ZYXEL.DESCRIPTION}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1645','ZYXEL MES3500-24S: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1646','ZYXEL MGS3520-28x: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1647','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1648','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1649','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1650','ZYXEL MGS3520-28x: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1651','ZYXEL MGS3520-28x: Temperature "{#ZYXEL.TEMPDESCRIPTION}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1652','ZYXEL MGS3520-28x: Nominal "{#ZYXEL.DESCRIPTION}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1653','ZYXEL MGS3520-28x: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1654','ZYXEL XGS-4728F: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1655','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1656','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1657','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1658','ZYXEL XGS-4728F: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1659','ZYXEL XGS-4728F: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1660','ZYXEL XGS-4728F: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1661','ZYXEL XGS-4728F: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1662','Nginx: HTTP location zone [{#NAME}]: Requests','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1663','Nginx: HTTP location zone [{#NAME}]: Responses','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1664','Nginx: HTTP server zone [{#NAME}]: Requests','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1665','Nginx: HTTP server zone [{#NAME}]: Responses','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1666','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Health checks','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1667','Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]: Responses','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1668','Nginx: Resolver [{#NAME}]: Requests','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1669','Nginx: Resolver [{#NAME}]: Responses','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1670','Nginx: Stream server zone [{#NAME}]: Sessions','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1671','Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]: Health checks','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1672','Nginx: Connections','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1673','Nginx: Requests','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1674','Nginx: SSL','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1675','Nginx: Uptime','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1676','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1677','Cache group [{#JMXNAME}]: Partitions','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1678','Thread pool [{#JMXNAME}]: Thread pool size','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1679','Data region {#JMXNAME}: Checkpoint buffer utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1680','Data region {#JMXNAME}: DataRegion utilisation','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1681','GridGain [{#JMXIGNITEINSTANCENAME}]: Jobs current state','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1682','GridGain [{#JMXIGNITEINSTANCENAME}]: Jobs rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1683','GridGain [{#JMXIGNITEINSTANCENAME}]: Communication messages rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1684','GridGain [{#JMXIGNITEINSTANCENAME}]: Discovery messages rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1685','GridGain [{#JMXIGNITEINSTANCENAME}]: Transactions','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1686','GridGain [{#JMXIGNITEINSTANCENAME}]: Transactions rate','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1687','Cache group [{#JMXGROUP}]: Cache hits','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1688','Cache group [{#JMXGROUP}]: Cache ops','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1689','Cache group [{#JMXGROUP}]: Cache transactions','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1690','F5 BIG-IP: Sensor [{#SLOT.INDEX}:{#TEMP.INDEX}] temperature','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1691','F5 BIG-IP: Voltage [{#VOLT.INDEX}] value','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1692','F5 BIG-IP: FAN [{#FAN.INDEX}] speed','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1693','F5 BIG-IP: Sensor [{#TEMP.INDEX}] temperature','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1694','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Usage ratio, avg 1m','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1695','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Usage ratio, avg 5m','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1696','F5 BIG-IP: Host [{#HOST.ID}] CPU{#CPU.ID}: Usage ratio, avg 5s','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1697','F5 BIG-IP: Sensor [{#CPU.SENSOR.SLOT}:{#CPU.SENSOR.INDEX}] FAN speed','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1698','F5 BIG-IP: Sensor [{#CPU.SENSOR.SLOT}:{#CPU.SENSOR.INDEX}] temperature','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1699','F5 BIG-IP: Mount point [{#PART.NAME}]: Blocks','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1700','F5 BIG-IP: Host [{#HOST.ID}]: Memory','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1701','F5 BIG-IP: Host [{#HOST.ID}]: Swap','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1702','F5 BIG-IP: Module [{#MODULE.NAME}] resource usage ratio','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1703','F5 BIG-IP: Interface [{#IF.NAME}]','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1704','F5 BIG-IP: Node [{#NODE.NAME}] network ratio','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1705','F5 BIG-IP: Pool [{#POOL.NAME}] network ratio','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1706','F5 BIG-IP: Virtual sever [{#VSERVER.NAME}] network','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1707','F5 BIG-IP: Virtual sever [{#VSERVER.NAME}] usage ratio','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1708','F5 BIG-IP: TCP/UDP statistics','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1709','HAProxy: Backend {#PXNAME} In/Out traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1710','HAProxy: Backend {#PXNAME} Redispatched requests and retried connections per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1711','HAProxy: Backend {#PXNAME} Responses by HTTP code','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1712','HAProxy: Frontend {#PXNAME} Errors and denials per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1713','HAProxy: Frontend {#PXNAME} In/Out traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1714','HAProxy: Frontend {#PXNAME} Requests and sessions per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1715','HAProxy: Frontend {#PXNAME} Responses by HTTP code','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1716','HAProxy: {#PXNAME} {#SVNAME} In/Out traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1717','HAProxy: {#PXNAME} {#SVNAME} Responses by HTTP code','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1718','HAProxy: {#PXNAME} {#SVNAME} Response time and time in queue','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1719','HAProxy: Backend {#PXNAME} In/Out traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1720','HAProxy: Backend {#PXNAME} Redispatched requests and retried connections per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1721','HAProxy: Backend {#PXNAME} Responses by HTTP code','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1722','HAProxy: Frontend {#PXNAME} Errors and denials per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1723','HAProxy: Frontend {#PXNAME} In/Out traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1724','HAProxy: Frontend {#PXNAME} Requests and sessions per second','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1725','HAProxy: Frontend {#PXNAME} Responses by HTTP code','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1726','HAProxy: {#PXNAME} {#SVNAME} In/Out traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1727','HAProxy: {#PXNAME} {#SVNAME} Responses by HTTP code','900','200','0','100',NULL,'1','1','1','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1728','HAProxy: {#PXNAME} {#SVNAME} Response time and time in queue','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1729','Cisco ASAv: CPU[{#SNMPINDEX}] Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1730','Cisco ASAv: Memory[{#SNMPVALUE}] Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1731','Cisco ASAv: {#CISCO.IF.NAME}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1732','Cisco ASAv: {#CISCO.IF.NAME}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1733','Cisco ASAv: {#CISCO.IF.NAME} Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1734','Cisco ASAv: {#CISCO.CRAS.USER} [{#CISCO.CRAS.INDEX}] Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1735','ZYXEL AAM1212-51 / IES-612: ADSL port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1736','ZYXEL AAM1212-51 / IES-612: Ethernet port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1737','ZYXEL AAM1212-51 / IES-612: "Temperature {#ZYXEL.TEMP.ID}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1738','ZYXEL AAM1212-51 / IES-612: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1739','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1740','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1741','ZYXEL ES3500-8PD: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1742','ZYXEL ES3500-8PD: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1743','ZYXEL ES3500-8PD: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1744','ZYXEL ES3500-8PD: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1745','ZYXEL ES3500-8PD: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1746','ZYXEL GS-4012F: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1747','ZYXEL GS-4012F: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1748','ZYXEL GS-4012F: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1749','ZYXEL GS-4012F: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1750','ZYXEL GS-4012F: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1751','ZYXEL GS-4012F: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1752','ZYXEL GS-4012F: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1753','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Packet buffer utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1754','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1755','ZYXEL IES-500x: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1756','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1757','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1758','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1759','ZYXEL IES-500x: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1760','ZYXEL IES-500x: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1761','ZYXEL IES-500x: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1762','ZYXEL IES-500x: "Temperature Slot {#ZYXEL.SLOT.ID} Sensor: {#ZYXEL.TEMP.ID}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1763','ZYXEL IES-500x: Slot {#ZYXEL.SLOT.ID}: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1764','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Packet buffer utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1765','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1766','ZYXEL IES-6000: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1767','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Memory utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1768','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1769','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1770','ZYXEL IES-6000: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1771','ZYXEL IES-6000: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1772','ZYXEL IES-6000: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1773','ZYXEL IES-6000: "Temperature Slot {#ZYXEL.SLOT.ID} Sensor: {#ZYXEL.TEMP.ID}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1774','ZYXEL IES-6000: Slot {#ZYXEL.SLOT.ID}: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1775','ZYXEL IES1248-51: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1776','ZYXEL IES1248-51: ADSL port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1777','ZYXEL IES1248-51: Ethernet port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1778','ZYXEL IES1248-51: "Temperature {#ZYXEL.TEMP.ID}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1779','ZYXEL IES1248-51: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1780','ZYXEL MES-3528: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1781','ZYXEL MES-3528: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1782','ZYXEL MES-3528: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1783','ZYXEL MES-3528: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1784','ZYXEL MES-3528: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1785','ZYXEL MES3500-10: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1786','ZYXEL MES3500-10: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1787','ZYXEL MES3500-10: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1788','ZYXEL MES3500-10: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1789','ZYXEL MES3500-10: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1790','ZYXEL MES3500-10: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1791','ZYXEL MES3500-10: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1792','ZYXEL MES3500-24: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1793','ZYXEL MES3500-24: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1794','ZYXEL MES3500-24: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1795','ZYXEL MES3500-24: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1796','ZYXEL MES3500-24: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1797','ZYXEL MES3500-24: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1798','ZYXEL MES3500-24: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1799','ZYXEL MGS-3712: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1800','ZYXEL MGS-3712: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1801','ZYXEL MGS-3712: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1802','ZYXEL MGS-3712: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1803','ZYXEL MGS-3712: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1804','ZYXEL MGS-3712: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1805','ZYXEL MGS-3712: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1806','ZYXEL MGS-3712: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1807','ZYXEL MGS-3712F: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1808','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1809','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1810','ZYXEL MGS-3712F: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1811','ZYXEL MGS-3712F: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1812','ZYXEL MGS-3712F: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1813','ZYXEL MGS-3712F: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1814','ZYXEL MGS-3712F: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1815','ZYXEL MES3500-24S: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1816','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1817','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1818','ZYXEL MES3500-24S: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1819','ZYXEL MES3500-24S: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1820','ZYXEL MES3500-24S: Temperature "{#ZYXEL.TEMPDESCRIPTION}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1821','ZYXEL MES3500-24S: Nominal "{#ZYXEL.DESCRIPTION}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1822','ZYXEL MES3500-24S: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1823','ZYXEL MGS3520-28x: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1824','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1825','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1826','ZYXEL MGS3520-28x: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1827','ZYXEL MGS3520-28x: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1828','ZYXEL MGS3520-28x: Temperature "{#ZYXEL.TEMPDESCRIPTION}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1829','ZYXEL MGS3520-28x: Nominal "{#ZYXEL.DESCRIPTION}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1830','ZYXEL MGS3520-28x: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1831','ZYXEL XGS-4728F: Fan #{#SNMPINDEX}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1832','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Packets traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1833','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1834','ZYXEL XGS-4728F: Port {#SNMPINDEX}: Utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1835','ZYXEL XGS-4728F: SFP {#ZYXEL.SFP.PORT}: {#ZYXEL.SFP.DESCRIPTION}','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1836','ZYXEL XGS-4728F: Temperature "{#ZYXEL.TEMP.ID}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1837','ZYXEL XGS-4728F: Nominal "{#ZYXEL.VOLT.NOMINAL}"','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1838','ZYXEL XGS-4728F: CPU utilization','900','200','0','100',NULL,'1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1839','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1841','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100',NULL,'1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('676','CPU utilization','900','200','0','100','675','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('677','CPU utilization','900','200','0','100','675','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('688','#{#SNMPINDEX}: CPU utilization','900','200','0','100','687','1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('692','CPU utilization','900','200','0','100','691','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('740','Interface {#IFDESCR}: Network traffic','900','200','0','100','741','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('742','Interface {#IFDESCR}: Network traffic','900','200','0','100','741','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('743','Interface {#IFDESCR}: Network traffic','900','200','0','100','741','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('746','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('747','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('748','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('749','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('750','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('752','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('753','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('754','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('755','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('756','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('758','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('759','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('760','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('762','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('763','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('764','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('773','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('785','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('787','{#SNMPVALUE}: CPU utilization','900','200','0','100','786','1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('790','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('865','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','745','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('867','{#DEVNAME}: Disk read/write rates','900','200','0','100','866','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('869','CPU usage{#SINGLETON}','900','200','0','100','868','1','1','1','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('871','CPU utilization{#SINGLETON}','900','200','0','100','870','1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('873','{#FSNAME}: Disk space usage','600','340','0','100','872','1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('875','Memory utilization','900','200','0','100','874','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('877','Memory usage','900','200','0','100','876','1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('879','Swap usage','900','200','0','100','878','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('881','System load','900','200','0','100','880','1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('883','CPU jumps','900','200','0','100','882','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('886','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','766','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('888','{#FSNAME}: Disk space usage','600','340','0','100','887','1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('900','Interface {#IFNAME}: Network traffic','900','200','0','100','899','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('903','System load','900','200','0','100','902','1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('906','CPU utilization','900','200','0','100','905','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('909','CPU usage','900','200','0','100','908','1','1','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('912','CPU jumps','900','200','0','100','911','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('915','Memory utilization','900','200','0','100','914','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('918','Memory usage','900','200','0','100','917','1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('921','Swap usage','900','200','0','100','920','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('924','Processes','900','200','0','100','923','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('927','{#FSNAME}: Disk space usage','600','340','0','100','926','1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('935','Interface {#IFNAME}: Network traffic','900','200','0','100','934','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('937','System load','900','200','0','100','936','1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('939','CPU utilization','900','200','0','100','938','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('941','CPU usage','900','200','0','100','940','1','1','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('943','CPU jumps','900','200','0','100','942','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('945','Memory utilization','900','200','0','100','944','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('947','Memory usage','900','200','0','100','946','1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('949','Swap usage','900','200','0','100','948','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('951','Processes','900','200','0','100','950','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('965','{#FSNAME}: Disk space usage','600','340','0','100','964','1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('973','CPU utilization','900','200','0','100','972','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('975','CPU jumps','900','200','0','100','974','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('977','CPU usage','900','200','0','100','976','1','1','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('979','Memory utilization','900','200','0','100','978','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('981','Swap usage','900','200','0','100','980','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('983','{#FSNAME}: Disk space usage','600','340','0','100','982','1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('991','CPU utilization','900','200','0','100','990','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('993','CPU jumps','900','200','0','100','992','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('995','CPU usage','900','200','0','100','994','1','1','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('997','Memory utilization','900','200','0','100','996','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('999','Swap usage','900','200','0','100','998','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1036','Memory utilization','900','200','0','100','1035','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1037','Memory utilization','900','200','0','100','1035','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1039','{#SNMPVALUE}: Memory utilization','900','200','0','100','1038','1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1040','{#SNMPVALUE}: Memory utilization','900','200','0','100','1038','1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1041','{#SNMPVALUE}: Memory utilization','900','200','0','100','1038','1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1061','{#MEMNAME}: Memory utilization','900','200','0','100','1060','1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1066','{#FSNAME}: Disk space usage','600','340','0','100','1065','1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1071','CPU utilization','900','200','0','100','1070','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1215','{#DEVNAME}: Disk average waiting time','900','200','0','100','1214','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1218','{#DEVNAME}: Disk read/write rates','900','200','0','100','1217','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1221','{#DEVNAME}: Disk utilization and queue','900','200','0','100','1220','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1224','{#DEVNAME}: Disk average waiting time','900','200','0','100','1223','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1226','{#DEVNAME}: Disk read/write rates','900','200','0','100','1225','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1228','{#DEVNAME}: Disk utilization and queue','900','200','0','100','1227','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1230','{#DEVNAME}: Disk read/write rates','900','200','0','100','1229','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1232','{#DEVNAME}: Disk utilization and queue','900','200','0','100','1231','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1234','{#DEVNAME}: Disk read/write rates','900','200','0','100','1233','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1236','{#DEVNAME}: Disk utilization and queue','900','200','0','100','1235','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1367','{#DEVNAME}: Disk average queue length','900','200','0','100','1366','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1369','{#DEVNAME}: Disk average waiting time','900','200','0','100','1368','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1371','{#DEVNAME}: Disk average queue length','900','200','0','100','1370','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1373','{#DEVNAME}: Disk average waiting time','900','200','0','100','1372','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1526','Zabbix server: Data gathering processes','900','200','0','100','1525','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1528','Zabbix server: Data handling processes','900','200','0','100','1527','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1530','Zabbix server: Internal processes','900','200','0','100','1529','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1532','Zabbix server: Reporting processes','900','200','0','100','1531','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1536','Zabbix server: Value cache effectiveness','900','200','0','100','1535','1','1','1','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1538','Zabbix server: Zabbix cache usage, % free','900','200','0','100','1537','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1540','Zabbix server: Zabbix data gathering process busy %','900','200','0','100','1539','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1542','Zabbix server: Zabbix internal process busy %','900','200','0','100','1541','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1544','Zabbix server: Zabbix internal queues','900','200','0','100','1543','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1546','Zabbix server: Zabbix server performance','900','200','0','100','1545','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1840','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','1839','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1842','Interface {#IFNAME}({#IFALIAS}): Network traffic','900','200','0','100','1841','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('889','{#FSNAME}: Disk space usage','600','340','0','100','888','1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('901','Interface {#IFNAME}: Network traffic','900','200','0','100','900','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('904','System load','900','200','0','100','903','1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('907','CPU utilization','900','200','0','100','906','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('910','CPU usage','900','200','0','100','909','1','1','1','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('913','CPU jumps','900','200','0','100','912','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('916','Memory utilization','900','200','0','100','915','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('919','Memory usage','900','200','0','100','918','1','1','0','1','0','0','0','1','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('922','Swap usage','900','200','0','100','921','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('925','Processes','900','200','0','100','924','1','1','0','1','0','0','0','0','0',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1063','{#MEMNAME}: Memory utilization','900','200','0','100','1061','1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1064','{#MEMNAME}: Memory utilization','900','200','0','100','1061','1','1','0','1','0','0','0','1','1',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1068','{#FSNAME}: Disk space usage','600','340','0','100','1066','1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1069','{#FSNAME}: Disk space usage','600','340','0','100','1066','1','1','2','1','1','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1073','CPU utilization','900','200','0','100','1071','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1074','CPU utilization','900','200','0','100','1071','1','1','0','1','0','0','0','1','1',NULL,NULL,'0','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1216','{#DEVNAME}: Disk average waiting time','900','200','0','100','1215','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1219','{#DEVNAME}: Disk read/write rates','900','200','0','100','1218','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs (graphid,name,width,height,yaxismin,yaxismax,templateid,show_work_period,show_triggers,graphtype,show_legend,show_3d,percent_left,percent_right,ymin_type,ymax_type,ymin_itemid,ymax_itemid,flags,discover) values ('1222','{#DEVNAME}: Disk utilization and queue','900','200','0','100','1221','1','1','0','1','0','0','0','0','0',NULL,NULL,'2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18830','859','28932','5','0','00AA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18831','859','28933','5','1','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18832','860','28929','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18833','860','28939','0','1','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18834','860','28931','0','2','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18835','860','28919','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18836','861','28930','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18837','861','28928','0','1','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18838','861','28915','0','2','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18839','861','28914','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18840','862','28934','0','0','C80000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18841','862','28935','0','1','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18842','862','28936','0','2','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18843','862','28937','0','3','C800C8','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18844','863','28922','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18845','863','28921','0','1','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18846','863','28920','0','2','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18847','864','28923','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18848','864','28924','0','1','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18849','864','28925','0','2','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('18850','864','28926','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45082','1001','29729','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45083','1001','29728','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45084','1001','29727','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45085','1001','29725','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45086','1001','29723','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45087','1001','29733','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45088','1001','29737','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45089','1001','29731','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45090','1000','29720','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45091','1000','29730','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45092','1000','29721','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45093','1000','29726','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45094','1000','29724','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45095','1000','29734','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45096','1000','29722','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45097','1000','29732','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45098','1027','30022','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45099','1027','30021','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45100','1027','30019','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45101','1008','29698','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45102','1008','29700','2','1','FF0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45103','1007','29691','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45104','1013','29657','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45105','1013','29658','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45106','1009','29687','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45107','1009','29694','2','1','FF0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45108','1029','30017','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45109','1029','30016','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45110','1029','30015','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45111','1031','30007','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45112','1031','30013','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45113','1031','30011','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45114','1031','30009','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45115','1031','30005','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45116','1031','30003','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45117','1031','30023','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45118','1031','30001','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45119','1030','30008','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45120','1030','30014','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45121','1030','30012','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45122','1030','30010','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45123','1030','30006','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45124','1030','30004','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45125','1030','30000','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45126','1030','30002','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45127','1011','29695','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45128','1011','29662','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45129','1028','30020','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45130','1010','29701','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45131','1010','29697','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45132','1012','29692','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45133','1015','29812','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45134','1015','29811','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45135','1015','29810','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45136','1015','29808','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45137','1015','29806','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45138','1015','29816','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45139','1015','29820','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45140','1015','29814','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45141','1014','29803','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45142','1014','29813','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45143','1014','29804','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45144','1014','29809','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45145','1014','29807','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45146','1014','29817','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45147','1014','29805','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45148','1014','29815','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45149','1016','29768','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45150','1016','29767','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45151','1016','29765','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45152','1022','29782','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45153','1022','29781','2','1','FF0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45154','1021','29783','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45155','1023','29780','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45156','1023','29784','2','1','FF0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45157','1018','29763','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45158','1018','29762','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45159','1018','29761','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45160','1020','29753','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45161','1020','29759','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45162','1020','29757','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45163','1020','29755','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45164','1020','29751','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45165','1020','29749','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45166','1020','29769','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45167','1020','29747','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45168','1019','29754','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45169','1019','29760','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45170','1019','29758','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45171','1019','29756','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45172','1019','29752','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45173','1019','29750','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45174','1019','29746','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45175','1019','29748','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45176','1025','29775','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45177','1025','29744','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45178','1017','29766','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45179','1024','29776','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45180','1024','29777','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('45181','1026','29772','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61601','1558','34228','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61602','1558','34231','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61603','1559','34233','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61604','1559','34236','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61605','1560','34237','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61606','1561','34238','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61607','1562','34267','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61608','1562','34259','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61609','1562','34269','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61610','1562','34261','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61611','1562','34270','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61612','1562','34262','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61613','1563','34268','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61614','1563','34260','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61615','1564','34258','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61616','1564','34266','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61617','1565','34273','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61618','1566','34281','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61619','1567','34282','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61620','1568','34241','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61621','1569','34297','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61622','1570','34309','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61623','1570','34301','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61624','1570','34311','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61625','1570','34303','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61626','1570','34312','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61627','1570','34304','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61628','1571','34310','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61629','1571','34302','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61630','1572','34300','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61631','1572','34308','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61632','1573','34315','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61633','1574','34316','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61634','1575','34285','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61635','1576','34333','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61636','1577','34334','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61637','1578','34335','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61638','1579','34336','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61639','1580','34344','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61640','1580','34354','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61641','1580','34345','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61642','1580','34340','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61643','1580','34347','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61644','1580','34341','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61645','1581','34338','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61646','1581','34339','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61647','1582','34361','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61648','1582','34368','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61649','1582','34359','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61650','1582','34366','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61651','1582','34358','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61652','1582','34365','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61653','1583','34360','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61654','1583','34367','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61655','1584','34369','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61656','1584','34362','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61657','1585','34382','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61658','1586','34383','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61659','1587','34400','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61660','1588','34401','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61661','1589','34402','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61662','1590','34403','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61663','1591','34411','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61664','1591','34421','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61665','1591','34412','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61666','1591','34407','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61667','1591','34414','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61668','1591','34408','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61669','1592','34405','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61670','1592','34406','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61671','1593','34428','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61672','1593','34435','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61673','1593','34426','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61674','1593','34433','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61675','1593','34425','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61676','1593','34432','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61677','1594','34427','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61678','1594','34434','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61679','1595','34436','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61680','1595','34429','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61681','1596','34449','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61682','1597','34450','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61683','1598','34466','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61684','1599','34474','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61685','1599','34477','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61686','1600','34479','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61687','1600','34482','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61688','1601','34483','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61689','1602','34484','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61690','1603','34509','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61691','1603','34501','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61692','1603','34511','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61693','1603','34503','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61694','1603','34512','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61695','1603','34504','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61696','1604','34510','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61697','1604','34502','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61698','1605','34500','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61699','1605','34508','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61700','1606','34515','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61701','1607','34487','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61702','1608','34551','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61703','1608','34543','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61704','1608','34553','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61705','1608','34545','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61706','1608','34554','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61707','1608','34546','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61708','1609','34552','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61709','1609','34544','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61710','1610','34542','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61711','1610','34550','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61712','1611','34557','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61713','1612','34565','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61714','1613','34566','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61715','1614','34525','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61716','1615','34595','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61717','1615','34587','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61718','1615','34597','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61719','1615','34589','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61720','1615','34598','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61721','1615','34590','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61722','1616','34596','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61723','1616','34588','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61724','1617','34586','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61725','1617','34594','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61726','1618','34601','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61727','1619','34609','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61728','1620','34610','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61729','1621','34569','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61730','1622','34627','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61731','1623','34639','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61732','1623','34631','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61733','1623','34641','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61734','1623','34633','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61735','1623','34642','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61736','1623','34634','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61737','1624','34640','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61738','1624','34632','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61739','1625','34630','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61740','1625','34638','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61741','1626','34645','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61742','1627','34653','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61743','1628','34654','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61744','1629','34613','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61745','1630','34671','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61746','1631','34683','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61747','1631','34675','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61748','1631','34685','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61749','1631','34677','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61750','1631','34686','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61751','1631','34678','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61752','1632','34684','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61753','1632','34676','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61754','1633','34674','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61755','1633','34682','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61756','1634','34689','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61757','1635','34697','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61758','1636','34698','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61759','1637','34657','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61760','1638','34716','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61761','1639','34728','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61762','1639','34720','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61763','1639','34730','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61764','1639','34722','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61765','1639','34731','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61766','1639','34723','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61767','1640','34729','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61768','1640','34721','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61769','1641','34719','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61770','1641','34727','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61771','1642','34734','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61772','1643','34742','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61773','1644','34743','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61774','1645','34701','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61775','1646','34761','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61776','1647','34773','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61777','1647','34765','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61778','1647','34775','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61779','1647','34767','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61780','1647','34776','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61781','1647','34768','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61782','1648','34774','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61783','1648','34766','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61784','1649','34764','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61785','1649','34772','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61786','1650','34779','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61787','1651','34787','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61788','1652','34788','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61789','1653','34746','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61790','1654','34806','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61791','1655','34819','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61792','1655','34811','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61793','1655','34821','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61794','1655','34813','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61795','1655','34822','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61796','1655','34814','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61797','1656','34820','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61798','1656','34812','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61799','1657','34810','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61800','1657','34818','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61801','1658','34825','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61802','1659','34833','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61803','1660','34834','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('61804','1661','34791','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62287','1374','32471','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62288','1375','32469','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62289','1375','32468','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62290','1376','32472','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62291','1376','32467','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62292','1377','32483','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62293','1377','32482','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62294','1378','32484','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62295','1378','32481','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62296','1379','32476','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62297','1379','32478','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62298','1379','32480','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62299','1172','30918','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62300','1172','30919','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62301','1172','30920','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62302','1172','30921','2','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62303','1173','30922','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62304','835','28744','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62305','835','28745','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62306','1174','30913','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62307','1175','30906','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62308','1175','30908','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62309','1175','30915','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62310','1175','30897','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62311','1175','30901','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62312','1175','30899','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62313','1175','30907','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62314','1175','30905','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62315','1175','30904','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62316','1175','30900','0','9','FFAD40','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62317','1175','30898','0','10','40CDFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62318','1176','30910','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62319','1176','30909','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62320','836','28798','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62321','836','28799','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62322','836','28800','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62323','836','28801','2','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62324','837','28803','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62325','838','28793','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62326','840','28787','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62327','840','28784','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62328','840','28782','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62329','840','28781','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62330','840','28780','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62331','840','28778','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62332','840','28786','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62333','840','28785','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62334','840','28783','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62335','840','28779','0','9','FFAD40','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62336','840','28796','0','10','40CDFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62337','839','28789','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62338','839','28788','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62339','1278','31855','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62340','1278','31856','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62341','1304','32007','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62342','1304','32010','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62343','1305','32008','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62344','1305','32011','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62345','1306','32003','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62346','1306','32004','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62347','1306','32009','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62348','1282','31818','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62349','1282','31825','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62350','1283','31850','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62351','1283','31819','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62352','1284','31824','1','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62353','1284','31821','1','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62354','1285','31839','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62355','1285','31841','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62356','1285','31842','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62357','1285','31837','2','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62358','1285','31838','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62359','1285','31829','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62360','1286','31833','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62361','1286','31834','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62362','1286','31835','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62363','1121','30606','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62364','1121','30590','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62365','1121','30582','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62366','1122','30580','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62367','1122','30578','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62368','1123','30586','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62369','1123','30608','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62370','1123','30585','2','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62371','1123','30589','2','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62372','1123','30584','2','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62373','1123','30588','2','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62374','1124','30583','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62375','1124','30587','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62376','1125','30555','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62377','1125','30554','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62378','1125','30556','2','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62379','1125','30557','2','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62380','1126','30565','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62381','1127','30567','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62382','1127','30568','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62383','1128','30536','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62384','1129','30566','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62385','1129','30549','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62386','1129','30553','2','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62387','1129','30570','2','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62388','1143','30714','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62389','1143','30716','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62390','1143','30717','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62391','1143','30715','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62392','1144','30753','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62393','1144','30738','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62394','1145','30718','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62395','1145','30737','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62396','1145','30727','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62397','1145','30729','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62398','1146','30730','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62399','1146','30732','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62400','1146','30731','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62401','1146','30733','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62402','1147','30734','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62403','1147','30736','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62404','1147','30735','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62405','1147','30758','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62406','1148','30711','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62407','1148','30706','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62408','1148','30710','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62409','1148','30712','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62410','1148','30702','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62411','1148','30707','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62412','1148','30704','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62413','1177','30927','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62414','1177','30944','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62415','1178','30935','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62416','1178','30942','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62417','1179','30949','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62418','1179','30950','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62419','1179','30951','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62420','1180','30952','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62421','1180','30954','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62422','1180','30955','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62423','1181','30936','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62424','1181','30940','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62425','1182','30930','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62426','1182','30929','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62427','1182','30928','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62428','1182','30931','2','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62429','1183','30934','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62430','1183','30941','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62431','1380','32498','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62432','1380','32499','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62433','1381','32505','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62434','1381','32508','0','1','2774A4','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62435','1381','32506','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62436','1381','32507','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62437','1381','32509','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62438','1381','32510','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62439','1382','32488','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62440','1382','32491','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62441','1382','32493','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62442','1382','32494','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62443','1383','32528','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62444','1383','32529','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62445','1384','32535','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62446','1384','32538','0','1','2774A4','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62447','1384','32536','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62448','1384','32537','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62449','1384','32539','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62450','1384','32540','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62451','1385','32518','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62452','1385','32521','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62453','1385','32523','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62454','1385','32524','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62455','1250','31527','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62456','1250','31529','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62457','1250','31499','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62458','1251','31532','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62459','1251','31534','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62460','1251','31538','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62461','1251','31536','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62462','1251','31528','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62463','1251','31542','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62464','1252','31552','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62465','1252','31551','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62466','1252','31541','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62467','1253','31513','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62468','1253','31526','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62469','1253','31525','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62470','1254','31502','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62471','1254','31501','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62472','1254','31503','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62473','1255','31505','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62474','1255','31504','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62475','1255','31506','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62476','1256','31508','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62477','1256','31507','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62478','1256','31509','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62479','1257','31511','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62480','1257','31510','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62481','1257','31500','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62482','1258','31514','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62483','1258','31512','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62484','1258','31515','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62485','1259','31516','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62486','1259','31517','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62487','1260','31523','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62488','1260','31522','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62489','1260','31524','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62490','1307','32051','1','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62491','1307','32057','1','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62492','1709','35805','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62493','1709','35804','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62494','1710','35789','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62495','1710','35806','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62496','1711','35800','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62497','1711','35799','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62498','1711','35798','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62499','1711','35796','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62500','1711','35788','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62501','1712','35810','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62502','1712','35809','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62503','1713','35807','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62504','1713','35808','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62505','1714','35817','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62506','1714','35816','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62507','1715','35811','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62508','1715','35812','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62509','1715','35813','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62510','1715','35814','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62511','1715','35815','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62512','1716','35842','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62513','1716','35841','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62514','1717','35836','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62515','1717','35835','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62516','1717','35834','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62517','1717','35832','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62518','1717','35822','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62519','1718','35827','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62520','1718','35828','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62521','1719','35864','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62522','1719','35863','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62523','1720','35848','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62524','1720','35865','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62525','1721','35859','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62526','1721','35858','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62527','1721','35857','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62528','1721','35855','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62529','1721','35847','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62530','1722','35869','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62531','1722','35868','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62532','1723','35866','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62533','1723','35867','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62534','1724','35876','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62535','1724','35875','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62536','1725','35870','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62537','1725','35871','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62538','1725','35872','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62539','1725','35873','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62540','1725','35874','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62541','1726','35901','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62542','1726','35900','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62543','1727','35895','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62544','1727','35894','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62545','1727','35893','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62546','1727','35891','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62547','1727','35881','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62548','1728','35886','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62549','1728','35887','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62550','1184','30982','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62551','1184','30980','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62552','1185','30983','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62553','1185','30981','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62554','1186','30976','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62555','1186','30985','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62556','1186','30997','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62557','1186','30970','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62558','1186','30973','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62559','1186','30995','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62560','1186','30998','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62561','1186','30978','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62562','1187','31024','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62563','1187','31022','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62564','1188','31025','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62565','1188','31023','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62566','1189','31018','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62567','1189','31027','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62568','1189','31039','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62569','1189','31012','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62570','1189','31015','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62571','1189','31037','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62572','1189','31040','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62573','1189','31020','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62574','1308','32078','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62575','1308','32077','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62576','1309','32088','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62577','1309','32087','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62578','1310','32071','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62579','1310','32102','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62580','1311','32108','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62581','1311','32109','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62582','1311','32106','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62583','1311','32107','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62584','1312','32083','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62585','1312','32084','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62586','1313','32080','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62587','1313','32081','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62588','1314','32086','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62589','1314','32100','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62590','1314','32073','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62591','1314','32131','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62592','1314','32118','2','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62593','1314','32101','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62594','1314','32125','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62595','1314','32126','2','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62596','1314','32127','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62597','1314','32128','0','9','FFAD40','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62598','1314','32129','2','10','40CDFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62599','1314','32130','0','11','40FFA0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62600','1315','32124','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62601','1315','32123','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62602','1315','32122','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62603','1315','32121','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62604','1315','32121','2','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62605','1315','32120','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62606','1316','32098','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62607','1316','32099','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62608','1316','32097','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62609','1316','32096','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62610','1130','30613','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62611','1130','30635','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62612','1130','30625','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62613','1131','30632','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62614','1131','30633','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62615','1131','30629','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62616','1132','30630','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62617','1132','30628','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62618','1132','30631','2','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62619','1133','30619','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62620','1133','30618','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62621','1134','30623','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62622','1134','30622','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62623','1135','30615','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62624','841','28813','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62625','841','28811','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62626','841','28812','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62627','841','28814','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62628','842','28817','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62629','842','28815','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62630','842','28816','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62631','844','28808','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62632','844','28807','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62633','843','28818','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62634','845','28829','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62635','845','28831','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62636','845','28832','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62637','845','28830','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62638','846','28826','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62639','846','28828','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62640','846','28827','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62641','847','28825','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62642','1662','34869','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62643','1663','34871','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62644','1663','34870','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62645','1663','34872','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62646','1663','34873','5','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62647','1663','34874','5','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62648','1664','34880','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62649','1665','34882','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62650','1665','34881','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62651','1665','34883','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62652','1665','34884','5','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62653','1665','34885','5','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62654','1666','34903','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62655','1666','34902','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62656','1666','34901','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62657','1667','34889','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62658','1667','34896','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62659','1667','34895','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62660','1667','34894','5','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62661','1667','34893','5','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62662','1668','34910','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62663','1668','34911','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62664','1668','34909','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62665','1669','34913','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62666','1669','34912','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62667','1669','34917','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62668','1669','34915','5','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62669','1669','34914','5','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62670','1669','34916','5','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62671','1669','34918','5','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62672','1669','34919','5','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62673','1670','34925','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62674','1670','34926','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62675','1670','34927','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62676','1671','34934','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62677','1671','34935','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62678','1671','34936','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62679','1672','34854','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62680','1672','34850','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62681','1672','34846','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62682','1672','34845','5','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62683','1673','34852','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62684','1674','34848','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62685','1674','34849','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62686','1674','34847','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62687','1675','34858','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62688','1287','31890','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62689','1287','31882','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62690','1287','31880','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62691','1287','31883','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62692','1288','31889','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62693','1288','31881','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62694','1288','31888','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62695','1289','31900','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62696','1289','31895','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62697','1289','31899','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62698','1289','31902','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62699','1290','31907','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62700','1290','31908','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62701','1290','31906','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62702','1412','32908','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62703','1412','32923','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62704','1412','32921','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62705','1412','32919','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62706','1412','32917','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62707','1412','32911','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62708','1412','32914','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62709','1412','32909','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62710','1413','32912','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62711','1413','32922','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62712','1413','32920','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62713','1413','32918','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62714','1413','32915','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62715','1413','32910','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62716','1413','32913','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62717','1413','32924','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62718','1414','32847','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62719','1414','32848','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62720','1414','32846','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62721','1415','32871','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62722','1415','32876','2','1','FF0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62723','1416','32875','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62724','1417','32839','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62725','1417','32838','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62726','1418','32878','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62727','1418','32873','2','1','FF0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62728','1419','32843','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62729','1419','32842','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62730','1419','32841','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62731','1420','32857','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62732','1420','32851','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62733','1420','32861','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62734','1420','32859','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62735','1420','32855','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62736','1420','32853','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62737','1420','32863','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62738','1420','32849','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62739','1421','32858','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62740','1421','32850','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62741','1421','32862','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62742','1421','32860','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62743','1421','32856','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62744','1421','32854','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62745','1421','32852','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62746','1421','32840','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62747','1422','32864','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62748','1423','32844','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62749','1424','32866','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62750','1424','32867','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62751','1425','32865','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62752','1426','33000','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62753','1426','33015','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62754','1426','33013','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62755','1426','33011','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62756','1426','33009','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62757','1426','33003','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62758','1426','33006','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62759','1426','33001','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62760','1427','33004','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62761','1427','33014','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62762','1427','33012','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62763','1427','33010','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62764','1427','33007','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62765','1427','33002','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62766','1427','33005','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62767','1427','33016','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62768','1428','32937','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62769','1428','32938','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62770','1428','32936','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62771','1429','32969','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62772','1429','32967','2','1','FF0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62773','1430','32966','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62774','1431','32964','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62775','1431','32962','2','1','FF0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62776','1432','32933','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62777','1432','32932','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62778','1432','32955','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62779','1433','32947','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62780','1433','32953','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62781','1433','32951','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62782','1433','32949','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62783','1433','32945','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62784','1433','32943','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62785','1433','32941','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62786','1433','32939','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62787','1434','32948','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62788','1434','32954','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62789','1434','32952','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62790','1434','32950','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62791','1434','32946','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62792','1434','32944','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62793','1434','32942','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62794','1434','32940','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62795','1435','32960','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62796','1436','32934','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62797','1437','32957','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62798','1437','32958','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62799','1438','32970','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62800','1291','31947','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62801','1291','31946','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62802','1292','31952','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62803','1292','31938','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62804','1292','31950','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62805','1293','31939','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62806','1293','31945','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62807','1293','31942','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62808','1294','31959','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62809','1294','31962','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62810','1295','31918','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62811','1295','31916','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62812','1295','31917','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62813','1296','31919','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62814','1296','31920','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62815','1296','31921','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62816','1297','31911','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62817','1297','31944','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62818','1298','31953','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62819','1298','31954','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62820','1298','31960','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62821','1298','31961','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62822','1298','31957','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62823','1298','31958','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62824','1298','31912','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62825','1298','31913','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62826','1298','31914','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62827','1298','31915','0','9','FFAD40','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62828','1298','31948','0','10','40CDFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62829','1298','31949','0','11','40FFA0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62830','1317','32146','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62831','1317','32145','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62832','1318','32151','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62833','1318','32150','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62834','1318','32153','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62835','1318','32152','5','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62836','1319','32157','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62837','1319','32155','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62838','1319','32156','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62839','1520','34128','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62840','1520','34127','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62841','1520','34130','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62842','1520','34131','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62843','1520','34132','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62844','1521','34134','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62845','1521','34149','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62846','1521','34153','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62847','1521','34152','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62848','1521','34150','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62849','1521','34148','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62850','1522','34167','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62851','1522','34166','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62852','1523','34164','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62853','1523','34165','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62854','1524','34108','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62855','1524','34109','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62856','1524','34110','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62857','1524','34111','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62858','1524','34113','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62859','1524','34107','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62860','1524','34114','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62861','1524','34116','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62862','1524','34122','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62863','1525','22404','0','0','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62864','1525','22399','0','1','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62865','1525','22416','0','2','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62866','1525','25366','0','3','FF33FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62867','1525','22418','0','4','009600','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62868','1525','22402','0','5','003300','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62869','1525','22400','0','6','33FFFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62870','1525','22689','0','7','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62871','1525','23171','0','8','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62872','1525','22401','0','9','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62873','1526','23269','0','0','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62874','1526','23264','0','1','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62875','1526','23261','0','2','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62876','1526','25367','0','3','FF33FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62877','1526','23260','0','4','009600','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62878','1526','23259','0','5','003300','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62879','1526','23270','0','6','33FFFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62880','1526','23262','0','7','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62881','1526','23267','0','8','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62882','1526','23328','0','9','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62883','1527','22406','0','0','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62884','1527','25665','0','1','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62885','1527','25666','0','2','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62886','1527','28537','0','3','00EEEE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62887','1527','28535','0','4','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62888','1528','23257','0','0','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62889','1528','25667','0','1','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62890','1528','25668','0','2','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62891','1528','28538','0','3','00EEEE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62892','1528','28536','0','4','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62893','1529','22426','0','0','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62894','1529','22408','0','1','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62895','1529','22412','0','2','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62896','1529','22414','0','3','FF66FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62897','1529','23663','0','4','009999','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62898','1529','22430','0','6','8048B4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62899','1529','22420','0','7','FD5434','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62900','1530','23268','0','0','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62901','1530','23258','0','1','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62902','1530','23253','0','2','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62903','1530','23266','0','3','FF66FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62904','1530','23664','0','4','009999','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62905','1530','23255','0','6','8048B4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62906','1530','23265','0','7','FD5434','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62907','1531','22422','0','0','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62908','1531','22424','0','1','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62909','1531','25370','0','2','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62910','1531','29822','0','3','00EEEE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62911','1532','23256','0','0','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62912','1532','23252','0','1','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62913','1532','25371','0','2','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62914','1532','29823','0','3','00EEEE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62915','1535','22199','0','0','C80000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62916','1535','22196','0','1','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62917','1536','23628','0','0','C80000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62918','1536','23625','0','1','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62919','1537','22185','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62920','1537','22189','0','1','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62921','1537','22396','0','2','00DDDD','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62922','1537','22183','0','3','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62923','1537','22191','0','4','999900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62924','1537','23634','0','5','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62925','1538','23276','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62926','1538','23273','0','1','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62927','1538','23275','0','2','00DDDD','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62928','1538','23274','0','3','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62929','1538','23620','0','4','999900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62930','1538','23635','0','5','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62931','1539','22404','0','0','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62932','1539','22399','0','1','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62933','1539','22416','0','2','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62934','1539','22430','0','3','FF33FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62935','1539','22418','0','4','009600','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62936','1539','22402','0','5','003300','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62937','1539','22420','0','6','CCCC00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62938','1539','22400','0','7','33FFFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62939','1539','22689','0','8','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62940','1539','23171','0','9','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62941','1539','22401','0','10','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62942','1540','23269','0','0','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62943','1540','23264','0','1','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62944','1540','23261','0','2','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62945','1540','23255','0','3','FF33FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62946','1540','23260','0','4','009600','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62947','1540','23259','0','5','003300','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62948','1540','23265','0','6','CCCC00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62949','1540','23270','0','7','33FFFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62950','1540','23262','0','8','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62951','1540','23267','0','9','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62952','1540','23328','0','10','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62953','1541','22426','0','0','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62954','1541','22422','0','1','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62955','1541','22408','0','2','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62956','1541','22424','0','3','00EEEE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62957','1541','22412','0','4','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62958','1541','22406','0','5','EE0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62959','1541','22414','0','6','FF66FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62960','1541','23663','0','7','009999','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62961','1541','25366','0','8','BBBB00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62962','1541','25370','0','9','AA0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62963','1541','25665','0','10','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62964','1541','25666','0','11','008800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62965','1541','28535','0','12','80B0E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62966','1541','28537','0','13','4080B0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62967','1541','29822','0','14','8000FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62968','1542','23268','0','0','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62969','1542','23256','0','1','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62970','1542','23258','0','2','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62971','1542','23252','0','3','00EEEE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62972','1542','23253','0','4','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62973','1542','23257','0','5','EE0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62974','1542','23266','0','6','FF66FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62975','1542','23664','0','7','009999','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62976','1542','25367','0','8','BBBB00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62977','1542','25371','0','9','AA0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62978','1542','25667','0','10','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62979','1542','25668','0','11','008800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62980','1542','28536','0','12','80B0E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62981','1542','28538','0','13','4080B0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62982','1542','29823','0','14','8000FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62983','1543','28248','0','0','008800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62984','1543','28533','0','1','EE0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62985','1544','28249','0','0','008800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62986','1544','28534','0','1','EE0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62987','1545','22187','5','0','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62988','1545','23251','0','1','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62989','1546','23277','5','0','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62990','1546','23272','0','1','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62991','1547','28581','0','0','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62992','1547','28574','0','1','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62993','1547','28571','0','2','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62994','1547','28562','0','3','FF33FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62995','1547','28570','0','4','009600','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62996','1547','28569','0','5','003300','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62997','1547','28552','0','6','33FFFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62998','1547','28573','0','7','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('62999','1547','28579','0','8','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63000','1547','28559','0','9','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63001','1548','28567','0','0','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63002','1548','28575','0','1','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63003','1548','28576','0','2','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63004','1548','28583','0','3','00EEEE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63005','1548','28582','0','4','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63006','1549','28572','0','0','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63007','1549','28568','0','1','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63008','1549','28564','0','2','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63009','1549','28578','0','3','FF66FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63010','1549','28580','0','4','009999','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63011','1549','28565','0','6','8048B4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63012','1549','28577','0','7','FD5434','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63013','1550','28566','0','0','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63014','1550','28561','0','1','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63015','1550','28563','0','2','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63016','1550','29821','0','3','00EEEE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63017','1552','28546','0','0','C80000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63018','1552','28545','0','1','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63019','1553','28551','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63020','1553','28543','0','1','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63021','1553','28542','0','2','00DDDD','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63022','1553','28549','0','3','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63023','1553','28544','0','4','999900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63024','1553','28548','0','5','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63025','1554','28581','0','0','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63026','1554','28574','0','1','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63027','1554','28571','0','2','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63028','1554','28565','0','3','FF33FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63029','1554','28570','0','4','009600','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63030','1554','28569','0','5','003300','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63031','1554','28577','0','6','CCCC00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63032','1554','28552','0','7','33FFFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63033','1554','28573','0','8','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63034','1554','28579','0','9','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63035','1554','28559','0','10','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63036','1555','28572','0','0','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63037','1555','28566','0','1','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63038','1555','28568','0','2','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63039','1555','28561','0','3','00EEEE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63040','1555','28564','0','4','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63041','1555','28567','0','5','EE0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63042','1555','28578','0','6','FF66FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63043','1555','28580','0','7','009999','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63044','1555','28562','0','8','BBBB00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63045','1555','28563','0','9','AA0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63046','1555','28575','0','10','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63047','1555','28576','0','11','008800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63048','1555','28582','0','12','80B0E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63049','1555','28583','0','13','4080B0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63050','1555','29821','0','14','8000FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63051','1556','28560','0','0','008800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63052','1556','28584','0','1','EE0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63053','1557','28550','5','0','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63054','1557','28540','0','1','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63055','1320','32196','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63056','1320','32197','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63057','1320','32195','2','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63058','1321','32200','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63059','1321','32199','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63060','1322','32175','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63061','1322','32165','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63062','1323','32162','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63063','1323','32163','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63064','1323','32190','2','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63065','1324','32192','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63066','1324','32179','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63067','1325','32168','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63068','1325','32166','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63069','803','28599','0','0','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63070','803','28596','0','1','00DDDD','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63071','803','28597','0','2','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63072','803','28598','0','3','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63073','804','28602','0','0','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63074','804','28606','0','1','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63075','804','28608','0','2','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63076','804','28615','0','3','FF33FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63077','804','28610','0','4','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63078','804','28611','0','5','003300','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63079','804','28616','0','6','33FFFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63080','804','28607','0','7','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63081','804','28604','0','8','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63082','804','28588','0','9','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63083','805','28612','0','0','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63084','805','28600','0','1','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63085','805','28613','0','2','EE0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63086','805','28605','0','3','FF66FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63087','805','28614','0','4','960000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63088','805','28601','0','5','009600','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63089','805','28603','0','6','009999','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63090','805','28609','0','7','BBBB00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63091','806','28595','0','0','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63092','806','28586','0','1','C80000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63093','529','23357','0','0','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63094','529','23341','0','1','00DDDD','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63095','529','23342','0','2','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63096','529','28251','0','3','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63097','530','23345','0','0','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63098','530','23348','0','1','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63099','530','23355','0','2','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63100','530','23352','0','3','FF33FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63101','530','23356','0','4','007700','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63102','530','23354','0','5','003300','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63103','530','23346','0','6','33FFFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63104','530','23349','0','7','DD0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63105','530','23344','0','8','000099','0','7','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63106','530','28250','0','9','00FF00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63107','531','23353','0','0','FFAA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63108','531','23347','0','1','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63109','531','23350','0','2','EE0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63110','531','23343','0','3','FF66FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63111','531','23351','0','4','0000EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63112','531','23360','0','5','00EE00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63113','531','25369','0','6','009999','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63114','531','25368','0','7','BBBB00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63115','531','28618','0','8','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63116','531','28619','0','9','008800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63117','807','28617','0','0','008800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63118','532','23340','5','0','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63119','532','23358','5','1','C80000','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63120','472','22945','5','0','00AA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63121','472','22946','5','1','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63122','473','22950','0','0','C80000','0','2','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63123','473','22948','0','1','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63124','471','22924','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63125','471','22920','0','1','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63126','469','22922','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63127','469','22923','0','1','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63128','469','22921','0','2','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63129','498','23109','0','0','009999','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63130','498','23112','0','1','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63131','498','23115','0','2','999900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63132','498','23113','0','3','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63133','498','23114','0','4','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63134','498','23110','0','5','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63135','540','22942','5','0','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63136','492','23073','5','0','00AA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63137','492','23074','5','1','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63138','467','22910','0','0','C80000','0','2','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63139','467','22908','0','1','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63140','465','22884','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63141','465','22880','0','1','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63142','463','22882','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63143','463','22883','0','1','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63144','463','22881','0','2','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63145','462','22886','1','0','009999','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63146','462','22888','1','1','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63147','462','22891','1','2','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63148','462','22892','1','3','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63149','462','22885','1','4','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63150','541','22902','5','0','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63151','464','22897','0','0','AA0000','0','2','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63152','464','22895','0','1','00AA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63153','478','22985','5','0','00AA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63154','478','22986','5','1','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63155','479','22990','0','0','C80000','0','2','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63156','479','22988','0','1','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63157','475','22962','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63158','475','22963','0','1','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63159','475','22961','0','2','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63160','474','22968','1','0','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63161','474','22971','1','1','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63162','474','22972','1','2','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63163','474','22965','1','3','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63164','542','22982','5','0','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63165','491','23070','0','0','C80000','0','2','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63166','491','23068','0','1','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63167','487','23042','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63168','487','23043','0','1','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63169','487','23041','0','2','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63170','543','23062','5','0','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63171','494','23077','5','0','00AA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63172','494','23078','5','1','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63173','493','23075','5','0','00AA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63174','493','23076','5','1','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63175','461','22870','0','0','C80000','0','2','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63176','461','22868','0','1','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63177','459','22844','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63178','459','22840','0','1','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63179','457','22842','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63180','457','22843','0','1','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63181','457','22841','0','2','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63182','456','22846','1','0','009999','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63183','456','22848','1','1','990099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63184','456','22851','1','2','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63185','456','22852','1','3','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63186','456','22845','1','4','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63187','544','22862','5','0','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63188','458','22857','0','0','AA0000','0','2','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63189','458','22855','0','1','00AA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63190','484','23025','5','0','00AA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63191','484','23026','5','1','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63192','485','23030','0','0','C80000','0','2','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63193','485','23028','0','1','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63194','483','23004','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63195','483','23000','0','1','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63196','481','23002','0','0','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63197','481','23003','0','1','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63198','481','23001','0','2','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63199','480','23007','1','0','999900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63200','480','23011','1','1','990000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63201','480','23012','1','2','000099','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63202','480','23005','1','3','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63203','545','23022','5','0','00C800','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63204','482','23017','0','0','AA0000','0','2','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63205','482','23015','0','1','00AA00','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63206','651','26928','5','0','EE0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63207','651','26927','0','1','000000','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63208','652','26925','2','0','880000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63209','652','26932','0','1','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63210','652','26930','0','2','00CCCC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63211','652','26931','0','3','000000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63212','652','26929','0','4','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63213','652','26926','0','5','777700','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63214','653','26933','2','0','EE0000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63215','653','26943','2','1','EE00EE','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63216','653','26935','0','2','000000','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63217','653','26936','4','3','000000','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63218','654','26934','2','0','880000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63219','654','26939','0','1','009900','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63220','654','26942','0','2','00CCCC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63221','654','26938','0','3','000000','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63222','654','26937','0','4','3333FF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63223','1326','32292','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63224','1326','32291','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63225','1326','32278','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63226','1326','32277','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63227','1327','32304','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63228','1327','32289','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63229','1328','32259','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63230','1328','32260','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63231','1329','32268','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63232','1329','32264','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63233','1330','32261','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63234','1330','32265','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63235','1330','32262','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63236','1330','32263','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63237','1330','32266','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63238','1330','32267','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63239','1331','32272','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63240','1331','32271','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63241','1332','32256','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63242','1332','32242','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63243','1333','32273','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63244','1333','32238','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63245','1334','32245','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63246','1334','32250','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63247','1334','32246','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63248','1334','32247','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63249','1334','32251','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63250','1334','32252','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63251','1159','30886','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63252','1159','30887','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63253','1160','30888','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63254','1160','30882','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63255','1160','30890','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63256','1160','30881','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63257','1160','30889','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63258','1161','30847','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63259','1161','30872','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63260','1162','30853','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63261','1162','30849','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63262','1162','30852','2','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63263','1162','30851','2','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63264','1162','30848','2','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63265','1163','30856','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63266','1163','30855','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63267','1163','30854','2','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63268','1164','30859','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63269','1164','30870','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63270','1165','30860','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63271','1165','30871','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63272','1166','30868','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63273','1166','30869','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63274','1166','30867','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63275','1166','30866','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63276','1166','30865','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63277','1167','30850','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63278','1167','30863','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63279','1167','30861','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63280','1168','30833','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63281','1168','30841','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63282','1168','30857','2','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63283','1169','30834','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63284','1169','30831','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63285','1170','30846','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63286','1488','30840','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63287','1488','30845','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63288','1488','30842','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63289','1488','30873','2','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63290','1677','35580','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63291','1677','35583','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63292','1677','35581','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63293','1677','35582','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63294','1678','35589','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63295','1678','35588','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63296','1678','35587','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63297','1679','35592','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63298','1679','35601','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63299','1680','35596','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63300','1680','35597','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63301','1681','35602','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63302','1681','35607','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63303','1681','35605','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63304','1681','35603','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63305','1682','35609','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63306','1682','35611','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63307','1682','35610','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63308','1683','35623','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63309','1683','35621','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63310','1684','35630','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63311','1684','35631','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63312','1685','35633','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63313','1685','35635','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63314','1686','35636','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63315','1686','35634','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63316','1687','35638','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63317','1687','35639','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63318','1688','35637','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63319','1688','35640','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63320','1688','35641','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63321','1689','35643','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63322','1689','35644','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63323','1390','32665','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63324','1390','32668','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63325','1390','32666','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63326','1390','32667','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63327','1391','32674','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63328','1391','32673','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63329','1391','32672','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63330','1392','32677','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63331','1392','32686','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63332','1393','32681','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63333','1393','32682','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63334','1394','32687','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63335','1394','32692','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63336','1394','32690','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63337','1394','32688','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63338','1395','32694','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63339','1395','32696','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63340','1395','32695','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63341','1396','32708','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63342','1396','32706','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63343','1397','32715','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63344','1397','32716','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63345','1398','32718','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63346','1398','32720','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63347','1399','32721','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63348','1399','32719','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63349','1400','32723','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63350','1400','32724','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63351','1401','32722','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63352','1401','32725','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63353','1401','32726','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63354','1402','32728','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63355','1402','32729','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63356','1439','33072','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63357','1439','33092','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63358','1440','33073','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63359','1440','33069','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63360','1441','33079','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63361','1441','33084','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63362','1441','33082','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63363','1441','33074','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63364','1441','33078','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63365','1441','33086','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63366','1441','33076','2','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63367','1442','33081','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63368','1442','33085','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63369','1442','33083','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63370','1442','33075','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63371','1442','33068','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63372','1442','33087','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63373','1442','33077','2','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63374','1443','33093','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63375','1443','33098','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63376','1444','33097','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63377','1444','33100','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63378','1444','33096','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63379','1444','33094','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63380','1445','33116','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63381','1446','33045','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63382','1446','33044','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63383','1446','33046','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63384','1447','33055','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63385','1447','33023','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63386','1448','33053','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63387','1448','33052','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63388','1448','33054','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63389','1449','33051','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63390','1449','33059','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63391','1449','33027','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63392','1450','33022','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63393','1450','33040','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63394','1450','33042','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63395','1450','33043','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63396','1451','33038','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63397','1451','33025','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63398','1451','33026','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63399','1451','33024','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63400','1452','33029','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63401','1452','33028','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63402','1453','33035','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63403','1453','33034','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63404','1453','33033','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63405','1453','33036','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63406','1453','33030','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63407','1453','33031','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63408','1454','33057','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63409','1454','33056','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63410','1454','33058','2','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63411','1455','33190','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63412','1455','33193','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63413','1455','33189','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63414','1455','33187','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63415','1456','33158','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63416','1456','33168','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63417','1456','33169','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63418','1456','33167','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63419','1456','33171','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63420','1457','33165','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63421','1457','33166','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63422','1457','33164','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63423','1457','33163','2','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63424','1458','33161','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63425','1458','33162','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63426','1458','33155','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63427','1459','33146','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63428','1459','33145','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63429','1460','33152','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63430','1460','33151','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63431','1460','33148','2','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63432','1460','33153','2','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63433','1460','33149','2','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63434','1460','33144','2','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63435','1190','31140','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63436','1190','31141','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63437','1261','31145','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63438','1261','31146','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63439','1261','31147','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63440','1191','31138','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63441','1192','31157','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63442','1192','31158','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63443','1193','31092','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63444','1193','31108','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63445','1193','31110','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63446','1193','31067','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63447','1193','31086','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63448','1193','31087','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63449','1194','31120','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63450','1194','31105','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63451','1194','31071','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63452','1194','31081','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63453','1195','31098','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63454','1195','31099','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63455','1196','31072','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63456','1196','31072','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63457','1197','31103','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63458','1197','31074','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63459','1198','31104','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63460','1198','31063','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63461','1198','31111','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63462','1198','31112','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63463','1198','31084','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63464','1199','31115','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63465','1199','31116','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63466','1199','31062','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63467','1199','31118','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63468','1199','31056','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63469','1200','31107','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63470','1200','31090','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63471','1201','31097','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63472','1201','31096','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63473','1202','31089','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63474','1202','31061','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63475','1203','31064','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63476','1204','31065','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63477','1204','31066','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63478','1204','31068','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63479','1204','31070','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63480','1204','31101','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63481','1204','31106','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63482','1204','31114','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63483','1205','31069','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63484','1206','31076','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63485','1206','31078','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63486','1206','31109','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63487','1206','31075','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63488','1207','31080','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63489','1207','31095','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63490','1208','31113','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63491','1208','31118','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63492','1209','31058','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63493','1209','31077','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63494','1209','31056','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63495','1209','31117','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63496','1109','30453','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63497','1109','30455','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63498','1110','30471','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63499','1110','30470','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63500','1110','30466','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63501','1110','30441','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63502','1111','30463','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63503','1111','30452','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63504','1111','30451','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63505','1111','30437','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63506','1112','30456','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63507','1112','30457','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63508','1112','30458','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63509','1112','30459','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63510','1113','30442','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63511','1113','30444','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63512','1113','30445','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63513','1114','30446','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63514','1114','30447','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63515','1114','31168','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63516','1114','30449','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63517','1136','30659','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63518','1136','30661','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63519','1137','30677','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63520','1137','30676','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63521','1137','30672','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63522','1137','30647','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63523','1138','30669','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63524','1138','30658','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63525','1138','30657','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63526','1138','30643','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63527','1139','30662','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63528','1139','30663','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63529','1139','30664','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63530','1139','30665','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63531','1140','30648','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63532','1140','30650','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63533','1140','30651','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63534','1141','30652','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63535','1141','30653','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63536','1141','31172','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63537','1141','30655','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63538','1115','30506','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63539','1115','30507','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63540','1116','30504','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63541','1116','30505','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63542','1116','30518','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63543','1116','30492','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63544','1117','30493','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63545','1117','30500','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63546','1117','30486','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63547','1117','30488','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63548','1118','30508','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63549','1118','30509','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63550','1118','30503','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63551','1118','30510','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63552','1119','30491','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63553','1119','30494','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63554','1119','30495','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63555','1120','30496','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63556','1120','30497','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63557','1120','31176','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63558','1120','30499','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63559','1262','31718','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63560','1262','31719','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63561','1263','31722','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63562','1263','31724','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63563','1263','32588','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63564','1264','31630','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63565','1264','31683','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63566','1265','31668','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63567','1265','31702','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63568','1265','31666','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63569','1266','31673','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63570','1266','31704','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63571','1267','31690','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63572','1267','31672','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63573','1268','31632','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63574','1268','31655','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63575','1269','31650','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63576','1269','31648','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63577','1269','31651','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63578','1269','31646','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63579','1269','31653','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63580','1270','31660','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63581','1270','31671','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63582','1270','31662','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63583','1270','31661','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63584','1270','31659','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63585','1270','31658','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63586','814','28730','0','0','66BB6A','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63587','814','28728','0','1','42A5F5','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63588','815','28712','0','0','66BB6A','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63589','816','28733','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63590','816','28715','0','1','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63591','816','28729','0','2','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63592','816','28732','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63593','817','28716','0','0','EC407A','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63594','818','28726','0','0','4CAF50','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63595','818','28723','0','1','03A9F4','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63596','818','28720','0','2','9C27B0','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63597','818','28725','5','3','81C784','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63598','818','28722','5','4','90CAF9','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63599','818','28719','5','5','CE93D8','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63600','819','28727','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63601','819','28724','0','1','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63602','819','28721','0','2','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63603','820','28740','5','0','66BB6A','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63604','820','28739','0','1','42A5F5','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63605','821','28738','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63606','821','28737','0','1','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63607','821','28736','0','2','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63608','821','28735','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63609','821','28734','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63610','822','28693','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63611','822','28698','0','1','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63612','822','28694','0','2','2774A4','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63613','822','28697','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63614','822','28702','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63615','822','28696','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63616','823','28700','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63617','823','28699','0','1','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63618','823','28701','0','2','2774A4','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63619','823','28695','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63620','824','28708','5','0','C8E6C9','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63621','824','28709','0','1','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63622','824','28704','0','2','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63623','824','28705','0','3','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63624','824','28706','0','4','2774A4','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63625','824','28707','0','5','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63626','824','28703','0','6','AC8C14','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63627','825','28674','5','1','A5D6A7','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63628','825','28673','0','2','039BE5','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63629','826','28677','0','0','42A5F5','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63630','827','28689','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63631','827','28688','0','1','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63632','827','28690','0','2','2774A4','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63633','827','28691','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63634','828','28684','0','0','66BB6A','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63635','828','28681','0','1','03A9F4','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63636','829','28710','0','0','29B6F6','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63637','829','28692','0','1','AB47BC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63638','1210','31269','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63639','1210','31252','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63640','1210','31251','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63641','1210','31250','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63642','1210','31249','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63643','1210','31248','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63644','1210','31246','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63645','1210','31245','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63646','1210','31247','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63647','1210','31247','0','9','FFAD40','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63648','1211','31243','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63649','1212','31266','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63650','1212','31265','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63651','1212','31263','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63652','1212','31262','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63653','1212','31260','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63654','1212','31259','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63655','1212','31258','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63656','1212','31256','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63657','1212','31257','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63658','1212','31244','0','9','FFAD40','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63659','1212','31255','0','10','40CDFF','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63660','1212','31254','0','11','40FFA0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63661','1212','31253','0','12','AE4500','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63662','1213','31242','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63663','1386','32598','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63664','1386','32599','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63665','1386','32600','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63666','1087','30346','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63667','1087','30345','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63668','1088','30350','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63669','1088','30349','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63670','1089','30396','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63671','1090','30398','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63672','1091','30322','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63673','1091','30277','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63674','1092','30284','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63675','1093','30313','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63676','1093','30314','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63677','1093','30315','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63678','1093','30316','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63679','1094','30279','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63680','1094','30280','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63681','1095','30290','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63682','1095','30293','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63683','1096','30318','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63684','1096','30308','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63685','1096','30320','2','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63686','1097','30317','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63687','1098','30289','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63688','1098','30291','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63689','1099','30334','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63690','1099','30325','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63691','1100','30306','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63692','1101','30274','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63693','1102','30281','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63694','1060','30159','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63695','1061','30165','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63696','1063','30177','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63697','1064','30183','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63698','1065','30161','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63699','1065','30162','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63700','1066','30167','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63701','1066','30168','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63702','1068','30179','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63703','1068','30180','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63704','1069','30185','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63705','1069','30186','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63706','1070','30142','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63707','1071','30143','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63708','1073','30145','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63709','1074','30146','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63710','741','27084','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63711','741','27085','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63712','741','27083','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63713','741','27086','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63714','741','27082','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63715','741','27079','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63716','742','27622','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63717','742','27625','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63718','742','27624','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63719','742','27621','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63720','742','27623','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63721','742','27620','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63722','743','27979','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63723','743','27982','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63724','743','27981','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63725','743','27978','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63726','743','27980','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63727','743','27977','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63728','740','28008','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63729','740','28011','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63730','740','28010','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63731','740','28007','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63732','740','28009','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63733','740','28006','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63734','745','27104','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63735','745','27105','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63736','745','27103','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63737','745','27106','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63738','745','27102','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63739','745','27099','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63740','746','27183','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63741','746','27186','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63742','746','27185','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63743','746','27182','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63744','746','27184','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63745','746','27181','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63746','747','27218','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63747','747','27221','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63748','747','27220','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63749','747','27217','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63750','747','27219','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63751','747','27216','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63752','748','27254','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63753','748','27257','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63754','748','27256','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63755','748','27253','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63756','748','27255','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63757','748','27252','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63758','749','27275','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63759','749','27278','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63760','749','27277','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63761','749','27274','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63762','749','27276','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63763','749','27273','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63764','750','27324','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63765','750','27327','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63766','750','27326','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63767','750','27323','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63768','750','27325','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63769','750','27322','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63770','752','27453','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63771','752','27456','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63772','752','27455','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63773','752','27452','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63774','752','27454','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63775','752','27451','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63776','753','27489','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63777','753','27492','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63778','753','27491','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63779','753','27488','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63780','753','27490','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63781','753','27487','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63782','754','27523','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63783','754','27526','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63784','754','27525','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63785','754','27522','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63786','754','27524','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63787','754','27521','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63788','755','27559','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63789','755','27562','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63790','755','27561','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63791','755','27558','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63792','755','27560','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63793','755','27557','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63794','756','27645','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63795','756','27648','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63796','756','27647','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63797','756','27644','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63798','756','27646','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63799','756','27643','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63800','758','27725','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63801','758','27728','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63802','758','27727','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63803','758','27724','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63804','758','27726','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63805','758','27723','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63806','759','27759','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63807','759','27762','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63808','759','27761','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63809','759','27758','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63810','759','27760','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63811','759','27757','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63812','760','27791','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63813','760','27794','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63814','760','27793','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63815','760','27790','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63816','760','27792','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63817','760','27789','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63818','762','27875','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63819','762','27878','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63820','762','27877','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63821','762','27874','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63822','762','27876','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63823','762','27873','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63824','763','27912','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63825','763','27915','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63826','763','27914','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63827','763','27911','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63828','763','27913','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63829','763','27910','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63830','764','27947','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63831','764','27950','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63832','764','27949','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63833','764','27946','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63834','764','27948','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63835','764','27945','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63836','773','28121','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63837','773','28124','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63838','773','28123','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63839','773','28120','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63840','773','28122','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63841','773','28119','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63842','785','28226','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63843','785','28229','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63844','785','28228','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63845','785','28225','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63846','785','28227','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63847','785','28224','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63848','790','28296','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63849','790','28299','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63850','790','28298','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63851','790','28295','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63852','790','28297','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63853','790','28294','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63854','865','28971','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63855','865','28974','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63856','865','28973','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63857','865','28970','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63858','865','28972','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63859','865','28969','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63860','766','27124','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63861','766','27125','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63862','766','27123','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63863','766','27126','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63864','766','27122','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63865','766','27119','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63866','886','29080','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63867','886','29083','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63868','886','29082','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63869','886','29079','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63870','886','29081','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63871','886','29078','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63872','668','27208','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63873','1032','30088','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63874','1032','30087','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63875','1033','30089','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63876','671','27240','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63877','1034','30093','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63878','675','27294','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63879','676','27299','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63880','677','27301','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63881','1035','30094','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63882','1036','30095','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63883','1037','30096','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63884','1729','35914','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63885','1730','35917','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63886','1731','35924','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63887','1731','35931','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63888','1731','35922','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63889','1731','35929','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63890','1731','35921','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63891','1731','35928','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63892','1732','35932','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63893','1732','35925','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63894','1733','35923','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63895','1733','35930','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63896','1734','35948','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63897','1734','35949','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63898','1461','33219','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63899','1462','33224','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63900','1463','33227','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63901','1463','33230','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63902','1463','33229','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63903','1463','33226','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63904','1463','33228','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63905','1463','33225','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63906','1464','33260','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63907','1465','33265','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63908','1466','33268','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63909','1466','33271','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63910','1466','33270','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63911','1466','33267','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63912','1466','33269','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63913','1466','33266','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63914','1467','33301','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63915','1468','33306','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63916','1469','33309','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63917','1469','33312','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63918','1469','33311','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63919','1469','33308','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63920','1469','33310','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63921','1469','33307','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63922','1470','33342','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63923','1471','33347','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63924','1472','33350','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63925','1472','33353','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63926','1472','33352','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63927','1472','33349','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63928','1472','33351','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63929','1472','33348','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63930','1473','33383','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63931','1474','33388','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63932','1475','33391','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63933','1475','33394','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63934','1475','33393','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63935','1475','33390','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63936','1475','33392','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63937','1475','33389','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63938','1038','30101','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63939','1039','30102','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63940','1040','30103','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63941','1041','30104','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63942','786','28246','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63943','787','28247','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63944','687','27417','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63945','688','27427','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63946','691','27376','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63947','692','27380','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63948','694','27478','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63949','1042','30105','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63950','1043','30107','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63951','698','27511','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63952','1044','30108','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63953','701','27547','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63954','1045','27591','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63955','1045','30110','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63956','1046','30111','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63957','704','27586','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63958','1690','35679','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63959','1691','35681','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63960','1692','35683','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63961','1693','35686','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63962','1694','35690','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63963','1694','35705','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63964','1694','35696','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63965','1694','35687','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63966','1694','35708','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63967','1694','35711','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63968','1694','35699','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63969','1695','35689','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63970','1695','35704','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63971','1695','35695','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63972','1695','35701','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63973','1695','35707','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63974','1695','35710','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63975','1695','35697','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63976','1696','35713','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63977','1696','35703','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63978','1696','35694','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63979','1696','35712','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63980','1696','35706','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63981','1696','35709','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63982','1696','35698','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63983','1697','35714','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63984','1698','35716','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63985','1699','35718','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63986','1699','35720','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63987','1700','35727','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63988','1700','35724','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63989','1701','35726','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63990','1701','35723','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63991','1702','35730','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63992','1702','35728','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63993','1702','35729','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63994','1703','35737','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63995','1703','35733','0','1','2774A4','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63996','1703','35743','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63997','1703','35739','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63998','1703','35736','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('63999','1703','35742','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64000','1704','35748','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64001','1704','35747','0','1','2774A4','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64002','1704','35750','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64003','1704','35749','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64004','1705','35756','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64005','1705','35755','0','1','2774A4','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64006','1705','35758','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64007','1705','35757','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64008','1706','35764','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64009','1706','35763','0','1','2774A4','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64010','1706','35766','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64011','1706','35765','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64012','1707','35771','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64013','1707','35769','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64014','1707','35770','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64015','1708','35651','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64016','1708','35649','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64017','1708','35647','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64018','1708','35653','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64019','1708','35652','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64020','1708','35650','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64021','708','27671','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64022','1047','30112','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64023','1048','30114','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64024','1048','30113','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64025','1049','30115','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64026','775','28143','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64027','714','27753','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64028','1050','30116','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64029','856','28894','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64030','1051','30118','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64031','1476','33419','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64032','1476','33422','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64033','1476','33421','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64034','1476','33418','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64035','1476','33420','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64036','1476','33417','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64037','1477','33427','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64038','1477','33428','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64039','1478','33431','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64040','1479','33407','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64041','724','27904','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64042','1299','31968','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64043','1299','31966','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64044','1299','31965','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64045','1299','31967','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64046','1052','27907','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64047','1052','27908','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64048','1053','30120','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64049','1335','32330','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64050','1335','32317','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64051','1336','32319','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64052','1336','32327','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64053','1336','32326','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64054','1337','32324','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64055','1337','32318','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64056','1338','32311','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64057','1338','32310','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64058','1338','32328','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64059','1339','32350','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64060','1339','32339','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64061','1340','32331','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64062','1341','32347','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64063','1341','32342','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64064','1342','32334','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64065','1342','32333','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64066','1342','32348','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64067','1343','32373','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64068','1343','32360','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64069','1344','32362','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64070','1344','32370','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64071','1344','32369','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64072','1345','32367','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64073','1345','32361','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64074','1346','32354','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64075','1346','32353','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64076','1346','32371','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64077','1347','32382','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64078','1348','32375','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64079','1349','32380','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64080','1350','32401','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64081','1351','32398','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64082','1351','32397','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64083','1351','32396','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64084','1352','32394','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64085','1353','32393','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64086','1354','32385','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64087','1354','32399','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64088','1355','32420','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64089','1356','32417','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64090','1356','32416','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64091','1356','32415','5','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64092','1357','32413','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64093','1358','32412','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64094','1359','32404','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64095','1359','32418','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64096','1360','32436','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64097','1361','32439','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64098','1362','32440','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64099','1363','32442','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64100','1364','32443','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64101','1365','32428','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64102','1365','32429','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64103','727','27936','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64104','1054','27935','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64105','1054','30122','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64106','1055','30123','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64107','730','27975','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64108','1056','30126','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64109','733','28003','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64110','1057','30131','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64111','736','28031','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64112','1058','30136','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64113','1735','35972','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64114','1735','35975','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64115','1736','35977','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64116','1736','35980','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64117','1737','35981','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64118','1738','35982','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64119','1739','36011','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64120','1739','36003','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64121','1739','36013','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64122','1739','36005','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64123','1739','36014','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64124','1739','36006','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64125','1740','36012','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64126','1740','36004','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64127','1741','36002','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64128','1741','36010','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64129','1742','36017','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64130','1743','36025','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64131','1744','36026','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64132','1745','35985','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64133','1746','36041','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64134','1747','36053','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64135','1747','36045','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64136','1747','36055','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64137','1747','36047','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64138','1747','36056','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64139','1747','36048','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64140','1748','36054','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64141','1748','36046','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64142','1749','36044','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64143','1749','36052','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64144','1750','36059','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64145','1751','36060','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64146','1752','36029','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64147','1753','36077','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64148','1754','36078','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64149','1755','36079','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64150','1756','36080','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64151','1757','36088','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64152','1757','36098','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64153','1757','36089','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64154','1757','36084','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64155','1757','36091','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64156','1757','36085','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64157','1758','36082','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64158','1758','36083','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64159','1759','36105','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64160','1759','36112','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64161','1759','36103','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64162','1759','36110','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64163','1759','36102','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64164','1759','36109','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64165','1760','36104','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64166','1760','36111','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64167','1761','36113','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64168','1761','36106','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64169','1762','36126','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64170','1763','36127','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64171','1764','36144','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64172','1765','36145','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64173','1766','36146','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64174','1767','36147','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64175','1768','36155','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64176','1768','36165','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64177','1768','36156','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64178','1768','36151','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64179','1768','36158','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64180','1768','36152','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64181','1769','36149','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64182','1769','36150','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64183','1770','36172','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64184','1770','36179','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64185','1770','36170','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64186','1770','36177','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64187','1770','36169','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64188','1770','36176','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64189','1771','36171','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64190','1771','36178','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64191','1772','36180','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64192','1772','36173','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64193','1773','36193','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64194','1774','36194','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64195','1775','36210','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64196','1776','36218','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64197','1776','36221','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64198','1777','36223','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64199','1777','36226','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64200','1778','36227','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64201','1779','36228','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64202','1780','36253','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64203','1780','36245','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64204','1780','36255','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64205','1780','36247','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64206','1780','36256','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64207','1780','36248','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64208','1781','36254','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64209','1781','36246','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64210','1782','36244','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64211','1782','36252','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64212','1783','36259','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64213','1784','36231','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64214','1785','36295','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64215','1785','36287','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64216','1785','36297','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64217','1785','36289','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64218','1785','36298','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64219','1785','36290','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64220','1786','36296','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64221','1786','36288','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64222','1787','36286','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64223','1787','36294','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64224','1788','36301','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64225','1789','36309','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64226','1790','36310','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64227','1791','36269','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64228','1792','36339','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64229','1792','36331','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64230','1792','36341','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64231','1792','36333','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64232','1792','36342','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64233','1792','36334','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64234','1793','36340','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64235','1793','36332','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64236','1794','36330','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64237','1794','36338','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64238','1795','36345','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64239','1796','36353','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64240','1797','36354','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64241','1798','36313','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64242','1799','36371','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64243','1800','36383','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64244','1800','36375','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64245','1800','36385','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64246','1800','36377','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64247','1800','36386','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64248','1800','36378','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64249','1801','36384','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64250','1801','36376','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64251','1802','36374','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64252','1802','36382','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64253','1803','36389','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64254','1804','36397','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64255','1805','36398','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64256','1806','36357','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64257','1807','36415','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64258','1808','36427','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64259','1808','36419','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64260','1808','36429','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64261','1808','36421','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64262','1808','36430','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64263','1808','36422','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64264','1809','36428','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64265','1809','36420','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64266','1810','36418','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64267','1810','36426','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64268','1811','36433','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64269','1812','36441','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64270','1813','36442','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64271','1814','36401','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64272','1815','36460','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64273','1816','36472','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64274','1816','36464','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64275','1816','36474','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64276','1816','36466','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64277','1816','36475','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64278','1816','36467','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64279','1817','36473','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64280','1817','36465','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64281','1818','36463','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64282','1818','36471','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64283','1819','36478','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64284','1820','36486','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64285','1821','36487','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64286','1822','36445','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64287','1823','36505','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64288','1824','36517','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64289','1824','36509','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64290','1824','36519','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64291','1824','36511','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64292','1824','36520','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64293','1824','36512','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64294','1825','36518','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64295','1825','36510','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64296','1826','36508','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64297','1826','36516','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64298','1827','36523','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64299','1828','36531','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64300','1829','36532','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64301','1830','36490','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64302','1831','36550','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64303','1832','36563','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64304','1832','36555','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64305','1832','36565','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64306','1832','36557','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64307','1832','36566','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64308','1832','36558','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64309','1833','36564','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64310','1833','36556','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64311','1834','36554','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64312','1834','36562','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64313','1835','36569','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64314','1836','36577','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64315','1837','36578','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64316','1838','36535','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64317','1214','31276','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64318','1214','31277','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64319','1215','31279','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64320','1215','31280','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64321','1216','31282','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64322','1216','31283','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64323','1217','31286','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64324','1217','31289','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64325','1218','31292','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64326','1218','31295','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64327','1219','31298','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64328','1219','31301','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64329','1220','31285','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64330','1220','31288','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64331','1221','31291','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64332','1221','31294','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64333','1222','31297','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64334','1222','31300','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64335','887','29211','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64336','887','29210','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64337','888','29225','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64338','888','29224','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64339','889','29239','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64340','889','29238','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64341','899','29216','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64342','899','29217','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64343','899','29218','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64344','899','29219','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64345','899','29220','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64346','899','29221','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64347','900','29230','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64348','900','29231','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64349','900','29232','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64350','900','29233','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64351','900','29234','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64352','900','29235','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64353','901','29244','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64354','901','29245','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64355','901','29246','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64356','901','29247','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64357','901','29248','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64358','901','29249','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64359','911','29089','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64360','911','29102','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64361','912','29126','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64362','912','29139','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64363','913','29163','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64364','913','29176','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64365','908','29098','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64366','908','29097','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64367','908','29095','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64368','908','29088','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64369','908','29094','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64370','908','29093','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64371','908','29092','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64372','908','29091','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64373','908','29090','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64374','909','29135','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64375','909','29134','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64376','909','29132','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64377','909','29125','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64378','909','29131','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64379','909','29130','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64380','909','29129','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64381','909','29128','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64382','909','29127','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64383','910','29172','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64384','910','29171','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64385','910','29169','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64386','910','29162','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64387','910','29168','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64388','910','29167','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64389','910','29166','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64390','910','29165','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64391','910','29164','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64392','905','29198','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64393','906','29199','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64394','907','29200','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64395','917','29104','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64396','917','29105','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64397','918','29141','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64398','918','29142','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64399','919','29178','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64400','919','29179','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64401','914','31270','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64402','915','31271','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64403','916','31272','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64404','923','29118','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64405','923','29119','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64406','923','29117','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64407','924','29155','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64408','924','29156','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64409','924','29154','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64410','925','29192','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64411','925','29193','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64412','925','29191','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64413','920','29107','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64414','920','29106','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64415','921','29144','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64416','921','29143','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64417','922','29181','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64418','922','29180','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64419','902','29096','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64420','902','29101','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64421','902','29100','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64422','902','29087','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64423','903','29133','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64424','903','29138','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64425','903','29137','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64426','903','29124','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64427','904','29170','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64428','904','29175','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64429','904','29174','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64430','904','29161','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64431','1223','31307','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64432','1223','31308','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64433','1224','31310','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64434','1224','31311','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64435','1225','31314','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64436','1225','31317','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64437','1226','31320','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64438','1226','31323','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64439','1227','31313','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64440','1227','31316','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64441','1228','31319','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64442','1228','31322','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64443','926','29356','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64444','926','29355','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64445','927','29370','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64446','927','29369','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64447','934','29361','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64448','934','29362','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64449','934','29363','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64450','934','29364','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64451','934','29365','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64452','934','29366','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64453','935','29375','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64454','935','29376','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64455','935','29377','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64456','935','29378','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64457','935','29379','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64458','935','29380','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64459','942','29275','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64460','942','29288','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64461','943','29312','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64462','943','29325','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64463','940','29284','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64464','940','29283','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64465','940','29281','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64466','940','29274','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64467','940','29280','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64468','940','29279','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64469','940','29278','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64470','940','29277','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64471','940','29276','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64472','941','29321','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64473','941','29320','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64474','941','29318','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64475','941','29311','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64476','941','29317','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64477','941','29316','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64478','941','29315','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64479','941','29314','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64480','941','29313','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64481','938','29347','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64482','939','29348','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64483','946','29290','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64484','946','29291','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64485','947','29327','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64486','947','29328','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64487','944','31303','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64488','945','31304','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64489','950','29304','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64490','950','29305','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64491','950','29303','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64492','951','29341','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64493','951','29342','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64494','951','29340','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64495','948','29293','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64496','948','29292','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64497','949','29330','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64498','949','29329','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64499','936','29282','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64500','936','29287','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64501','936','29286','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64502','936','29273','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64503','937','29319','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64504','937','29324','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64505','937','29323','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64506','937','29310','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64507','952','29436','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64508','952','29437','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64509','952','29438','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64510','952','29439','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64511','952','29441','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64512','952','29440','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64513','955','29434','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64514','955','29435','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64515','954','29448','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64516','954','29449','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64517','956','29452','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64518','956','29453','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64519','953','29446','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64520','953','29432','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64521','960','29405','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64522','960','29406','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64523','959','29426','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64524','959','29413','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64525','959','29411','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64526','959','29410','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64527','959','29399','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64528','959','29409','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64529','959','29412','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64530','959','29408','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64531','959','29407','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64532','958','29427','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64533','962','29403','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64534','962','29402','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64535','961','29396','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64536','963','29400','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64537','963','29401','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64538','957','29420','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64539','957','29419','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64540','957','29418','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64541','957','29417','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64542','866','29014','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64543','866','29015','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64544','867','29031','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64545','867','29032','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64546','868','29018','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64547','868','29019','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64548','868','29022','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64549','868','29023','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64550','868','29020','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64551','868','29024','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64552','868','29021','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64553','868','29025','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64554','868','29026','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64555','869','29035','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64556','869','29036','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64557','869','29039','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64558','869','29040','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64559','869','29037','0','4','FC6EA3','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64560','869','29041','0','5','6C59DC','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64561','869','29038','0','6','AC8C14','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64562','869','29042','0','7','611F27','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64563','869','29043','0','8','F230E0','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64564','870','29048','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64565','871','29049','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64566','872','29028','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64567','872','29027','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64568','873','29045','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64569','873','29044','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64570','882','28992','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64571','882','28991','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64572','883','29007','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64573','883','29006','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64574','876','28982','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64575','876','28983','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64576','877','28997','2','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64577','877','28998','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64578','874','28978','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64579','875','28993','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64580','878','28985','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64581','878','28984','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64582','879','29000','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64583','879','28999','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64584','880','28987','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64585','880','28988','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64586','880','28989','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64587','880','28990','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64588','881','29002','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64589','881','29003','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64590','881','29004','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64591','881','29005','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64592','1839','36585','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64593','1839','36588','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64594','1839','36587','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64595','1839','36584','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64596','1839','36586','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64597','1839','36583','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64598','1840','36591','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64599','1840','36594','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64600','1840','36593','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64601','1840','36590','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64602','1840','36592','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64603','1840','36589','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64604','964','29513','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64605','964','29512','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64606','965','29522','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64607','965','29521','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64608','1366','32445','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64609','1366','32448','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64610','1367','32449','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64611','1367','32452','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64612','1368','32446','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64613','1368','32447','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64614','1369','32450','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64615','1369','32451','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64616','1229','31337','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64617','1229','31338','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64618','1230','31341','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64619','1230','31342','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64620','1231','31336','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64621','1231','31335','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64622','1232','31340','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64623','1232','31339','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64624','974','29456','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64625','974','29455','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64626','975','29482','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64627','975','29481','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64628','976','29458','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64629','976','29457','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64630','977','29484','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64631','977','29483','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64632','972','29454','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64633','973','29480','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64634','978','29462','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64635','979','29488','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64636','980','31327','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64637','980','29466','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64638','981','31330','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64639','981','29492','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64640','1841','36607','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64641','1841','36610','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64642','1841','36609','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64643','1841','36606','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64644','1841','36608','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64645','1841','36605','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64646','1842','36613','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64647','1842','36616','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64648','1842','36615','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64649','1842','36612','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64650','1842','36614','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64651','1842','36611','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64652','982','29620','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64653','982','29619','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64654','983','29629','0','0','969696','0','9','2');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64655','983','29628','0','1','C80000','0','9','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64656','1370','32453','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64657','1370','32456','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64658','1371','32457','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64659','1371','32460','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64660','1372','32454','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64661','1372','32455','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64662','1373','32458','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64663','1373','32459','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64664','1233','31355','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64665','1233','31356','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64666','1234','31359','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64667','1234','31360','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64668','1235','31354','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64669','1235','31353','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64670','1236','31358','0','0','1A7C11','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64671','1236','31357','5','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64672','992','29563','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64673','992','29562','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64674','993','29589','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64675','993','29588','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64676','994','29565','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64677','994','29564','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64678','995','29591','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64679','995','29590','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64680','990','29561','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64681','991','29587','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64682','996','29569','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64683','997','29595','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64684','998','31345','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64685','998','29573','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64686','999','31348','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64687','999','29599','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64688','1489','33568','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64689','1490','33581','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64690','1490','33569','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64691','1491','33583','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64692','1491','33579','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64693','1492','33619','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64694','1493','33632','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64695','1493','33620','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64696','1494','33634','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64697','1494','33630','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64698','1495','33670','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64699','1496','33683','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64700','1496','33671','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64701','1497','33685','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64702','1497','33681','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64703','1498','33721','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64704','1499','33734','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64705','1499','33722','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64706','1500','33736','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64707','1500','33732','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64708','1501','33772','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64709','1502','33785','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64710','1502','33773','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64711','1503','33787','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64712','1503','33783','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64713','1504','33823','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64714','1505','33836','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64715','1505','33824','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64716','1506','33838','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64717','1506','33834','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64718','1507','33874','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64719','1508','33887','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64720','1508','33875','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64721','1509','33889','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64722','1509','33885','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64723','1510','33925','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64724','1481','33445','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64725','1481','33433','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64726','1482','33447','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64727','1482','33443','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64728','1511','33930','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64729','1512','33943','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64730','1512','33931','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64731','1513','33945','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64732','1513','33941','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64733','1514','33981','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64734','1515','33994','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64735','1515','33982','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64736','1516','33996','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64737','1516','33992','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64738','1517','34032','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64739','1518','34045','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64740','1518','34033','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64741','1519','34047','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64742','1519','34043','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64743','1403','32790','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64744','1404','32809','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64745','1404','32807','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64746','1404','32811','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64747','1405','32804','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64748','1405','32805','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64749','1405','32806','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64750','1406','32810','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64751','1406','32808','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64752','1406','32812','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64753','1407','32815','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64754','1408','32819','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64755','1408','32817','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64756','1408','32821','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64757','1409','32820','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64758','1409','32818','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64759','1409','32822','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64760','1410','32828','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64761','1410','32827','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64762','1410','32823','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64763','1411','32777','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64764','1411','32778','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64765','1483','33525','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64766','1483','33524','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64767','1483','33523','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64768','1483','33522','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64769','1484','33564','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64770','1484','33554','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64771','1485','33500','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64772','1485','33507','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64773','1485','33509','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64774','1485','33508','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64775','1486','33480','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64776','1486','33491','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64777','1486','33488','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64778','1486','33489','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64779','1487','33506','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64780','1487','33505','0','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64781','1487','33512','0','2','F63100','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64782','1487','33504','0','3','A54F10','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64783','1387','32632','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64784','1388','32635','1','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64785','1388','32635','1','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64786','1389','32643','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64787','1389','32646','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64788','1389','32645','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64789','1389','32642','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64790','1389','32644','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64791','1389','32641','0','5','6C59DC','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64792','1142','30689','0','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64793','1676','34973','5','0','1A7C11','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64794','1676','34978','2','1','2774A4','0','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64795','1676','34976','0','2','F63100','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64796','1676','34971','0','3','A54F10','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64797','1676','34975','0','4','FC6EA3','1','2','0');
INSERT INTO graphs_items (gitemid,graphid,itemid,drawtype,sortorder,color,yaxisside,calc_fnc,type) values ('64798','1676','34970','0','5','6C59DC','1','2','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('365','10186','{$ICMP_LOSS_WARN}','20','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('366','10186','{$ICMP_RESPONSE_TIME_WARN}','0.15','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('370','10188','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('376','10190','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('382','10192','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('393','10207','{$TEMP_CRIT}','75','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('394','10207','{$TEMP_WARN}','65','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('395','10207','{$PSU_CRIT_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('396','10207','{$FAN_CRIT_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('399','10207','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('402','10208','{$TEMP_CRIT}','75','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('403','10208','{$TEMP_WARN}','65','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('404','10208','{$HEALTH_CRIT_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('405','10208','{$HEALTH_WARN_STATUS:"offline"}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('406','10208','{$HEALTH_WARN_STATUS:"testing"}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('407','10208','{$TEMP_WARN_STATUS}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('408','10208','{$PSU_CRIT_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('409','10208','{$FAN_CRIT_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('410','10208','{$PSU_OK_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('411','10208','{$FAN_OK_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('414','10208','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('417','10210','{$TEMP_CRIT}','75','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('418','10210','{$TEMP_WARN}','65','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('419','10210','{$PSU_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('420','10210','{$FAN_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('421','10210','{$PSU_OK_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('422','10210','{$FAN_OK_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('425','10210','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('428','10211','{$TEMP_CRIT}','75','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('429','10211','{$TEMP_WARN}','65','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('430','10211','{$PSU_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('431','10211','{$FAN_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('432','10211','{$PSU_OK_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('433','10211','{$FAN_OK_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('436','10211','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('439','10217','{$TEMP_CRIT:"CPU"}','75','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('440','10217','{$TEMP_WARN:"CPU"}','70','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('441','10217','{$TEMP_WARN_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('442','10217','{$TEMP_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('443','10217','{$TEMP_DISASTER_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('469','10221','{$TEMP_CRIT}','65','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('470','10221','{$TEMP_WARN}','55','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('471','10221','{$PSU_CRIT_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('472','10221','{$FAN_CRIT_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('473','10221','{$PSU_OK_STATUS}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('474','10221','{$FAN_OK_STATUS}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('477','10221','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('480','10222','{$TEMP_CRIT}','75','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('481','10222','{$TEMP_WARN}','65','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('482','10222','{$PSU_CRIT_STATUS}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('483','10222','{$FAN_CRIT_STATUS}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('486','10222','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('489','10223','{$TEMP_CRIT}','75','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('490','10223','{$TEMP_WARN}','65','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('491','10223','{$PSU_CRIT_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('492','10223','{$FAN_CRIT_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('495','10223','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('498','10224','{$TEMP_CRIT}','65','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('499','10224','{$TEMP_WARN}','55','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('500','10224','{$TEMP_CRIT_STATUS}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('501','10224','{$PSU_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('502','10224','{$FAN_CRIT_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('507','10224','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('510','10227','{$FAN_CRIT_STATUS:"fanError"}','41','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('511','10227','{$FAN_CRIT_STATUS:"hardwareFaulty"}','91','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('512','10227','{$PSU_CRIT_STATUS:"psuError"}','51','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('513','10227','{$PSU_CRIT_STATUS:"rpsError"}','61','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('514','10227','{$PSU_CRIT_STATUS:"hardwareFaulty"}','91','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('517','10227','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('518','10227','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('519','10227','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('533','10229','{$FAN_CRIT_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('536','10229','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('537','10229','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('538','10229','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('541','10230','{$TEMP_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('542','10230','{$TEMP_WARN_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('543','10230','{$PSU_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('544','10230','{$FAN_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('547','10230','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('548','10230','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('549','10230','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('552','10231','{$TEMP_CRIT:"Routing Engine"}','80','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('553','10231','{$TEMP_WARN:"Routing Engine"}','70','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('554','10231','{$HEALTH_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('555','10231','{$FAN_CRIT_STATUS}','6','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('556','10231','{$PSU_CRIT_STATUS}','6','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('559','10231','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('560','10231','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('561','10231','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('572','10233','{$TEMP_CRIT:"CPU"}','75','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('573','10233','{$TEMP_WARN:"CPU"}','70','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('576','10233','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('577','10233','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('578','10233','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('581','10234','{$TEMP_WARN_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('582','10234','{$TEMP_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('583','10234','{$PSU_CRIT_STATUS:"failed"}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('584','10234','{$FAN_CRIT_STATUS:"failed"}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('587','10234','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('588','10234','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('589','10234','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('592','10235','{$TEMP_CRIT}','75','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('593','10235','{$TEMP_WARN}','65','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('594','10235','{$PSU_CRIT_STATUS}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('595','10235','{$FAN_CRIT_STATUS}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('619','10250','{$FAN_CRIT_STATUS:"bad"}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('620','10250','{$PSU_CRIT_STATUS:"bad"}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('625','10250','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('626','10250','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('627','10250','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('647','10230','{$PSU_WARN_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('648','10217','{$PSU_CRIT_STATUS:"critical"}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('649','10217','{$PSU_CRIT_STATUS:"shutdown"}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('650','10217','{$PSU_WARN_STATUS:"warning"}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('651','10217','{$PSU_WARN_STATUS:"notFunctioning"}','6','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('652','10217','{$FAN_CRIT_STATUS:"critical"}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('653','10217','{$FAN_CRIT_STATUS:"shutdown"}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('654','10217','{$FAN_WARN_STATUS:"warning"}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('655','10217','{$FAN_WARN_STATUS:"notFunctioning"}','6','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('656','10250','{$FAN_WARN_STATUS:"warning"}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('657','10250','{$PSU_WARN_STATUS:"warning"}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('659','10254','{$FAN_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('661','10254','{$PSU_CRIT_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('674','10217','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('675','10217','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('676','10217','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('677','10255','{$DISK_ARRAY_CACHE_BATTERY_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('678','10255','{$DISK_ARRAY_CACHE_BATTERY_OK_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('679','10255','{$DISK_ARRAY_CACHE_BATTERY_WARN_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('680','10255','{$DISK_ARRAY_CRIT_STATUS:"critical"}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('681','10255','{$DISK_ARRAY_FAIL_STATUS:"nonRecoverable"}','6','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('682','10255','{$DISK_ARRAY_WARN_STATUS:"nonCritical"}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('683','10255','{$DISK_FAIL_STATUS:"critical"}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('684','10255','{$DISK_FAIL_STATUS:"nonRecoverable"}','6','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('685','10255','{$DISK_SMART_FAIL_STATUS}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('686','10255','{$DISK_WARN_STATUS:"nonCritical"}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('687','10255','{$FAN_CRIT_STATUS:"criticalLower"}','8','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('688','10255','{$FAN_CRIT_STATUS:"criticalUpper"}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('689','10255','{$FAN_CRIT_STATUS:"failed"}','10','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('690','10255','{$FAN_CRIT_STATUS:"nonRecoverableLower"}','9','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('691','10255','{$FAN_CRIT_STATUS:"nonRecoverableUpper"}','6','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('692','10255','{$FAN_WARN_STATUS:"nonCriticalLower"}','7','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('693','10255','{$FAN_WARN_STATUS:"nonCriticalUpper"}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('694','10255','{$HEALTH_CRIT_STATUS}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('695','10255','{$HEALTH_DISASTER_STATUS}','6','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('696','10255','{$HEALTH_WARN_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('697','10255','{$PSU_CRIT_STATUS:"critical"}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('698','10255','{$PSU_CRIT_STATUS:"nonRecoverable"}','6','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('699','10255','{$PSU_WARN_STATUS:"nonCritical"}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('700','10255','{$TEMP_CRIT:"Ambient"}','35','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('701','10255','{$TEMP_CRIT:"CPU"}','75','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('702','10255','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('703','10255','{$TEMP_CRIT_STATUS}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('704','10255','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('705','10255','{$TEMP_DISASTER_STATUS}','6','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('706','10255','{$TEMP_WARN:"Ambient"}','30','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('707','10255','{$TEMP_WARN:"CPU"}','70','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('708','10255','{$TEMP_WARN_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('709','10255','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('710','10255','{$VDISK_CRIT_STATUS:"failed"}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('711','10255','{$VDISK_WARN_STATUS:"degraded"}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('712','10256','{$DISK_ARRAY_CACHE_BATTERY_CRIT_STATUS:"capacitorFailed"}','7','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('713','10256','{$DISK_ARRAY_CACHE_BATTERY_CRIT_STATUS:"failed"}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('714','10256','{$DISK_ARRAY_CACHE_BATTERY_WARN_STATUS:"degraded"}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('715','10256','{$DISK_ARRAY_CACHE_BATTERY_WARN_STATUS:"notPresent"}','6','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('716','10256','{$DISK_ARRAY_CACHE_CRIT_STATUS:"cacheModCriticalFailure"}','8','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('717','10256','{$DISK_ARRAY_CACHE_OK_STATUS:"enabled"}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('718','10256','{$DISK_ARRAY_CACHE_WARN_STATUS:"cacheModDegradedFailsafeSpeed"}','7','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('719','10256','{$DISK_ARRAY_CACHE_WARN_STATUS:"cacheModFlashMemNotAttached"}','6','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('720','10256','{$DISK_ARRAY_CACHE_WARN_STATUS:"cacheReadCacheNotMapped"}','9','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('721','10256','{$DISK_ARRAY_CACHE_WARN_STATUS:"invalid"}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('722','10256','{$DISK_ARRAY_CRIT_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('723','10256','{$DISK_ARRAY_WARN_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('724','10256','{$DISK_FAIL_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('725','10256','{$DISK_SMART_FAIL_STATUS:"replaceDrive"}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('726','10256','{$DISK_SMART_FAIL_STATUS:"replaceDriveSSDWearOut"}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('727','10256','{$DISK_WARN_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('728','10256','{$FAN_CRIT_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('729','10256','{$FAN_WARN_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('730','10256','{$HEALTH_CRIT_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('731','10256','{$HEALTH_WARN_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('732','10256','{$PSU_CRIT_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('733','10256','{$PSU_WARN_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('739','10256','{$VDISK_CRIT_STATUS}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('740','10256','{$VDISK_OK_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('752','10258','{$DISK_OK_STATUS}','Normal','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('753','10258','{$FAN_OK_STATUS}','Normal','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('754','10258','{$HEALTH_CRIT_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('755','10258','{$HEALTH_DISASTER_STATUS}','0','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('756','10258','{$HEALTH_WARN_STATUS}','4','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('757','10258','{$PSU_OK_STATUS}','Normal','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('758','10258','{$TEMP_CRIT:"Ambient"}','35','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('759','10258','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('760','10258','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('761','10258','{$TEMP_WARN:"Ambient"}','30','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('762','10258','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('763','10259','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('764','10259','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('765','10259','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('769','10261','{$ADDRESS}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('770','10261','{$PORT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('771','10262','{$ADDRESS}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('772','10262','{$PORT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('787','10263','{$PG.CACHE_HITRATIO.MIN.WARN}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('788','10263','{$PG.CHECKPOINTS_REQ.MAX.WARN}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('789','10263','{$PG.CONFLICTS.MAX.WARN}','0','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('790','10263','{$PG.CONN_IDLE_IN_TRANS.MAX.WARN}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('791','10263','{$PG.CONN_TOTAL_PCT.MAX.WARN}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('792','10263','{$PG.CONN_WAIT.MAX.WARN}','0','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('793','10263','{$PG.DB}','postgres','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('794','10263','{$PG.DEADLOCKS.MAX.WARN}','0','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('795','10263','{$PG.FROZENXID_PCT_STOP.MIN.HIGH}','75','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('796','10263','{$PG.HOST}','127.0.0.1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('797','10263','{$PG.LLD.FILTER.DBNAME}','(.*)','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('798','10263','{$PG.LOCKS.MAX.WARN}','100','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('799','10263','{$PG.PING_TIME.MAX.WARN}','1s','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('800','10263','{$PG.PORT}','5432','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('801','10263','{$PG.QUERY_ETIME.MAX.WARN}','30','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('802','10263','{$PG.REPL_LAG.MAX.WARN}','10m','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('803','10263','{$PG.SLOW_QUERIES.MAX.WARN}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('804','10263','{$PG.TRANS_ACTIVE.MAX.WARN}','30s','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('805','10263','{$PG.TRANS_IDLE.MAX.WARN}','30s','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('806','10263','{$PG.TRANS_WAIT.MAX.WARN}','30s','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('807','10263','{$PG.USER}','zbx_monitor','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('808','10264','{$APACHE.PROCESS_NAME}','httpd','Apache server process name','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('809','10264','{$APACHE.RESPONSE_TIME.MAX.WARN}','10','Maximum Apache response time in seconds for trigger expression','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('810','10264','{$APACHE.STATUS.HOST}','127.0.0.1','Hostname or IP address of the Apache status page','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('811','10264','{$APACHE.STATUS.PATH}','server-status?auto','The URL path','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('812','10264','{$APACHE.STATUS.PORT}','80','The port of Apache status page','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('813','10265','{$APACHE.RESPONSE_TIME.MAX.WARN}','10','Maximum Apache response time in seconds for trigger expression','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('814','10265','{$APACHE.STATUS.PATH}','server-status?auto','The URL path','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('815','10265','{$APACHE.STATUS.PORT}','80','The port of Apache status page','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('816','10265','{$APACHE.STATUS.SCHEME}','http','Request scheme which may be http or https','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('817','10266','{$NGINX.DROP_RATE.MAX.WARN}','1','The critical rate of the dropped connections for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('818','10266','{$NGINX.RESPONSE_TIME.MAX.WARN}','10','The Nginx maximum response time in seconds for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('819','10266','{$NGINX.STUB_STATUS.HOST}','localhost','Hostname or IP of Nginx stub_status host or container.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('820','10266','{$NGINX.STUB_STATUS.PATH}','basic_status','The path of Nginx stub_status page.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('821','10266','{$NGINX.STUB_STATUS.PORT}','80','The port of Nginx stub_status host or container.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('822','10267','{$NGINX.DROP_RATE.MAX.WARN}','1','The critical rate of the dropped connections for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('823','10267','{$NGINX.RESPONSE_TIME.MAX.WARN}','10','The Nginx maximum response time in seconds for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('824','10267','{$NGINX.STUB_STATUS.PATH}','basic_status','The path of Nginx stub_status page.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('825','10267','{$NGINX.STUB_STATUS.PORT}','80','The port of Nginx stub_status host or container.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('826','10267','{$NGINX.STUB_STATUS.SCHEME}','http','The protocol http or https of Nginx stub_status host or container.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('827','10170','{$MYSQL.ABORTED_CONN.MAX.WARN}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('828','10170','{$MYSQL.HOST}','localhost','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('829','10170','{$MYSQL.PORT}','3306','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('830','10170','{$MYSQL.REPL_LAG.MAX.WARN}','30m','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('831','10170','{$MYSQL.SLOW_QUERIES.MAX.WARN}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('832','10268','{$MEMORY.AVAILABLE.MIN}','20M','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('833','10268','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('834','10268','{$SWAP.PFREE.MIN.WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('835','10269','{$VFS.DEV.DEVNAME.MATCHES}','.+','This macro is used in block devices discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('836','10269','{$VFS.DEV.DEVNAME.NOT_MATCHES}','^(loop[0-9]*|sd[a-z][0-9]+|nbd[0-9]+|sr[0-9]+|fd[0-9]+|dm-[0-9]+|ram[0-9]+|ploop[a-z0-9]+|md[0-9]*|hcp[0-9]*|zram[0-9]*)','This macro is used in block devices discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('837','10270','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('838','10270','{$LOAD_AVG_PER_CPU.MAX.WARN}','1.5','Load per CPU considered sustainable. Tune if needed.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('839','10271','{$VFS.FS.FSNAME.MATCHES}','.+','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('840','10271','{$VFS.FS.FSNAME.NOT_MATCHES}','^(/dev|/sys|/run|/proc|.+/shm$)','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('841','10271','{$VFS.FS.FSTYPE.MATCHES}','.*(\.4|\.9|hrStorageFixedDisk|hrStorageFlashMemory)$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('842','10271','{$VFS.FS.FSTYPE.NOT_MATCHES}','^\s$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('843','10271','{$VFS.FS.INODE.PFREE.MIN.CRIT}','10','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('844','10271','{$VFS.FS.INODE.PFREE.MIN.WARN}','20','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('845','10271','{$VFS.FS.PUSED.MAX.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('846','10271','{$VFS.FS.PUSED.MAX.WARN}','80','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('847','10272','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('848','10272','{$LOAD_AVG_PER_CPU.MAX.WARN}','1.5','Load per CPU considered sustainable. Tune if needed.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('849','10273','{$VFS.FS.FSNAME.MATCHES}','.+','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('850','10273','{$VFS.FS.FSNAME.NOT_MATCHES}','^(/dev|/sys|/run|/proc|.+/shm$)','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('851','10273','{$VFS.FS.FSTYPE.MATCHES}','^(btrfs|ext2|ext3|ext4|reiser|xfs|ffs|ufs|jfs|jfs2|vxfs|hfs|apfs|refs|ntfs|fat32|zfs)$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('852','10273','{$VFS.FS.FSTYPE.NOT_MATCHES}','^\s$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('853','10273','{$VFS.FS.INODE.PFREE.MIN.CRIT}','10','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('854','10273','{$VFS.FS.INODE.PFREE.MIN.WARN}','20','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('855','10273','{$VFS.FS.PUSED.MAX.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('856','10273','{$VFS.FS.PUSED.MAX.WARN}','80','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('857','10274','{$MEMORY.AVAILABLE.MIN}','20M','This macro is used as a threshold in memory available trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('858','10274','{$MEMORY.UTIL.MAX}','90','This macro is used as a threshold in memory utilization trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('859','10274','{$SWAP.PFREE.MIN.WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('860','10275','{$VFS.DEV.DEVNAME.MATCHES}','.+','This macro is used in block devices discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('861','10275','{$VFS.DEV.DEVNAME.NOT_MATCHES}','^(loop[0-9]*|sd[a-z][0-9]+|nbd[0-9]+|sr[0-9]+|fd[0-9]+|dm-[0-9]+|ram[0-9]+|ploop[a-z0-9]+|md[0-9]*|hcp[0-9]*|zram[0-9]*)','This macro is used in block devices discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('862','10275','{$VFS.DEV.READ.AWAIT.WARN}','20','Disk read average response time (in ms) before the trigger would fire','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('863','10275','{$VFS.DEV.WRITE.AWAIT.WARN}','20','Disk write average response time (in ms) before the trigger would fire','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('864','10276','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('866','10276','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('867','10276','{$NET.IF.IFNAME.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('868','10276','{$NET.IF.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12})','Filter out loopbacks, nulls, docker veth links and docker0 bridge by default','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('869','10277','{$KERNEL.MAXFILES.MIN}','256','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('870','10277','{$KERNEL.MAXPROC.MIN}','1024','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('871','10277','{$SYSTEM.FUZZYTIME.MAX}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('872','10278','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('873','10278','{$LOAD_AVG_PER_CPU.MAX.WARN}','1.5','Load per CPU considered sustainable. Tune if needed.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('874','10279','{$VFS.FS.FSNAME.MATCHES}','.+','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('875','10279','{$VFS.FS.FSNAME.NOT_MATCHES}','^(/dev|/sys|/run|/proc|.+/shm$)','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('876','10279','{$VFS.FS.FSTYPE.MATCHES}','^(btrfs|ext2|ext3|ext4|reiser|xfs|ffs|ufs|jfs|jfs2|vxfs|hfs|apfs|refs|ntfs|fat32|zfs)$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('877','10279','{$VFS.FS.FSTYPE.NOT_MATCHES}','^\s$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('878','10279','{$VFS.FS.INODE.PFREE.MIN.CRIT}','10','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('879','10279','{$VFS.FS.INODE.PFREE.MIN.WARN}','20','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('880','10279','{$VFS.FS.PUSED.MAX.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('881','10279','{$VFS.FS.PUSED.MAX.WARN}','80','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('882','10280','{$MEMORY.AVAILABLE.MIN}','20M','This macro is used as a threshold in memory available trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('883','10280','{$MEMORY.UTIL.MAX}','90','This macro is used as a threshold in memory utilization trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('884','10280','{$SWAP.PFREE.MIN.WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('885','10281','{$VFS.DEV.DEVNAME.MATCHES}','.+','This macro is used in block devices discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('886','10281','{$VFS.DEV.DEVNAME.NOT_MATCHES}','^(loop[0-9]*|sd[a-z][0-9]+|nbd[0-9]+|sr[0-9]+|fd[0-9]+|dm-[0-9]+|ram[0-9]+|ploop[a-z0-9]+|md[0-9]*|hcp[0-9]*|zram[0-9]*)','This macro is used in block devices discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('887','10281','{$VFS.DEV.READ.AWAIT.WARN}','20','Disk read average response time (in ms) before the trigger would fire','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('888','10281','{$VFS.DEV.WRITE.AWAIT.WARN}','20','Disk write average response time (in ms) before the trigger would fire','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('889','10282','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('891','10282','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('892','10282','{$NET.IF.IFNAME.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('893','10282','{$NET.IF.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12})','Filter out loopbacks, nulls, docker veth links and docker0 bridge by default','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('894','10283','{$KERNEL.MAXFILES.MIN}','256','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('895','10283','{$KERNEL.MAXPROC.MIN}','1024','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('896','10283','{$SYSTEM.FUZZYTIME.MAX}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('897','10285','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('898','10285','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('899','10285','{$IF.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('900','10285','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('901','10285','{$KERNEL.MAXFILES.MIN}','256','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('902','10285','{$LOAD_AVG_PER_CPU.MAX.WARN}','1.5','Load per CPU considered sustainable. Tune if needed.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('903','10285','{$MEMORY.AVAILABLE.MIN}','20M','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('904','10285','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('905','10285','{$NET.IF.IFALIAS.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('906','10285','{$NET.IF.IFALIAS.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('907','10285','{$NET.IF.IFNAME.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('908','10285','{$NET.IF.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12})','Filter out loopbacks, nulls, docker veth links and docker0 bridge by default','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('909','10285','{$NET.IF.IFOPERSTATUS.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('910','10285','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}','^7$','Ignore notPresent(7)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('911','10285','{$NODE_EXPORTER_PORT}','9100','TCP Port node_exporter is listening on.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('912','10285','{$SWAP.PFREE.MIN.WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('913','10285','{$SYSTEM.FUZZYTIME.MAX}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('914','10285','{$VFS.DEV.DEVNAME.MATCHES}','.+','This macro is used in block devices discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('915','10285','{$VFS.DEV.DEVNAME.NOT_MATCHES}','^(loop[0-9]*|sd[a-z][0-9]+|nbd[0-9]+|sr[0-9]+|fd[0-9]+|dm-[0-9]+|ram[0-9]+|ploop[a-z0-9]+|md[0-9]*|hcp[0-9]*|zram[0-9]*)','This macro is used in block devices discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('916','10285','{$VFS.DEV.READ.AWAIT.WARN}','20','Disk read average response time (in ms) before the trigger would fire','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('917','10285','{$VFS.DEV.WRITE.AWAIT.WARN}','20','Disk write average response time (in ms) before the trigger would fire','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('918','10285','{$VFS.FS.FSDEVICE.MATCHES}','^.+$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('919','10285','{$VFS.FS.FSDEVICE.NOT_MATCHES}','^\s$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('920','10285','{$VFS.FS.FSNAME.MATCHES}','.+','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('921','10285','{$VFS.FS.FSNAME.NOT_MATCHES}','^(/dev|/sys|/run|/proc|.+/shm$)','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('922','10285','{$VFS.FS.FSTYPE.MATCHES}','^(btrfs|ext2|ext3|ext4|reiser|xfs|ffs|ufs|jfs|jfs2|vxfs|hfs|apfs|refs|ntfs|fat32|zfs)$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('923','10285','{$VFS.FS.FSTYPE.NOT_MATCHES}','^\s$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('924','10285','{$VFS.FS.INODE.PFREE.MIN.CRIT}','10','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('925','10285','{$VFS.FS.INODE.PFREE.MIN.WARN}','20','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('926','10285','{$VFS.FS.PUSED.MAX.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('927','10285','{$VFS.FS.PUSED.MAX.WARN}','80','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('928','10286','{$CPU.INTERRUPT.CRIT.MAX}','50','The critical threshold of the % Interrupt Time counter.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('929','10286','{$CPU.PRIV.CRIT.MAX}','30','The threshold of the % Privileged Time counter.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('930','10286','{$CPU.QUEUE.CRIT.MAX}','3','The threshold of the Processor Queue Length counter.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('931','10286','{$CPU.UTIL.CRIT}','90','The critical threshold of the CPU utilization in %.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('932','10287','{$MEM.PAGE_SEC.CRIT.MAX}','1000','The warning threshold of the Memory Pages/sec counter.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('933','10287','{$MEM.PAGE_TABLE_CRIT.MIN}','5000','The warning threshold of the Free System Page Table Entries counter.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('934','10287','{$MEMORY.UTIL.MAX}','90','The warning threshold of the Memory util item.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('935','10287','{$SWAP.PFREE.MIN.WARN}','20','The warning threshold of the minimum free swap.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('936','10288','{$VFS.FS.FSDRIVETYPE.MATCHES}','fixed','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('937','10288','{$VFS.FS.FSDRIVETYPE.NOT_MATCHES}','^\s$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('938','10288','{$VFS.FS.FSNAME.MATCHES}','.*','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('939','10288','{$VFS.FS.FSNAME.NOT_MATCHES}','^(/dev|/sys|/run|/proc|.+/shm$)','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('940','10288','{$VFS.FS.FSTYPE.MATCHES}','.*','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('941','10288','{$VFS.FS.FSTYPE.NOT_MATCHES}','^\s$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('942','10288','{$VFS.FS.PUSED.MAX.CRIT}','90','The critical threshold of the filesystem utilization in percent.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('943','10288','{$VFS.FS.PUSED.MAX.WARN}','80','The warning threshold of the filesystem utilization in percent.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('944','10289','{$VFS.DEV.DEVNAME.MATCHES}','.*','This macro is used in physical disks discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('945','10289','{$VFS.DEV.DEVNAME.NOT_MATCHES}','_Total','This macro is used in physical disks discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('946','10289','{$VFS.DEV.UTIL.MAX.WARN}','95','The warning threshold of disk time utilization in percent.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('947','10290','{$SYSTEM.FUZZYTIME.MAX}','60','The threshold for difference of system time in seconds.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('948','10291','{$NET.IF.IFALIAS.MATCHES}','.*','This macro is used in Network interface discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('949','10291','{$NET.IF.IFALIAS.NOT_MATCHES}','CHANGE_THIS','This macro is used in Network interface discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('950','10291','{$NET.IF.IFDESCR.MATCHES}','.*','This macro is used in Network interface discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('951','10291','{$NET.IF.IFDESCR.NOT_MATCHES}','CHANGE_THIS','This macro is used in Network interface discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('952','10291','{$NET.IF.IFNAME.MATCHES}','.*','This macro is used in Network interface discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('953','10291','{$NET.IF.IFNAME.NOT_MATCHES}','Miniport|Virtual|Teredo|Kernel|Loopback|Bluetooth|HTTPS|6to4|QoS|Layer','This macro is used in Network interface discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('958','10292','{$AGENT.NODATA_TIMEOUT}','30m','No data timeout for active agents. Consider to keep it relatively high.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('959','10050','{$AGENT.TIMEOUT}','3m','Timeout after which agent is considered unavailable. Works only for agents reachable from Zabbix server/proxy (passive mode).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('960','10293','{$CPU.INTERRUPT.CRIT.MAX}','50','The critical threshold of the % Interrupt Time counter.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('961','10293','{$CPU.PRIV.CRIT.MAX}','30','The threshold of the % Privileged Time counter.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('962','10293','{$CPU.QUEUE.CRIT.MAX}','3','The threshold of the Processor Queue Length counter.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('963','10293','{$CPU.UTIL.CRIT}','90','The critical threshold of the CPU utilization in %.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('964','10294','{$MEM.PAGE_SEC.CRIT.MAX}','1000','The warning threshold of the Memory Pages/sec counter.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('965','10294','{$MEM.PAGE_TABLE_CRIT.MIN}','5000','The warning threshold of the Free System Page Table Entries counter.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('966','10294','{$MEMORY.UTIL.MAX}','90','The warning threshold of the Memory util item.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('967','10294','{$SWAP.PFREE.MIN.WARN}','20','The warning threshold of the minimum free swap.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('968','10295','{$VFS.FS.FSDRIVETYPE.MATCHES}','fixed','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('969','10295','{$VFS.FS.FSDRIVETYPE.NOT_MATCHES}','^\s$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('970','10295','{$VFS.FS.FSNAME.MATCHES}','.*','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('971','10295','{$VFS.FS.FSNAME.NOT_MATCHES}','^(/dev|/sys|/run|/proc|.+/shm$)','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('972','10295','{$VFS.FS.FSTYPE.MATCHES}','.*','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('973','10295','{$VFS.FS.FSTYPE.NOT_MATCHES}','^\s$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('974','10295','{$VFS.FS.PUSED.MAX.CRIT}','90','The critical threshold of the filesystem utilization in percent.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('975','10295','{$VFS.FS.PUSED.MAX.WARN}','80','The warning threshold of the filesystem utilization in percent.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('976','10296','{$VFS.DEV.DEVNAME.MATCHES}','.*','This macro is used in physical disks discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('977','10296','{$VFS.DEV.DEVNAME.NOT_MATCHES}','_Total','This macro is used in physical disks discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('978','10296','{$VFS.DEV.UTIL.MAX.WARN}','95','The warning threshold of disk time utilization in percent.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('979','10297','{$SYSTEM.FUZZYTIME.MAX}','60','The threshold for difference of system time in seconds.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('980','10298','{$NET.IF.IFALIAS.MATCHES}','.*','This macro is used in Network interface discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('981','10298','{$NET.IF.IFALIAS.NOT_MATCHES}','CHANGE_THIS','This macro is used in Network interface discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('982','10298','{$NET.IF.IFDESCR.MATCHES}','.*','This macro is used in Network interface discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('983','10298','{$NET.IF.IFDESCR.NOT_MATCHES}','CHANGE_THIS','This macro is used in Network interface discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('984','10298','{$NET.IF.IFNAME.MATCHES}','.*','This macro is used in Network interface discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('985','10298','{$NET.IF.IFNAME.NOT_MATCHES}','Miniport|Virtual|Teredo|Kernel|Loopback|Bluetooth|HTTPS|6to4|QoS|Layer','This macro is used in Network interface discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('991','10300','{$RABBITMQ.API.PASSWORD}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('992','10300','{$RABBITMQ.API.PORT}','15672','The port of RabbitMQ API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('993','10300','{$RABBITMQ.API.USER}','zbx_monitor','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('995','10300','{$RABBITMQ.LLD.FILTER.EXCHANGE.MATCHES}','.*','Filter of discoverable exchanges','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('996','10300','{$RABBITMQ.LLD.FILTER.EXCHANGE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered exchanges','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('997','10301','{$RABBITMQ.API.HOST}','127.0.0.1','The hostname or IP of RabbitMQ API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('998','10301','{$RABBITMQ.API.PASSWORD}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('999','10301','{$RABBITMQ.API.PORT}','15672','The port of RabbitMQ API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1000','10301','{$RABBITMQ.API.USER}','zbx_monitor','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1001','10301','{$RABBITMQ.CLUSTER.NAME}','rabbit','The name of RabbitMQ cluster','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1002','10301','{$RABBITMQ.LLD.FILTER.QUEUE.MATCHES}','.*','Filter of discoverable queues','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1003','10301','{$RABBITMQ.LLD.FILTER.QUEUE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered queues','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1004','10301','{$RABBITMQ.MESSAGES.MAX.WARN}','1000','Maximum number of messages in the queue for trigger expression','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1005','10301','{$RABBITMQ.PROCESS_NAME}','beam.smp','RabbitMQ server process name','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1006','10301','{$RABBITMQ.RESPONSE_TIME.MAX.WARN}','10','Maximum RabbitMQ response time in seconds for trigger expression','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1007','10302','{$RABBITMQ.API.PASSWORD}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1008','10302','{$RABBITMQ.API.PORT}','15672','The port of RabbitMQ API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1009','10302','{$RABBITMQ.API.SCHEME}','http','Request scheme which may be http or https','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1010','10302','{$RABBITMQ.API.USER}','zbx_monitor','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1012','10302','{$RABBITMQ.LLD.FILTER.EXCHANGE.MATCHES}','.*','Filter of discoverable exchanges','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1013','10302','{$RABBITMQ.LLD.FILTER.EXCHANGE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered exchanges','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1014','10303','{$RABBITMQ.API.PASSWORD}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1015','10303','{$RABBITMQ.API.PORT}','15672','The port of RabbitMQ API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1016','10303','{$RABBITMQ.API.SCHEME}','http','Request scheme which may be http or https','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1017','10303','{$RABBITMQ.API.USER}','zbx_monitor','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1018','10303','{$RABBITMQ.CLUSTER.NAME}','rabbit','The name of RabbitMQ cluster','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1019','10303','{$RABBITMQ.LLD.FILTER.QUEUE.MATCHES}','.*','Filter of discoverable queues','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1020','10303','{$RABBITMQ.LLD.FILTER.QUEUE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered queues','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1021','10303','{$RABBITMQ.MESSAGES.MAX.WARN}','1000','Maximum number of messages in the queue for trigger expression','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1022','10303','{$RABBITMQ.RESPONSE_TIME.MAX.WARN}','10','Maximum RabbitMQ response time in seconds for trigger expression','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1024','10204','{$SNMP.TIMEOUT}','5m','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1039','10190','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1040','10190','{$IF.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1041','10190','{$NET.IF.IFADMINSTATUS.MATCHES}','^.*','Ignore notPresent(6)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1042','10190','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}','^2$','Ignore down(2) administrative status','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1043','10190','{$NET.IF.IFALIAS.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1044','10190','{$NET.IF.IFALIAS.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1045','10190','{$NET.IF.IFDESCR.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1046','10190','{$NET.IF.IFDESCR.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1047','10190','{$NET.IF.IFNAME.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1048','10190','{$NET.IF.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12})','Filter out loopbacks, nulls, docker veth links and docker0 bridge by default','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1049','10190','{$NET.IF.IFOPERSTATUS.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1050','10190','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}','^6$','Ignore notPresent(6)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1051','10190','{$NET.IF.IFTYPE.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1052','10190','{$NET.IF.IFTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1065','10188','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1066','10188','{$IF.UTIL.MAX}','95','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1067','10188','{$NET.IF.IFADMINSTATUS.MATCHES}','^.*','Ignore notPresent(6)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1068','10188','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}','^2$','Ignore down(2) administrative status','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1069','10188','{$NET.IF.IFDESCR.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1070','10188','{$NET.IF.IFDESCR.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1071','10188','{$NET.IF.IFNAME.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1072','10188','{$NET.IF.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12})','Filter out loopbacks, nulls, docker veth links and docker0 bridge by default','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1073','10188','{$NET.IF.IFOPERSTATUS.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1074','10188','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}','^6$','Ignore notPresent(6)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1075','10188','{$NET.IF.IFTYPE.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1076','10188','{$NET.IF.IFTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1077','10192','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1078','10192','{$IF.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1079','10192','{$NET.IF.IFADMINSTATUS.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1080','10192','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}','^2$','Ignore down(2) administrative status','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1081','10192','{$NET.IF.IFALIAS.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1082','10192','{$NET.IF.IFALIAS.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1083','10192','{$NET.IF.IFDESCR.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1084','10192','{$NET.IF.IFDESCR.NOT_MATCHES}','Miniport|Virtual|Teredo|Kernel|Loopback|Bluetooth|HTTPS|6to4|QoS|Layer|isatap|ISATAP','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1085','10192','{$NET.IF.IFNAME.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1086','10192','{$NET.IF.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12})','Filter out loopbacks, nulls, docker veth links and docker0 bridge by default','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1087','10192','{$NET.IF.IFOPERSTATUS.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1088','10192','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}','^6$','Ignore notPresent(6)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1089','10192','{$NET.IF.IFTYPE.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1090','10192','{$NET.IF.IFTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1091','10300','{$RABBITMQ.API.CLUSTER_HOST}','127.0.0.1','The hostname or IP of RabbitMQ cluster API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1092','10304','{$DISK_ARRAY_CACHE_BATTERY_CRIT_STATUS}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1093','10304','{$DISK_ARRAY_CACHE_BATTERY_OK_STATUS}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1094','10304','{$DISK_ARRAY_CRIT_STATUS:"inoperable"}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1095','10304','{$DISK_ARRAY_OK_STATUS:"operable"}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1096','10304','{$DISK_ARRAY_WARN_STATUS:"degraded"}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1097','10304','{$DISK_CRIT_STATUS:"bad"}','16','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1098','10304','{$DISK_CRIT_STATUS:"predictiveFailure"}','11','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1099','10304','{$DISK_FAIL_STATUS:"failed"}','9','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1100','10304','{$FAN_CRIT_STATUS:"inoperable"}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1101','10304','{$FAN_WARN_STATUS:"degraded"}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1102','10304','{$HEALTH_CRIT_STATUS:"computeFailed"}','30','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1103','10304','{$HEALTH_CRIT_STATUS:"configFailure"}','33','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1104','10304','{$HEALTH_CRIT_STATUS:"inoperable"}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1105','10304','{$HEALTH_CRIT_STATUS:"unconfigFailure"}','34','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1106','10304','{$HEALTH_WARN_STATUS:"diagnosticsFailed"}','204','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1107','10304','{$HEALTH_WARN_STATUS:"powerProblem"}','62','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1108','10304','{$HEALTH_WARN_STATUS:"testFailed"}','35','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1109','10304','{$HEALTH_WARN_STATUS:"thermalProblem"}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1110','10304','{$HEALTH_WARN_STATUS:"voltageProblem"}','62','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1111','10304','{$PSU_CRIT_STATUS:"inoperable"}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1112','10304','{$PSU_WARN_STATUS:"degraded"}','3','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1113','10304','{$TEMP_CRIT:"Ambient"}','35','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1114','10304','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1115','10304','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1116','10304','{$TEMP_WARN:"Ambient"}','30','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1117','10304','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1118','10304','{$VDISK_OK_STATUS:"equipped"}','10','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1119','10207','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1120','10207','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1121','10208','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1122','10208','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1123','10209','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1124','10209','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1125','10212','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1126','10252','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1127','10213','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1128','10215','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1129','10221','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1130','10221','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1131','10222','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1132','10222','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1133','10223','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1134','10223','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1135','10224','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1136','10224','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1137','10227','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1138','10227','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1139','10250','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1140','10250','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1141','10229','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1142','10229','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1143','10231','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1144','10231','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1145','10233','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1146','10233','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1147','10233','{$VFS.FS.PUSED.MAX.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1148','10233','{$VFS.FS.PUSED.MAX.WARN}','80','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1149','10234','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1150','10234','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1151','10235','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1152','10235','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1153','10235','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1154','10236','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1155','10236','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1156','10237','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1157','10237','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1158','10254','{$MEMORY.NAME.NOT_MATCHES}','(Buffer|Cache)','Filter is overridden to ignore RAM(Cache) and RAM(Buffers) memory objects.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1159','10254','{$VFS.FS.PUSED.MAX.CRIT}','95','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1160','10254','{$VFS.FS.PUSED.MAX.WARN}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1161','10305','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1162','10306','{$MEMORY.NAME.MATCHES}','.*','This macro is used in memory discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1163','10306','{$MEMORY.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in memory discovery. Can be overridden on the host or linked template level if you need to filter out results.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1164','10306','{$MEMORY.TYPE.MATCHES}','.*(\.2|hrStorageRam)$','This macro is used in memory discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1165','10306','{$MEMORY.TYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in memory discovery. Can be overridden on the host or linked template level if you need to filter out results.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1166','10306','{$MEMORY.UTIL.MAX}','90','The warning threshold of the "Physical memory: Memory utilization" item.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1167','10307','{$VFS.FS.FSNAME.MATCHES}','.+','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1168','10307','{$VFS.FS.FSNAME.NOT_MATCHES}','^(/dev|/sys|/run|/proc|.+/shm$)','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1169','10307','{$VFS.FS.FSTYPE.MATCHES}','.*(\.4|\.9|hrStorageFixedDisk|hrStorageFlashMemory)$','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1170','10307','{$VFS.FS.FSTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1171','10307','{$VFS.FS.PUSED.MAX.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1172','10307','{$VFS.FS.PUSED.MAX.WARN}','80','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1173','10308','{$HAPROXY.BACK_ERESP.MAX.WARN}','10','Maximum of responses with error on BACKEND for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1174','10308','{$HAPROXY.BACK_QCUR.MAX.WARN}','10','Maximum number of requests on BACKEND unassigned in queue for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1175','10308','{$HAPROXY.BACK_QTIME.MAX.WARN}','10s','Maximum of average time spent in queue on BACKEND for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1176','10308','{$HAPROXY.BACK_RTIME.MAX.WARN}','10s','Maximum of average BACKEND response time for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1177','10308','{$HAPROXY.FRONT_DREQ.MAX.WARN}','10','The HAProxy maximum denied requests for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1178','10308','{$HAPROXY.FRONT_EREQ.MAX.WARN}','10','The HAProxy maximum number of request errors for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1179','10308','{$HAPROXY.FRONT_SUTIL.MAX.WARN}','80','Maximum of session usage percentage on frontend for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1180','10308','{$HAPROXY.RESPONSE_TIME.MAX.WARN}','10s','The HAProxy stats page maximum response time in seconds for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1181','10308','{$HAPROXY.SERVER_ERESP.MAX.WARN}','10','Maximum of responses with error on server for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1182','10308','{$HAPROXY.SERVER_QCUR.MAX.WARN}','10','Maximum number of requests on server unassigned in queue for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1183','10308','{$HAPROXY.SERVER_QTIME.MAX.WARN}','10s','Maximum of average time spent in queue on server for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1184','10308','{$HAPROXY.SERVER_RTIME.MAX.WARN}','10s','Maximum of average server response time for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1185','10308','{$HAPROXY.STATS.PATH}','stats','The path of HAProxy stats page.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1186','10308','{$HAPROXY.STATS.PORT}','8404','The port of the HAProxy stats host or container.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1187','10308','{$HAPROXY.STATS.SCHEME}','http','The scheme of HAProxy stats page(http/https).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1188','10309','{$HAPROXY.BACK_ERESP.MAX.WARN}','10','Maximum of responses with error on Backend for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1189','10309','{$HAPROXY.BACK_QCUR.MAX.WARN}','10','Maximum number of requests on Backend unassigned in queue for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1190','10309','{$HAPROXY.BACK_QTIME.MAX.WARN}','10s','Maximum of average time spent in queue on Backend for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1191','10309','{$HAPROXY.BACK_RTIME.MAX.WARN}','10s','Maximum of average Backend response time for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1192','10309','{$HAPROXY.FRONT_DREQ.MAX.WARN}','10','The HAProxy maximum denied requests for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1193','10309','{$HAPROXY.FRONT_EREQ.MAX.WARN}','10','The HAProxy maximum number of request errors for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1194','10309','{$HAPROXY.FRONT_SUTIL.MAX.WARN}','80','Maximum of session usage percentage on frontend for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1195','10309','{$HAPROXY.PASSWORD}','','The password of the HAProxy stats page.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1196','10309','{$HAPROXY.RESPONSE_TIME.MAX.WARN}','10s','The HAProxy stats page maximum response time in seconds for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1197','10309','{$HAPROXY.SERVER_ERESP.MAX.WARN}','10','Maximum of responses with error on server for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1198','10309','{$HAPROXY.SERVER_QCUR.MAX.WARN}','10','Maximum number of requests on server unassigned in queue for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1199','10309','{$HAPROXY.SERVER_QTIME.MAX.WARN}','10s','Maximum of average time spent in queue on server for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1200','10309','{$HAPROXY.SERVER_RTIME.MAX.WARN}','10s','Maximum of average server response time for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1202','10309','{$HAPROXY.STATS.PATH}','stats','The path of the HAProxy stats page.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1203','10309','{$HAPROXY.STATS.PORT}','8404','The port of the HAProxy stats host or container.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1204','10309','{$HAPROXY.STATS.SCHEME}','http','The scheme of HAProxy stats page(http/https).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1205','10309','{$HAPROXY.USERNAME}','','The username of the HAProxy stats page.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1206','10310','{$REDIS.CLIENTS.PRC.MAX.WARN}','80','Maximum percentage of connected clients','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1207','10310','{$REDIS.CONN.URI}','tcp://localhost:6379','Connection string in the URI format (password is not used). This param overwrites a value configured in the "Server" option of the configuration file (if it''s set), otherwise, the plugin''s default value is used: "tcp://localhost:6379"','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1208','10310','{$REDIS.LLD.FILTER.DB.MATCHES}','.*','Filter of discoverable databases','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1209','10310','{$REDIS.LLD.FILTER.DB.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered databases','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1210','10310','{$REDIS.LLD.PROCESS_NAME}','redis-server','Redis server process name for LLD','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1211','10310','{$REDIS.MEM.FRAG_RATIO.MAX.WARN}','1.5','Maximum memory fragmentation ratio','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1212','10310','{$REDIS.MEM.PUSED.MAX.WARN}','90','Maximum percentage of memory used','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1213','10310','{$REDIS.PROCESS_NAME}','redis-server','Redis server process name','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1214','10310','{$REDIS.REPL.LAG.MAX.WARN}','30s','Maximum replication lag in seconds','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1215','10310','{$REDIS.SLOWLOG.COUNT.MAX.WARN}','1','Maximum number of slowlog entries per second','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1228','10314','{$SERVICE.NAME.MATCHES}','^.*$','This macro is used in Service discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1229','10314','{$SERVICE.NAME.NOT_MATCHES}','^RemoteRegistry|MMCSS|gupdate|SysmonLog|clr_optimization_v.+|clr_optimization_v.+|sppsvc|gpsvc|Pml Driver HPZ12|Net Driver HPZ12|MapsBroker|IntelAudioService|Intel\(R\) TPM Provisioning Service|dbupdate|DoSvc$','This macro is used in Service discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1230','10314','{$SERVICE.STARTUPNAME.MATCHES}','^automatic|automatic delayed$','This macro is used in Service discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1231','10314','{$SERVICE.STARTUPNAME.NOT_MATCHES}','^manual|disabled$','This macro is used in Service discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1232','10291','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1233','10291','{$IF.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1234','10291','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1235','10315','{$SERVICE.NAME.MATCHES}','^.*$','This macro is used in Service discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1236','10315','{$SERVICE.NAME.NOT_MATCHES}','^RemoteRegistry|MMCSS|gupdate|SysmonLog|clr_optimization_v.+|clr_optimization_v.+|sppsvc|gpsvc|Pml Driver HPZ12|Net Driver HPZ12|MapsBroker|IntelAudioService|Intel\(R\) TPM Provisioning Service|dbupdate|DoSvc$','This macro is used in Service discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1237','10315','{$SERVICE.STARTUPNAME.MATCHES}','^automatic|automatic delayed$','This macro is used in Service discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1238','10315','{$SERVICE.STARTUPNAME.NOT_MATCHES}','^manual|disabled$','This macro is used in Service discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1239','10298','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1240','10298','{$IF.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1241','10298','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1242','10316','{$MYSQL.ABORTED_CONN.MAX.WARN}','3','The number of failed attempts to connect to the MySQL server for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1243','10316','{$MYSQL.BUFF_UTIL.MIN.WARN}','50','The minimum buffer pool utilization in percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1244','10316','{$MYSQL.HOST}','localhost','Hostname or IP of MySQL host or container.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1245','10316','{$MYSQL.PORT}','3306','MySQL service port.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1246','10316','{$MYSQL.REPL_LAG.MAX.WARN}','30m','The lag of slave from master for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1247','10316','{$MYSQL.SLOW_QUERIES.MAX.WARN}','3','The number of slow queries for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1248','10317','{$MYSQL.ABORTED_CONN.MAX.WARN}','3','Number of failed attempts to connect to the MySQL server for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1249','10317','{$MYSQL.BUFF_UTIL.MIN.WARN}','50','The minimum buffer pool utilization in percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1250','10317','{$MYSQL.DSN}','<Put your DSN here>','System data source name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1251','10317','{$MYSQL.PASSWORD}','<Put your password here>','MySQL user password.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1252','10317','{$MYSQL.REPL_LAG.MAX.WARN}','30m','The lag of slave from master for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1253','10317','{$MYSQL.SLOW_QUERIES.MAX.WARN}','3','Number of slow queries for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1254','10317','{$MYSQL.USER}','<Put your username here>','MySQL username.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1255','10318','{$DOCKER.LLD.FILTER.CONTAINER.MATCHES}','.*','Filter of discoverable containers','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1256','10318','{$DOCKER.LLD.FILTER.CONTAINER.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered containers','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1257','10318','{$DOCKER.LLD.FILTER.IMAGE.MATCHES}','.*','Filter of discoverable images','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1258','10318','{$DOCKER.LLD.FILTER.IMAGE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered images','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1259','10319','{$MEMCACHED.CONN.PRC.MAX.WARN}','80','Maximum percentage of connected clients','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1260','10319','{$MEMCACHED.CONN.QUEUED.MAX.WARN}','1','Maximum number of queued connections per second','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1261','10319','{$MEMCACHED.CONN.THROTTLED.MAX.WARN}','1','Maximum number of throttled connections per second','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1262','10319','{$MEMCACHED.CONN.URI}','tcp://localhost:11211','Connection string in the URI format (password is not used). This param overwrites a value configured in the "Plugins.Memcached.Uri" option of the configuration file (if it''s set), otherwise, the plugin''s default value is used: "tcp://localhost:11211"','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1263','10319','{$MEMCACHED.MEM.PUSED.MAX.WARN}','90','Maximum percentage of memory used','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1264','10320','{$MYSQL.ABORTED_CONN.MAX.WARN}','3','Number of failed attempts to connect to the MySQL server for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1265','10320','{$MYSQL.BUFF_UTIL.MIN.WARN}','50','The minimum buffer pool utilization percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1266','10320','{$MYSQL.DSN}','<Put your DSN>','System data source name such as <tcp://host:port or unix:/path/to/socket)/>.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1267','10320','{$MYSQL.PASSWORD}','','MySQL user password.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1268','10320','{$MYSQL.REPL_LAG.MAX.WARN}','30m','The lag of slave from master for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1269','10320','{$MYSQL.SLOW_QUERIES.MAX.WARN}','3','The number of slow queries for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1270','10320','{$MYSQL.USER}','','MySQL user name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1271','10321','{$IPMI.PASSWORD}','','This macro is used for access to BMC. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1272','10321','{$IPMI.SENSOR_TYPE.MATCHES}','.*','This macro is used in sensors discovery. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1273','10321','{$IPMI.SENSOR_TYPE.NOT_MATCHES}','invalid','This macro is used in sensors discovery. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1274','10321','{$IPMI.USER}','','This macro is used for access to BMC. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1275','10322','{$ELASTICSEARCH.FETCH_LATENCY.MAX.WARN}','100','Maximum of fetch latency in milliseconds for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1276','10322','{$ELASTICSEARCH.FLUSH_LATENCY.MAX.WARN}','100','Maximum of flush latency in milliseconds for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1277','10322','{$ELASTICSEARCH.HEAP_USED.MAX.CRIT}','95','The maximum percent in the use of JVM heap for critically trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1278','10322','{$ELASTICSEARCH.HEAP_USED.MAX.WARN}','85','The maximum percent in the use of JVM heap for warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1279','10322','{$ELASTICSEARCH.INDEXING_LATENCY.MAX.WARN}','100','Maximum of indexing latency in milliseconds for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1280','10322','{$ELASTICSEARCH.PASSWORD}','','The password of the Elasticsearch.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1281','10322','{$ELASTICSEARCH.PORT}','9200','The port of the Elasticsearch host.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1282','10322','{$ELASTICSEARCH.QUERY_LATENCY.MAX.WARN}','100','Maximum of query latency in milliseconds for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1283','10322','{$ELASTICSEARCH.RESPONSE_TIME.MAX.WARN}','10s','The ES cluster maximum response time in seconds for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1284','10322','{$ELASTICSEARCH.SCHEME}','http','The scheme of the Elasticsearch (http/https).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1285','10322','{$ELASTICSEARCH.USERNAME}','','The username of the Elasticsearch.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1286','10323','{$CLICKHOUSE.DELAYED.FILES.DISTRIBUTED.COUNT.MAX.WARN}','600','Maximum size of distributed files queue to insert for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1287','10323','{$CLICKHOUSE.DELAYED.INSERTS.MAX.WARN}','0','Maximum number of delayed inserts for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1288','10323','{$CLICKHOUSE.LLD.FILTER.DB.MATCHES}','.*','Filter of discoverable databases','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1289','10323','{$CLICKHOUSE.LLD.FILTER.DB.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered databases','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1290','10323','{$CLICKHOUSE.LLD.FILTER.DICT.MATCHES}','.*','Filter of discoverable dictionaries','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1291','10323','{$CLICKHOUSE.LLD.FILTER.DICT.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered dictionaries','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1292','10323','{$CLICKHOUSE.LOG_POSITION.DIFF.MAX.WARN}','30','Maximum diff between log_pointer and log_max_index.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1293','10323','{$CLICKHOUSE.NETWORK.ERRORS.MAX.WARN}','5','Maximum number of smth for trigger expression','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1294','10323','{$CLICKHOUSE.PARTS.PER.PARTITION.WARN}','300','Maximum number of parts per partition for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1295','10323','{$CLICKHOUSE.PASSWORD}','zabbix_pass','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1296','10323','{$CLICKHOUSE.PORT}','8123','The port of ClickHouse HTTP endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1297','10323','{$CLICKHOUSE.QUERY_TIME.MAX.WARN}','600','Maximum ClickHouse query time in seconds for trigger expression','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1298','10323','{$CLICKHOUSE.QUEUE.SIZE.MAX.WARN}','20','Maximum size of the queue for operations waiting to be performed for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1299','10323','{$CLICKHOUSE.REPLICA.MAX.WARN}','600','Replication lag across all tables for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1300','10323','{$CLICKHOUSE.SCHEME}','http','Request scheme which may be http or https','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1301','10323','{$CLICKHOUSE.USER}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1302','10264','{$APACHE.STATUS.SCHEME}','http','Request scheme which may be http or https','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1303','10324','{$ETCD.GRPC_CODE.MATCHES}','.*','Filter of discoverable gRPC codes https://github.com/grpc/grpc/blob/master/doc/statuscodes.md','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1304','10324','{$ETCD.GRPC_CODE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered gRPC codes https://github.com/grpc/grpc/blob/master/doc/statuscodes.md','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1305','10324','{$ETCD.GRPC_CODE.TRIGGER.MATCHES}','Aborted|Unavailable','Filter of discoverable gRPC codes which will be create triggers','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1306','10324','{$ETCD.GRPC.ERRORS.MAX.WARN}','1','Maximum number of gRPC requests failures','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1307','10324','{$ETCD.HTTP.FAIL.MAX.WARN}','2','Maximum number of HTTP requests failures','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1308','10324','{$ETCD.LEADER.CHANGES.MAX.WARN}','5','Maximum number of leader changes','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1309','10324','{$ETCD.OPEN.FDS.MAX.WARN}','90','Maximum percentage of used file descriptors','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1310','10324','{$ETCD.PASSWORD}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1311','10324','{$ETCD.PORT}','2379','The port of Etcd API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1312','10324','{$ETCD.PROPOSAL.FAIL.MAX.WARN}','2','Maximum number of proposal failures','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1313','10324','{$ETCD.PROPOSAL.PENDING.MAX.WARN}','5','Maximum number of proposals in queue','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1314','10324','{$ETCD.SCHEME}','http','Request scheme which may be http or https','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1315','10324','{$ETCD.USER}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1316','10325','{$IIS.APPPOOL.MATCHES}','.+','This macro is used in application pools discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1317','10325','{$IIS.APPPOOL.MONITORED}','1','Monitoring status for discovered application pools. Use context to avoid trigger firing for specific application pools. "1" - enabled, "0" - disabled.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1318','10325','{$IIS.APPPOOL.NOT_MATCHES}','<CHANGE_IF_NEEDED>','This macro is used in application pools discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1319','10325','{$IIS.PORT}','80','Listening port.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1320','10325','{$IIS.QUEUE.MAX.TIME}','5m','The time during which the queue length may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1321','10325','{$IIS.QUEUE.MAX.WARN}','','Maximum application pool''s request queue length for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1322','10325','{$IIS.SERVICE}','http','The service (http/https/etc) for port check. See "net.tcp.service" documentation page for more information: https://www.zabbix.com/documentation/5.0/manual/config/items/itemtypes/simple_checks','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1323','10326','{$IIS.APPPOOL.MATCHES}','.+','This macro is used in application pools discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1324','10326','{$IIS.APPPOOL.MONITORED}','1','Monitoring status for discovered application pools. Use context to avoid trigger firing for specific application pools. "1" - enabled, "0" - disabled.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1325','10326','{$IIS.APPPOOL.NOT_MATCHES}','<CHANGE_IF_NEEDED>','This macro is used in application pools discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1326','10326','{$IIS.PORT}','80','Listening port.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1327','10326','{$IIS.QUEUE.MAX.TIME}','5m','The time during which the queue length may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1328','10326','{$IIS.QUEUE.MAX.WARN}','','Maximum application pool''s request queue length for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1329','10326','{$IIS.SERVICE}','http','The service (http/https/etc) for port check. See "net.tcp.service" documentation page for more information: https://www.zabbix.com/documentation/5.0/manual/config/items/itemtypes/simple_checks','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1330','10327','{$MSSQL.AVERAGE_WAIT_TIME.MAX}','500','The maximum average wait time in ms - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1331','10327','{$MSSQL.BUFFER_CACHE_RATIO.MIN.CRIT}','30','The minimum % buffer cache hit ratio - for the High trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1332','10327','{$MSSQL.BUFFER_CACHE_RATIO.MIN.WARN}','50','The minimum % buffer cache hit ratio - for the Warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1333','10327','{$MSSQL.DBNAME.MATCHES}','.*','This macro is used in database discovery. It can be overridden on a host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1334','10327','{$MSSQL.DBNAME.NOT_MATCHES}','master|tempdb|model|msdb','This macro is used in database discovery. It can be overridden on a host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1335','10327','{$MSSQL.DEADLOCKS.MAX}','1','The maximum deadlocks per second - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1336','10327','{$MSSQL.DSN}','<Put your DSN here>','System data source name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1337','10327','{$MSSQL.FREE_LIST_STALLS.MAX}','2','The maximum free list stalls per second - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1338','10327','{$MSSQL.LAZY_WRITES.MAX}','20','The maximum lazy writes per second - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1339','10327','{$MSSQL.LOCK_REQUESTS.MAX}','1000','The maximum lock requests per second - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1340','10327','{$MSSQL.LOCK_TIMEOUTS.MAX}','1','The maximum lock timeouts per second - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1341','10327','{$MSSQL.LOG_FLUSH_WAIT_TIME.MAX}','1','The maximum log flush wait time in ms - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1342','10327','{$MSSQL.LOG_FLUSH_WAITS.MAX}','1','The maximum log flush waits per second - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1345','10327','{$MSSQL.PAGE_LIFE_EXPECTANCY.MIN}','300','The minimum page life expectancy - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1346','10327','{$MSSQL.PAGE_READS.MAX}','90','The maximum page reads per second - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1347','10327','{$MSSQL.PAGE_WRITES.MAX}','90','The maximum page writes per second - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1348','10327','{$MSSQL.PASSWORD}','<Put your password here>','MSSQL user password.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1349','10327','{$MSSQL.PERCENT_COMPILATIONS.MAX}','10','The maximum percentage of Transact-SQL compilations - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1350','10327','{$MSSQL.PERCENT_LOG_USED.MAX}','80','The maximum percentage of log used - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1351','10327','{$MSSQL.PERCENT_READAHEAD.MAX}','20','The maximum percentage of pages read/sec in anticipation of use - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1352','10327','{$MSSQL.PERCENT_RECOMPILATIONS.MAX}','10','The maximum percentage of Transact-SQL recompilations - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1353','10327','{$MSSQL.PORT}','1433','MSSQL TCP port.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1354','10327','{$MSSQL.USER}','<Put your username here>','MSSQL username.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1355','10327','{$MSSQL.WORK_FILES.MAX}','20','The maximum number of work files created per second - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1356','10327','{$MSSQL.WORK_TABLES.MAX}','20','The maximum number of work tables created per second - for the trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1357','10327','{$MSSQL.WORKTABLES_FROM_CACHE_RATIO.MIN.CRIT}','90','The minimum percentage of the worktables from cache ratio - for the High trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1358','10316','{$MYSQL.CREATED_TMP_DISK_TABLES.MAX.WARN}','10','The maximum number of created tmp tables on a disk per second for trigger expressions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1359','10316','{$MYSQL.CREATED_TMP_FILES.MAX.WARN}','10','The maximum number of created tmp files on a disk per second for trigger expressions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1360','10316','{$MYSQL.CREATED_TMP_TABLES.MAX.WARN}','30','The maximum number of created tmp tables in memory per second for trigger expressions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1361','10320','{$MYSQL.CREATED_TMP_DISK_TABLES.MAX.WARN}','10','The maximum number of created tmp tables on a disk per second for trigger expressions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1362','10320','{$MYSQL.CREATED_TMP_FILES.MAX.WARN}','10','The maximum number of created tmp files on a disk per second for trigger expressions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1363','10320','{$MYSQL.CREATED_TMP_TABLES.MAX.WARN}','30','The maximum number of created tmp tables in memory per second for trigger expressions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1364','10317','{$MYSQL.CREATED_TMP_DISK_TABLES.MAX.WARN}','10','The maximum number of created tmp tables on a disk per second for trigger expressions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1365','10317','{$MYSQL.CREATED_TMP_FILES.MAX.WARN}','10','The maximum number of created tmp files on a disk per second for trigger expressions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1366','10317','{$MYSQL.CREATED_TMP_TABLES.MAX.WARN}','30','The maximum number of created tmp tables in memory per second for trigger expressions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1367','10328','{$PG.CONFLICTS.MAX.WARN}','0','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1368','10328','{$PG.CONN_TOTAL_PCT.MAX.WARN}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1369','10328','{$PG.DEADLOCKS.MAX.WARN}','0','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1370','10328','{$PG.LLD.FILTER.DBNAME}','(.+)','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1371','10328','{$PG.PASSWORD}','postgres','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1372','10328','{$PG.URI}','tcp://localhost:5432','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1373','10328','{$PG.USER}','postgres','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1374','10327','{$MSSQL.INSTANCE}','SQLServer','The instance name for the default instance is SQLServer. For named instance set the macro value as MSSQL$instance name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1398','10169','{$JMX.CPU.LOAD.MAX}','85','A threshold in percent for CPU utilization trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1399','10169','{$JMX.CPU.LOAD.TIME}','5m','The time during which the CPU utilization may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1400','10169','{$JMX.FILE.DESCRIPTORS.MAX}','85','A threshold in percent for file descriptors count trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1401','10169','{$JMX.FILE.DESCRIPTORS.TIME}','3m','The time during which the file descriptors count may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1402','10169','{$JMX.HEAP.MEM.USAGE.MAX}','85','A threshold in percent for Heap memory utilization trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1403','10169','{$JMX.HEAP.MEM.USAGE.TIME}','10m','The time during which the Heap memory utilization may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1404','10169','{$JMX.MP.USAGE.MAX}','85','A threshold in percent for memory pools utilization trigger. Use a context to change the threshold for a specific pool.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1405','10169','{$JMX.MP.USAGE.TIME}','10m','The time during which the memory pools utilization may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1406','10169','{$JMX.NONHEAP.MEM.USAGE.MAX}','85','A threshold in percent for Non-heap memory utilization trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1407','10169','{$JMX.NONHEAP.MEM.USAGE.TIME}','10m','The time during which the Non-heap memory utilization may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1408','10330','{$VMWARE.PASSWORD}','','VMware service {$USERNAME} user password','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1409','10330','{$VMWARE.URL}','','VMware service (vCenter or ESX hypervisor) SDK URL (https://servername/sdk)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1410','10330','{$VMWARE.USERNAME}','','VMware service user name','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1411','10333','{$ORACLE.ASM.USED.PCT.MAX.HIGH}','95','Maximum percentage of used ASM disk group for high trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1412','10333','{$ORACLE.ASM.USED.PCT.MAX.WARN}','90','Maximum percentage of used ASM disk group for warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1413','10333','{$ORACLE.CONCURRENCY.MAX.WARN}','80','Maximum percentage of sessions concurrency usage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1414','10333','{$ORACLE.CONNSTRING}','tcp://localhost:1521','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1415','10333','{$ORACLE.DB.FILE.MAX.WARN}','80','Maximum percentage of database files for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1416','10333','{$ORACLE.DBNAME.MATCHES}','.*','This macro is used in database discovery. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1417','10333','{$ORACLE.DBNAME.NOT_MATCHES}','PDB\$SEED','This macro is used in database discovery. It can be overridden on a host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1418','10333','{$ORACLE.EXPIRE.PASSWORD.MIN.WARN}','7','Number of days of warning before password expires (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1419','10333','{$ORACLE.PASSWORD}','zabbix_password','Oracle user password.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1420','10333','{$ORACLE.PGA.USE.MAX.WARN}','90','Maximum percentage of PGA usage alert threshold (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1421','10333','{$ORACLE.PROCESSES.MAX.WARN}','80','Maximum percentage of active processes alert threshold (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1422','10333','{$ORACLE.REDO.MIN.WARN}','3','Minimum number of REDO logs alert threshold (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1423','10333','{$ORACLE.SERVICE}','ORA','Oracle Service Name','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1424','10333','{$ORACLE.SESSION.LOCK.MAX.TIME}','600','Maximum session lock duration in seconds for count the session as a prolongely locked query.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1425','10333','{$ORACLE.SESSION.LONG.LOCK.MAX.WARN}','3','Maximum number of the prolongely locked sessions alert threshold (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1426','10333','{$ORACLE.SESSIONS.LOCK.MAX.WARN}','20','Maximum percentage of locked sessions alert threshold (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1427','10333','{$ORACLE.SESSIONS.MAX.WARN}','80','Maximum percentage of active sessions alert threshold (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1428','10333','{$ORACLE.SHARED.FREE.MIN.WARN}','5','Minimum percentage of free shared pool alert threshold (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1429','10333','{$ORACLE.TABLESPACE.NAME.MATCHES}','.*','This macro is used in tablespace discovery. It can be overridden on a host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1430','10333','{$ORACLE.TABLESPACE.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in tablespace discovery. It can be overridden on a host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1431','10333','{$ORACLE.TBS.USED.PCT.MAX.HIGH}','95','Maximum percentage of used (Used bytes/Allocated bytes) tablespace high severity alert threshold (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1432','10333','{$ORACLE.TBS.USED.PCT.MAX.WARN}','90','Maximum percentage of used (Used bytes/Allocated bytes) tablespace warning severity alert threshold (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1433','10333','{$ORACLE.USER}','zabbix','Oracle username.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1434','10334','{$CEPH.API.KEY}','zabbix_pass','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1435','10334','{$CEPH.CONNSTRING}','https://localhost:8003','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1436','10334','{$CEPH.USER}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1437','10335','{$PHP_FPM.HOST}','localhost','Hostname or IP of PHP-FPM status host or container.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1438','10335','{$PHP_FPM.PING.PAGE}','ping','The path of PHP-FPM ping page.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1439','10335','{$PHP_FPM.PING.REPLY}','pong','Expected reply to the ping.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1440','10335','{$PHP_FPM.PORT}','80','The port of PHP-FPM status host or container.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1441','10335','{$PHP_FPM.PROCESS_NAME}','php-fpm','PHP-FPM process name','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1442','10335','{$PHP_FPM.QUEUE.WARN.MAX}','80','The maximum PHP-FPM queue usage percent for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1443','10335','{$PHP_FPM.STATUS.PAGE}','status','The path of PHP-FPM status page.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1444','10336','{$PHP_FPM.HOST}','localhost','Hostname or IP of PHP-FPM status host or container.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1445','10336','{$PHP_FPM.PING.PAGE}','ping','The path of PHP-FPM ping page.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1446','10336','{$PHP_FPM.PING.REPLY}','pong','Expected reply to the ping.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1447','10336','{$PHP_FPM.PORT}','80','The port of PHP-FPM status host or container.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1448','10336','{$PHP_FPM.QUEUE.WARN.MAX}','80','The maximum PHP-FPM queue usage percent for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1449','10336','{$PHP_FPM.SCHEME}','http','Request scheme which may be http or https','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1450','10336','{$PHP_FPM.STATUS.PAGE}','status','The path of PHP-FPM status page.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1451','10337','{$SQUID.FILE.DESC.WARN.MIN}','100','The threshold for minimum number of available file descriptors','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1452','10337','{$SQUID.HTTP.PORT}','3128','http_port configured in squid.conf (Default: 3128)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1453','10337','{$SQUID.PAGE.FAULT.WARN}','90','The threshold for sys page faults rate in percent of received HTTP requests','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1454','10337','{$SQUID.SNMP.COMMUNITY}','public','SNMP community allowed by ACL in squid.conf','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1455','10337','{$SQUID.SNMP.PORT}','3401','snmp_port configured in squid.conf (Default: 3401)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1456','10233','{$IFNAME.LTEMODEM.MATCHES}','^lte','This macro is used in LTE modem discovery. It can be overridden on the host.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1457','10233','{$IFNAME.WIFI.MATCHES}','WIFI','This macro is used in CAPsMAN AP channel discovery. It can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1458','10233','{$LTEMODEM.RSRP.MIN.WARN}','-100','The LTE modem RSRP minimum value for warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1459','10233','{$LTEMODEM.RSRQ.MIN.WARN}','-20','The LTE modem RSRQ minimum value for warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1460','10233','{$LTEMODEM.RSSI.MIN.WARN}','-100','The LTE modem RSSI minimum value for warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1461','10233','{$LTEMODEM.SINR.MIN.WARN}','0','The LTE modem SINR minimum value for warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1470','10339','{$HADOOP.CAPACITY_REMAINING.MIN.WARN}','20','The Hadoop cluster capacity remaining percent for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1471','10339','{$HADOOP.NAMENODE.HOST}','NameNode','The Hadoop NameNode host IP address or FQDN.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1472','10339','{$HADOOP.NAMENODE.PORT}','9870','The Hadoop NameNode Web-UI port.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1473','10339','{$HADOOP.NAMENODE.RESPONSE_TIME.MAX.WARN}','10s','The Hadoop NameNode API page maximum response time in seconds for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1474','10339','{$HADOOP.RESOURCEMANAGER.HOST}','ResourceManager','The Hadoop ResourceManager host IP address or FQDN.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1475','10339','{$HADOOP.RESOURCEMANAGER.PORT}','8088','The Hadoop ResourceManager Web-UI port.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1476','10339','{$HADOOP.RESOURCEMANAGER.RESPONSE_TIME.MAX.WARN}','10s','The Hadoop ResourceManager API page maximum response time in seconds for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1477','10340','{$KAFKA.NET_PROC_AVG_IDLE.MIN.WARN}','30','The minimum Network processor average idle percent for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1478','10340','{$KAFKA.PASSWORD}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1479','10340','{$KAFKA.REQUEST_HANDLER_AVG_IDLE.MIN.WARN}','30','The minimum Request handler average idle percent for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1480','10340','{$KAFKA.TOPIC.MATCHES}','.*','Filter of discoverable topics','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1481','10340','{$KAFKA.TOPIC.NOT_MATCHES}','__consumer_offsets','Filter to exclude discovered topics','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1482','10340','{$KAFKA.USER}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1483','10260','{$TOMCAT.LLD.FILTER.MATCHES}','.*','Filter for discoverable objects. Can be used with following contexts: "GlobalRequestProcessor", "ThreadPool", "Manager"','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1484','10260','{$TOMCAT.LLD.FILTER.NOT_MATCHES}','CHANGE IF NEEDED','Filter to exclude discovered objects. Can be used with following contexts: "GlobalRequestProcessor", "ThreadPool", "Manager"','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1485','10260','{$TOMCAT.PASSWORD}','','Password for JMX','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1486','10260','{$TOMCAT.THREADS.MAX.PCT}','75','Threshold for busy worker threads trigger. Can be used with {#JMXNAME} as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1487','10260','{$TOMCAT.THREADS.MAX.TIME}','5m','The time during which the number of busy threads can exceed the threshold. Can be used with {#JMXNAME} as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1488','10260','{$TOMCAT.USER}','','User for JMX','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1489','10341','{$ZOOKEEPER.COMMAND_URL}','commands','The URL for listing and issuing commands relative to the root URL (admin.commandURL).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1490','10341','{$ZOOKEEPER.FILE_DESCRIPTORS.MAX.WARN}','85','Maximum percentage of file descriptors usage alert threshold (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1491','10341','{$ZOOKEEPER.OUTSTANDING_REQ.MAX.WARN}','10','Maximum number of outstanding requests (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1492','10341','{$ZOOKEEPER.PENDING_SYNCS.MAX.WARN}','10','Maximum number of pending syncs from the followers (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1493','10341','{$ZOOKEEPER.PORT}','8080','The port the embedded Jetty server listens on (admin.serverPort).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1494','10341','{$ZOOKEEPER.SCHEME}','http','Request scheme which may be http or https','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1495','10342','{$CASSANDRA.KEY_SPACE.MATCHES}','.*','Filter of discoverable key spaces','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1496','10342','{$CASSANDRA.KEY_SPACE.NOT_MATCHES}','(system|system_auth|system_distributed|system_schema)','Filter to exclude discovered key spaces','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1497','10342','{$CASSANDRA.PASSWORD}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1498','10342','{$CASSANDRA.PENDING_TASKS.MAX.HIGH}','500','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1499','10342','{$CASSANDRA.PENDING_TASKS.MAX.WARN}','350','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1500','10342','{$CASSANDRA.USER}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1501','10343','{$BATTERY.TEMP.MAX.CRIT}','60','Battery high temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1502','10343','{$BATTERY.TEMP.MAX.WARN}','45','Battery high temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1503','10343','{$BATTERY.TEMP.MIN.CRIT}','-20','Battery low temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1504','10343','{$BATTERY.TEMP.MIN.WARN}','0','Battery low temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1505','10343','{$CHARGE.STATE.CRIT}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1506','10343','{$CHARGE.STATE.WARN}','2','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1507','10343','{$LOAD.STATE.CRIT:"fault"}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1508','10343','{$LOAD.STATE.CRIT:"lvd"}','3','lvd','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1509','10343','{$LOAD.STATE.WARN:"disconnect"}','5','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1510','10343','{$LOAD.STATE.WARN:"lvdWarning"}','2','lvdWarning','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1511','10343','{$LOAD.STATE.WARN:"override"}','7','override','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1512','10343','{$VOLTAGE.MAX.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1513','10343','{$VOLTAGE.MAX.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1514','10343','{$VOLTAGE.MIN.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1515','10343','{$VOLTAGE.MIN.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1516','10344','{$BATTERY.TEMP.MAX.CRIT}','60','Battery high temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1517','10344','{$BATTERY.TEMP.MAX.WARN}','45','Battery high temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1518','10344','{$BATTERY.TEMP.MIN.CRIT}','-20','Battery low temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1519','10344','{$BATTERY.TEMP.MIN.WARN}','0','Battery low temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1520','10344','{$CHARGE.STATE.CRIT}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1521','10344','{$CHARGE.STATE.WARN}','2','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1522','10344','{$LOAD.STATE.CRIT:"fault"}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1523','10344','{$LOAD.STATE.CRIT:"lvd"}','3','lvd','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1524','10344','{$LOAD.STATE.WARN:"disconnect"}','5','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1525','10344','{$LOAD.STATE.WARN:"lvdWarning"}','2','lvdWarning','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1526','10344','{$LOAD.STATE.WARN:"override"}','7','override','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1527','10344','{$VOLTAGE.MAX.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1528','10344','{$VOLTAGE.MAX.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1529','10344','{$VOLTAGE.MIN.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1530','10344','{$VOLTAGE.MIN.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1531','10345','{$BATTERY.TEMP.MAX.CRIT}','60','Battery high temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1532','10345','{$BATTERY.TEMP.MAX.WARN}','45','Battery high temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1533','10345','{$BATTERY.TEMP.MIN.CRIT}','-20','Battery low temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1534','10345','{$BATTERY.TEMP.MIN.WARN}','0','Battery low temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1535','10345','{$CHARGE.STATE.CRIT}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1536','10345','{$CHARGE.STATE.WARN}','2','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1537','10345','{$LOAD.STATE.CRIT:"fault"}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1538','10345','{$LOAD.STATE.CRIT:"lvd"}','3','lvd','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1539','10345','{$LOAD.STATE.WARN:"disconnect"}','5','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1540','10345','{$LOAD.STATE.WARN:"lvdWarning"}','2','lvdWarning','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1541','10345','{$LOAD.STATE.WARN:"override"}','7','override','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1542','10345','{$VOLTAGE.MAX.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1543','10345','{$VOLTAGE.MAX.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1544','10345','{$VOLTAGE.MIN.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1545','10345','{$VOLTAGE.MIN.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1546','10346','{$BATTERY.TEMP.MAX.CRIT}','60','Battery high temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1547','10346','{$BATTERY.TEMP.MAX.WARN}','45','Battery high temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1548','10346','{$BATTERY.TEMP.MIN.CRIT}','-20','Battery low temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1549','10346','{$BATTERY.TEMP.MIN.WARN}','0','Battery low temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1550','10346','{$CHARGE.STATE.CRIT}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1551','10346','{$CHARGE.STATE.WARN}','2','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1552','10346','{$LOAD.STATE.CRIT:"fault"}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1553','10346','{$LOAD.STATE.CRIT:"lvd"}','3','lvd','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1554','10346','{$LOAD.STATE.WARN:"disconnect"}','5','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1555','10346','{$LOAD.STATE.WARN:"lvdWarning"}','2','lvdWarning','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1556','10346','{$LOAD.STATE.WARN:"override"}','7','override','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1557','10346','{$VOLTAGE.MAX.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1558','10346','{$VOLTAGE.MAX.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1559','10346','{$VOLTAGE.MIN.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1560','10346','{$VOLTAGE.MIN.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1561','10347','{$BATTERY.TEMP.MAX.CRIT}','60','Battery high temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1562','10347','{$BATTERY.TEMP.MAX.WARN}','45','Battery high temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1563','10347','{$BATTERY.TEMP.MIN.CRIT}','-20','Battery low temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1564','10347','{$BATTERY.TEMP.MIN.WARN}','0','Battery low temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1565','10347','{$CHARGE.STATE.CRIT}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1566','10347','{$CHARGE.STATE.WARN}','2','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1567','10347','{$LOAD.STATE.CRIT:"fault"}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1568','10347','{$LOAD.STATE.CRIT:"lvd"}','3','lvd','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1569','10347','{$LOAD.STATE.WARN:"disconnect"}','5','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1570','10347','{$LOAD.STATE.WARN:"lvdWarning"}','2','lvdWarning','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1571','10347','{$LOAD.STATE.WARN:"override"}','7','override','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1572','10347','{$VOLTAGE.MAX.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1573','10347','{$VOLTAGE.MAX.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1574','10347','{$VOLTAGE.MIN.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1575','10347','{$VOLTAGE.MIN.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1576','10348','{$BATTERY.TEMP.MAX.CRIT}','60','Battery high temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1577','10348','{$BATTERY.TEMP.MAX.WARN}','45','Battery high temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1578','10348','{$BATTERY.TEMP.MIN.CRIT}','-20','Battery low temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1579','10348','{$BATTERY.TEMP.MIN.WARN}','0','Battery low temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1580','10348','{$CHARGE.STATE.CRIT}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1581','10348','{$CHARGE.STATE.WARN}','2','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1582','10348','{$LOAD.STATE.CRIT:"fault"}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1583','10348','{$LOAD.STATE.CRIT:"lvd"}','3','lvd','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1584','10348','{$LOAD.STATE.WARN:"disconnect"}','5','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1585','10348','{$LOAD.STATE.WARN:"lvdWarning"}','2','lvdWarning','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1586','10348','{$LOAD.STATE.WARN:"override"}','7','override','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1587','10348','{$VOLTAGE.MAX.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1588','10348','{$VOLTAGE.MAX.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1589','10348','{$VOLTAGE.MIN.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1590','10348','{$VOLTAGE.MIN.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1591','10349','{$BATTERY.TEMP.MAX.CRIT}','60','Battery high temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1592','10349','{$BATTERY.TEMP.MAX.WARN}','45','Battery high temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1593','10349','{$BATTERY.TEMP.MIN.CRIT}','-20','Battery low temperature critical value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1594','10349','{$BATTERY.TEMP.MIN.WARN}','0','Battery low temperature warning value','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1595','10349','{$CHARGE.STATE.CRIT}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1596','10349','{$CHARGE.STATE.WARN}','2','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1597','10349','{$LOAD.STATE.CRIT:"fault"}','4','fault','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1598','10349','{$LOAD.STATE.CRIT:"lvd"}','3','lvd','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1599','10349','{$LOAD.STATE.WARN:"disconnect"}','5','disconnect','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1600','10349','{$LOAD.STATE.WARN:"lvdWarning"}','2','lvdWarning','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1601','10349','{$LOAD.STATE.WARN:"override"}','7','override','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1602','10349','{$VOLTAGE.MAX.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1603','10349','{$VOLTAGE.MAX.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1604','10349','{$VOLTAGE.MIN.CRIT}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1605','10349','{$VOLTAGE.MIN.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1606','10289','{$VFS.DEV.READ.AWAIT.WARN}','0.02','Disk read average response time (in s) before the trigger would fire.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1607','10289','{$VFS.DEV.WRITE.AWAIT.WARN}','0.02','Disk write average response time (in s) before the trigger would fire.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1608','10296','{$VFS.DEV.READ.AWAIT.WARN}','0.02','Disk read average response time (in s) before the trigger would fire.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1609','10296','{$VFS.DEV.WRITE.AWAIT.WARN}','0.02','Disk write average response time (in s) before the trigger would fire.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1610','10350','{$ACTIVEMQ.BROKER.CONSUMERS.MIN.HIGH}','1','Minimum amount of consumers for broker. Can be used with broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1611','10350','{$ACTIVEMQ.BROKER.CONSUMERS.MIN.TIME}','5m','Time during which there may be no consumers on destination. Can be used with broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1612','10350','{$ACTIVEMQ.BROKER.PRODUCERS.MIN.HIGH}','1','Minimum amount of producers for broker. Can be used with broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1613','10350','{$ACTIVEMQ.BROKER.PRODUCERS.MIN.TIME}','5m','Time during which there may be no producers on broker. Can be used with broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1614','10350','{$ACTIVEMQ.DESTINATION.CONSUMERS.MIN.HIGH}','1','Minimum amount of consumers for destination. Can be used with destination name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1615','10350','{$ACTIVEMQ.DESTINATION.CONSUMERS.MIN.TIME}','10m','Time during which there may be no consumers in destination. Can be used with destination name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1616','10350','{$ACTIVEMQ.DESTINATION.PRODUCERS.MIN.HIGH}','1','Minimum amount of producers for destination. Can be used with destination name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1617','10350','{$ACTIVEMQ.DESTINATION.PRODUCERS.MIN.TIME}','10m','Time during which there may be no producers on destination. Can be used with destination name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1618','10350','{$ACTIVEMQ.EXPIRIED.WARN}','0','Threshold for expiried messages count. Can be used with destination name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1619','10350','{$ACTIVEMQ.LLD.FILTER.BROKER.MATCHES}','.*','Filter of discoverable discovered brokers','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1620','10350','{$ACTIVEMQ.LLD.FILTER.BROKER.NOT_MATCHES}','CHANGE IF NEEDED','Filter to exclude discovered brokers','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1621','10350','{$ACTIVEMQ.LLD.FILTER.DESTINATION.MATCHES}','.*','Filter of discoverable discovered destinations','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1622','10350','{$ACTIVEMQ.LLD.FILTER.DESTINATION.NOT_MATCHES}','CHANGE IF NEEDED','Filter to exclude discovered destinations','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1623','10350','{$ACTIVEMQ.MEM.MAX.HIGH}','90','Memory threshold for HIGH trigger. Can be used with destination or broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1624','10350','{$ACTIVEMQ.MEM.MAX.WARN}','75','Memory threshold for AVERAGE trigger. Can be used with destination or broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1625','10350','{$ACTIVEMQ.MEM.TIME}','5m','Time during which the metric can be above the threshold. Can be used with destination or broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1626','10350','{$ACTIVEMQ.MSG.RATE.WARN.TIME}','15m','The time for message enqueue/dequeue rate. Can be used with destination or broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1627','10350','{$ACTIVEMQ.PASSWORD}','activemq','Password for JMX','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1628','10350','{$ACTIVEMQ.PORT}','1099','Port for JMX','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1629','10350','{$ACTIVEMQ.QUEUE.ENABLED}','1','Use this to disable alerting for specific destination. 1 = enabled, 0 = disabled. Can be used with destination name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1630','10350','{$ACTIVEMQ.QUEUE.TIME}','10m','Time during which the QueueSize can be higher than threshold. Can be used with destination name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1631','10350','{$ACTIVEMQ.QUEUE.WARN}','100','Threshold for QueueSize. Can be used with destination name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1632','10350','{$ACTIVEMQ.STORE.MAX.HIGH}','90','Storage threshold for HIGH trigger. Can be used with broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1633','10350','{$ACTIVEMQ.STORE.MAX.WARN}','75','Storage threshold for AVERAGE trigger. Can be used with broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1634','10350','{$ACTIVEMQ.STORE.TIME}','5m','Time during which the metric can be above the threshold. Can be used with destination or broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1635','10350','{$ACTIVEMQ.TEMP.MAX.HIGH}','90','Temp threshold for HIGH trigger. Can be used with broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1636','10350','{$ACTIVEMQ.TEMP.MAX.WARN}','75','Temp threshold for AVERAGE trigger. Can be used with broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1637','10350','{$ACTIVEMQ.TEMP.TIME}','5m','Time during which the metric can be above the threshold. Can be used with destination or broker name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1638','10350','{$ACTIVEMQ.TOTAL.CONSUMERS.COUNT}','TotalConsumerCount','Attribute for TotalConsumerCount per destination. Used to suppress destination''s triggers when the count of consumers on the broker is lower than threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1639','10350','{$ACTIVEMQ.TOTAL.PRODUCERS.COUNT}','TotalProducerCount','Attribute for TotalProducerCount per destination. Used to suppress destination''s triggers when the count of consumers on the broker is lower than threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1640','10350','{$ACTIVEMQ.USER}','admin','User for JMX','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1641','10351','{$MS.EXCHANGE.DB.ACTIVE.READ.TIME}','5m','The time during which the active database read operations latency may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1642','10351','{$MS.EXCHANGE.DB.ACTIVE.READ.WARN}','0.02','Threshold for active database read operations latency trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1643','10351','{$MS.EXCHANGE.DB.ACTIVE.WRITE.TIME}','10m','The time during which the active database write operations latency may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1644','10351','{$MS.EXCHANGE.DB.ACTIVE.WRITE.WARN}','0.05','Threshold for active database write operations latency trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1645','10351','{$MS.EXCHANGE.DB.FAULTS.TIME}','5m','The time during which the database page faults may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1646','10351','{$MS.EXCHANGE.DB.FAULTS.WARN}','0','Threshold for database page faults trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1647','10351','{$MS.EXCHANGE.DB.PASSIVE.READ.TIME}','5m','The time during which the passive database read operations latency may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1648','10351','{$MS.EXCHANGE.DB.PASSIVE.READ.WARN}','0.2','Threshold for passive database read operations latency trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1649','10351','{$MS.EXCHANGE.DB.PASSIVE.WRITE.TIME}','10m','The time during which the passive database write operations latency may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1650','10351','{$MS.EXCHANGE.LDAP.TIME}','5m','The time during which the LDAP metrics may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1651','10351','{$MS.EXCHANGE.LDAP.WARN}','0.05','Threshold for LDAP triggers.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1652','10351','{$MS.EXCHANGE.LOG.STALLS.TIME}','10m','The time during which the log records stalled may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1653','10351','{$MS.EXCHANGE.LOG.STALLS.WARN}','100','Threshold for log records stalled trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1654','10351','{$MS.EXCHANGE.PERF.INTERVAL}','60','Update interval for perf_counter_en items.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1655','10351','{$MS.EXCHANGE.RPC.COUNT.TIME}','5m','The time during which the RPC total requests may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1656','10351','{$MS.EXCHANGE.RPC.COUNT.WARN}','70','Threshold for LDAP triggers.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1657','10351','{$MS.EXCHANGE.RPC.TIME}','10m','The time during which the RPC requests latency may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1658','10351','{$MS.EXCHANGE.RPC.WARN}','0.05','Threshold for RPC requests latency trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1659','10352','{$MS.EXCHANGE.DB.ACTIVE.READ.TIME}','5m','The time during which the active database read operations latency may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1660','10352','{$MS.EXCHANGE.DB.ACTIVE.READ.WARN}','0.02','Threshold for active database read operations latency trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1661','10352','{$MS.EXCHANGE.DB.ACTIVE.WRITE.TIME}','10m','The time during which the active database write operations latency may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1662','10352','{$MS.EXCHANGE.DB.ACTIVE.WRITE.WARN}','0.05','Threshold for active database write operations latency trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1663','10352','{$MS.EXCHANGE.DB.FAULTS.TIME}','5m','The time during which the database page faults may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1664','10352','{$MS.EXCHANGE.DB.FAULTS.WARN}','0','Threshold for database page faults trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1665','10352','{$MS.EXCHANGE.DB.PASSIVE.READ.TIME}','5m','The time during which the passive database read operations latency may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1666','10352','{$MS.EXCHANGE.DB.PASSIVE.READ.WARN}','0.2','Threshold for passive database read operations latency trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1667','10352','{$MS.EXCHANGE.DB.PASSIVE.WRITE.TIME}','10m','The time during which the passive database write operations latency may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1668','10352','{$MS.EXCHANGE.LDAP.TIME}','5m','The time during which the LDAP metrics may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1669','10352','{$MS.EXCHANGE.LDAP.WARN}','0.05','Threshold for LDAP triggers.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1670','10352','{$MS.EXCHANGE.LOG.STALLS.TIME}','10m','The time during which the log records stalled may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1671','10352','{$MS.EXCHANGE.LOG.STALLS.WARN}','100','Threshold for log records stalled trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1672','10352','{$MS.EXCHANGE.PERF.INTERVAL}','60','Update interval for perf_counter_en items.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1673','10352','{$MS.EXCHANGE.RPC.COUNT.TIME}','5m','The time during which the RPC total requests may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1674','10352','{$MS.EXCHANGE.RPC.COUNT.WARN}','70','Threshold for LDAP triggers.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1675','10352','{$MS.EXCHANGE.RPC.TIME}','10m','The time during which the RPC requests latency may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1676','10352','{$MS.EXCHANGE.RPC.WARN}','0.05','Threshold for RPC requests latency trigger.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1677','10316','{$MYSQL.INNODB_LOG_FILES}','2','Number of physical files in the InnoDB redo log for calculating innodb_log_file_size.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1678','10320','{$MYSQL.INNODB_LOG_FILES}','2','Number of physical files in the InnoDB redo log for calculating innodb_log_file_size.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1679','10317','{$MYSQL.INNODB_LOG_FILES}','2','Number of physical files in the InnoDB redo log for calculating innodb_log_file_size.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1680','10333','{$ORACLE.TBS.UTIL.PCT.MAX.HIGH}','90','Maximum percentage of utilization (Allocated bytes/Max bytes) tablespace high severity alert threshold (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1681','10333','{$ORACLE.TBS.UTIL.PCT.MAX.WARN}','80','Maximum percentage of utilization (Allocated bytes/Max bytes) tablespace warning severity alert threshold (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1684','10328','{$PG.DATABASE}','postgres','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1685','10328','{$PG.LLD.FILTER.APPLICATION}','(.+)','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1686','10353','{$CPU.UTIL.CRIT}','90','The critical threshold of the CPU utilization in %.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1687','10353','{$FAS3220.FS.AVAIL.MIN.CRIT}','10G','Minimum available space on the disk. Can be used with {#FSNAME} as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1688','10353','{$FAS3220.FS.NAME.MATCHES}','.*','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1689','10353','{$FAS3220.FS.NAME.NOT_MATCHES}','snapshot','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1690','10353','{$FAS3220.FS.PUSED.MAX.CRIT}','90','Maximum percentage of disk used. Can be used with {#FSNAME} as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1691','10353','{$FAS3220.FS.TIME}','10G','The time during which disk usage may exceed the threshold. Can be used with {#FSNAME} as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1692','10353','{$FAS3220.FS.TYPE.MATCHES}','.*','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.
Value should be integer:
  2 - flexibleVolume,
  3 - aggregate,
  4 - stripedAggregate,
  5 - stripedVolume.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1693','10353','{$FAS3220.FS.TYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in filesystems discovery. Can be overridden on the host or linked template level.
Value should be integer:
  2 - flexibleVolume,
  3 - aggregate,
  4 - stripedAggregate,
  5 - stripedVolume.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1694','10353','{$FAS3220.FS.USE.PCT}','1','Macro define what threshold will be used for disk space trigger:
  0 - use Bytes ({$FAS3220.FS.AVAIL.MIN.CRIT})
  1 - use percents ({$FAS3220.FS.PUSED.MAX.CRIT})
Can be used with {#FSNAME} as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1695','10353','{$FAS3220.NET.PORT.NAME.MATCHES}','.*','This macro is used in net ports discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1696','10353','{$FAS3220.NET.PORT.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in net ports discovery. Can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1697','10353','{$FAS3220.NET.PORT.ROLE.MATCHES}','.*','This macro is used in net ports discovery. Can be overridden on the host or linked template level.
{#ROLE} is integer. Possible values:
  0 - undef
  1 - cluster
  2 - data
  3 - node-mgmt
  4 - intercluster
  5 - cluster-mgmt','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1698','10353','{$FAS3220.NET.PORT.ROLE.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in net ports discovery. Can be overridden on the host or linked template level.
{#ROLE} is integer. Possible values:
  0 - undef
  1 - cluster
  2 - data
  3 - node-mgmt
  4 - intercluster
  5 - cluster-mgmt','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1699','10353','{$FAS3220.NET.PORT.TYPE.MATCHES}','.*','This macro is used in net ports discovery. Can be overridden on the host or linked template level.
{#TYPE} is integer. Possible values: physical, if-group, vlan, undef.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1700','10353','{$FAS3220.NET.PORT.TYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in net ports discovery. Can be overridden on the host or linked template level.
{#TYPE} is integer. Possible values: physical, if-group, vlan, undef.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1701','10353','{$IF.ERRORS.WARN}','','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1702','10353','{$IF.UTIL.MAX}','95','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1703','10354','{$IGNITE.CHECKPOINT.PUSED.MAX.HIGH}','80','The maximum percent of checkpoint buffer utilization for high trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1704','10354','{$IGNITE.CHECKPOINT.PUSED.MAX.WARN}','66','The maximum percent of checkpoint buffer utilization for warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1705','10354','{$IGNITE.DATA.REGION.PUSED.MAX.HIGH}','90','The maximum percent of data region utilization for high trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1706','10354','{$IGNITE.DATA.REGION.PUSED.MAX.WARN}','80','The maximum percent of data region utilization for warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1707','10354','{$IGNITE.JOBS.QUEUE.MAX.WARN}','10','The maximum number of queued jobs for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1708','10354','{$IGNITE.LLD.FILTER.CACHE.MATCHES}','.*','Filter of discoverable cache groups.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1709','10354','{$IGNITE.LLD.FILTER.CACHE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered cache groups.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1710','10354','{$IGNITE.LLD.FILTER.DATA.REGION.MATCHES}','.*','Filter of discoverable data regions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1711','10354','{$IGNITE.LLD.FILTER.DATA.REGION.NOT_MATCHES}','^(sysMemPlc|TxLog)$','Filter to exclude discovered data regions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1712','10354','{$IGNITE.LLD.FILTER.THREAD.POOL.MATCHES}','.*','Filter of discoverable thread pools.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1713','10354','{$IGNITE.LLD.FILTER.THREAD.POOL.NOT_MATCHES}','^(GridCallbackExecutor|GridRebalanceStripedExecutor|GridDataStreamExecutor|StripedExecutor)$','Filter to exclude discovered thread pools.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1714','10354','{$IGNITE.PASSWORD}','<secret>','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1715','10354','{$IGNITE.PME.DURATION.MAX.HIGH}','60000','The maximum PME duration in ms for high trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1716','10354','{$IGNITE.PME.DURATION.MAX.WARN}','10000','The maximum PME duration in ms for warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1717','10354','{$IGNITE.THREAD.QUEUE.MAX.WARN}','1000','Threshold for thread pool queue size. Can be used with thread pool name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1718','10354','{$IGNITE.THREADS.COUNT.MAX.WARN}','1000','The maximum number of running threads for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1719','10354','{$IGNITE.USER}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1720','10355','{$SMART.ATTRIBUTE.ID.MATCHES}','CHANGE_IF_NEEDED','This macro is used in overrides of attribute discovery for filtering IDs. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1721','10355','{$SMART.DISK.NAME.MATCHES}','CHANGE_IF_NEEDED','This macro is used in overrides of attribute discovery for filtering IDs. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1722','10355','{$SMART.TEMPERATURE.MAX.CRIT}','65','This macro is used for trigger expression. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1723','10355','{$SMART.TEMPERATURE.MAX.WARN}','50','This macro is used for trigger expression. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1724','10356','{$SMART.ATTRIBUTE.ID.MATCHES}','CHANGE_IF_NEEDED','This macro is used in overrides of attribute discovery for filtering IDs. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1725','10356','{$SMART.DISK.NAME.MATCHES}','CHANGE_IF_NEEDED','This macro is used in overrides of attribute discovery for filtering IDs. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1726','10356','{$SMART.TEMPERATURE.MAX.CRIT}','65','This macro is used for trigger expression. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1727','10356','{$SMART.TEMPERATURE.MAX.WARN}','50','This macro is used for trigger expression. It can be overridden on the host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1728','10357','{$CPU.UTIL.CRIT}','90','The critical threshold of the CPU utilization in %.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1729','10357','{$HUAWEI.5300.DISK.TEMP.MAX.TIME}','5m','The time during which temperature of disk may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1730','10357','{$HUAWEI.5300.DISK.TEMP.MAX.WARN}','45','Maximum temperature of disk. Can be used with {#MODEL} as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1731','10357','{$HUAWEI.5300.LUN.IO.TIME.MAX.TIME}','5m','The time during which average I/O response time of LUN may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1732','10357','{$HUAWEI.5300.LUN.IO.TIME.MAX.WARN}','100','Maximum average I/O response time of LUN in milliseconds.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1733','10357','{$HUAWEI.5300.MEM.MAX.TIME}','5m','The time during which memory usage may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1734','10357','{$HUAWEI.5300.MEM.MAX.WARN}','90','Maximum percentage of memory used','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1735','10357','{$HUAWEI.5300.NODE.IO.DELAY.MAX.TIME}','5m','The time during which verage I/O latency of node may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1736','10357','{$HUAWEI.5300.NODE.IO.DELAY.MAX.WARN}','20','Maximum average I/O latency of node in milliseconds.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1737','10357','{$HUAWEI.5300.POOL.CAPACITY.THRESH.TIME}','5m','The time during which free capacity may exceed the {#THRESHOLD} from hwInfoStoragePoolFullThreshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1738','10357','{$HUAWEI.5300.TEMP.MAX.TIME}','3m','The time during which temperature of enclosure may exceed the threshold.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1739','10357','{$HUAWEI.5300.TEMP.MAX.WARN}','35','Maximum temperature of enclosure','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1740','10358','{$RABBITMQ.API.CLUSTER_HOST}','127.0.0.1','The hostname or IP of RabbitMQ cluster API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1741','10358','{$RABBITMQ.API.PASSWORD}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1742','10358','{$RABBITMQ.API.PORT}','15672','The port of RabbitMQ API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1743','10358','{$RABBITMQ.API.USER}','zbx_monitor','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1744','10358','{$RABBITMQ.LLD.FILTER.EXCHANGE.MATCHES}','.*','Filter of discoverable exchanges','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1745','10358','{$RABBITMQ.LLD.FILTER.EXCHANGE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered exchanges','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1746','10359','{$RABBITMQ.API.HOST}','127.0.0.1','The hostname or IP of RabbitMQ API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1747','10359','{$RABBITMQ.API.PASSWORD}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1748','10359','{$RABBITMQ.API.PORT}','15672','The port of RabbitMQ API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1749','10359','{$RABBITMQ.API.USER}','zbx_monitor','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1750','10359','{$RABBITMQ.CLUSTER.NAME}','rabbit','The name of RabbitMQ cluster','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1751','10359','{$RABBITMQ.LLD.FILTER.QUEUE.MATCHES}','.*','Filter of discoverable queues','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1752','10359','{$RABBITMQ.LLD.FILTER.QUEUE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered queues','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1753','10359','{$RABBITMQ.MESSAGES.MAX.WARN}','1000','Maximum number of messages in the queue for trigger expression','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1754','10359','{$RABBITMQ.PROCESS_NAME}','beam.smp','RabbitMQ server process name','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1755','10359','{$RABBITMQ.RESPONSE_TIME.MAX.WARN}','10','Maximum RabbitMQ response time in seconds for trigger expression','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1756','10360','{$RABBITMQ.API.PASSWORD}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1757','10360','{$RABBITMQ.API.PORT}','15672','The port of RabbitMQ API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1758','10360','{$RABBITMQ.API.SCHEME}','http','Request scheme which may be http or https','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1759','10360','{$RABBITMQ.API.USER}','zbx_monitor','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1760','10360','{$RABBITMQ.LLD.FILTER.EXCHANGE.MATCHES}','.*','Filter of discoverable exchanges','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1761','10360','{$RABBITMQ.LLD.FILTER.EXCHANGE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered exchanges','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1762','10361','{$RABBITMQ.API.PASSWORD}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1763','10361','{$RABBITMQ.API.PORT}','15672','The port of RabbitMQ API endpoint','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1764','10361','{$RABBITMQ.API.SCHEME}','http','Request scheme which may be http or https','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1765','10361','{$RABBITMQ.API.USER}','zbx_monitor','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1766','10361','{$RABBITMQ.CLUSTER.NAME}','rabbit','The name of RabbitMQ cluster','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1767','10361','{$RABBITMQ.LLD.FILTER.QUEUE.MATCHES}','.*','Filter of discoverable queues','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1768','10361','{$RABBITMQ.LLD.FILTER.QUEUE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered queues','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1769','10361','{$RABBITMQ.MESSAGES.MAX.WARN}','1000','Maximum number of messages in the queue for trigger expression','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1770','10361','{$RABBITMQ.RESPONSE_TIME.MAX.WARN}','10','Maximum RabbitMQ response time in seconds for trigger expression','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1771','10362','{$MONGODB.CONNS.PCT.USED.MAX.WARN}','80','Maximum percentage of used connections','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1772','10362','{$MONGODB.CONNSTRING}','tcp://localhost:27017','Connection string in the URI format (password is not used). This param overwrites a value configured in the "Server" option of the configuration file (if it''s set), otherwise, the plugin''s default value is used: "tcp://localhost:27017"','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1773','10362','{$MONGODB.CURSOR.OPEN.MAX.WARN}','10000','Maximum number of open cursors','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1774','10362','{$MONGODB.CURSOR.TIMEOUT.MAX.WARN}','1','Maximum number of cursors timing out per second','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1775','10362','{$MONGODB.LLD.FILTER.COLLECTION.MATCHES}','.*','Filter of discoverable collections','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1776','10362','{$MONGODB.LLD.FILTER.COLLECTION.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered collections','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1777','10362','{$MONGODB.LLD.FILTER.DB.MATCHES}','.*','Filter of discoverable databases','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1778','10362','{$MONGODB.LLD.FILTER.DB.NOT_MATCHES}','(admin|config|local)','Filter to exclude discovered databases','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1779','10362','{$MONGODB.PASSWORD}','','MongoDB user password','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1780','10362','{$MONGODB.REPL.LAG.MAX.WARN}','10s','Maximum replication lag in seconds','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1781','10362','{$MONGODB.USER}','','MongoDB username','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1782','10362','{$MONGODB.WIRED_TIGER.TICKETS.AVAILABLE.MIN.WARN}','5','Minimum number of available WiredTiger read or write tickets remaining','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1783','10363','{$MONGODB.CONNS.AVAILABLE.MIN.WARN}','1000','Minimum number of available connections','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1784','10363','{$MONGODB.CONNSTRING}','tcp://localhost:27017','Connection string in the URI format (password is not used). This param overwrites a value configured in the "Server" option of the configuration file (if it''s set), otherwise, the plugin''s default value is used: "tcp://localhost:27017"','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1785','10363','{$MONGODB.CURSOR.OPEN.MAX.WARN}','10000','Maximum number of open cursors','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1786','10363','{$MONGODB.CURSOR.TIMEOUT.MAX.WARN}','1','Maximum number of cursors timing out per second','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1787','10363','{$MONGODB.LLD.FILTER.COLLECTION.MATCHES}','.*','Filter of discoverable collections','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1788','10363','{$MONGODB.LLD.FILTER.COLLECTION.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered collections','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1789','10363','{$MONGODB.LLD.FILTER.DB.MATCHES}','.*','Filter of discoverable databases','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1790','10363','{$MONGODB.LLD.FILTER.DB.NOT_MATCHES}','(admin|config|local)','Filter to exclude discovered databases','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1791','10363','{$MONGODB.PASSWORD}','','MongoDB user password','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1792','10363','{$MONGODB.USER}','','MongoDB username','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1793','10364','{$MONGODB.CONNSTRING}','{#MONGOD_URI}','Connection string in the URI format (password is not used).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1794','10365','{$MONGODB.CONNSTRING}','{#MONGOD_URI}','Connection string in the URI format (password is not used).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1795','10366','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1796','10366','{$ICMP_LOSS_WARN}','20','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1797','10366','{$ICMP_RESPONSE_TIME_WARN}','0.15','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1798','10366','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1799','10366','{$IF.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1800','10366','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1801','10366','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1802','10366','{$NET.IF.IFADMINSTATUS.MATCHES}','^.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1803','10366','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}','^2$','Ignore down(2) administrative status','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1804','10366','{$NET.IF.IFALIAS.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1805','10366','{$NET.IF.IFALIAS.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1806','10366','{$NET.IF.IFDESCR.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1807','10366','{$NET.IF.IFDESCR.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1808','10366','{$NET.IF.IFNAME.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1809','10366','{$NET.IF.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12})','Filter out loopbacks, nulls, docker veth links and docker0 bridge by default','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1810','10366','{$NET.IF.IFOPERSTATUS.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1811','10366','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}','^6$','Ignore notPresent(6)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1812','10366','{$NET.IF.IFTYPE.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1813','10366','{$NET.IF.IFTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1814','10366','{$SNMP.TIMEOUT}','5m','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1815','10366','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1816','10366','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1817','10366','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1818','10367','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1819','10367','{$ICMP_LOSS_WARN}','20','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1820','10367','{$ICMP_RESPONSE_TIME_WARN}','0.15','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1821','10367','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1822','10367','{$IF.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1823','10367','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1824','10367','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1825','10367','{$NET.IF.IFADMINSTATUS.MATCHES}','^.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1826','10367','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}','^2$','Ignore down(2) administrative status','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1827','10367','{$NET.IF.IFALIAS.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1828','10367','{$NET.IF.IFALIAS.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1829','10367','{$NET.IF.IFDESCR.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1830','10367','{$NET.IF.IFDESCR.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1831','10367','{$NET.IF.IFNAME.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1832','10367','{$NET.IF.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12})','Filter out loopbacks, nulls, docker veth links and docker0 bridge by default','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1833','10367','{$NET.IF.IFOPERSTATUS.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1834','10367','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}','^6$','Ignore notPresent(6)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1835','10367','{$NET.IF.IFTYPE.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1836','10367','{$NET.IF.IFTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1837','10367','{$SNMP.TIMEOUT}','5m','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1838','10367','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1839','10367','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1840','10367','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1841','10368','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1842','10368','{$ICMP_LOSS_WARN}','20','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1843','10368','{$ICMP_RESPONSE_TIME_WARN}','0.15','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1844','10368','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1845','10368','{$IF.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1846','10368','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1847','10368','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1848','10368','{$NET.IF.IFADMINSTATUS.MATCHES}','^.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1849','10368','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}','^2$','Ignore down(2) administrative status','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1850','10368','{$NET.IF.IFALIAS.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1851','10368','{$NET.IF.IFALIAS.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1852','10368','{$NET.IF.IFDESCR.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1853','10368','{$NET.IF.IFDESCR.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1854','10368','{$NET.IF.IFNAME.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1855','10368','{$NET.IF.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12})','Filter out loopbacks, nulls, docker veth links and docker0 bridge by default','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1856','10368','{$NET.IF.IFOPERSTATUS.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1857','10368','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}','^6$','Ignore notPresent(6)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1858','10368','{$NET.IF.IFTYPE.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1859','10368','{$NET.IF.IFTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1860','10368','{$SNMP.TIMEOUT}','5m','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1861','10368','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1862','10368','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1863','10368','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1864','10369','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1865','10369','{$ICMP_LOSS_WARN}','20','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1866','10369','{$ICMP_RESPONSE_TIME_WARN}','0.15','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1867','10369','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1868','10369','{$IF.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1869','10369','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1870','10369','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1871','10369','{$NET.IF.IFADMINSTATUS.MATCHES}','^.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1872','10369','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}','^2$','Ignore down(2) administrative status','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1873','10369','{$NET.IF.IFALIAS.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1874','10369','{$NET.IF.IFALIAS.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1875','10369','{$NET.IF.IFDESCR.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1876','10369','{$NET.IF.IFDESCR.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1877','10369','{$NET.IF.IFNAME.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1878','10369','{$NET.IF.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12})','Filter out loopbacks, nulls, docker veth links and docker0 bridge by default','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1879','10369','{$NET.IF.IFOPERSTATUS.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1880','10369','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}','^6$','Ignore notPresent(6)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1881','10369','{$NET.IF.IFTYPE.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1882','10369','{$NET.IF.IFTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1883','10369','{$SNMP.TIMEOUT}','5m','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1884','10369','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1885','10369','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1886','10369','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1887','10370','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1888','10370','{$ICMP_LOSS_WARN}','20','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1889','10370','{$ICMP_RESPONSE_TIME_WARN}','0.15','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1890','10370','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1891','10370','{$IF.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1892','10370','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1893','10370','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1894','10370','{$NET.IF.IFADMINSTATUS.MATCHES}','^.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1895','10370','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}','^2$','Ignore down(2) administrative status','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1896','10370','{$NET.IF.IFALIAS.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1897','10370','{$NET.IF.IFALIAS.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1898','10370','{$NET.IF.IFDESCR.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1899','10370','{$NET.IF.IFDESCR.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1900','10370','{$NET.IF.IFNAME.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1901','10370','{$NET.IF.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12})','Filter out loopbacks, nulls, docker veth links and docker0 bridge by default','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1902','10370','{$NET.IF.IFOPERSTATUS.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1903','10370','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}','^6$','Ignore notPresent(6)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1904','10370','{$NET.IF.IFTYPE.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1905','10370','{$NET.IF.IFTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1906','10370','{$SNMP.TIMEOUT}','5m','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1907','10370','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1908','10370','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1909','10370','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1910','10251','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1911','10251','{$FAN.STATUS.CRIT}','3','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1912','10251','{$ICMP.LOSS.WARN}','20','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1913','10251','{$ICMP.RESPONSE_TIME.WARN}','0.15','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1914','10251','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1915','10251','{$IF.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1916','10251','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1917','10251','{$MEMORY.NAME.MATCHES}','.*','This macro is used in memory discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1918','10251','{$MEMORY.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in memory discovery. Can be overridden on the host level if you need to filter out results.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1919','10251','{$MEMORY.TYPE.MATCHES}','.*(\.2|hrStorageRam)$','This macro is used in memory discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1920','10251','{$MEMORY.TYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in memory discovery. Can be overridden on the host level if you need to filter out results.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1921','10251','{$MEMORY.UTIL.MAX}','90','The warning threshold of the "Physical memory: Memory utilization" item.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1922','10251','{$NET.IF.IFADMINSTATUS.MATCHES}','^.*','Ignore notPresent(6)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1923','10251','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}','^2$','Ignore down(2) administrative status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1924','10251','{$NET.IF.IFALIAS.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1925','10251','{$NET.IF.IFALIAS.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1926','10251','{$NET.IF.IFDESCR.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1927','10251','{$NET.IF.IFDESCR.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1928','10251','{$NET.IF.IFNAME.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1929','10251','{$NET.IF.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12})','Filter out loopbacks, nulls, docker veth links and docker0 bridge by default.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1930','10251','{$NET.IF.IFOPERSTATUS.MATCHES}','^.*$','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1931','10251','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}','^6$','Ignore notPresent(6).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1932','10251','{$NET.IF.IFTYPE.MATCHES}','.*','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1933','10251','{$NET.IF.IFTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1934','10251','{$PSU.STATUS.CRIT}','2','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1935','10251','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1936','10251','{$TEMP.MAX.CRIT}','60','The temperature maximum critical value for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1937','10251','{$TEMP.MAX.WARN}','50','The temperature maximum warning value for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1938','10251','{$TEMP.MIN.CRIT}','5','The temperature minimum critical value for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1939','10251','{$TEMP.STATUS.WARN}','3','The critical value of the TEMP sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1940','10251','{$VFS.FS.FSNAME.MATCHES}','.+','This macro is used in filesystems discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1941','10251','{$VFS.FS.FSNAME.NOT_MATCHES}','^(/dev|/sys|/$|/run|/proc|.+/shm$)','This macro is used in filesystems discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1942','10251','{$VFS.FS.FSTYPE.MATCHES}','.*(\.4|\.9|hrStorageFixedDisk|hrStorageFlashMemory)$','This macro is used in filesystems discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1943','10251','{$VFS.FS.FSTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in filesystems discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1944','10251','{$VFS.FS.PUSED.MAX.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1945','10251','{$VFS.FS.PUSED.MAX.WARN}','80','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1946','10371','{$BATTERY.TEMP.MAX.WARN}','55','Maximum battery temperature for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1949','10371','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1950','10371','{$TIME.PERIOD}','15m','Time period for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1951','10371','{$UPS.INPUT_FREQ.MAX.WARN}','50.3','Maximum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1952','10371','{$UPS.INPUT_FREQ.MIN.WARN}','49.7','Minimum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1953','10371','{$UPS.INPUT_VOLT.MAX.WARN}','243','Maximum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1954','10371','{$UPS.INPUT_VOLT.MIN.WARN}','197','Minimum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1955','10371','{$UPS.OUTPUT.MAX.WARN}','80','Maximum output load in % for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1956','10372','{$HTTP.AGENT.TIMEOUT}','3s','The HTTP agent timeout to wait for a response from AFF700.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1957','10372','{$PASSWORD}','','AFF700 user password.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1958','10372','{$URL}','','AFF700 cluster URL address.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1959','10372','{$USERNAME}','','AFF700 user name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1960','10373','{$BATTERY.CAPACITY.MIN.WARN}','50','Minimum battery capacity percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1961','10373','{$BATTERY.TEMP.MAX.WARN}','55','Maximum battery temperature for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1964','10373','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1965','10373','{$TIME.PERIOD}','15m','Time period for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1966','10373','{$UPS.INPUT_FREQ.MAX.WARN}','50.3','Maximum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1967','10373','{$UPS.INPUT_FREQ.MIN.WARN}','49.7','Minimum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1968','10373','{$UPS.INPUT_VOLT.MAX.WARN}','243','Maximum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1969','10373','{$UPS.INPUT_VOLT.MIN.WARN}','197','Minimum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1970','10373','{$UPS.OUTPUT.MAX.WARN}','80','Maximum output load in % for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1971','10374','{$BATTERY.CAPACITY.MIN.WARN}','50','Minimum battery capacity percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1972','10374','{$BATTERY.TEMP.MAX.WARN}','55','Maximum battery temperature for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1975','10374','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1976','10374','{$TIME.PERIOD}','15m','Time period for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1977','10374','{$UPS.INPUT_FREQ.MAX.WARN}','50.3','Maximum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1978','10374','{$UPS.INPUT_FREQ.MIN.WARN}','49.7','Minimum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1979','10374','{$UPS.INPUT_VOLT.MAX.WARN}','243','Maximum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1980','10374','{$UPS.INPUT_VOLT.MIN.WARN}','197','Minimum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1981','10374','{$UPS.OUTPUT.MAX.WARN}','80','Maximum output load in % for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1982','10375','{$BATTERY.CAPACITY.MIN.WARN}','50','Minimum battery capacity percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1983','10375','{$BATTERY.TEMP.MAX.WARN}','55','Maximum battery temperature for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1986','10375','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1987','10375','{$TIME.PERIOD}','15m','Time period for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1988','10375','{$UPS.INPUT_FREQ.MAX.WARN}','50.3','Maximum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1989','10375','{$UPS.INPUT_FREQ.MIN.WARN}','49.7','Minimum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1990','10375','{$UPS.INPUT_VOLT.MAX.WARN}','243','Maximum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1991','10375','{$UPS.INPUT_VOLT.MIN.WARN}','197','Minimum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1992','10375','{$UPS.OUTPUT.MAX.WARN}','80','Maximum output load in % for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1993','10376','{$BATTERY.CAPACITY.MIN.WARN}','50','Minimum battery capacity percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1994','10376','{$BATTERY.TEMP.MAX.WARN}','55','Maximum battery temperature for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1997','10376','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1998','10376','{$TIME.PERIOD}','15m','Time period for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('1999','10376','{$UPS.INPUT_FREQ.MAX.WARN}','50.3','Maximum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2000','10376','{$UPS.INPUT_FREQ.MIN.WARN}','49.7','Minimum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2001','10376','{$UPS.INPUT_VOLT.MAX.WARN}','243','Maximum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2002','10376','{$UPS.INPUT_VOLT.MIN.WARN}','197','Minimum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2003','10376','{$UPS.OUTPUT.MAX.WARN}','80','Maximum output load in % for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2004','10377','{$BATTERY.CAPACITY.MIN.WARN}','50','Minimum battery capacity percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2005','10377','{$BATTERY.TEMP.MAX.WARN}','55','Maximum battery temperature for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2008','10377','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2009','10377','{$TIME.PERIOD}','15m','Time period for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2010','10377','{$UPS.INPUT_FREQ.MAX.WARN}','50.3','Maximum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2011','10377','{$UPS.INPUT_FREQ.MIN.WARN}','49.7','Minimum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2012','10377','{$UPS.INPUT_VOLT.MAX.WARN}','243','Maximum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2013','10377','{$UPS.INPUT_VOLT.MIN.WARN}','197','Minimum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2014','10377','{$UPS.OUTPUT.MAX.WARN}','80','Maximum output load in % for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2015','10378','{$BATTERY.CAPACITY.MIN.WARN}','50','Minimum battery capacity percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2016','10378','{$BATTERY.TEMP.MAX.WARN}','55','Maximum battery temperature for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2019','10378','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2020','10378','{$TIME.PERIOD}','15m','Time period for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2021','10378','{$UPS.INPUT_FREQ.MAX.WARN}','50.3','Maximum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2022','10378','{$UPS.INPUT_FREQ.MIN.WARN}','49.7','Minimum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2023','10378','{$UPS.INPUT_VOLT.MAX.WARN}','243','Maximum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2024','10378','{$UPS.INPUT_VOLT.MIN.WARN}','197','Minimum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2025','10378','{$UPS.OUTPUT.MAX.WARN}','80','Maximum output load in % for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2026','10379','{$BATTERY.CAPACITY.MIN.WARN}','50','Minimum battery capacity percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2027','10379','{$BATTERY.TEMP.MAX.WARN}','55','Maximum battery temperature for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2030','10379','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2031','10379','{$TIME.PERIOD}','15m','Time period for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2032','10379','{$UPS.INPUT_FREQ.MAX.WARN}','50.3','Maximum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2033','10379','{$UPS.INPUT_FREQ.MIN.WARN}','49.7','Minimum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2034','10379','{$UPS.INPUT_VOLT.MAX.WARN}','243','Maximum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2035','10379','{$UPS.INPUT_VOLT.MIN.WARN}','197','Minimum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2036','10379','{$UPS.OUTPUT.MAX.WARN}','80','Maximum output load in % for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2037','10371','{$BATTERY.CAPACITY.MIN.WARN}','50','Minimum battery capacity percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2038','10380','{$BATTERY.CAPACITY.MIN.WARN}','50','Minimum battery capacity percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2039','10380','{$BATTERY.TEMP.MAX.WARN}','55','Maximum battery temperature for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2042','10380','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2043','10380','{$TIME.PERIOD}','15m','Time period for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2044','10380','{$UPS.INPUT_FREQ.MAX.WARN}','50.3','Maximum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2045','10380','{$UPS.INPUT_FREQ.MIN.WARN}','49.7','Minimum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2046','10380','{$UPS.INPUT_VOLT.MAX.WARN}','243','Maximum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2047','10380','{$UPS.INPUT_VOLT.MIN.WARN}','197','Minimum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2048','10380','{$UPS.OUTPUT.MAX.WARN}','80','Maximum output load in % for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2049','10381','{$BATTERY.CAPACITY.MIN.WARN}','50','Minimum battery capacity percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2050','10381','{$BATTERY.TEMP.MAX.WARN}','55','Maximum battery temperature for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2053','10381','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2054','10381','{$TIME.PERIOD}','15m','Time period for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2055','10381','{$UPS.INPUT_FREQ.MAX.WARN}','50.3','Maximum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2056','10381','{$UPS.INPUT_FREQ.MIN.WARN}','49.7','Minimum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2057','10381','{$UPS.INPUT_VOLT.MAX.WARN}','243','Maximum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2058','10381','{$UPS.INPUT_VOLT.MIN.WARN}','197','Minimum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2059','10381','{$UPS.OUTPUT.MAX.WARN}','80','Maximum output load in % for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2060','10382','{$BATTERY.CAPACITY.MIN.WARN}','50','Minimum battery capacity percentage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2061','10382','{$BATTERY.TEMP.MAX.WARN}','55','Maximum battery temperature for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2064','10382','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2065','10382','{$TIME.PERIOD}','15m','Time period for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2066','10382','{$UPS.INPUT_FREQ.MAX.WARN}','50.3','Maximum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2067','10382','{$UPS.INPUT_FREQ.MIN.WARN}','49.7','Minimum input frequency for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2068','10382','{$UPS.INPUT_VOLT.MAX.WARN}','243','Maximum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2069','10382','{$UPS.INPUT_VOLT.MIN.WARN}','197','Minimum input voltage for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2070','10382','{$UPS.OUTPUT.MAX.WARN}','80','Maximum output load in % for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2071','10383','{$WILDFLY.DEPLOYMENT.MATCHES}','.*','Filter of discoverable deployments','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2072','10383','{$WILDFLY.DEPLOYMENT.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered deployments','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2073','10383','{$WILDFLY.JMX.PROTOCOL}','remote+http','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2074','10383','{$WILDFLY.PASSWORD}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2075','10383','{$WILDFLY.SERVER.MATCHES}','.*','Filter of discoverable servers','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2076','10383','{$WILDFLY.SERVER.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered servers','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2077','10383','{$WILDFLY.USER}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2078','10384','{$WILDFLY.CONN.USAGE.WARN.MAX}','80','The maximum connection usage percent for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2079','10384','{$WILDFLY.CONN.WAIT.MAX.WARN}','300','The maximum number of waiting connections for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2080','10384','{$WILDFLY.DEPLOYMENT.MATCHES}','.*','Filter of discoverable deployments','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2081','10384','{$WILDFLY.DEPLOYMENT.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered deployments','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2082','10384','{$WILDFLY.JMX.PROTOCOL}','remote+http','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2083','10384','{$WILDFLY.PASSWORD}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2084','10384','{$WILDFLY.USER}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2085','10327','{$MSSQL.BACKUP_DIFF.CRIT}','6d','The maximum days without a differential backup - for the High trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2086','10327','{$MSSQL.BACKUP_DIFF.WARN}','3d','The maximum days without a differential backup - for the Warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2087','10327','{$MSSQL.BACKUP_DURATION.WARN}','1h','The maximum job duration - for the Warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2088','10327','{$MSSQL.BACKUP_FULL.CRIT}','10d','The maximum days without a full backup - for the High trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2089','10327','{$MSSQL.BACKUP_FULL.WARN}','9d','The maximum days without a full backup - for the Warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2090','10327','{$MSSQL.BACKUP_LOG.CRIT}','8h','The maximum days without a log backup - for the High trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2091','10327','{$MSSQL.BACKUP_LOG.WARN}','4h','The maximum days without a log backup - for the Warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2092','10327','{$MSSQL.JOB.MATCHES}','.*','This macro is used in job discovery. It can be overridden on a host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2093','10327','{$MSSQL.JOB.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in job discovery. It can be overridden on a host or linked template level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2094','10385','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2095','10385','{$ZYXEL.ADSL.ATN.MAX}','40','Type the maximum signal attenuation','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2096','10385','{$ZYXEL.ADSL.SNR.MIN}','8','Type the minimum signal to noise margin (0-31 dB)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2097','10385','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2098','10385','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}','.*','Filter of discoverable link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2099','10385','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}','2','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2100','10386','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2101','10386','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2102','10386','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2103','10386','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2104','10386','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2105','10386','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2106','10386','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2107','10386','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2108','10386','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2109','10386','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2110','10386','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2111','10386','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2112','10386','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2113','10387','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2114','10387','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2115','10387','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2116','10387','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2117','10387','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2118','10387','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2119','10387','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2120','10388','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2121','10388','{$ZYXEL.ADSL.ATN.MAX}','40','Type the maximum signal attenuation','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2122','10388','{$ZYXEL.ADSL.SNR.MIN}','8','Type the minimum signal to noise margin (0-31 dB)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2123','10388','{$ZYXEL.LLD.FILTER..SLOT.STATUS.NOT_MATCHES}','1','Filter to exclude discovered slots by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2124','10388','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2125','10388','{$ZYXEL.LLD.FILTER.IF.DESC.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2126','10388','{$ZYXEL.LLD.FILTER.IF.DESC.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2127','10388','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}','.*','Filter of discoverable link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2128','10388','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}','2','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2129','10388','{$ZYXEL.LLD.FILTER.SLOT.STATUS.MATCHES}','.*','Filter by discoverable slot status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2130','10389','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2131','10389','{$ZYXEL.ADSL.ATN.MAX}','40','Type the maximum signal attenuation','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2132','10389','{$ZYXEL.ADSL.SNR.MIN}','8','Type the minimum signal to noise margin (0-31 dB)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2133','10389','{$ZYXEL.LLD.FILTER..SLOT.STATUS.NOT_MATCHES}','1','Filter to exclude discovered slots by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2134','10389','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2135','10389','{$ZYXEL.LLD.FILTER.IF.DESC.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2136','10389','{$ZYXEL.LLD.FILTER.IF.DESC.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2137','10389','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}','.*','Filter of discoverable link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2138','10389','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}','2','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2139','10389','{$ZYXEL.LLD.FILTER.SLOT.STATUS.MATCHES}','.*','Filter by discoverable slot status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2140','10390','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2141','10390','{$ZYXEL.ADSL.ATN.MAX}','40','Type the maximum signal attenuation','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2142','10390','{$ZYXEL.ADSL.SNR.MIN}','8','Type the minimum signal to noise margin (0-31 dB)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2143','10390','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2144','10390','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}','.*','Filter of discoverable link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2145','10390','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}','2','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2146','10391','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2147','10391','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2148','10391','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2149','10391','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2150','10391','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2151','10391','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2152','10391','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2153','10391','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2154','10391','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2155','10391','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2156','10391','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2157','10391','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2158','10392','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2159','10392','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2160','10392','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2161','10392','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2162','10392','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2163','10392','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2164','10392','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2165','10392','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2166','10392','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2167','10392','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2168','10392','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2169','10392','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2170','10392','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2171','10393','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2172','10393','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2173','10393','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2174','10393','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2175','10393','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2176','10393','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2177','10393','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2178','10393','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2179','10393','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2180','10393','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2181','10393','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2182','10393','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2183','10393','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2184','10394','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2185','10394','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2186','10394','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2187','10394','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2188','10394','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2189','10394','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2190','10394','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2191','10394','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2192','10394','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2193','10394','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2194','10394','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2195','10394','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2196','10395','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2197','10395','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2198','10395','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2199','10395','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2200','10395','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2201','10395','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2202','10395','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2203','10395','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2204','10395','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2205','10395','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2206','10395','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2207','10395','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2208','10396','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2209','10396','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2210','10396','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2211','10396','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2212','10396','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2|3|4','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link
3 - XFP
4 - CX4','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2213','10396','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2214','10396','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2215','10396','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2216','10396','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2217','10396','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2218','10396','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2219','10396','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2220','10396','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2221','10397','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2222','10397','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2223','10397','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2224','10397','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2225','10397','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2|3|4','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link
3 - XFP
4 - CX4','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2226','10397','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2227','10397','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2228','10397','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2229','10397','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2230','10397','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2231','10397','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2232','10397','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2233','10397','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2234','10398','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2235','10398','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2236','10398','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2237','10398','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','NEED TRIGGERS','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2238','10398','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2239','10398','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2240','10398','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2241','10398','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2242','10398','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2243','10398','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2244','10398','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2245','10398','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2246','10398','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2247','10399','{$NGINX.API.ENDPOINT}','','NGINX Plus API URL in the format `<scheme>://<host>:<port>/<location>/`','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2248','10399','{$NGINX.DROP_RATE.MAX.WARN}','1','The critical rate of the dropped connections for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2249','10399','{$NGINX.HTTP.UPSTREAM.4XX.MAX.WARN}','5','Maximum percentage of errors with status code 4xx (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2250','10399','{$NGINX.HTTP.UPSTREAM.5XX.MAX.WARN}','5','Maximum percentage of errors with status code 4xx (for trigger expression).','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2251','10399','{$NGINX.LLD.FILTER.HTTP.LOCATION.ZONE.MATCHES}','.*','Filter of discoverable HTTP location zones','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2252','10399','{$NGINX.LLD.FILTER.HTTP.LOCATION.ZONE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered HTTP location zones','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2253','10399','{$NGINX.LLD.FILTER.HTTP.UPSTREAM.MATCHES}','.*','Filter of discoverable HTTP upstreams','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2254','10399','{$NGINX.LLD.FILTER.HTTP.UPSTREAM.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered HTTP upstreams','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2255','10399','{$NGINX.LLD.FILTER.HTTP.ZONE.MATCHES}','.*','Filter of discoverable HTTP server zones','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2256','10399','{$NGINX.LLD.FILTER.HTTP.ZONE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered HTTP server zones','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2257','10399','{$NGINX.LLD.FILTER.RESOLVER.MATCHES}','.*','Filter of discoverable Resolvers','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2258','10399','{$NGINX.LLD.FILTER.RESOLVER.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered Resolvers','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2259','10399','{$NGINX.LLD.FILTER.STREAM.UPSTREAM.MATCHES}','.*','Filter of discoverable Stream upstreams','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2260','10399','{$NGINX.LLD.FILTER.STREAM.UPSTREAM.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered Stream upstreams','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2261','10399','{$NGINX.LLD.FILTER.STREAM.ZONE.MATCHES}','.*','Filter of discoverable Stream server zones','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2262','10399','{$NGINX.LLD.FILTER.STREAM.ZONE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered Stream server zones','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2263','10400','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT}','2','The cache battery critical state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2264','10400','{$DISK.ARRAY.CACHE.BATTERY.STATUS.OK}','1','The cache battery normal state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2265','10400','{$DISK.ARRAY.STATUS.CRIT:"inoperable"}','2','The array controller critical state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2266','10400','{$DISK.ARRAY.STATUS.OK:"operable"}','1','The array controller normal state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2267','10400','{$DISK.ARRAY.STATUS.WARN:"degraded"}','3','The array controller warning state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2268','10400','{$DISK.STATUS.CRIT:"bad"}','16','The disk critical state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2269','10400','{$DISK.STATUS.CRIT:"predictiveFailure"}','11','The disk critical state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2270','10400','{$DISK.STATUS.FAIL:"failed"}','9','The disk fail state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2271','10400','{$FAN.STATUS.CRIT:"inoperable"}','2','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2272','10400','{$FAN.STATUS.WARN:"degraded"}','3','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2273','10400','{$HEALTH.STATUS.CRIT:"computeFailed"}','30','The unit health critical state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2274','10400','{$HEALTH.STATUS.CRIT:"configFailure"}','33','The unit health critical state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2275','10400','{$HEALTH.STATUS.CRIT:"inoperable"}','60','The unit health critical state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2276','10400','{$HEALTH.STATUS.CRIT:"unconfigFailure"}','34','The unit health critical state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2277','10400','{$HEALTH.STATUS.WARN:"diagnosticsFailed"}','204','The unit health warning state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2278','10400','{$HEALTH.STATUS.WARN:"powerProblem"}','62','The unit health warning state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2279','10400','{$HEALTH.STATUS.WARN:"testFailed"}','35','The unit health warning state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2280','10400','{$HEALTH.STATUS.WARN:"thermalProblem"}','60','The unit health warning state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2281','10400','{$HEALTH.STATUS.WARN:"voltageProblem"}','62','The unit health warning state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2282','10400','{$IF.ERRORS.WARN}','2','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2283','10400','{$IFCONTROL}','1','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2284','10400','{$NET.IFADMINSTATUS.MATCHES}','^.*','This macro is used in network interface discovery. Can be overridden on the host level. Ignore notPresent(6) by default.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2285','10400','{$NET.IFADMINSTATUS.NOT_MATCHES}','^2$','This macro is used in network interface discovery. Can be overridden on the host level. Ignore down(2) administrative status by default.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2286','10400','{$NET.IFALIAS.MATCHES}','.*','This macro is used in network interface discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2287','10400','{$NET.IFALIAS.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in network interface discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2288','10400','{$NET.IFDESCR.MATCHES}','.*','This macro is used in network interface discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2289','10400','{$NET.IFDESCR.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in network interface discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2290','10400','{$NET.IFNAME.MATCHES}','^.*$','This macro is used in network interface discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2291','10400','{$NET.IFNAME.NOT_MATCHES}','(^Software Loopback Interface|^NULL[0-9.]*$|^[Ll]o[0-9.]*$|^[Ss]ystem$|^Nu[0-9.]*$|^veth[0-9a-z]+$|docker[0-9]+|br-[a-z0-9]{12}|sup-fc0)','This macro is used in network interface discovery. Can be overridden on the host level. Filter out loopbacks, sup-fc0, nulls, docker veth links and docker0 bridge by default.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2292','10400','{$NET.IFOPERSTATUS.MATCHES}','^.*$','This macro is used in network interface discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2293','10400','{$NET.IFOPERSTATUS.NOT_MATCHES}','^6$','This macro is used in network interface discovery. Can be overridden on the host level. Ignore notPresent(6) by default.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2294','10400','{$NET.IFTYPE.MATCHES}','.*','This macro is used in network interface discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2295','10400','{$NET.IFTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','This macro is used in network interface discovery. Can be overridden on the host level.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2296','10400','{$PSU.STATUS.CRIT:"inoperable"}','2','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2297','10400','{$PSU.STATUS.WARN:"degraded"}','3','The warning value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2298','10400','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2299','10400','{$TEMP.MAX.CRIT:"Ambient"}','35','The temperature maximum critical value for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2300','10400','{$TEMP.MAX.WARN:"Ambient"}','30','The temperature maximum warning value for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2301','10400','{$VDISK.STATUS.OK:"equipped"}','10','The vdisk normal state for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2306','10402','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT}','3','The critical status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2307','10402','{$DISK.ARRAY.CACHE.BATTERY.STATUS.OK}','2','The OK status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2308','10402','{$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN}','4','The warning status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2309','10402','{$DISK.ARRAY.STATUS.CRIT}','5','The critical status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2310','10402','{$DISK.ARRAY.STATUS.FAIL}','6','The disaster status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2311','10402','{$DISK.ARRAY.STATUS.WARN}','4','The warning status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2312','10402','{$DISK.SMART.STATUS.FAIL}','1','The critical S.M.A.R.T status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2313','10402','{$DISK.STATUS.FAIL:"critical"}','5','The critical status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2314','10402','{$DISK.STATUS.FAIL:"nonRecoverable"}','6','The critical status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2315','10402','{$DISK.STATUS.WARN:"nonCritical"}','4','The warning status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2316','10402','{$FAN.STATUS.CRIT:"criticalLower"}','8','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2317','10402','{$FAN.STATUS.CRIT:"criticalUpper"}','5','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2318','10402','{$FAN.STATUS.CRIT:"failed"}','10','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2319','10402','{$FAN.STATUS.CRIT:"nonRecoverableLower"}','9','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2320','10402','{$FAN.STATUS.CRIT:"nonRecoverableUpper"}','6','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2321','10402','{$FAN.STATUS.WARN:"nonCriticalLower"}','7','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2322','10402','{$FAN.STATUS.WARN:"nonCriticalUpper"}','4','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2323','10402','{$HEALTH.STATUS.CRIT}','5','The critical status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2324','10402','{$HEALTH.STATUS.DISASTER}','6','The disaster status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2325','10402','{$HEALTH.STATUS.WARN}','4','The warning status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2326','10402','{$PSU.STATUS.CRIT:"critical"}','5','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2327','10402','{$PSU.STATUS.CRIT:"nonRecoverable"}','6','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2328','10402','{$PSU.STATUS.WARN:"nonCritical"}','4','The warning value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2329','10402','{$SENSOR.TEMP.STATUS.CRIT:"criticalLower"}','8','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2330','10402','{$SENSOR.TEMP.STATUS.CRIT:"criticalUpper"}','5','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2331','10402','{$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableLower"}','9','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2332','10402','{$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableUpper"}','6','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2333','10402','{$SENSOR.TEMP.STATUS.OK}','3','The OK status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2334','10402','{$SENSOR.TEMP.STATUS.WARN:"nonCriticalLower"}','7','The warning status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2335','10402','{$SENSOR.TEMP.STATUS.WARN:"nonCriticalUpper"}','4','The warning status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2336','10402','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2337','10402','{$VDISK.STATUS.CRIT:"failed"}','3','The critical status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2338','10402','{$VDISK.STATUS.WARN:"degraded"}','4','The warning status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2343','10404','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT}','3','The critical status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2344','10404','{$DISK.ARRAY.CACHE.BATTERY.STATUS.OK}','2','The OK status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2345','10404','{$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN}','4','The warning status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2346','10404','{$DISK.ARRAY.STATUS.CRIT}','5','The critical status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2347','10404','{$DISK.ARRAY.STATUS.FAIL}','6','The disaster status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2348','10404','{$DISK.ARRAY.STATUS.WARN}','4','The warning status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2349','10404','{$DISK.SMART.STATUS.FAIL}','1','The critical S.M.A.R.T status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2350','10404','{$DISK.STATUS.FAIL:"critical"}','5','The critical status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2351','10404','{$DISK.STATUS.FAIL:"nonRecoverable"}','6','The critical status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2352','10404','{$DISK.STATUS.WARN:"nonCritical"}','4','The warning status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2353','10404','{$FAN.STATUS.CRIT:"criticalLower"}','8','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2354','10404','{$FAN.STATUS.CRIT:"criticalUpper"}','5','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2355','10404','{$FAN.STATUS.CRIT:"failed"}','10','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2356','10404','{$FAN.STATUS.CRIT:"nonRecoverableLower"}','9','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2357','10404','{$FAN.STATUS.CRIT:"nonRecoverableUpper"}','6','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2358','10404','{$FAN.STATUS.WARN:"nonCriticalLower"}','7','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2359','10404','{$FAN.STATUS.WARN:"nonCriticalUpper"}','4','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2360','10404','{$HEALTH.STATUS.CRIT}','5','The critical status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2361','10404','{$HEALTH.STATUS.DISASTER}','6','The disaster status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2362','10404','{$HEALTH.STATUS.WARN}','4','The warning status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2363','10404','{$PSU.STATUS.CRIT:"critical"}','5','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2364','10404','{$PSU.STATUS.CRIT:"nonRecoverable"}','6','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2365','10404','{$PSU.STATUS.WARN:"nonCritical"}','4','The warning value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2366','10404','{$SENSOR.TEMP.STATUS.CRIT:"criticalLower"}','8','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2367','10404','{$SENSOR.TEMP.STATUS.CRIT:"criticalUpper"}','5','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2368','10404','{$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableLower"}','9','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2369','10404','{$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableUpper"}','6','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2370','10404','{$SENSOR.TEMP.STATUS.OK}','3','The OK status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2371','10404','{$SENSOR.TEMP.STATUS.WARN:"nonCriticalLower"}','7','The warning status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2372','10404','{$SENSOR.TEMP.STATUS.WARN:"nonCriticalUpper"}','4','The warning status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2373','10404','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2374','10404','{$VDISK.STATUS.CRIT:"failed"}','3','The critical status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2375','10404','{$VDISK.STATUS.WARN:"degraded"}','4','The warning status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2380','10406','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT}','3','The critical status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2381','10406','{$DISK.ARRAY.CACHE.BATTERY.STATUS.OK}','2','The OK status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2382','10406','{$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN}','4','The warning status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2383','10406','{$DISK.ARRAY.STATUS.CRIT}','5','The critical status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2384','10406','{$DISK.ARRAY.STATUS.FAIL}','6','The disaster status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2385','10406','{$DISK.ARRAY.STATUS.WARN}','4','The warning status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2386','10406','{$DISK.SMART.STATUS.FAIL}','1','The critical S.M.A.R.T status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2387','10406','{$DISK.STATUS.FAIL:"critical"}','5','The critical status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2388','10406','{$DISK.STATUS.FAIL:"nonRecoverable"}','6','The critical status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2389','10406','{$DISK.STATUS.WARN:"nonCritical"}','4','The warning status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2390','10406','{$FAN.STATUS.CRIT:"criticalLower"}','8','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2391','10406','{$FAN.STATUS.CRIT:"criticalUpper"}','5','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2392','10406','{$FAN.STATUS.CRIT:"failed"}','10','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2393','10406','{$FAN.STATUS.CRIT:"nonRecoverableLower"}','9','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2394','10406','{$FAN.STATUS.CRIT:"nonRecoverableUpper"}','6','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2395','10406','{$FAN.STATUS.WARN:"nonCriticalLower"}','7','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2396','10406','{$FAN.STATUS.WARN:"nonCriticalUpper"}','4','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2397','10406','{$HEALTH.STATUS.CRIT}','5','The critical status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2398','10406','{$HEALTH.STATUS.DISASTER}','6','The disaster status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2399','10406','{$HEALTH.STATUS.WARN}','4','The warning status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2400','10406','{$PSU.STATUS.CRIT:"critical"}','5','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2401','10406','{$PSU.STATUS.CRIT:"nonRecoverable"}','6','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2402','10406','{$PSU.STATUS.WARN:"nonCritical"}','4','The warning value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2403','10406','{$SENSOR.TEMP.STATUS.CRIT:"criticalLower"}','8','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2404','10406','{$SENSOR.TEMP.STATUS.CRIT:"criticalUpper"}','5','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2405','10406','{$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableLower"}','9','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2406','10406','{$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableUpper"}','6','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2407','10406','{$SENSOR.TEMP.STATUS.OK}','3','The OK status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2408','10406','{$SENSOR.TEMP.STATUS.WARN:"nonCriticalLower"}','7','The warning status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2409','10406','{$SENSOR.TEMP.STATUS.WARN:"nonCriticalUpper"}','4','The warning status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2410','10406','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2411','10406','{$VDISK.STATUS.CRIT:"failed"}','3','The critical status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2412','10406','{$VDISK.STATUS.WARN:"degraded"}','4','The warning status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2417','10408','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT}','3','The critical status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2418','10408','{$DISK.ARRAY.CACHE.BATTERY.STATUS.OK}','2','The OK status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2419','10408','{$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN}','4','The warning status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2420','10408','{$DISK.ARRAY.STATUS.CRIT}','5','The critical status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2421','10408','{$DISK.ARRAY.STATUS.FAIL}','6','The disaster status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2422','10408','{$DISK.ARRAY.STATUS.WARN}','4','The warning status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2423','10408','{$DISK.SMART.STATUS.FAIL}','1','The critical S.M.A.R.T status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2424','10408','{$DISK.STATUS.FAIL:"critical"}','5','The critical status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2425','10408','{$DISK.STATUS.FAIL:"nonRecoverable"}','6','The critical status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2426','10408','{$DISK.STATUS.WARN:"nonCritical"}','4','The warning status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2427','10408','{$FAN.STATUS.CRIT:"criticalLower"}','8','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2428','10408','{$FAN.STATUS.CRIT:"criticalUpper"}','5','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2429','10408','{$FAN.STATUS.CRIT:"failed"}','10','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2430','10408','{$FAN.STATUS.CRIT:"nonRecoverableLower"}','9','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2431','10408','{$FAN.STATUS.CRIT:"nonRecoverableUpper"}','6','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2432','10408','{$FAN.STATUS.WARN:"nonCriticalLower"}','7','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2433','10408','{$FAN.STATUS.WARN:"nonCriticalUpper"}','4','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2434','10408','{$HEALTH.STATUS.CRIT}','5','The critical status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2435','10408','{$HEALTH.STATUS.DISASTER}','6','The disaster status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2436','10408','{$HEALTH.STATUS.WARN}','4','The warning status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2437','10408','{$PSU.STATUS.CRIT:"critical"}','5','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2438','10408','{$PSU.STATUS.CRIT:"nonRecoverable"}','6','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2439','10408','{$PSU.STATUS.WARN:"nonCritical"}','4','The warning value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2440','10408','{$SENSOR.TEMP.STATUS.CRIT:"criticalLower"}','8','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2441','10408','{$SENSOR.TEMP.STATUS.CRIT:"criticalUpper"}','5','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2442','10408','{$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableLower"}','9','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2443','10408','{$SENSOR.TEMP.STATUS.CRIT:"nonRecoverableUpper"}','6','The critical status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2444','10408','{$SENSOR.TEMP.STATUS.OK}','3','The OK status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2445','10408','{$SENSOR.TEMP.STATUS.WARN:"nonCriticalLower"}','7','The warning status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2446','10408','{$SENSOR.TEMP.STATUS.WARN:"nonCriticalUpper"}','4','The warning status of the temperature probe for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2447','10408','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2448','10408','{$VDISK.STATUS.CRIT:"failed"}','3','The critical status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2449','10408','{$VDISK.STATUS.WARN:"degraded"}','4','The warning status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2450','10409','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"capacitorFailed"}','7','The critical status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2451','10409','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"failed"}','4','The critical status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2452','10409','{$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN:"degraded"}','5','The warning status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2453','10409','{$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN:"notPresent"}','6','The warning status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2454','10409','{$DISK.ARRAY.CACHE.STATUS.CRIT:"cacheModCriticalFailure"}','8','The critical status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2455','10409','{$DISK.ARRAY.CACHE.STATUS.OK:"enabled"}','3','The normal status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2456','10409','{$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModDegradedFailsafeSpeed"}','7','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2457','10409','{$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModFlashMemNotAttached"}','6','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2458','10409','{$DISK.ARRAY.CACHE.STATUS.WARN:"cacheReadCacheNotMapped"}','9','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2459','10409','{$DISK.ARRAY.CACHE.STATUS.WARN:"invalid"}','2','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2460','10409','{$DISK.ARRAY.STATUS.CRIT}','4','The critical status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2461','10409','{$DISK.ARRAY.STATUS.WARN}','3','The warning status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2462','10409','{$DISK.SMART.STATUS.FAIL:"replaceDrive"}','3','The critical S.M.A.R.T status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2463','10409','{$DISK.SMART.STATUS.FAIL:"replaceDriveSSDWearOut"}','4','The critical S.M.A.R.T status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2464','10409','{$DISK.STATUS.FAIL}','3','The critical status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2465','10409','{$DISK.STATUS.WARN}','4','The warning status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2466','10409','{$FAN.STATUS.CRIT}','4','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2467','10409','{$FAN.STATUS.WARN}','3','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2468','10409','{$HEALTH.STATUS.CRIT}','4','The critical status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2469','10409','{$HEALTH.STATUS.WARN}','3','The warning status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2470','10409','{$PSU.STATUS.CRIT}','4','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2471','10409','{$PSU.STATUS.WARN}','3','The warning value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2472','10409','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2473','10409','{$VDISK.STATUS.CRIT}','3','The critical status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2474','10409','{$VDISK.STATUS.OK}','2','The normal status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2475','10410','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"capacitorFailed"}','7','The critical status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2476','10410','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"failed"}','4','The critical status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2477','10410','{$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN:"degraded"}','5','The warning status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2478','10410','{$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN:"notPresent"}','6','The warning status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2479','10410','{$DISK.ARRAY.CACHE.STATUS.CRIT:"cacheModCriticalFailure"}','8','The critical status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2480','10410','{$DISK.ARRAY.CACHE.STATUS.OK:"enabled"}','3','The normal status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2481','10410','{$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModDegradedFailsafeSpeed"}','7','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2482','10410','{$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModFlashMemNotAttached"}','6','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2483','10410','{$DISK.ARRAY.CACHE.STATUS.WARN:"cacheReadCacheNotMapped"}','9','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2484','10410','{$DISK.ARRAY.CACHE.STATUS.WARN:"invalid"}','2','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2485','10410','{$DISK.ARRAY.STATUS.CRIT}','4','The critical status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2486','10410','{$DISK.ARRAY.STATUS.WARN}','3','The warning status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2487','10410','{$DISK.SMART.STATUS.FAIL:"replaceDrive"}','3','The critical S.M.A.R.T status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2488','10410','{$DISK.SMART.STATUS.FAIL:"replaceDriveSSDWearOut"}','4','The critical S.M.A.R.T status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2489','10410','{$DISK.STATUS.FAIL}','3','The critical status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2490','10410','{$DISK.STATUS.WARN}','4','The warning status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2491','10410','{$FAN.STATUS.CRIT}','4','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2492','10410','{$FAN.STATUS.WARN}','3','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2493','10410','{$HEALTH.STATUS.CRIT}','4','The critical status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2494','10410','{$HEALTH.STATUS.WARN}','3','The warning status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2495','10410','{$PSU.STATUS.CRIT}','4','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2496','10410','{$PSU.STATUS.WARN}','3','The warning value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2497','10410','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2498','10410','{$VDISK.STATUS.CRIT}','3','The critical status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2499','10410','{$VDISK.STATUS.OK}','2','The normal status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2500','10411','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"capacitorFailed"}','7','The critical status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2501','10411','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"failed"}','4','The critical status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2502','10411','{$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN:"degraded"}','5','The warning status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2503','10411','{$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN:"notPresent"}','6','The warning status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2504','10411','{$DISK.ARRAY.CACHE.STATUS.CRIT:"cacheModCriticalFailure"}','8','The critical status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2505','10411','{$DISK.ARRAY.CACHE.STATUS.OK:"enabled"}','3','The normal status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2506','10411','{$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModDegradedFailsafeSpeed"}','7','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2507','10411','{$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModFlashMemNotAttached"}','6','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2508','10411','{$DISK.ARRAY.CACHE.STATUS.WARN:"cacheReadCacheNotMapped"}','9','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2509','10411','{$DISK.ARRAY.CACHE.STATUS.WARN:"invalid"}','2','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2510','10411','{$DISK.ARRAY.STATUS.CRIT}','4','The critical status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2511','10411','{$DISK.ARRAY.STATUS.WARN}','3','The warning status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2512','10411','{$DISK.SMART.STATUS.FAIL:"replaceDrive"}','3','The critical S.M.A.R.T status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2513','10411','{$DISK.SMART.STATUS.FAIL:"replaceDriveSSDWearOut"}','4','The critical S.M.A.R.T status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2514','10411','{$DISK.STATUS.FAIL}','3','The critical status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2515','10411','{$DISK.STATUS.WARN}','4','The warning status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2516','10411','{$FAN.STATUS.CRIT}','4','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2517','10411','{$FAN.STATUS.WARN}','3','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2518','10411','{$HEALTH.STATUS.CRIT}','4','The critical status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2519','10411','{$HEALTH.STATUS.WARN}','3','The warning status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2520','10411','{$PSU.STATUS.CRIT}','4','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2521','10411','{$PSU.STATUS.WARN}','3','The warning value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2522','10411','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2523','10411','{$VDISK.STATUS.CRIT}','3','The critical status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2524','10411','{$VDISK.STATUS.OK}','2','The normal status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2525','10412','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"capacitorFailed"}','7','The critical status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2526','10412','{$DISK.ARRAY.CACHE.BATTERY.STATUS.CRIT:"failed"}','4','The critical status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2527','10412','{$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN:"degraded"}','5','The warning status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2528','10412','{$DISK.ARRAY.CACHE.BATTERY.STATUS.WARN:"notPresent"}','6','The warning status of the disk array cache battery for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2529','10412','{$DISK.ARRAY.CACHE.STATUS.CRIT:"cacheModCriticalFailure"}','8','The critical status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2530','10412','{$DISK.ARRAY.CACHE.STATUS.OK:"enabled"}','3','The normal status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2531','10412','{$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModDegradedFailsafeSpeed"}','7','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2532','10412','{$DISK.ARRAY.CACHE.STATUS.WARN:"cacheModFlashMemNotAttached"}','6','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2533','10412','{$DISK.ARRAY.CACHE.STATUS.WARN:"cacheReadCacheNotMapped"}','9','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2534','10412','{$DISK.ARRAY.CACHE.STATUS.WARN:"invalid"}','2','The warning status of the disk array cache for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2535','10412','{$DISK.ARRAY.STATUS.CRIT}','4','The critical status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2536','10412','{$DISK.ARRAY.STATUS.WARN}','3','The warning status of the disk array for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2537','10412','{$DISK.SMART.STATUS.FAIL:"replaceDrive"}','3','The critical S.M.A.R.T status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2538','10412','{$DISK.SMART.STATUS.FAIL:"replaceDriveSSDWearOut"}','4','The critical S.M.A.R.T status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2539','10412','{$DISK.STATUS.FAIL}','3','The critical status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2540','10412','{$DISK.STATUS.WARN}','4','The warning status of the disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2541','10412','{$FAN.STATUS.CRIT}','4','The critical value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2542','10412','{$FAN.STATUS.WARN}','3','The warning value of the FAN sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2543','10412','{$HEALTH.STATUS.CRIT}','4','The critical status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2544','10412','{$HEALTH.STATUS.WARN}','3','The warning status of the health for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2545','10412','{$PSU.STATUS.CRIT}','4','The critical value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2546','10412','{$PSU.STATUS.WARN}','3','The warning value of the PSU sensor for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2547','10412','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2548','10412','{$VDISK.STATUS.CRIT}','3','The critical status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2549','10412','{$VDISK.STATUS.OK}','2','The normal status of the virtual disk for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2553','10413','{$SYSTEMD.ACTIVESTATE.SERVICE.MATCHES}','active','Filter of systemd service units by active state','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2554','10413','{$SYSTEMD.ACTIVESTATE.SERVICE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter of systemd service units by active state','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2555','10413','{$SYSTEMD.ACTIVESTATE.SOCKET.MATCHES}','active','Filter of systemd socket units by active state','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2556','10413','{$SYSTEMD.ACTIVESTATE.SOCKET.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter of systemd socket units by active state','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2557','10413','{$SYSTEMD.NAME.SERVICE.MATCHES}','.*','Filter of systemd service units by name','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2558','10413','{$SYSTEMD.NAME.SERVICE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter of systemd service units by name','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2559','10413','{$SYSTEMD.NAME.SOCKET.MATCHES}','.*','Filter of systemd socket units by name','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2560','10413','{$SYSTEMD.NAME.SOCKET.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter of systemd socket units by name','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2561','10413','{$SYSTEMD.UNITFILESTATE.SERVICE.MATCHES}','enabled','Filter of systemd service units by unit file state','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2562','10413','{$SYSTEMD.UNITFILESTATE.SERVICE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter of systemd service units by unit file state','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2563','10413','{$SYSTEMD.UNITFILESTATE.SOCKET.MATCHES}','enabled','Filter of systemd socket units by unit file state','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2564','10413','{$SYSTEMD.UNITFILESTATE.SOCKET.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter of systemd socket units by unit file state','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2565','10414','{$GRIDGAIN.CHECKPOINT.PUSED.MAX.HIGH}','80','The maximum percent of checkpoint buffer utilization for high trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2566','10414','{$GRIDGAIN.CHECKPOINT.PUSED.MAX.WARN}','66','The maximum percent of checkpoint buffer utilization for warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2567','10414','{$GRIDGAIN.DATA.REGION.PUSED.MAX.HIGH}','90','The maximum percent of data region utilization for high trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2568','10414','{$GRIDGAIN.DATA.REGION.PUSED.MAX.WARN}','80','The maximum percent of data region utilization for warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2569','10414','{$GRIDGAIN.JOBS.QUEUE.MAX.WARN}','10','The maximum number of queued jobs for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2570','10414','{$GRIDGAIN.LLD.FILTER.CACHE.MATCHES}','.*','Filter of discoverable cache groups.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2571','10414','{$GRIDGAIN.LLD.FILTER.CACHE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered cache groups.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2572','10414','{$GRIDGAIN.LLD.FILTER.DATA.REGION.MATCHES}','.*','Filter of discoverable data regions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2573','10414','{$GRIDGAIN.LLD.FILTER.DATA.REGION.NOT_MATCHES}','^(sysMemPlc|TxLog)$','Filter to exclude discovered data regions.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2574','10414','{$GRIDGAIN.LLD.FILTER.THREAD.POOL.MATCHES}','.*','Filter of discoverable thread pools.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2575','10414','{$GRIDGAIN.LLD.FILTER.THREAD.POOL.NOT_MATCHES}','^(GridCallbackExecutor|GridRebalanceStripedExecutor|GridDataStreamExecutor|StripedExecutor)$','Filter to exclude discovered thread pools.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2576','10414','{$GRIDGAIN.PASSWORD}','<secret>','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2577','10414','{$GRIDGAIN.PME.DURATION.MAX.HIGH}','60000','The maximum PME duration in ms for high trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2578','10414','{$GRIDGAIN.PME.DURATION.MAX.WARN}','10000','The maximum PME duration in ms for warning trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2579','10414','{$GRIDGAIN.THREAD.QUEUE.MAX.WARN}','1000','Threshold for thread pool queue size. Can be used with thread pool name as context.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2580','10414','{$GRIDGAIN.THREADS.COUNT.MAX.WARN}','1000','The maximum number of running threads for trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2581','10414','{$GRIDGAIN.USER}','zabbix','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2582','10415','{$BIGIP.CERT.MIN}','7','Minimum number of days before certificate expiration.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2583','10415','{$BIGIP.CPU.UTIL.WARN.MAX}','85','The warning threshold of the CPU utilization in %.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2584','10415','{$BIGIP.CPU.UTIL.WARN.MIN}','65','The recovery threshold of the CPU utilization in %.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2585','10415','{$BIGIP.FS.FREE.WARN.MAX}','20','The recovery threshold of the file system utilization in %.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2586','10415','{$BIGIP.FS.FREE.WARN.MIN}','10','The warning threshold of the file system utilization in %.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2587','10415','{$BIGIP.LLD.FILTER.PART.NAME.MATCHES}','.*','Filter of discoverable mount point names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2588','10415','{$BIGIP.LLD.FILTER.PART.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by mount point names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2589','10415','{$BIGIP.MEMORY.UTIL.WARN.MAX}','85','The warning threshold of the memory utilization in %.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2590','10415','{$BIGIP.MEMORY.UTIL.WARN.MIN}','65','The recovery threshold of the memory utilization in %.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2591','10415','{$BIGIP.SWAP.UTIL.WARN.MAX}','85','The warning threshold of the swap utilization in %.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2592','10415','{$BIGIP.SWAP.UTIL.WARN.MIN}','65','The recovery threshold of the swap utilization in %.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2593','10415','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2594','10256','{$TEMP_CRIT_LOW}','5','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2595','10256','{$TEMP_CRIT}','60','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2596','10256','{$TEMP_WARN}','50','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2597','10416','{$CERT.EXPIRY.WARN}','7','Number of days until the certificate expires.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2598','10416','{$CERT.WEBSITE.HOSTNAME}','<Put DNS name>','The website DNS name for the connection.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2599','10416','{$CERT.WEBSITE.IP}','','The website IP address for the connection.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2600','10416','{$CERT.WEBSITE.PORT}','443','The TLS/SSL port number of the website.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2601','10417','{$CISCO.LLD.FILTER.IF.ADMIN.MATCHES}','1','Filter of discoverable interfaces by admin status.
1 - Up
2 - Down
3 - Testing','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2602','10417','{$CISCO.LLD.FILTER.IF.ADMIN.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by admin status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2603','10417','{$CISCO.LLD.FILTER.IF.CONTROL.MATCHES}','.*','Filter triggers by discoverable interface names.
Used in overrides. Triggers will only be created for interfaces whose names contain the value of the macro.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2604','10417','{$CISCO.LLD.FILTER.IF.DESC.MATCHES}','.*','Filter by discoverable interface description.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2605','10417','{$CISCO.LLD.FILTER.IF.DESC.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by description.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2606','10417','{$CISCO.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2607','10417','{$CISCO.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2608','10417','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2609','10417','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2610','10417','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2611','10418','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2612','10418','{$ZYXEL.ADSL.ATN.MAX}','40','Type the maximum signal attenuation','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2613','10418','{$ZYXEL.ADSL.SNR.MIN}','8','Type the minimum signal to noise margin (0-31 dB)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2614','10418','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2615','10418','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}','.*','Filter of discoverable link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2616','10418','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}','2','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2617','10419','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2618','10419','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2619','10419','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2620','10419','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2621','10419','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2622','10419','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2623','10419','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2624','10419','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2625','10419','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2626','10419','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2627','10419','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2628','10419','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2629','10419','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2630','10420','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2631','10420','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2632','10420','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2633','10420','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2634','10420','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2635','10420','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2636','10420','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2637','10421','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2638','10421','{$ZYXEL.ADSL.ATN.MAX}','40','Type the maximum signal attenuation','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2639','10421','{$ZYXEL.ADSL.SNR.MIN}','8','Type the minimum signal to noise margin (0-31 dB)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2640','10421','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2641','10421','{$ZYXEL.LLD.FILTER.IF.DESC.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2642','10421','{$ZYXEL.LLD.FILTER.IF.DESC.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2643','10421','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}','.*','Filter of discoverable link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2644','10421','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}','2','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2645','10421','{$ZYXEL.LLD.FILTER.SLOT.STATUS.MATCHES}','.*','Filter by discoverable slot status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2646','10421','{$ZYXEL.LLD.FILTER.SLOT.STATUS.NOT_MATCHES}','1','Filter to exclude discovered slots by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2647','10422','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2648','10422','{$ZYXEL.ADSL.ATN.MAX}','40','Type the maximum signal attenuation','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2649','10422','{$ZYXEL.ADSL.SNR.MIN}','8','Type the minimum signal to noise margin (0-31 dB)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2650','10422','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2651','10422','{$ZYXEL.LLD.FILTER.IF.DESC.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2652','10422','{$ZYXEL.LLD.FILTER.IF.DESC.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2653','10422','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}','.*','Filter of discoverable link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2654','10422','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}','2','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2655','10422','{$ZYXEL.LLD.FILTER.SLOT.STATUS.MATCHES}','.*','Filter by discoverable slot status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2656','10422','{$ZYXEL.LLD.FILTER.SLOT.STATUS.NOT_MATCHES}','1','Filter to exclude discovered slots by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2657','10423','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2658','10423','{$ZYXEL.ADSL.ATN.MAX}','40','Type the maximum signal attenuation','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2659','10423','{$ZYXEL.ADSL.SNR.MIN}','8','Type the minimum signal to noise margin (0-31 dB)','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2660','10423','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2661','10423','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}','.*','Filter of discoverable link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2662','10423','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}','2','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2663','10424','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2664','10424','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2665','10424','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2666','10424','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2667','10424','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2668','10424','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2669','10424','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2670','10424','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2671','10424','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2672','10424','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2673','10424','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2674','10424','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2675','10425','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2676','10425','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2677','10425','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2678','10425','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2679','10425','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2680','10425','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2681','10425','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2682','10425','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2683','10425','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2684','10425','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2685','10425','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2686','10425','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2687','10425','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2688','10426','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2689','10426','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2690','10426','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2691','10426','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2692','10426','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2693','10426','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2694','10426','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2695','10426','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2696','10426','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2697','10426','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2698','10426','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2699','10426','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2700','10426','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2701','10427','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2702','10427','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2703','10427','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2704','10427','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2705','10427','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2706','10427','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2707','10427','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2708','10427','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2709','10427','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2710','10427','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2711','10427','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2712','10427','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2713','10428','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2714','10428','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2715','10428','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2716','10428','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2717','10428','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2718','10428','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2719','10428','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2720','10428','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2721','10428','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2722','10428','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2723','10428','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2724','10428','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2725','10429','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2726','10429','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2727','10429','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2728','10429','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2729','10429','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2|3|4','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link
3 - XFP
4 - CX4','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2730','10429','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2731','10429','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2732','10429','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2733','10429','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2734','10429','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2735','10429','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2736','10429','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2737','10429','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2738','10430','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2739','10430','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2740','10430','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2741','10430','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2742','10430','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2|3|4','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link
3 - XFP
4 - CX4','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2743','10430','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2744','10430','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2745','10430','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2746','10430','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2747','10430','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2748','10430','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2749','10430','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2750','10430','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2751','10431','{$CPU.UTIL.CRIT}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2752','10431','{$MEMORY.UTIL.MAX}','90','','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2753','10431','{$SNMP.TIMEOUT}','5m','The time interval for SNMP agent availability trigger expression.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2754','10431','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}','CHANGE_IF_NEEDED','Triggers will be created only for interfaces whose description contains the value of this macro','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2755','10431','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}','1|2','Filter of discoverable link types.
0 - Down link
1 - Cooper link
2 - Fiber link','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2756','10431','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by link types.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2757','10431','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}','.*','Filter by discoverable interface names.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2758','10431','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered interfaces by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2759','10431','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}','1|2','Filter of discoverable status.
0 - OK with DDM
1 - OK without DDM
2 - nonoperational','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2760','10431','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}','CHANGE_IF_NEEDED','Filter to exclude discovered by status.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2761','10431','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}','.*','Filter by discoverable SFP modules name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2762','10431','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}','N/A','Filter to exclude discovered SFP modules by name.','0');
INSERT INTO hostmacro (hostmacroid,hostid,macro,value,description,type) values ('2763','10431','{$ZYXEL.LLD.SFP.UPDATE}','10m','Receiving data from the SFP module is slow, we do not recommend setting the interval less than 10 minutes.','0');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('92','10084','4');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('175','10093','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('176','10169','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('177','10095','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('178','10094','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('179','10096','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('180','10097','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('181','10098','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('182','10099','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('183','10100','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('184','10101','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('185','10102','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('186','10103','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('187','10050','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('188','10048','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('189','10047','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('190','10170','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('191','10076','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('192','10075','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('193','10077','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('194','10001','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('195','10079','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('196','10074','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('197','10078','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('198','10081','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('199','10171','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('200','10172','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('209','10183','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('211','10185','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('212','10186','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('214','10188','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('216','10190','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('218','10192','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('230','10204','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('233','10207','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('234','10208','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('235','10209','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('236','10210','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('237','10211','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('238','10212','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('239','10213','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('241','10215','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('242','10216','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('243','10217','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('244','10218','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('246','10220','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('247','10221','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('248','10222','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('249','10223','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('250','10224','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('252','10226','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('253','10227','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('255','10229','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('256','10230','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('257','10231','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('259','10233','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('260','10234','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('261','10235','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('262','10236','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('263','10237','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('274','10248','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('275','10249','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('276','10250','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('277','10251','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('278','10252','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('279','10253','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('280','10254','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('281','10255','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('282','10256','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('284','10258','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('285','10259','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('286','10260','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('287','10261','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('288','10262','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('289','10263','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('290','10264','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('291','10265','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('292','10266','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('293','10267','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('294','10268','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('295','10269','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('296','10270','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('297','10271','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('298','10272','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('299','10273','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('300','10274','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('301','10275','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('302','10276','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('303','10277','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('304','10278','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('305','10279','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('306','10280','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('307','10281','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('308','10282','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('309','10283','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('310','10284','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('311','10285','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('312','10286','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('313','10287','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('314','10288','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('315','10289','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('316','10290','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('317','10291','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('318','10292','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('319','10293','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('320','10294','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('321','10295','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('322','10296','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('323','10297','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('324','10298','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('325','10299','10');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('326','10300','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('327','10301','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('328','10302','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('329','10303','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('330','10304','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('331','10305','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('332','10306','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('333','10307','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('334','10308','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('335','10309','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('336','10310','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('340','10314','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('341','10315','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('342','10316','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('343','10317','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('344','10318','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('345','10319','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('346','10320','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('347','10321','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('348','10322','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('349','10323','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('350','10324','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('351','10325','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('352','10326','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('353','10327','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('354','10328','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('356','10330','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('357','10173','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('358','10174','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('359','10175','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('360','10333','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('361','10334','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('362','10335','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('363','10336','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('364','10337','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('366','10339','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('367','10340','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('368','10341','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('369','10342','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('370','10343','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('371','10344','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('372','10345','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('373','10346','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('374','10347','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('375','10348','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('376','10349','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('377','10350','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('378','10351','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('379','10352','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('380','10353','16');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('381','10354','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('382','10355','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('383','10356','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('384','10357','16');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('385','10358','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('386','10359','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('387','10360','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('388','10361','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('389','10362','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('390','10363','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('391','10366','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('392','10367','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('393','10368','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('394','10369','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('395','10370','8');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('396','10371','17');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('397','10372','16');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('398','10373','17');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('399','10374','17');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('400','10375','17');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('401','10376','17');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('402','10377','17');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('403','10378','17');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('404','10379','17');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('405','10380','17');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('406','10381','17');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('407','10382','17');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('408','10383','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('409','10384','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('410','10385','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('411','10386','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('412','10387','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('413','10388','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('414','10389','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('415','10390','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('416','10391','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('417','10392','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('418','10393','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('419','10394','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('420','10395','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('421','10396','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('422','10397','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('423','10398','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('424','10399','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('425','10400','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('427','10402','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('429','10404','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('431','10406','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('433','10408','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('434','10409','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('435','10410','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('436','10411','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('437','10412','11');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('438','10413','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('439','10414','13');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('440','10415','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('441','10416','12');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('442','10417','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('443','10418','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('444','10419','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('445','10420','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('446','10421','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('447','10422','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('448','10423','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('449','10424','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('450','10425','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('451','10426','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('452','10427','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('453','10428','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('454','10429','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('455','10430','9');
INSERT INTO hosts_groups (hostgroupid,hostid,groupid) values ('456','10431','9');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('4','10001','10050');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('31','10074','10050');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('32','10075','10050');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('33','10076','10050');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('34','10077','10050');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('35','10078','10050');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('36','10079','10050');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('37','10081','10050');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('38','10084','10047');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('39','10084','10001');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('134','10204','10186');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('135','10207','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('136','10207','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('137','10207','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('138','10208','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('139','10208','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('140','10210','10209');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('141','10210','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('142','10210','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('143','10211','10209');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('144','10211','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('145','10211','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('146','10218','10216');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('147','10218','10217');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('148','10218','10213');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('149','10218','10212');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('150','10218','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('151','10218','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('152','10218','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('159','10220','10216');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('160','10220','10217');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('161','10220','10212');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('162','10220','10215');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('163','10220','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('164','10221','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('165','10221','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('166','10221','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('167','10222','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('168','10222','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('169','10223','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('170','10223','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('171','10223','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('172','10224','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('173','10224','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('174','10224','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('178','10226','10188');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('179','10226','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('180','10226','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('181','10227','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('182','10227','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('183','10227','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('188','10229','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('189','10229','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('190','10229','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('191','10230','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('192','10230','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('193','10231','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('194','10231','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('195','10231','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('200','10233','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('201','10233','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('202','10234','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('203','10234','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('204','10235','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('205','10235','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('206','10235','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('207','10236','10188');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('208','10236','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('218','10250','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('219','10250','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('220','10250','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('224','10253','10216');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('225','10253','10217');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('226','10253','10212');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('227','10253','10252');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('228','10253','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('229','10253','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('230','10254','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('231','10254','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('232','10254','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('233','10255','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('234','10256','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('236','10258','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('237','10259','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('238','10248','10183');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('239','10248','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('240','10248','10190');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('241','10248','10270');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('242','10248','10269');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('243','10248','10271');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('244','10248','10268');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('245','10249','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('246','10249','10185');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('247','10249','10192');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('248','10001','10272');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('249','10001','10275');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('250','10001','10273');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('251','10001','10277');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('252','10001','10274');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('253','10001','10276');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('254','10284','10278');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('255','10284','10281');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('256','10284','10279');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('257','10284','10283');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('258','10284','10280');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('259','10284','10282');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('261','10081','10286');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('262','10081','10288');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('263','10081','10290');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('264','10081','10287');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('265','10081','10291');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('266','10081','10289');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('267','10299','10293');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('268','10299','10295');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('269','10299','10297');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('270','10299','10294');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('271','10299','10298');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('272','10299','10296');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('273','10299','10292');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('274','10284','10292');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('275','10304','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('276','10254','10185');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('277','10185','10305');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('278','10185','10306');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('279','10185','10307');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('283','10081','10314');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('284','10299','10315');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('285','10237','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('286','10237','10188');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('287','10173','10330');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('288','10174','10330');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('289','10175','10330');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('290','10331','10175');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('291','10332','10174');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('292','10353','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('293','10357','10204');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('294','10364','10362');
INSERT INTO hosts_templates (hosttemplateid,hostid,templateid) values ('295','10365','10362');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46596','740','28909');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46597','740','28910');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46598','740','28911');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46599','740','28912');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46600','1124','28913');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46601','740','28914');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46602','740','28915');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46603','740','28916');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46604','740','28917');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46605','740','28918');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46606','740','28919');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46607','740','28920');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46608','740','28921');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46609','740','28922');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46610','740','28923');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46611','740','28924');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46612','740','28925');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46613','740','28926');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46614','740','28927');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46615','740','28928');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46616','740','28929');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46617','740','28930');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46618','740','28931');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46619','740','28932');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46620','740','28933');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46621','740','28934');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46622','740','28935');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46623','740','28936');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46624','740','28937');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46625','740','28938');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46626','740','28939');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46627','740','28940');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46628','740','28941');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46629','740','28942');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46630','740','28943');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46631','740','28944');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46632','740','28945');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46633','740','28946');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46634','740','28947');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46635','740','28950');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46636','1124','28951');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46637','740','28952');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46638','740','28953');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('46639','740','28954');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95508','1264','29653');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95509','1264','29654');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95510','1263','29655');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95511','1263','29656');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95512','1263','29657');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95513','1263','29658');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95514','1263','29659');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95515','1263','29660');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95516','1264','29661');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95517','1263','29662');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95518','1262','29998');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95519','1262','29999');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95520','1263','29687');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95521','1263','29688');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95522','1263','29691');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95523','1263','29692');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95524','1263','29693');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95525','1263','29694');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95526','1263','29695');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95527','1263','29696');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95528','1263','29697');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95529','1263','29698');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95530','1263','29699');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95531','1263','29700');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95532','1263','29701');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95533','1261','30000');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95534','1261','30001');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95535','1261','30002');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95536','1261','30003');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95537','1261','30004');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95538','1261','30005');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95539','1261','30006');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95540','1261','30007');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95541','1261','30008');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95542','1261','30009');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95543','1261','30010');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95544','1261','30011');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95545','1261','30012');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95546','1261','30013');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95547','1261','30014');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95548','1261','30015');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95549','1261','30016');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95550','1261','30017');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95551','1261','30018');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95552','1261','30019');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95553','1261','30020');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95554','1261','30021');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95555','1261','30022');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95556','1261','30023');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95557','1263','30024');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95558','1263','30025');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95559','1266','29738');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95560','1266','29739');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95561','1268','29741');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95562','1267','29742');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95563','1267','29743');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95564','1267','29744');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95565','1268','29745');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95566','1268','30043');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95567','1265','29746');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95568','1265','29747');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95569','1265','29748');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95570','1265','29749');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95571','1265','29750');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95572','1265','29751');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95573','1265','29752');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95574','1265','29753');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95575','1265','29754');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95576','1265','29755');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95577','1265','29756');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95578','1265','29757');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95579','1265','29758');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95580','1265','29759');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95581','1265','29760');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95582','1265','29761');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95583','1265','29762');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95584','1265','29763');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95585','1265','29764');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95586','1265','29765');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95587','1265','29766');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95588','1265','29767');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95589','1265','29768');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95590','1265','29769');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95591','1267','29771');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95592','1267','29772');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95593','1267','29773');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95594','1267','29774');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95595','1267','29775');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95596','1267','29776');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95597','1267','29777');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95598','1267','29779');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95599','1267','29780');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95600','1267','29781');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95601','1267','29782');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95602','1267','29783');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95603','1267','29784');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95604','1267','30044');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('95605','1267','30045');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127344','1518','34207');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127345','1515','34208');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127346','1515','34209');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127347','1515','34210');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127348','1515','34211');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127349','1515','34212');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127350','1515','34213');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127351','1515','34214');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127352','1518','34215');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127353','1518','34216');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127354','1519','34237');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127355','1517','34238');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127356','1525','34239');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127357','1521','34240');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127358','1520','34241');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127359','1521','34242');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127360','1521','34243');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127361','1521','34244');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127362','1521','34245');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127363','1521','34246');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127364','1521','34247');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127365','1525','34248');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127366','1522','34255');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127367','1526','34281');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127368','1524','34282');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127369','1532','34283');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127370','1529','34284');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127371','1527','34285');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127372','1529','34286');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127373','1529','34287');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127374','1529','34288');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127375','1529','34289');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127376','1529','34290');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127377','1529','34291');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127378','1532','34292');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127379','1528','34297');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127380','1533','34315');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127381','1531','34316');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127382','1540','34317');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127383','1536','34318');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127384','1536','34319');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127385','1536','34320');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127386','1536','34321');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127387','1536','34322');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127388','1540','34323');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127389','1535','34335');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127390','1548','34384');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127391','1544','34385');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127392','1544','34386');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127393','1544','34387');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127394','1544','34388');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127395','1544','34389');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127396','1548','34390');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127397','1543','34402');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127398','1554','34451');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127399','1551','34452');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127400','1551','34453');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127401','1551','34454');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127402','1551','34455');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127403','1551','34456');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127404','1551','34457');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127405','1551','34458');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127406','1554','34459');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127407','1554','34460');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127408','1550','34466');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127409','1555','34483');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127410','1553','34484');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127411','1559','34485');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127412','1557','34486');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127413','1556','34487');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127414','1557','34488');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127415','1557','34489');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127416','1557','34490');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127417','1557','34491');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127418','1557','34492');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127419','1557','34493');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127420','1559','34494');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127421','1565','34523');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127422','1561','34524');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127423','1560','34525');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127424','1561','34526');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127425','1561','34527');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127426','1561','34528');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127427','1561','34529');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127428','1561','34530');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127429','1561','34531');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127430','1565','34532');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127431','1562','34539');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127432','1566','34565');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127433','1564','34566');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127434','1572','34567');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127435','1568','34568');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127436','1567','34569');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127437','1568','34570');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127438','1568','34571');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127439','1568','34572');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127440','1568','34573');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127441','1568','34574');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127442','1568','34575');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127443','1572','34576');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127444','1569','34583');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127445','1573','34609');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127446','1571','34610');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127447','1579','34611');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127448','1576','34612');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127449','1574','34613');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127450','1576','34614');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127451','1576','34615');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127452','1576','34616');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127453','1576','34617');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127454','1576','34618');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127455','1576','34619');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127456','1579','34620');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127457','1575','34627');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127458','1580','34653');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127459','1578','34654');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127460','1586','34655');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127461','1583','34656');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127462','1581','34657');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127463','1583','34658');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127464','1583','34659');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127465','1583','34660');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127466','1583','34661');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127467','1583','34662');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127468','1583','34663');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127469','1586','34664');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127470','1582','34671');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127471','1587','34697');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127472','1585','34698');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127473','1594','34699');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127474','1590','34700');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127475','1588','34701');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127476','1590','34702');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127477','1590','34703');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127478','1590','34704');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127479','1591','34705');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127480','1590','34706');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127481','1590','34707');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127482','1590','34708');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127483','1594','34709');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127484','1589','34716');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127485','1595','34742');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127486','1593','34743');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127487','1602','34744');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127488','1598','34745');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127489','1596','34746');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127490','1598','34747');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127491','1598','34748');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127492','1598','34749');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127493','1599','34750');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127494','1598','34751');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127495','1598','34752');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127496','1598','34753');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127497','1602','34754');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127498','1597','34761');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127499','1603','34787');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127500','1601','34788');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127501','1610','34789');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127502','1606','34790');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127503','1604','34791');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127504','1606','34792');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127505','1606','34793');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127506','1606','34794');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127507','1606','34795');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127508','1606','34796');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127509','1606','34797');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127510','1610','34798');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127511','1605','34806');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127512','1607','34807');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127513','1611','34833');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('127514','1609','34834');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129207','1116','28743');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129208','1116','28744');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129209','1116','28745');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129210','1116','28746');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129211','1116','28747');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129212','1116','28748');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129213','1117','30896');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129214','1116','30897');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129215','1116','30898');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129216','1116','30899');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129217','1116','30900');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129218','1116','30901');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129219','1116','30902');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129220','1116','30903');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129221','1116','30904');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129222','1116','30905');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129223','1116','30906');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129224','1116','30907');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129225','1116','30908');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129226','1116','30909');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129227','1116','30910');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129228','1116','30911');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129229','1116','30912');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129230','1116','30913');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129231','1116','30914');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129232','1116','30915');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129233','1116','30917');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129234','1116','30918');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129235','1116','30919');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129236','1116','30920');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129237','1116','30921');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129238','1116','30922');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129239','1119','28775');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129240','1118','28776');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129241','1118','28777');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129242','1118','28778');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129243','1118','28779');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129244','1118','28780');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129245','1118','28781');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129246','1118','28782');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129247','1118','28783');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129248','1118','28784');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129249','1118','28785');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129250','1118','28786');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129251','1118','28787');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129252','1118','28788');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129253','1118','28789');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129254','1118','28790');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129255','1118','28791');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129256','1118','28792');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129257','1118','28793');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129258','1118','28794');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129259','1118','28795');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129260','1118','28796');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129261','1118','28798');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129262','1118','28799');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129263','1118','28800');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129264','1118','28801');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129265','1118','28802');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129266','1118','28803');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129267','1349','31800');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129268','1349','31801');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129269','1349','31802');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129270','1348','31803');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129271','1349','31804');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129272','1348','31805');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129273','1348','31806');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129274','1348','31807');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129275','1348','31808');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129276','1348','31809');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129277','1348','31810');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129278','1348','31811');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129279','1348','31812');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129280','1348','31813');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129281','1348','31814');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129282','1348','31815');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129283','1348','31816');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129284','1348','31817');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129285','1348','31818');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129286','1348','31819');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129287','1348','31820');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129288','1348','31821');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129289','1348','31822');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129290','1348','31823');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129291','1348','31824');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129292','1348','31825');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129293','1348','31826');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129294','1348','31827');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129295','1348','31828');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129296','1348','31829');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129297','1348','31830');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129298','1348','31831');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129299','1348','31832');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129300','1348','31833');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129301','1348','31834');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129302','1348','31835');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129303','1348','31836');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129304','1348','31837');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129305','1348','31838');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129306','1348','31839');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129307','1348','31840');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129308','1348','31841');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129309','1348','31842');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129310','1348','31843');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129311','1348','31844');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129312','1348','31845');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129313','1348','31846');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129314','1348','31847');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129315','1348','31848');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129316','1348','31849');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129317','1348','31850');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129318','1753','35772');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129319','1752','35773');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129320','1752','35774');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129321','1752','35775');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129322','1752','35776');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129323','1752','35777');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129324','1752','35778');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129325','1752','35779');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129326','1752','35780');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129327','1752','35781');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129328','1752','35782');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129329','1752','35783');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129330','1752','35784');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129331','1319','30527');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129332','1319','30528');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129333','1319','30529');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129334','1318','30530');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129335','1319','30531');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129336','1318','30532');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129337','1318','30533');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129338','1318','30534');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129339','1318','30535');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129340','1318','30536');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129341','1318','30537');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129342','1318','30538');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129343','1318','30539');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129344','1318','30540');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129345','1318','30541');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129346','1318','30542');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129347','1318','30543');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129348','1318','30544');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129349','1318','30545');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129350','1318','30546');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129351','1318','30547');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129352','1318','30548');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129353','1318','30549');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129354','1318','30550');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129355','1318','30551');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129356','1318','30552');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129357','1318','30553');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129358','1318','30554');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129359','1318','30555');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129360','1318','30556');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129361','1318','30557');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129362','1318','30558');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129363','1318','30559');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129364','1318','30560');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129365','1318','30561');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129366','1318','30562');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129367','1318','30563');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129368','1318','30564');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129369','1318','30565');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129370','1318','30566');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129371','1318','30567');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129372','1318','30568');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129373','1318','30569');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129374','1318','30570');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129375','1326','30690');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129376','1327','30691');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129377','1326','30692');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129378','1327','30693');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129379','1327','30694');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129380','1326','30695');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129381','1326','30696');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129382','1326','30697');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129383','1326','30698');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129384','1326','30699');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129385','1326','30700');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129386','1326','30701');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129387','1326','30702');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129388','1326','30703');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129389','1326','30704');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129390','1326','30705');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129391','1326','30706');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129392','1326','30707');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129393','1326','30708');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129394','1326','30709');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129395','1326','30710');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129396','1326','30711');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129397','1326','30712');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129398','1327','30719');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129399','1327','30739');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129400','1327','30743');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129401','1327','30744');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129402','1327','30746');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129403','1327','30747');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129404','1327','30754');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129405','1327','30756');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129406','1331','30923');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129407','1331','30924');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129408','1332','30925');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129409','1332','30926');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129410','1331','30927');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129411','1331','30928');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129412','1331','30929');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129413','1331','30930');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129414','1331','30931');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129415','1331','30932');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129416','1331','30933');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129417','1331','30934');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129418','1331','30935');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129419','1331','30936');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129420','1331','30937');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129421','1331','30938');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129422','1331','30939');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129423','1331','30940');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129424','1331','30941');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129425','1331','30942');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129426','1331','30943');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129427','1331','30944');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129428','1331','30945');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129429','1331','30946');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129430','1331','30947');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129431','1331','30948');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129432','1331','30949');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129433','1331','30950');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129434','1331','30951');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129435','1331','30952');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129436','1331','30953');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129437','1331','30954');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129438','1331','30955');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129439','1331','30956');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129440','1331','30957');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129441','1331','30958');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129442','1331','30959');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129443','1331','30960');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129444','1331','30963');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129445','1411','32486');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129446','1411','32487');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129447','1411','32488');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129448','1411','32489');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129449','1411','32490');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129450','1411','32491');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129451','1411','32492');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129452','1411','32493');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129453','1411','32494');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129454','1411','32498');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129455','1411','32499');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129456','1411','32500');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129457','1412','32516');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129458','1412','32517');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129459','1412','32518');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129460','1412','32519');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129461','1412','32520');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129462','1412','32521');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129463','1412','32522');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129464','1412','32523');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129465','1412','32524');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129466','1412','32528');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129467','1412','32529');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129468','1412','32530');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129469','1341','31499');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129470','1341','31500');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129471','1341','31501');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129472','1341','31502');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129473','1341','31503');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129474','1341','31504');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129475','1341','31505');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129476','1341','31506');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129477','1341','31507');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129478','1341','31508');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129479','1341','31509');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129480','1341','31510');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129481','1341','31511');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129482','1341','31512');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129483','1341','31513');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129484','1341','31514');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129485','1341','31515');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129486','1341','31516');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129487','1341','31517');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129488','1341','31518');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129489','1341','31519');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129490','1341','31520');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129491','1341','31521');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129492','1341','31522');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129493','1341','31523');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129494','1341','31524');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129495','1341','31525');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129496','1341','31526');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129497','1341','31527');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129498','1341','31528');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129499','1341','31529');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129500','1341','31530');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129501','1341','31531');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129502','1341','31532');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129503','1341','31533');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129504','1341','31534');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129505','1341','31535');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129506','1341','31536');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129507','1341','31537');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129508','1341','31538');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129509','1341','31539');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129510','1341','31540');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129511','1341','31541');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129512','1341','31542');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129513','1341','31543');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129514','1341','31544');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129515','1341','31545');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129516','1341','31546');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129517','1341','31547');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129518','1341','31548');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129519','1341','31549');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129520','1341','31550');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129521','1341','31551');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129522','1341','31552');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129523','1341','31553');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129524','1358','32012');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129525','1358','32013');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129526','1357','32014');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129527','1357','32015');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129528','1357','32016');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129529','1358','32017');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129530','1357','32018');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129531','1358','32019');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129532','1357','32020');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129533','1357','32021');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129534','1357','32022');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129535','1357','32023');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129536','1357','32024');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129537','1357','32025');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129538','1357','32026');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129539','1357','32027');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129540','1357','32028');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129541','1357','32029');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129542','1357','32030');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129543','1357','32031');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129544','1357','32032');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129545','1357','32033');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129546','1357','32034');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129547','1357','32035');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129548','1357','32036');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129549','1357','32037');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129550','1357','32038');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129551','1357','32039');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129552','1357','32040');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129553','1357','32041');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129554','1357','32042');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129555','1357','32043');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129556','1357','32044');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129557','1357','32045');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129558','1358','32048');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129559','1358','32049');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129560','1299','35785');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129561','1298','30187');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129562','1298','30188');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129563','1299','30189');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129564','1299','30190');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129565','1298','30191');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129566','1298','30192');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129567','1301','35844');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129568','1301','30230');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129569','1301','30231');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129570','1300','30789');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129571','1300','30790');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129572','1300','30234');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129573','1300','30235');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129574','1333','30968');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129575','1333','30969');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129576','1333','30970');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129577','1333','30971');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129578','1333','30972');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129579','1333','30973');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129580','1333','30974');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129581','1333','30975');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129582','1333','30976');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129583','1333','30977');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129584','1333','30978');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129585','1333','30979');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129586','1333','30980');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129587','1333','30981');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129588','1333','30982');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129589','1333','30983');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129590','1333','30984');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129591','1333','30985');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129592','1333','30986');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129593','1333','30987');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129594','1333','30988');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129595','1333','30989');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129596','1333','30990');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129597','1333','30991');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129598','1333','30992');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129599','1333','30993');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129600','1333','30994');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129601','1333','30995');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129602','1333','30996');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129603','1333','30997');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129604','1333','30998');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129605','1333','30999');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129606','1333','31000');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129607','1333','31001');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129608','1333','31002');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129609','1333','31003');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129610','1333','31004');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129611','1334','31010');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129612','1334','31011');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129613','1334','31012');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129614','1334','31013');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129615','1334','31014');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129616','1334','31015');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129617','1334','31016');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129618','1334','31017');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129619','1334','31018');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129620','1334','31019');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129621','1334','31020');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129622','1334','31021');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129623','1334','31022');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129624','1334','31023');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129625','1334','31024');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129626','1334','31025');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129627','1334','31026');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129628','1334','31027');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129629','1334','31028');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129630','1334','31029');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129631','1334','31030');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129632','1334','31031');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129633','1334','31032');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129634','1334','31033');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129635','1334','31034');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129636','1334','31035');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129637','1334','31036');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129638','1334','31037');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129639','1334','31038');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129640','1334','31039');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129641','1334','31040');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129642','1334','31041');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129643','1334','31042');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129644','1334','31043');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129645','1334','31044');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129646','1334','31045');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129647','1334','31046');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129648','1359','32071');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129649','1359','32072');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129650','1359','32073');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129651','1359','32074');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129652','1359','32075');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129653','1359','32076');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129654','1359','32077');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129655','1359','32078');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129656','1359','32079');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129657','1359','32080');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129658','1359','32081');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129659','1359','32082');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129660','1359','32083');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129661','1359','32084');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129662','1359','32085');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129663','1359','32086');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129664','1359','32087');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129665','1359','32088');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129666','1359','32089');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129667','1359','32090');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129668','1359','32091');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129669','1359','32092');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129670','1359','32093');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129671','1359','32094');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129672','1359','32095');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129673','1359','32096');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129674','1359','32097');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129675','1359','32098');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129676','1359','32099');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129677','1359','32100');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129678','1359','32101');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129679','1359','32102');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129680','1359','32103');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129681','1359','32104');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129682','1359','32105');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129683','1359','32106');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129684','1359','32107');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129685','1359','32108');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129686','1359','32109');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129687','1359','32110');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129688','1359','32111');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129689','1359','32112');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129690','1359','32113');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129691','1359','32114');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129692','1359','32115');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129693','1359','32116');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129694','1359','32117');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129695','1359','32118');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129696','1359','32119');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129697','1359','32120');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129698','1359','32121');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129699','1359','32122');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129700','1359','32123');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129701','1359','32124');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129702','1359','32125');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129703','1359','32126');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129704','1359','32127');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129705','1359','32128');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129706','1359','32129');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129707','1359','32130');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129708','1359','32131');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129709','1359','32132');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129710','1320','30611');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129711','1321','30612');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129712','1320','30613');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129713','1320','30614');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129714','1320','30615');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129715','1320','30616');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129716','1320','30617');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129717','1320','30618');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129718','1320','30619');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129719','1320','30620');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129720','1320','30621');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129721','1320','30622');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129722','1320','30623');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129723','1320','30624');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129724','1320','30625');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129725','1320','30626');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129726','1320','30627');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129727','1320','30628');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129728','1320','30629');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129729','1320','30630');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129730','1320','30631');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129731','1320','30632');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129732','1320','30633');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129733','1320','30634');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129734','1320','30635');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129735','1320','30636');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129736','1121','28804');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129737','1120','28805');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129738','1120','28806');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129739','1120','28807');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129740','1120','28808');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129741','1120','28809');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129742','1120','28810');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129743','1120','28811');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129744','1120','28812');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129745','1120','28813');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129746','1120','28814');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129747','1120','28815');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129748','1120','28816');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129749','1120','28817');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129750','1120','28818');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129751','1120','28819');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129752','1120','28820');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129753','1123','28821');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129754','1122','28822');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129755','1122','28823');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129756','1122','28824');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129757','1122','28825');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129758','1122','28826');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129759','1122','28827');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129760','1122','28828');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129761','1122','28829');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129762','1122','28830');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129763','1122','28831');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129764','1122','28832');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129765','1122','28833');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129766','1613','34835');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129767','1613','34836');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129768','1613','34837');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129769','1613','34838');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129770','1613','34839');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129771','1613','34840');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129772','1613','34841');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129773','1613','34842');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129774','1613','34843');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129775','1613','34844');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129776','1612','34845');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129777','1612','34846');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129778','1612','34847');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129779','1612','34848');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129780','1612','34849');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129781','1612','34850');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129782','1612','34851');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129783','1612','34852');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129784','1612','34853');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129785','1612','34854');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129786','1612','34855');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129787','1612','34856');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129788','1612','34857');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129789','1612','34858');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129790','1351','31868');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129791','1351','31869');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129792','1350','31870');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129793','1350','31871');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129794','1350','31872');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129795','1350','31873');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129796','1350','31874');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129797','1350','31875');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129798','1350','31876');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129799','1350','31877');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129800','1350','31878');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129801','1350','31879');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129802','1350','31880');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129803','1350','31881');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129804','1350','31882');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129805','1350','31883');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129806','1350','31884');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129807','1350','31885');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129808','1350','31886');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129809','1350','31887');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129810','1350','31888');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129811','1350','31889');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129812','1350','31890');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129813','1352','31891');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129814','1353','31892');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129815','1353','31893');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129816','1352','31894');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129817','1352','31895');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129818','1352','31896');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129819','1352','31897');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129820','1352','31898');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129821','1352','31899');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129822','1352','31900');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129823','1352','31901');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129824','1352','31902');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129825','1352','31903');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129826','1352','31904');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129827','1352','31905');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129828','1352','31906');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129829','1352','31907');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129830','1352','31908');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129831','1352','31909');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129832','1426','32829');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129833','1426','32830');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129834','1427','32831');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129835','1427','32832');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129836','1428','32833');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129837','1428','32834');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129838','1428','32835');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129839','1427','32836');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129840','1427','32837');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129841','1427','32838');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129842','1427','32839');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129843','1425','32840');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129844','1425','32841');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129845','1425','32842');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129846','1425','32843');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129847','1425','32844');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129848','1425','32845');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129849','1425','32846');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129850','1425','32847');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129851','1425','32848');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129852','1425','32849');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129853','1425','32850');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129854','1425','32851');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129855','1425','32852');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129856','1425','32853');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129857','1425','32854');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129858','1425','32855');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129859','1425','32856');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129860','1425','32857');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129861','1425','32858');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129862','1425','32859');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129863','1425','32860');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129864','1425','32861');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129865','1425','32862');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129866','1425','32863');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129867','1427','32864');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129868','1427','32865');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129869','1427','32866');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129870','1427','32867');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129871','1427','32868');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129872','1427','32869');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129873','1427','32870');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129874','1427','32871');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129875','1427','32872');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129876','1427','32873');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129877','1427','32874');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129878','1427','32875');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129879','1427','32876');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129880','1427','32877');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129881','1427','32878');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129882','1425','32884');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129883','1427','32885');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129884','1427','32886');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129885','1427','32887');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129886','1427','32888');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129887','1427','32889');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129888','1427','32890');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129889','1430','32925');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129890','1430','32926');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129891','1431','32927');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129892','1432','32928');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129893','1432','32929');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129894','1432','32930');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129895','1431','32931');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129896','1429','32932');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129897','1429','32933');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129898','1429','32934');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129899','1429','32935');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129900','1429','32936');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129901','1429','32937');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129902','1429','32938');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129903','1429','32939');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129904','1429','32940');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129905','1429','32941');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129906','1429','32942');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129907','1429','32943');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129908','1429','32944');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129909','1429','32945');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129910','1429','32946');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129911','1429','32947');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129912','1429','32948');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129913','1429','32949');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129914','1429','32950');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129915','1429','32951');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129916','1429','32952');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129917','1429','32953');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129918','1429','32954');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129919','1429','32955');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129920','1431','32956');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129921','1431','32957');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129922','1431','32958');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129923','1431','32959');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129924','1431','32960');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129925','1431','32961');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129926','1431','32962');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129927','1431','32963');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129928','1431','32964');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129929','1431','32965');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129930','1431','32966');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129931','1431','32967');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129932','1431','32968');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129933','1431','32969');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129934','1431','32970');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129935','1429','32976');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129936','1431','32977');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129937','1431','32978');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129938','1431','32979');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129939','1431','32980');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129940','1431','32981');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129941','1431','32982');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129942','1354','31910');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129943','1354','31911');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129944','1354','31912');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129945','1354','31913');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129946','1354','31914');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129947','1354','31915');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129948','1354','31916');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129949','1354','31917');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129950','1354','31918');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129951','1354','31919');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129952','1354','31920');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129953','1354','31921');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129954','1354','31922');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129955','1354','31923');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129956','1354','31924');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129957','1354','31925');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129958','1354','31926');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129959','1354','31927');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129960','1354','31928');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129961','1354','31929');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129962','1354','31930');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129963','1354','31931');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129964','1354','31932');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129965','1354','31933');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129966','1354','31934');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129967','1354','31935');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129968','1354','31936');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129969','1354','31937');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129970','1354','31938');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129971','1354','31939');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129972','1354','31940');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129973','1354','31941');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129974','1354','31942');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129975','1354','31943');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129976','1354','31944');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129977','1354','31945');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129978','1354','31946');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129979','1354','31947');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129980','1354','31948');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129981','1354','31949');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129982','1354','31950');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129983','1354','31951');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129984','1354','31952');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129985','1354','31953');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129986','1354','31954');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129987','1354','31955');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129988','1354','31956');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129989','1354','31957');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129990','1354','31958');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129991','1354','31959');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129992','1354','31960');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129993','1354','31961');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129994','1354','31962');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129995','1354','31963');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129996','1737','35560');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129997','1737','35561');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129998','1109','28511');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('129999','1342','31554');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130000','1342','31555');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130001','1342','31556');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130002','1343','31557');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130003','1343','31558');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130004','1343','31559');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130005','1343','31560');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130006','1343','31561');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130007','1343','31562');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130008','1343','31563');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130009','1343','31564');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130010','1343','31565');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130011','1343','31566');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130012','1343','31567');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130013','1343','31568');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130014','1343','31569');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130015','1343','31570');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130016','1343','31571');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130017','1343','31572');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130018','1343','31573');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130019','1343','31574');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130020','1343','31575');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130021','1344','31576');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130022','1344','31577');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130023','1344','31578');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130024','1344','31579');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130025','1344','31580');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130026','1344','31581');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130027','1344','31582');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130028','1344','31583');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130029','1344','31584');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130030','1344','31585');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130031','1344','31586');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130032','1344','31587');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130033','1344','31588');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130034','1344','31589');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130035','1344','31590');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130036','1344','31591');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130037','1344','31592');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130038','1344','31593');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130039','1344','31594');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130040','1344','31595');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130041','1344','31596');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130042','1342','31605');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130043','1342','31606');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130044','1342','31607');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130045','1342','31608');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130046','1342','31609');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130047','1343','31610');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130048','1343','31611');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130049','1343','31612');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130050','1343','31613');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130051','1343','31614');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130052','1343','31615');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130053','1343','31616');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130054','1343','31617');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130055','1343','31618');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130056','1343','31619');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130057','1343','31620');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130058','1343','31621');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130059','1344','31622');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130060','1344','31623');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130061','1344','31624');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130062','1344','31625');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130063','1512','34094');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130064','1512','34095');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130065','1512','34096');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130066','1512','34097');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130067','1512','34098');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130068','1513','34106');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130069','1513','34107');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130070','1513','34108');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130071','1513','34109');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130072','1513','34110');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130073','1513','34111');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130074','1513','34112');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130075','1513','34113');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130076','1513','34114');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130077','1513','34115');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130078','1513','34116');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130079','1513','34117');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130080','1513','34118');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130081','1513','34119');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130082','1513','34120');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130083','1513','34121');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130084','1513','34122');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130085','179','10061');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130086','179','10062');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130087','179','10063');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130088','179','10064');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130089','179','10065');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130090','179','10066');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130091','179','22183');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130092','179','22185');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130093','179','22187');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130094','179','22189');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130095','179','22191');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130096','179','22196');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130097','179','22199');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130098','179','22219');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130099','179','22396');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130100','179','22399');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130101','179','22400');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130102','179','22401');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130103','179','22402');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130104','179','22404');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130105','179','22406');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130106','179','22408');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130107','179','22412');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130108','179','22414');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130109','179','22416');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130110','179','22418');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130111','179','22420');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130112','179','22422');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130113','179','22424');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130114','179','22426');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130115','179','22430');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130116','179','22689');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130117','179','23171');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130118','179','23251');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130119','179','23634');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130120','179','23661');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130121','179','23663');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130122','179','25366');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130123','179','25370');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130124','179','25665');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130125','179','25666');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130126','179','28248');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130127','179','28533');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130128','179','28535');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130129','179','28537');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130130','179','29822');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130131','179','34189');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130132','345','10073');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130133','345','10074');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130134','345','10075');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130135','345','10076');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130136','345','10077');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130137','345','10078');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130138','345','23252');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130139','345','23253');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130140','345','23255');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130141','345','23256');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130142','345','23257');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130143','345','23258');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130144','345','23259');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130145','345','23260');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130146','345','23261');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130147','345','23262');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130148','345','23264');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130149','345','23265');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130150','345','23266');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130151','345','23267');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130152','345','23268');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130153','345','23269');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130154','345','23270');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130155','345','23271');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130156','345','23272');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130157','345','23273');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130158','345','23274');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130159','345','23275');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130160','345','23276');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130161','345','23277');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130162','345','23328');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130163','345','23620');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130164','345','23625');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130165','345','23628');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130166','345','23635');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130167','345','23662');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130168','345','23664');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130169','345','25367');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130170','345','25371');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130171','345','25667');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130172','345','25668');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130173','345','28249');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130174','345','28534');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130175','345','28536');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130176','345','28538');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130177','345','29823');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130178','345','34196');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130179','1514','28539');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130180','1110','28540');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130181','1110','28541');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130182','1110','28542');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130183','1110','28543');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130184','1110','28544');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130185','1110','28545');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130186','1110','28546');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130187','1110','28547');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130188','1110','28548');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130189','1110','28549');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130190','1110','28550');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130191','1110','28551');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130192','1110','28552');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130193','1110','28553');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130194','1110','28554');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130195','1110','28555');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130196','1110','28556');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130197','1110','28557');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130198','1110','28558');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130199','1110','28559');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130200','1110','28560');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130201','1110','28561');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130202','1110','28562');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130203','1110','28563');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130204','1110','28564');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130205','1110','28565');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130206','1110','28566');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130207','1110','28567');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130208','1110','28568');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130209','1110','28569');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130210','1110','28570');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130211','1110','28571');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130212','1110','28572');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130213','1110','28573');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130214','1110','28574');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130215','1110','28575');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130216','1110','28576');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130217','1110','28577');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130218','1110','28578');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130219','1110','28579');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130220','1110','28580');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130221','1110','28581');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130222','1110','28582');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130223','1110','28583');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130224','1110','28584');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130225','1110','29821');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130226','1110','31053');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130227','1360','32158');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130228','1360','32159');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130229','1361','32160');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130230','1361','32161');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130231','1361','32162');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130232','1361','32163');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130233','1361','32164');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130234','1361','32165');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130235','1361','32166');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130236','1361','32167');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130237','1361','32168');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130238','1361','32169');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130239','1361','32170');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130240','1361','32171');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130241','1361','32172');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130242','1361','32173');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130243','1361','32174');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130244','1361','32175');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130245','1361','32176');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130246','1361','32177');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130247','1361','32178');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130248','1361','32179');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130249','1361','32180');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130250','1361','32181');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130251','1361','32182');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130252','1361','32183');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130253','1361','32184');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130254','1361','32185');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130255','1361','32186');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130256','1361','32187');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130257','1361','32188');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130258','1361','32189');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130259','1361','32190');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130260','1361','32191');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130261','1361','32192');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130262','1361','32201');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130263','1361','32202');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130264','1361','32203');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130265','1361','32204');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130266','1361','32205');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130267','1361','32206');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130268','446','23644');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130269','447','23645');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130270','448','23646');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130271','449','23647');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130272','450','23648');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130273','451','23649');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130274','452','23650');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130275','453','23651');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130276','1111','28585');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130277','1111','28586');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130278','1111','28587');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130279','1111','28588');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130280','1111','28589');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130281','1111','28590');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130282','1111','28591');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130283','1111','28592');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130284','1111','28593');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130285','1111','28594');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130286','1111','28595');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130287','1111','28596');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130288','1111','28597');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130289','1111','28598');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130290','1111','28599');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130291','1111','28600');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130292','1111','28601');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130293','1111','28602');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130294','1111','28603');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130295','1111','28604');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130296','1111','28605');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130297','1111','28606');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130298','1111','28607');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130299','1111','28608');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130300','1111','28609');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130301','1111','28610');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130302','1111','28611');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130303','1111','28612');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130304','1111','28613');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130305','1111','28614');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130306','1111','28615');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130307','1111','28616');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130308','1111','31052');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130309','454','23652');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130310','455','23653');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130311','456','23654');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130312','356','10067');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130313','356','10068');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130314','356','10069');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130315','356','10070');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130316','356','10071');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130317','356','10072');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130318','356','23340');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130319','356','23341');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130320','356','23342');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130321','356','23343');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130322','356','23344');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130323','356','23345');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130324','356','23346');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130325','356','23347');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130326','356','23348');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130327','356','23349');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130328','356','23350');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130329','356','23351');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130330','356','23352');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130331','356','23353');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130332','356','23354');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130333','356','23355');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130334','356','23356');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130335','356','23357');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130336','356','23358');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130337','356','23359');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130338','356','23360');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130339','356','25368');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130340','356','25369');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130341','356','28250');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130342','356','28251');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130343','356','28617');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130344','356','28618');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130345','356','28619');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130346','280','22917');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130347','280','22918');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130348','273','22920');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130349','279','22920');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130350','273','22921');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130351','279','22921');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130352','273','22922');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130353','279','22922');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130354','273','22923');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130355','279','22923');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130356','273','22924');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130357','279','22924');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130358','275','22933');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130359','278','22933');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130360','275','22934');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130361','278','22934');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130362','275','22938');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130363','278','22938');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130364','275','22939');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130365','278','22939');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130366','278','22940');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130367','281','22940');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130368','281','22941');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130369','276','22942');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130370','276','22943');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130371','273','23108');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130372','331','23108');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130373','279','23108');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130374','273','23109');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130375','331','23109');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130376','279','23109');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130377','273','23110');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130378','279','23110');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130379','273','23111');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130380','331','23111');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130381','279','23111');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130382','273','23112');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130383','331','23112');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130384','279','23112');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130385','273','23113');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130386','279','23113');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130387','273','23114');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130388','279','23114');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130389','273','23115');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130390','279','23115');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130391','274','23116');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130392','279','23116');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130393','274','23117');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130394','279','23117');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130395','273','23118');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130396','331','23118');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130397','273','23119');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130398','279','23119');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130399','273','23120');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130400','279','23120');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130401','273','23121');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130402','279','23121');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130403','276','23122');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130404','279','23122');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130405','273','23123');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130406','279','23123');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130407','276','23124');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130408','276','23125');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130409','276','23126');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130410','276','23127');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130411','276','23128');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130412','276','23129');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130413','276','23130');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130414','276','23131');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130415','277','22945');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130416','277','22946');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130417','274','22948');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130418','274','22949');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130419','274','22950');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130420','274','22951');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130421','274','22952');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130422','268','22875');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130423','268','22876');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130424','270','22877');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130425','270','22878');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130426','265','22879');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130427','268','22879');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130428','263','22880');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130429','269','22880');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130430','263','22881');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130431','269','22881');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130432','263','22882');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130433','269','22882');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130434','263','22883');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130435','269','22883');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130436','263','22884');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130437','269','22884');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130438','263','22885');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130439','269','22885');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130440','263','22886');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130441','269','22886');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130442','263','22888');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130443','269','22888');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130444','263','22891');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130445','269','22891');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130446','263','22892');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130447','269','22892');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130448','265','22893');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130449','268','22893');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130450','265','22894');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130451','268','22894');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130452','266','22895');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130453','266','22896');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130454','266','22897');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130455','265','22898');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130456','268','22898');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130457','265','22899');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130458','268','22899');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130459','268','22900');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130460','271','22900');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130461','271','22901');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130462','266','22902');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130463','266','22903');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130464','264','22908');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130465','264','22909');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130466','264','22910');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130467','264','22911');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130468','264','22912');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130469','267','23073');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130470','267','23074');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130471','283','22961');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130472','289','22961');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130473','283','22962');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130474','289','22962');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130475','283','22963');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130476','289','22963');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130477','283','22965');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130478','289','22965');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130479','283','22968');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130480','289','22968');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130481','283','22971');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130482','289','22971');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130483','283','22972');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130484','289','22972');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130485','285','22973');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130486','288','22973');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130487','285','22974');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130488','288','22974');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130489','285','22978');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130490','288','22978');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130491','288','22980');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130492','291','22980');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130493','291','22981');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130494','286','22982');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130495','286','22983');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130496','287','22985');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130497','287','22986');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130498','284','22988');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130499','284','22989');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130500','284','22990');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130501','284','22991');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130502','284','22992');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130503','308','23035');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130504','308','23036');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130505','305','23039');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130506','308','23039');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130507','303','23041');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130508','309','23041');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130509','303','23042');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130510','309','23042');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130511','303','23043');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130512','309','23043');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130513','305','23053');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130514','308','23053');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130515','305','23054');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130516','308','23054');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130517','305','23058');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130518','308','23058');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130519','305','23059');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130520','308','23059');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130521','308','23060');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130522','311','23060');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130523','311','23061');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130524','306','23062');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130525','306','23063');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130526','307','23077');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130527','307','23078');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130528','304','23068');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130529','304','23069');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130530','304','23070');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130531','304','23071');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130532','304','23072');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130533','258','22835');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130534','258','22836');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130535','260','22837');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130536','260','22838');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130537','255','22839');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130538','258','22839');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130539','253','22840');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130540','259','22840');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130541','253','22841');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130542','259','22841');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130543','253','22842');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130544','259','22842');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130545','253','22843');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130546','259','22843');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130547','253','22844');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130548','259','22844');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130549','253','22845');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130550','259','22845');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130551','253','22846');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130552','259','22846');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130553','253','22848');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130554','259','22848');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130555','253','22851');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130556','259','22851');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130557','253','22852');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130558','259','22852');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130559','255','22853');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130560','258','22853');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130561','255','22854');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130562','258','22854');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130563','256','22855');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130564','256','22856');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130565','256','22857');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130566','255','22858');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130567','258','22858');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130568','255','22859');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130569','258','22859');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130570','258','22860');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130571','261','22860');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130572','261','22861');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130573','256','22862');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130574','256','22863');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130575','254','22868');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130576','254','22869');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130577','254','22870');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130578','254','22871');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130579','254','22872');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130580','257','23075');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130581','257','23076');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130582','298','22996');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130583','300','22997');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130584','300','22998');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130585','295','22999');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130586','298','22999');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130587','293','23000');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130588','299','23000');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130589','293','23001');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130590','299','23001');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130591','293','23002');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130592','299','23002');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130593','293','23003');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130594','299','23003');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130595','293','23004');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130596','299','23004');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130597','293','23005');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130598','299','23005');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130599','293','23007');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130600','299','23007');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130601','293','23011');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130602','299','23011');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130603','293','23012');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130604','299','23012');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130605','295','23013');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130606','298','23013');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130607','295','23014');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130608','298','23014');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130609','296','23015');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130610','296','23016');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130611','296','23017');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130612','295','23018');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130613','298','23018');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130614','295','23019');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130615','298','23019');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130616','298','23020');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130617','301','23020');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130618','301','23021');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130619','296','23022');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130620','296','23023');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130621','297','23025');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130622','297','23026');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130623','294','23028');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130624','294','23029');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130625','294','23030');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130626','294','23031');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130627','294','23032');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130628','743','26925');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130629','743','26926');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130630','741','26927');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130631','742','26928');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130632','743','26929');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130633','743','26930');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130634','743','26931');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130635','743','26932');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130636','745','26933');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130637','746','26934');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130638','744','26935');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130639','744','26936');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130640','746','26937');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130641','746','26938');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130642','746','26939');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130643','746','26940');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130644','746','26941');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130645','746','26942');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130646','745','26943');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130647','1362','32207');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130648','1362','32208');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130649','1362','32209');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130650','1362','32210');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130651','1362','32211');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130652','1362','32212');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130653','1362','32213');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130654','1362','32214');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130655','1362','32215');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130656','1362','32216');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130657','1362','32217');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130658','1362','32218');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130659','1362','32219');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130660','1362','32220');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130661','1362','32221');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130662','1362','32222');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130663','1362','32223');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130664','1362','32224');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130665','1362','32225');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130666','1362','32226');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130667','1362','32227');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130668','1362','32228');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130669','1362','32229');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130670','1362','32230');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130671','1362','32231');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130672','1362','32232');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130673','1362','32233');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130674','1362','32234');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130675','1362','32235');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130676','1362','32236');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130677','1362','32237');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130678','1362','32238');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130679','1362','32239');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130680','1362','32240');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130681','1362','32241');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130682','1362','32242');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130683','1362','32243');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130684','1362','32244');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130685','1362','32245');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130686','1362','32246');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130687','1362','32247');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130688','1362','32248');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130689','1362','32249');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130690','1362','32250');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130691','1362','32251');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130692','1362','32252');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130693','1362','32253');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130694','1362','32254');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130695','1362','32255');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130696','1362','32256');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130697','1362','32257');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130698','1362','32258');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130699','1362','32259');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130700','1362','32260');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130701','1362','32261');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130702','1362','32262');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130703','1362','32263');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130704','1362','32264');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130705','1362','32265');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130706','1362','32266');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130707','1362','32267');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130708','1362','32268');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130709','1362','32269');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130710','1362','32270');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130711','1362','32271');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130712','1362','32272');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130713','1362','32273');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130714','1328','30821');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130715','1328','30822');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130716','1330','30823');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130717','1330','30824');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130718','1330','30825');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130719','1330','30826');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130720','1328','30827');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130721','1330','30828');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130722','1330','30829');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130723','1330','30830');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130724','1328','31054');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130725','1328','30831');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130726','1328','30832');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130727','1328','30833');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130728','1328','30834');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130729','1328','30835');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130730','1329','30836');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130731','1328','30837');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130732','1328','30838');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130733','1328','30839');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130734','1329','30840');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130735','1328','30841');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130736','1329','30842');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130737','1329','30843');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130738','1329','30844');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130739','1329','30845');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130740','1328','30846');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130741','1328','30847');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130742','1328','30848');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130743','1328','30849');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130744','1328','30850');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130745','1328','30851');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130746','1328','30852');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130747','1328','30853');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130748','1328','30854');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130749','1328','30855');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130750','1328','30856');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130751','1328','30857');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130752','1328','30858');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130753','1328','30859');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130754','1328','30860');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130755','1328','30861');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130756','1328','30862');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130757','1328','30863');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130758','1328','30864');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130759','1328','30865');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130760','1328','30866');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130761','1328','30867');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130762','1328','30868');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130763','1328','30869');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130764','1328','30870');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130765','1328','30871');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130766','1328','30872');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130767','1329','30873');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130768','1434','33017');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130769','1434','33018');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130770','1433','33019');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130771','1434','33020');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130772','1434','33021');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130773','1433','33022');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130774','1433','33023');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130775','1433','33024');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130776','1433','33025');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130777','1433','33026');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130778','1433','33027');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130779','1433','33028');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130780','1433','33029');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130781','1433','33030');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130782','1433','33031');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130783','1433','33032');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130784','1433','33033');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130785','1433','33034');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130786','1433','33035');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130787','1433','33036');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130788','1433','33037');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130789','1433','33038');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130790','1433','33039');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130791','1433','33040');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130792','1433','33041');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130793','1433','33042');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130794','1433','33043');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130795','1433','33044');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130796','1433','33045');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130797','1433','33046');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130798','1433','33047');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130799','1433','33048');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130800','1433','33049');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130801','1433','33050');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130802','1433','33051');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130803','1433','33052');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130804','1433','33053');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130805','1433','33054');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130806','1433','33055');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130807','1433','33056');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130808','1433','33057');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130809','1433','33058');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130810','1433','33059');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130811','1433','33060');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130812','1434','33065');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130813','1434','33066');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130814','1433','33122');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130815','1433','33123');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130816','1433','33124');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130817','1433','33125');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130818','1433','33126');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130819','1433','33127');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130820','1433','33128');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130821','1433','33129');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130822','1433','33130');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130823','1433','33131');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130824','1433','33132');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130825','1433','33133');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130826','1433','33134');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130827','1433','33135');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130828','1433','33136');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130829','1433','33137');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130830','1433','33138');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130831','1435','33139');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130832','1436','33140');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130833','1435','33141');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130834','1436','33142');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130835','1435','33144');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130836','1435','33145');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130837','1435','33146');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130838','1435','33147');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130839','1435','33148');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130840','1435','33149');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130841','1435','33150');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130842','1435','33151');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130843','1435','33152');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130844','1435','33153');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130845','1435','33154');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130846','1435','33155');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130847','1435','33156');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130848','1435','33157');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130849','1435','33158');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130850','1435','33159');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130851','1435','33160');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130852','1435','33161');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130853','1435','33162');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130854','1435','33163');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130855','1435','33164');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130856','1435','33165');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130857','1435','33166');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130858','1435','33167');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130859','1435','33168');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130860','1435','33169');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130861','1435','33170');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130862','1435','33171');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130863','1435','33172');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130864','1435','33567');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130865','1436','33177');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130866','1436','33178');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130867','1336','31055');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130868','1335','31056');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130869','1335','31057');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130870','1335','31058');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130871','1335','31626');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130872','1335','31627');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130873','1335','31628');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130874','1336','34173');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130875','1336','34174');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130876','1336','31059');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130877','1335','31060');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130878','1335','31061');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130879','1335','31062');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130880','1335','31063');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130881','1335','31064');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130882','1335','31065');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130883','1335','31066');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130884','1335','31067');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130885','1335','31068');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130886','1335','31069');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130887','1335','31070');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130888','1335','31071');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130889','1335','31072');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130890','1335','31073');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130891','1335','31074');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130892','1335','31075');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130893','1335','31076');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130894','1335','31077');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130895','1335','31078');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130896','1335','31079');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130897','1335','31080');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130898','1335','31081');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130899','1335','31082');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130900','1335','31083');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130901','1335','31084');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130902','1335','31085');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130903','1335','31086');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130904','1335','31087');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130905','1335','31088');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130906','1335','31089');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130907','1335','31090');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130908','1336','31091');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130909','1335','31092');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130910','1336','31093');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130911','1336','31094');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130912','1335','31095');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130913','1335','31096');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130914','1335','31097');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130915','1335','31098');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130916','1335','31099');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130917','1335','31100');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130918','1335','31101');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130919','1335','31102');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130920','1335','31103');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130921','1335','31104');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130922','1335','31105');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130923','1335','31106');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130924','1335','31107');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130925','1335','31108');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130926','1335','31109');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130927','1335','31110');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130928','1335','31111');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130929','1335','31112');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130930','1335','31113');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130931','1335','31114');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130932','1335','31115');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130933','1335','31116');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130934','1335','31117');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130935','1335','31118');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130936','1335','31119');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130937','1335','31120');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130938','1335','31121');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130939','1336','31128');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130940','1336','31129');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130941','1336','31130');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130942','1336','31132');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130943','1336','33194');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130944','1314','30431');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130945','1314','30432');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130946','1315','30433');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130947','1314','30434');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130948','1314','30435');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130949','1314','32546');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130950','1315','30436');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130951','1314','30437');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130952','1314','30438');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130953','1314','30439');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130954','1314','30440');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130955','1314','30441');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130956','1314','30442');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130957','1315','30443');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130958','1314','30444');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130959','1314','30445');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130960','1314','30446');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130961','1314','30447');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130962','1314','30449');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130963','1314','30450');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130964','1314','30451');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130965','1314','30452');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130966','1314','30453');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130967','1314','30454');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130968','1314','30455');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130969','1314','30456');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130970','1314','30457');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130971','1314','30458');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130972','1314','30459');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130973','1314','30460');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130974','1314','30461');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130975','1314','30462');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130976','1314','30463');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130977','1314','30464');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130978','1314','30465');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130979','1314','30466');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130980','1314','30470');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130981','1314','30471');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130982','1314','31168');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130983','1314','31169');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130984','1314','31170');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130985','1314','31171');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130986','1314','32547');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130987','1314','32548');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130988','1314','32549');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130989','1314','32550');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130990','1314','32551');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130991','1314','32552');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130992','1314','30474');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130993','1315','30475');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130994','1314','30476');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130995','1314','30477');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130996','1314','30478');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130997','1314','32554');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130998','1314','32555');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('130999','1314','32556');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131000','1314','32557');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131001','1314','32558');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131002','1314','32559');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131003','1322','30637');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131004','1322','30638');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131005','1323','30639');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131006','1322','30640');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131007','1322','30641');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131008','1322','32560');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131009','1323','30642');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131010','1322','30643');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131011','1322','30644');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131012','1322','30645');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131013','1322','30646');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131014','1322','30647');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131015','1322','30648');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131016','1323','30649');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131017','1322','30650');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131018','1322','30651');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131019','1322','30652');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131020','1322','30653');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131021','1322','30655');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131022','1322','30656');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131023','1322','30657');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131024','1322','30658');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131025','1322','30659');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131026','1322','30660');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131027','1322','30661');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131028','1322','30662');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131029','1322','30663');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131030','1322','30664');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131031','1322','30665');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131032','1322','30666');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131033','1322','30667');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131034','1322','30668');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131035','1322','30669');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131036','1322','30670');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131037','1322','30671');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131038','1322','30672');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131039','1322','30676');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131040','1322','30677');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131041','1322','31172');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131042','1322','31173');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131043','1322','31174');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131044','1322','31175');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131045','1322','32561');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131046','1322','32562');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131047','1322','32563');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131048','1322','32564');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131049','1322','32565');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131050','1322','32566');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131051','1322','30680');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131052','1323','30681');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131053','1322','30682');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131054','1322','30683');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131055','1322','30684');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131056','1322','32568');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131057','1322','32569');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131058','1322','32570');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131059','1322','32571');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131060','1322','32572');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131061','1322','32573');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131062','1317','30479');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131063','1316','30480');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131064','1316','30481');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131065','1316','30482');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131066','1316','30483');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131067','1316','32574');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131068','1316','30484');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131069','1317','30485');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131070','1316','30486');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131071','1317','30487');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131072','1316','30488');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131073','1316','30489');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131074','1316','30490');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131075','1316','30491');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131076','1316','30492');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131077','1316','30493');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131078','1316','30494');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131079','1316','30495');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131080','1316','30496');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131081','1316','30497');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131082','1316','30499');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131083','1316','30500');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131084','1316','30503');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131085','1316','30504');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131086','1316','30505');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131087','1316','30506');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131088','1316','30507');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131089','1316','30508');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131090','1316','30509');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131091','1316','30510');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131092','1316','30512');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131093','1316','30513');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131094','1316','30514');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131095','1316','30515');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131096','1316','30516');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131097','1316','30517');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131098','1316','30518');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131099','1316','30519');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131100','1316','31176');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131101','1316','31177');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131102','1316','31178');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131103','1316','31179');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131104','1316','32575');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131105','1316','32576');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131106','1316','32577');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131107','1316','32578');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131108','1316','32579');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131109','1316','32580');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131110','1316','30522');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131111','1317','30523');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131112','1316','30524');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131113','1316','30525');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131114','1316','30526');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131115','1316','32582');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131116','1316','32583');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131117','1316','32584');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131118','1316','32585');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131119','1316','32586');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131120','1316','32587');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131121','1345','31629');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131122','1345','31630');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131123','1346','31631');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131124','1345','31632');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131125','1346','31633');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131126','1346','31634');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131127','1346','31635');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131128','1346','31636');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131129','1346','31637');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131130','1346','31638');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131131','1346','31639');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131132','1345','31640');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131133','1345','31641');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131134','1346','31642');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131135','1346','31643');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131136','1346','31644');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131137','1346','31645');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131138','1345','31646');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131139','1345','31647');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131140','1345','31648');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131141','1345','31649');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131142','1345','31650');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131143','1345','31651');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131144','1345','31652');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131145','1345','31653');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131146','1345','31654');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131147','1345','31655');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131148','1345','31656');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131149','1345','31657');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131150','1345','31658');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131151','1345','31659');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131152','1345','31660');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131153','1345','31661');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131154','1345','31662');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131155','1345','31663');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131156','1345','31664');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131157','1345','31665');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131158','1345','31666');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131159','1345','31667');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131160','1345','31668');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131161','1345','31669');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131162','1345','31670');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131163','1345','31671');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131164','1345','31672');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131165','1345','31673');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131166','1345','31674');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131167','1345','31675');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131168','1345','31676');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131169','1345','31677');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131170','1345','31678');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131171','1345','31679');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131172','1345','31680');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131173','1345','31681');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131174','1345','31682');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131175','1345','31683');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131176','1345','31684');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131177','1345','31685');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131178','1345','31686');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131179','1345','31687');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131180','1345','31688');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131181','1345','31689');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131182','1345','31690');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131183','1345','31691');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131184','1345','31692');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131185','1345','31693');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131186','1345','31694');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131187','1345','31695');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131188','1345','31696');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131189','1345','31697');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131190','1345','31698');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131191','1345','31699');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131192','1345','31700');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131193','1345','31701');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131194','1345','31702');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131195','1345','31703');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131196','1345','31704');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131197','1345','31705');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131198','1115','28671');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131199','1115','28672');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131200','1114','28673');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131201','1114','28674');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131202','1115','28675');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131203','1114','28676');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131204','1114','28677');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131205','1114','28678');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131206','1114','28679');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131207','1114','28680');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131208','1114','28681');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131209','1115','28682');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131210','1115','28683');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131211','1114','28684');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131212','1114','28685');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131213','1115','28686');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131214','1115','28687');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131215','1114','28688');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131216','1114','28689');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131217','1114','28690');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131218','1114','28691');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131219','1114','28692');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131220','1114','28693');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131221','1114','28694');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131222','1114','28695');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131223','1114','28696');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131224','1114','28697');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131225','1114','28698');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131226','1114','28699');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131227','1114','28700');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131228','1114','28701');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131229','1114','28702');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131230','1114','28703');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131231','1114','28704');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131232','1114','28705');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131233','1114','28706');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131234','1114','28707');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131235','1114','28708');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131236','1114','28709');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131237','1114','28710');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131238','1115','28713');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131239','1115','28714');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131240','1338','31180');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131241','1337','31181');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131242','1338','31182');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131243','1338','31183');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131244','1338','31185');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131245','1338','31186');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131246','1337','31188');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131247','1337','31189');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131248','1337','31190');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131249','1337','31191');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131250','1337','31192');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131251','1337','31193');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131252','1337','31194');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131253','1338','31195');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131254','1338','31196');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131255','1337','32592');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131256','1338','32595');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131257','1337','34944');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131258','1337','34945');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131259','1337','31197');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131260','1337','31199');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131261','1337','31200');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131262','1337','31201');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131263','1337','31202');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131264','1337','31203');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131265','1337','31204');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131266','1337','31205');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131267','1337','31206');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131268','1337','31207');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131269','1337','31208');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131270','1337','31209');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131271','1337','31210');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131272','1337','31211');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131273','1337','31212');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131274','1337','31213');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131275','1337','31215');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131276','1337','31216');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131277','1337','31217');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131278','1337','31218');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131279','1337','31219');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131280','1337','31220');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131281','1337','31221');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131282','1337','31222');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131283','1337','31223');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131284','1337','31224');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131285','1337','31225');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131286','1337','31226');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131287','1337','31227');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131288','1337','31228');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131289','1337','31229');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131290','1337','31230');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131291','1337','31231');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131292','1337','31232');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131293','1337','31233');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131294','1337','31234');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131295','1337','31235');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131296','1337','31236');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131297','1337','31237');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131298','1337','31238');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131299','1337','31239');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131300','1337','32596');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131301','1302','30273');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131302','1302','30274');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131303','1303','30275');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131304','1303','30276');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131305','1302','30277');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131306','1302','30278');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131307','1302','30279');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131308','1302','30280');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131309','1302','30281');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131310','1302','30282');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131311','1302','30283');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131312','1302','30284');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131313','1302','30285');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131314','1302','30286');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131315','1302','30287');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131316','1302','30288');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131317','1302','30289');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131318','1302','30290');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131319','1302','30291');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131320','1302','30292');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131321','1302','30293');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131322','1302','30294');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131323','1302','30295');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131324','1302','30296');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131325','1302','30297');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131326','1302','30298');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131327','1302','30299');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131328','1302','30300');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131329','1302','30301');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131330','1302','30302');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131331','1302','30303');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131332','1302','30304');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131333','1302','30305');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131334','1302','30306');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131335','1302','30307');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131336','1302','30308');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131337','1302','30309');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131338','1302','30310');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131339','1302','30311');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131340','1302','30312');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131341','1302','30313');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131342','1302','30314');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131343','1302','30315');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131344','1302','30316');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131345','1302','30317');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131346','1302','30318');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131347','1302','30319');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131348','1302','30320');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131349','1302','30321');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131350','1302','30322');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131351','1302','30323');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131352','1302','30324');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131353','1302','30325');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131354','1302','30326');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131355','1302','30327');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131356','1302','30328');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131357','1302','30329');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131358','1302','30330');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131359','1302','30331');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131360','1302','30332');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131361','1302','30333');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131362','1302','30334');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131363','1302','30335');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131364','1302','30336');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131365','1302','30344');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131366','1302','30345');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131367','1302','30346');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131368','1302','30347');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131369','1302','30351');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131370','1302','30352');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131371','1302','30353');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131372','1302','30354');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131373','1302','30355');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131374','1302','30356');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131375','1302','30357');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131376','1302','30358');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131377','1302','30359');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131378','1302','30360');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131379','1302','30361');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131380','1302','30362');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131381','1302','30363');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131382','1302','30364');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131383','1302','30365');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131384','1302','30366');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131385','1302','30367');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131386','1302','30368');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131387','1302','30369');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131388','1302','30370');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131389','1302','30371');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131390','1302','30372');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131391','1302','30373');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131392','1302','30374');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131393','1302','30375');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131394','1302','30376');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131395','1302','30377');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131396','1302','30378');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131397','1302','30379');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131398','1302','30380');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131399','1302','30381');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131400','1302','30382');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131401','1302','30383');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131402','1302','30384');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131403','1302','30385');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131404','1302','30386');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131405','1302','30387');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131406','1302','30388');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131407','1302','30389');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131408','1302','30390');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131409','1302','30391');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131410','1302','30392');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131411','1302','30393');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131412','1302','30394');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131413','1302','30395');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131414','1302','30397');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131415','1302','30398');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131416','1302','30399');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131417','1302','30400');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131418','1302','30401');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131419','1302','30402');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131420','1302','30403');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131421','1302','30404');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131422','780','27065');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131423','780','27066');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131424','780','27067');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131425','799','27149');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131426','799','27150');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131427','799','27151');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131428','805','27192');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131429','805','27193');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131430','805','27194');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131431','813','27225');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131432','813','27226');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131433','813','27227');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131434','822','27261');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131435','822','27262');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131436','822','27263');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131437','825','27282');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131438','825','27283');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131439','825','27284');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131440','842','27333');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131441','842','27334');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131442','842','27335');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131443','847','27365');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131444','847','27366');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131445','847','27367');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131446','876','27462');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131447','876','27463');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131448','876','27464');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131449','885','27496');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131450','885','27497');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131451','885','27498');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131452','894','27532');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131453','894','27533');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131454','894','27534');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131455','903','27568');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131456','903','27569');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131457','903','27570');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131458','915','27631');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131459','915','27632');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131460','915','27633');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131461','918','27654');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131462','918','27655');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131463','918','27656');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131464','936','27734');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131465','936','27735');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131466','936','27736');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131467','944','27766');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131468','944','27767');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131469','944','27768');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131470','951','27800');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131471','951','27801');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131472','951','27802');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131473','971','27882');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131474','971','27883');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131475','971','27884');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131476','979','27919');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131477','979','27920');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131478','979','27921');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131479','988','27956');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131480','988','27957');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131481','988','27958');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131482','994','27986');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131483','994','27987');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131484','994','27988');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131485','1000','28015');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131486','1000','28016');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131487','1000','28017');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131488','1030','28130');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131489','1030','28131');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131490','1030','28132');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131491','1055','28233');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131492','1055','28234');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131493','1055','28235');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131494','1060','28282');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131495','1060','28283');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131496','1060','28284');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131497','1070','28330');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131498','1070','28331');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131499','1070','28332');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131500','1079','28377');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131501','1079','28378');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131502','1079','28379');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131503','1095','28454');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131504','1095','28455');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131505','1095','28456');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131506','1102','28482');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131507','1102','28483');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131508','1102','28484');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131509','1127','28957');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131510','1127','28958');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131511','1127','28959');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131512','1136','29050');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131513','1136','29051');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131514','1136','29052');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131515','1271','30046');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131516','1271','30047');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131517','1271','30048');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131518','1414','32601');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131519','1414','32602');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131520','1414','32603');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131521','1422','32765');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131522','1422','32766');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131523','1422','32767');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131524','800','27152');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131525','799','27154');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131526','800','27157');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131527','799','29844');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131528','800','29845');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131529','800','29846');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131530','800','29847');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131531','800','29848');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131532','804','27195');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131533','804','27199');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131534','805','27202');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131535','812','27228');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131536','812','27232');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131537','813','27235');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131538','821','27264');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131539','821','27268');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131540','822','27271');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131541','824','27285');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131542','824','27289');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131543','825','27292');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131544','841','27336');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131545','841','27340');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131546','842','27343');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131547','846','27368');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131548','846','27372');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131549','847','27375');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131550','875','27465');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131551','875','27469');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131552','876','27472');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131553','884','27499');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131554','884','27503');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131555','885','27506');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131556','893','27535');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131557','893','27539');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131558','894','27542');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131559','902','27571');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131560','902','27575');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131561','903','27578');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131562','914','27634');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131563','914','27638');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131564','915','27641');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131565','917','27657');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131566','917','27661');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131567','918','27664');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131568','935','27737');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131569','935','27741');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131570','936','27744');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131571','943','27769');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131572','943','27773');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131573','944','27776');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131574','950','27803');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131575','950','27807');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131576','951','27810');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131577','970','27885');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131578','970','27889');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131579','971','27892');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131580','978','27922');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131581','978','27926');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131582','979','27929');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131583','987','27959');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131584','987','27963');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131585','988','27966');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131586','993','27989');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131587','993','27993');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131588','994','27996');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131589','999','28018');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131590','999','28022');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131591','1000','28025');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131592','1029','28133');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131593','1029','28137');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131594','1030','28140');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131595','1054','28236');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131596','1054','28240');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131597','1055','28243');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131598','1059','28285');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131599','1059','28289');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131600','1060','28292');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131601','1069','28333');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131602','1069','28337');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131603','1070','28340');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131604','1078','28380');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131605','1078','28384');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131606','1079','28387');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131607','1094','28457');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131608','1094','28461');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131609','1095','28464');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131610','1101','28485');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131611','1101','28489');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131612','1102','28492');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131613','1126','28960');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131614','1126','28964');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131615','1127','28967');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131616','1135','29053');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131617','1135','29057');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131618','1136','29060');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131619','1000','29834');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131620','999','29835');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131621','999','29836');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131622','999','29837');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131623','999','29838');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131624','805','29849');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131625','804','29850');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131626','804','29851');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131627','804','29852');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131628','804','29853');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131629','813','29854');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131630','812','29855');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131631','812','29856');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131632','812','29857');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131633','812','29858');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131634','822','29859');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131635','821','29860');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131636','821','29861');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131637','821','29862');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131638','821','29863');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131639','825','29864');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131640','824','29865');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131641','824','29866');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131642','824','29867');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131643','824','29868');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131644','842','29869');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131645','841','29870');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131646','841','29871');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131647','841','29872');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131648','841','29873');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131649','847','29874');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131650','846','29875');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131651','846','29876');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131652','846','29877');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131653','846','29878');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131654','876','29879');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131655','875','29880');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131656','875','29881');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131657','875','29882');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131658','875','29883');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131659','885','29884');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131660','884','29885');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131661','884','29886');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131662','884','29887');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131663','884','29888');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131664','894','29889');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131665','893','29890');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131666','893','29891');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131667','893','29892');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131668','893','29893');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131669','903','29894');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131670','902','29895');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131671','902','29896');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131672','902','29897');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131673','902','29898');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131674','915','29899');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131675','914','29900');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131676','914','29901');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131677','914','29902');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131678','914','29903');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131679','918','29904');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131680','917','29905');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131681','917','29906');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131682','917','29907');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131683','917','29908');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131684','936','29909');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131685','935','29910');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131686','935','29911');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131687','935','29912');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131688','935','29913');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131689','944','29914');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131690','943','29915');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131691','943','29916');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131692','943','29917');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131693','943','29918');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131694','951','29919');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131695','950','29920');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131696','950','29921');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131697','950','29922');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131698','950','29923');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131699','971','29924');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131700','970','29925');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131701','970','29926');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131702','970','29927');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131703','970','29928');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131704','979','29929');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131705','978','29930');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131706','978','29931');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131707','978','29932');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131708','978','29933');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131709','988','29934');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131710','987','29935');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131711','987','29936');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131712','987','29937');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131713','987','29938');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131714','994','29939');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131715','993','29940');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131716','993','29941');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131717','993','29942');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131718','993','29943');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131719','1030','29944');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131720','1029','29945');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131721','1029','29946');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131722','1029','29947');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131723','1029','29948');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131724','1055','29954');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131725','1054','29955');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131726','1054','29956');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131727','1054','29957');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131728','1054','29958');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131729','1060','29959');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131730','1059','29960');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131731','1059','29961');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131732','1059','29962');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131733','1059','29963');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131734','1070','29964');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131735','1069','29965');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131736','1069','29966');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131737','1069','29967');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131738','1069','29968');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131739','1079','29969');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131740','1078','29970');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131741','1078','29971');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131742','1078','29972');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131743','1078','29973');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131744','1095','29974');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131745','1094','29975');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131746','1094','29976');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131747','1094','29977');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131748','1094','29978');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131749','1102','29979');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131750','1101','29980');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131751','1101','29981');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131752','1101','29982');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131753','1101','29983');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131754','1127','29984');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131755','1126','29985');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131756','1126','29986');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131757','1126','29987');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131758','1126','29988');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131759','1136','29989');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131760','1135','29990');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131761','1135','29991');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131762','1135','29992');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131763','1135','29993');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131764','1270','30049');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131765','1270','30050');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131766','1270','30051');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131767','1270','30052');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131768','1270','30053');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131769','1270','30054');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131770','1271','30055');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131771','1271','30056');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131772','1413','32604');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131773','1413','32605');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131774','1413','32606');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131775','1413','32607');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131776','1413','32608');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131777','1413','32609');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131778','1414','32610');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131779','1414','32611');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131780','1421','32768');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131781','1421','32769');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131782','1421','32770');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131783','1421','32771');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131784','1421','32772');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131785','1421','32773');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131786','1422','32774');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131787','1422','32775');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131788','1283','30142');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131789','1286','30143');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131790','1292','30145');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131791','1295','30146');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131792','1284','30157');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131793','1284','30158');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131794','1284','30159');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131795','1287','30163');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131796','1287','30164');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131797','1287','30165');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131798','1293','30175');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131799','1293','30176');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131800','1293','30177');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131801','1296','30181');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131802','1296','30182');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131803','1296','30183');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131804','1419','32741');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131805','1420','32753');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131806','1221','22231');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131807','1221','22232');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131808','1221','23318');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131809','1222','29544');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131810','1223','29545');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131811','1223','29546');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131812','1224','29547');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131813','1225','10020');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131814','1225','10059');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131815','1226','22833');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131816','1226','22834');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131817','1228','22873');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131818','1228','22874');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131819','1230','22913');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131820','1230','22914');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131821','1232','22953');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131822','1232','22954');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131823','1234','22993');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131824','1234','22994');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131825','1236','23033');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131826','1236','23034');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131827','1238','23160');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131828','1238','23161');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131829','1225','23319');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131830','1226','23320');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131831','1228','23321');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131832','1230','23322');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131833','1232','23323');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131834','1234','23324');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131835','1236','23325');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131836','1238','23326');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131837','1161','29548');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131838','1227','29549');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131839','1229','29550');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131840','1231','29551');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131841','1233','29552');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131842','1235','29553');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131843','1237','29554');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131844','1219','29555');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131845','1241','29558');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131846','1242','29559');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131847','1241','29560');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131848','1269','29995');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131849','1192','29996');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131850','1269','29997');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131851','1240','23287');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131852','1240','23288');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131853','1240','23327');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131854','1171','29557');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131855','810','27203');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131856','807','27207');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131857','806','27208');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131858','810','30086');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131859','807','30087');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131860','807','30088');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131861','807','30089');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131862','808','27212');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131863','809','27213');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131864','810','27214');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131865','1279','30091');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131866','1279','30092');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131867','1364','28305');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131868','1068','28323');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131869','1068','28324');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131870','1062','28325');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131871','1062','28326');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131872','1064','28327');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131873','1064','28328');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131874','1066','28329');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131875','1363','32307');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131876','819','27236');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131877','819','27237');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131878','813','27238');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131879','814','27240');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131880','815','30093');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131881','816','27246');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131882','816','27247');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131883','817','27248');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131884','818','27249');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131885','818','27250');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131886','826','27294');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131887','831','27295');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131888','831','27296');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131889','835','27297');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131890','827','30094');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131891','836','27299');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131892','838','27301');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131893','837','30095');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131894','839','30096');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131895','829','27312');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131896','830','27313');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131897','828','27314');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131898','828','27315');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131899','833','27316');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131900','834','27317');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131901','832','27318');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131902','835','27319');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131903','835','27320');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131904','1755','35903');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131905','1755','35904');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131906','1755','35905');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131907','1755','35906');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131908','1757','35907');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131909','1757','35908');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131910','1754','35914');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131911','1756','35915');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131912','1756','35916');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131913','1756','35917');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131914','1444','33197');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131915','1444','33198');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131916','1444','33199');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131917','1439','33200');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131918','1439','33201');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131919','1439','33202');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131920','1440','33203');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131921','1440','33204');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131922','1439','33205');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131923','1439','33206');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131924','1439','33207');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131925','1440','33208');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131926','1444','33209');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131927','1444','33210');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131928','1437','33219');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131929','1440','33220');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131930','1438','33221');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131931','1441','33222');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131932','1441','33223');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131933','1441','33224');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131934','1443','33235');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131935','1445','33236');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131936','1445','33237');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131937','1453','33238');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131938','1453','33239');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131939','1453','33240');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131940','1448','33241');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131941','1448','33242');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131942','1448','33243');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131943','1449','33244');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131944','1449','33245');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131945','1448','33246');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131946','1448','33247');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131947','1448','33248');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131948','1449','33249');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131949','1453','33250');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131950','1453','33251');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131951','1446','33260');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131952','1449','33261');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131953','1447','33262');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131954','1450','33263');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131955','1450','33264');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131956','1450','33265');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131957','1452','33276');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131958','1454','33277');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131959','1454','33278');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131960','1462','33279');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131961','1462','33280');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131962','1462','33281');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131963','1457','33282');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131964','1457','33283');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131965','1457','33284');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131966','1458','33285');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131967','1458','33286');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131968','1457','33287');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131969','1457','33288');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131970','1457','33289');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131971','1458','33290');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131972','1462','33291');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131973','1462','33292');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131974','1455','33301');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131975','1458','33302');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131976','1456','33303');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131977','1459','33304');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131978','1459','33305');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131979','1459','33306');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131980','1461','33317');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131981','1463','33318');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131982','1463','33319');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131983','1471','33320');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131984','1471','33321');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131985','1471','33322');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131986','1466','33323');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131987','1466','33324');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131988','1466','33325');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131989','1467','33326');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131990','1467','33327');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131991','1466','33328');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131992','1466','33329');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131993','1466','33330');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131994','1467','33331');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131995','1471','33332');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131996','1471','33333');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131997','1464','33342');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131998','1467','33343');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('131999','1465','33344');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132000','1468','33345');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132001','1468','33346');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132002','1468','33347');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132003','1470','33358');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132004','1472','33359');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132005','1472','33360');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132006','1480','33361');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132007','1480','33362');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132008','1480','33363');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132009','1475','33364');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132010','1475','33365');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132011','1475','33366');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132012','1476','33367');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132013','1476','33368');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132014','1475','33369');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132015','1475','33370');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132016','1475','33371');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132017','1476','33372');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132018','1480','33373');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132019','1480','33374');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132020','1473','33383');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132021','1476','33384');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132022','1474','33385');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132023','1477','33386');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132024','1477','33387');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132025','1477','33388');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132026','1479','33399');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132027','1481','33400');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132028','1481','33401');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132029','851','27376');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132030','852','27378');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132031','852','27379');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132032','852','30097');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132033','869','27380');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132034','870','27382');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132035','870','27383');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132036','858','27385');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132037','858','27386');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132038','1048','28209');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132039','1048','28210');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132040','858','30098');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132041','870','30099');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132042','1048','30100');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132043','848','27415');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132044','848','27416');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132045','849','27417');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132046','852','27419');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132047','853','27420');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132048','853','27421');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132049','854','27422');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132050','855','27423');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132051','1056','28246');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132052','848','30101');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132053','856','27425');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132054','856','27426');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132055','857','27427');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132056','858','27428');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132057','859','27429');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132058','859','27430');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132059','860','27431');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132060','861','27432');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132061','868','27443');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132062','868','27444');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132063','870','27445');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132064','871','27446');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132065','871','27447');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132066','872','27448');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132067','873','27449');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132068','1048','28208');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132069','1049','28215');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132070','1050','28216');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132071','1051','28217');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132072','1051','28218');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132073','1052','28220');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132074','1052','28222');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132075','1057','28247');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132076','856','30102');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132077','868','30103');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132078','1052','30104');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132079','877','27478');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132080','880','27479');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132081','881','27480');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132082','882','27481');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132083','882','27482');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132084','882','27483');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132085','882','27484');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132086','879','27485');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132087','878','30105');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132088','891','27508');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132089','891','27509');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132090','891','27510');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132091','886','27511');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132092','891','30106');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132093','888','27517');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132094','890','27518');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132095','889','27519');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132096','887','30107');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132097','900','27543');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132098','900','27544');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132099','900','27545');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132100','900','27546');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132101','895','27547');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132102','897','27553');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132103','899','27554');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132104','898','27555');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132105','896','30108');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132106','909','27579');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132107','909','27580');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132108','909','27582');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132109','909','27583');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132110','906','27584');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132111','906','27585');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132112','904','27586');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132113','909','30109');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132114','905','27591');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132115','907','27593');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132116','908','27594');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132117','908','27595');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132118','905','30110');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132119','905','30111');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132120','1742','35646');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132121','1749','35647');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132122','1748','35648');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132123','1749','35649');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132124','1749','35650');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132125','1749','35651');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132126','1749','35652');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132127','1749','35653');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132128','1742','35654');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132129','1742','35655');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132130','1742','35656');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132131','1742','35657');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132132','1742','35658');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132133','1742','35659');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132134','1742','35660');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132135','1742','35661');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132136','1742','35662');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132137','1748','35663');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132138','1750','35679');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132139','1751','35680');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132140','1751','35681');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132141','1747','35682');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132142','1740','35683');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132143','1740','35684');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132144','1746','35685');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132145','1750','35686');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132146','1739','35687');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132147','1739','35688');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132148','1739','35689');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132149','1739','35690');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132150','1739','35691');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132151','1739','35692');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132152','1739','35693');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132153','1739','35694');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132154','1739','35695');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132155','1739','35696');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132156','1739','35697');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132157','1739','35698');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132158','1739','35699');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132159','1739','35700');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132160','1739','35701');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132161','1739','35702');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132162','1739','35703');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132163','1739','35704');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132164','1739','35705');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132165','1739','35706');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132166','1739','35707');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132167','1739','35708');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132168','1739','35709');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132169','1739','35710');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132170','1739','35711');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132171','1739','35712');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132172','1739','35713');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132173','1739','35714');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132174','1739','35715');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132175','1739','35716');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132176','1743','35722');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132177','1743','35723');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132178','1743','35724');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132179','1743','35725');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132180','1743','35726');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132181','1743','35727');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132182','1744','35728');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132183','1744','35729');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132184','1744','35730');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132185','1744','35731');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132186','919','27671');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132187','921','27672');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132188','922','27673');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132189','923','27674');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132190','924','27675');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132191','924','27676');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132192','924','27677');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132193','924','27678');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132194','924','27679');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132195','920','30112');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132196','1036','28141');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132197','1036','28142');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132198','1031','28143');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132199','1033','28150');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132200','1032','28153');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132201','1034','28154');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132202','1035','28155');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132203','1033','28156');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132204','1036','28157');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132205','1036','28158');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132206','1032','30113');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132207','1032','30114');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132208','1032','30115');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132209','941','27748');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132210','941','27749');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132211','941','27750');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132212','939','27751');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132213','937','27753');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132214','941','27754');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132215','940','27755');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132216','938','30116');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132217','948','27777');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132218','948','27778');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132219','945','27783');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132220','945','27784');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132221','948','27785');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132222','946','27786');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132223','947','27787');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132224','957','27812');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132225','957','27813');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132226','951','27814');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132227','957','30117');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132228','954','27821');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132229','956','27822');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132230','955','27823');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132231','952','28894');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132232','953','30118');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132233','1486','33402');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132234','1486','33403');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132235','1486','33404');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132236','1483','33405');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132237','1483','33406');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132238','1482','33407');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132239','1483','33408');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132240','1483','33409');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132241','1483','33410');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132242','1483','33411');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132243','1486','33412');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132244','1486','33413');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132245','1044','28200');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132246','1044','28201');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132247','1045','28202');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132248','1045','28203');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132249','1047','28204');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132250','1047','28205');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132251','1046','28206');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132252','1484','33429');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132253','1484','33430');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132254','1484','33431');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132255','976','27893');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132256','976','27894');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132257','976','27895');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132258','973','27898');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132259','973','27900');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132260','976','30119');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132261','973','30120');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132262','972','27904');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132263','974','27905');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132264','975','27906');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132265','975','27907');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132266','975','27908');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132267','974','31790');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132268','1365','32308');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132269','1368','32309');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132270','1370','32310');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132271','1370','32311');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132272','1366','32312');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132273','1369','32313');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132274','1369','32314');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132275','1369','32315');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132276','1369','32316');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132277','1368','32317');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132278','1368','32318');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132279','1365','32319');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132280','1367','32320');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132281','1367','32321');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132282','1367','32322');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132283','1366','32323');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132284','1366','32324');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132285','1371','32325');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132286','1365','32326');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132287','1365','32327');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132288','1370','32328');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132289','1366','32330');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132290','1372','32331');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132291','1376','32332');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132292','1377','32333');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132293','1377','32334');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132294','1373','32335');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132295','1376','32336');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132296','1376','32337');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132297','1376','32338');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132298','1375','32339');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132299','1378','32340');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132300','1375','32341');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132301','1375','32342');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132302','1374','32343');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132303','1374','32344');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132304','1374','32345');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132305','1373','32346');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132306','1373','32347');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132307','1377','32348');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132308','1373','32350');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132309','1379','32351');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132310','1382','32352');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132311','1384','32353');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132312','1384','32354');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132313','1380','32355');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132314','1383','32356');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132315','1383','32357');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132316','1383','32358');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132317','1383','32359');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132318','1382','32360');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132319','1382','32361');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132320','1379','32362');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132321','1381','32363');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132322','1381','32364');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132323','1381','32365');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132324','1380','32366');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132325','1380','32367');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132326','1385','32368');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132327','1379','32369');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132328','1379','32370');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132329','1384','32371');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132330','1380','32373');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132331','1390','32374');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132332','1387','32375');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132333','1387','32376');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132334','1388','32377');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132335','1388','32378');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132336','1388','32379');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132337','1389','32380');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132338','1386','32382');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132339','1391','32383');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132340','1393','32384');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132341','1395','32385');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132342','1392','32386');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132343','1394','32387');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132344','1394','32388');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132345','1394','32389');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132346','1393','32390');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132347','1392','32391');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132348','1391','32392');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132349','1392','32393');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132350','1392','32394');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132351','1396','32395');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132352','1391','32396');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132353','1391','32397');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132354','1391','32398');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132355','1395','32399');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132356','1392','32401');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132357','1397','32402');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132358','1399','32403');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132359','1401','32404');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132360','1398','32405');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132361','1400','32406');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132362','1400','32407');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132363','1400','32408');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132364','1399','32409');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132365','1398','32410');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132366','1397','32411');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132367','1398','32412');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132368','1398','32413');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132369','1402','32414');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132370','1397','32415');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132371','1397','32416');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132372','1397','32417');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132373','1401','32418');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132374','1398','32420');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132375','1409','32421');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132376','1407','32422');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132377','1405','32423');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132378','1405','32424');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132379','1407','32425');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132380','1407','32426');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132381','1407','32427');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132382','1408','32428');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132383','1408','32429');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132384','1404','32436');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132385','1404','32437');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132386','1404','32438');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132387','1403','32439');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132388','1404','32440');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132389','1406','32441');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132390','1406','32442');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132391','1406','32443');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132392','1406','32444');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132393','985','27930');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132394','985','27931');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132395','981','27935');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132396','980','27936');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132397','985','30121');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132398','981','30122');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132399','981','30123');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132400','982','27940');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132401','982','27941');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132402','984','27942');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132403','983','27943');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132404','991','27967');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132405','991','27968');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132406','991','27970');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132407','991','27971');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132408','990','27972');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132409','990','27973');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132410','989','27975');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132411','1282','30124');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132412','991','30125');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132413','990','30126');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132414','1280','30129');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132415','1281','30130');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132416','997','27997');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132417','997','27998');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132418','997','27999');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132419','997','28000');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132420','995','28003');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132421','996','30131');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132422','1003','28026');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132423','1003','28027');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132424','1001','28031');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132425','1002','30132');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132426','1002','30133');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132427','1002','30134');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132428','1002','30135');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132429','1002','30136');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132430','1761','35951');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132431','1758','35952');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132432','1758','35953');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132433','1758','35954');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132434','1758','35955');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132435','1758','35956');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132436','1758','35957');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132437','1758','35958');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132438','1761','35959');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132439','1761','35960');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132440','1762','35981');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132441','1760','35982');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132442','1768','35983');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132443','1764','35984');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132444','1763','35985');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132445','1764','35986');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132446','1764','35987');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132447','1764','35988');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132448','1764','35989');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132449','1764','35990');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132450','1764','35991');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132451','1768','35992');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132452','1765','35999');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132453','1769','36025');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132454','1767','36026');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132455','1775','36027');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132456','1772','36028');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132457','1770','36029');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132458','1772','36030');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132459','1772','36031');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132460','1772','36032');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132461','1772','36033');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132462','1772','36034');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132463','1772','36035');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132464','1775','36036');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132465','1771','36041');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132466','1776','36059');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132467','1774','36060');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132468','1783','36061');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132469','1779','36062');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132470','1779','36063');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132471','1779','36064');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132472','1779','36065');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132473','1779','36066');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132474','1783','36067');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132475','1778','36079');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132476','1791','36128');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132477','1787','36129');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132478','1787','36130');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132479','1787','36131');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132480','1787','36132');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132481','1787','36133');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132482','1791','36134');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132483','1786','36146');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132484','1797','36195');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132485','1794','36196');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132486','1794','36197');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132487','1794','36198');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132488','1794','36199');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132489','1794','36200');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132490','1794','36201');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132491','1794','36202');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132492','1797','36203');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132493','1797','36204');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132494','1793','36210');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132495','1798','36227');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132496','1796','36228');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132497','1802','36229');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132498','1800','36230');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132499','1799','36231');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132500','1800','36232');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132501','1800','36233');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132502','1800','36234');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132503','1800','36235');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132504','1800','36236');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132505','1800','36237');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132506','1802','36238');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132507','1808','36267');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132508','1804','36268');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132509','1803','36269');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132510','1804','36270');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132511','1804','36271');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132512','1804','36272');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132513','1804','36273');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132514','1804','36274');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132515','1804','36275');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132516','1808','36276');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132517','1805','36283');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132518','1809','36309');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132519','1807','36310');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132520','1815','36311');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132521','1811','36312');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132522','1810','36313');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132523','1811','36314');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132524','1811','36315');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132525','1811','36316');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132526','1811','36317');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132527','1811','36318');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132528','1811','36319');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132529','1815','36320');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132530','1812','36327');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132531','1816','36353');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132532','1814','36354');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132533','1822','36355');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132534','1819','36356');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132535','1817','36357');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132536','1819','36358');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132537','1819','36359');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132538','1819','36360');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132539','1819','36361');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132540','1819','36362');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132541','1819','36363');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132542','1822','36364');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132543','1818','36371');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132544','1823','36397');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132545','1821','36398');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132546','1829','36399');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132547','1826','36400');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132548','1824','36401');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132549','1826','36402');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132550','1826','36403');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132551','1826','36404');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132552','1826','36405');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132553','1826','36406');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132554','1826','36407');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132555','1829','36408');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132556','1825','36415');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132557','1830','36441');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132558','1828','36442');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132559','1837','36443');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132560','1833','36444');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132561','1831','36445');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132562','1833','36446');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132563','1833','36447');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132564','1833','36448');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132565','1834','36449');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132566','1833','36450');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132567','1833','36451');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132568','1833','36452');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132569','1837','36453');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132570','1832','36460');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132571','1838','36486');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132572','1836','36487');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132573','1845','36488');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132574','1841','36489');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132575','1839','36490');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132576','1841','36491');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132577','1841','36492');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132578','1841','36493');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132579','1842','36494');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132580','1841','36495');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132581','1841','36496');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132582','1841','36497');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132583','1845','36498');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132584','1840','36505');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132585','1846','36531');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132586','1844','36532');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132587','1853','36533');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132588','1849','36534');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132589','1847','36535');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132590','1849','36536');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132591','1849','36537');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132592','1849','36538');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132593','1849','36539');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132594','1849','36540');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132595','1849','36541');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132596','1853','36542');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132597','1848','36550');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132598','1850','36551');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132599','1854','36577');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132600','1852','36578');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132601','1142','29087');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132602','1142','29088');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132603','1142','29089');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132604','1142','29090');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132605','1142','29091');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132606','1142','29092');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132607','1142','29093');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132608','1142','29094');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132609','1142','29095');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132610','1142','29096');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132611','1142','29097');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132612','1142','29098');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132613','1142','29099');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132614','1142','29100');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132615','1142','29101');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132616','1142','29102');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132617','1144','29103');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132618','1144','29104');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132619','1144','29105');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132620','1144','29106');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132621','1144','29107');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132622','1144','29108');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132623','1151','29110');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132624','1148','29111');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132625','1148','29112');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132626','1148','29113');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132627','1148','29114');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132628','1148','29115');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132629','1148','29116');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132630','1148','29117');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132631','1148','29118');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132632','1148','29119');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132633','1150','29120');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132634','1149','29121');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132635','1149','29122');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132636','1149','29123');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132637','1152','29124');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132638','1152','29125');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132639','1152','29126');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132640','1152','29127');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132641','1152','29128');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132642','1152','29129');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132643','1152','29130');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132644','1152','29131');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132645','1152','29132');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132646','1152','29133');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132647','1152','29134');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132648','1152','29135');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132649','1152','29136');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132650','1152','29137');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132651','1152','29138');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132652','1152','29139');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132653','1154','29140');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132654','1154','29141');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132655','1154','29142');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132656','1154','29143');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132657','1154','29144');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132658','1154','29145');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132659','1161','29147');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132660','1158','29148');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132661','1158','29149');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132662','1158','29150');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132663','1158','29151');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132664','1158','29152');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132665','1158','29153');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132666','1158','29154');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132667','1158','29155');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132668','1158','29156');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132669','1160','29157');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132670','1159','29158');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132671','1159','29159');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132672','1159','29160');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132673','1162','29161');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132674','1162','29162');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132675','1162','29163');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132676','1162','29164');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132677','1162','29165');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132678','1162','29166');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132679','1162','29167');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132680','1162','29168');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132681','1162','29169');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132682','1162','29170');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132683','1162','29171');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132684','1162','29172');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132685','1162','29173');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132686','1162','29174');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132687','1162','29175');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132688','1162','29176');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132689','1164','29177');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132690','1164','29178');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132691','1164','29179');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132692','1164','29180');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132693','1164','29181');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132694','1164','29182');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132695','1171','29184');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132696','1168','29185');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132697','1168','29186');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132698','1168','29187');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132699','1168','29188');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132700','1168','29189');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132701','1168','29190');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132702','1168','29191');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132703','1168','29192');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132704','1168','29193');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132705','1170','29194');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132706','1169','29195');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132707','1169','29196');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132708','1169','29197');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132709','1142','29198');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132710','1144','31270');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132711','1152','29199');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132712','1154','31271');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132713','1162','29200');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132714','1164','31272');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132715','1146','31278');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132716','1156','31281');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132717','1166','31284');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132718','1146','31287');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132719','1146','31290');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132720','1156','31293');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132721','1156','31296');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132722','1166','31299');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132723','1166','31302');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132724','1173','29273');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132725','1173','29274');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132726','1173','29275');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132727','1173','29276');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132728','1173','29277');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132729','1173','29278');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132730','1173','29279');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132731','1173','29280');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132732','1173','29281');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132733','1173','29282');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132734','1173','29283');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132735','1173','29284');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132736','1173','29285');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132737','1173','29286');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132738','1173','29287');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132739','1173','29288');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132740','1175','29289');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132741','1175','29290');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132742','1175','29291');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132743','1175','29292');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132744','1175','29293');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132745','1175','29294');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132746','1182','29296');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132747','1179','29297');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132748','1179','29298');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132749','1179','29299');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132750','1179','29300');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132751','1179','29301');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132752','1179','29302');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132753','1179','29303');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132754','1179','29304');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132755','1179','29305');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132756','1181','29306');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132757','1180','29307');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132758','1180','29308');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132759','1180','29309');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132760','1183','29310');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132761','1183','29311');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132762','1183','29312');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132763','1183','29313');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132764','1183','29314');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132765','1183','29315');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132766','1183','29316');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132767','1183','29317');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132768','1183','29318');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132769','1183','29319');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132770','1183','29320');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132771','1183','29321');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132772','1183','29322');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132773','1183','29323');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132774','1183','29324');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132775','1183','29325');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132776','1185','29326');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132777','1185','29327');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132778','1185','29328');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132779','1185','29329');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132780','1185','29330');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132781','1185','29331');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132782','1192','29333');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132783','1189','29334');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132784','1189','29335');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132785','1189','29336');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132786','1189','29337');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132787','1189','29338');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132788','1189','29339');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132789','1189','29340');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132790','1189','29341');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132791','1189','29342');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132792','1191','29343');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132793','1190','29344');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132794','1190','29345');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132795','1190','29346');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132796','1173','29347');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132797','1175','31303');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132798','1183','29348');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132799','1185','31304');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132800','1177','31309');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132801','1187','31312');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132802','1177','31315');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132803','1177','31318');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132804','1187','31321');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132805','1187','31324');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132806','1201','29395');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132807','1196','29396');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132808','1196','29397');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132809','1194','29398');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132810','1193','29399');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132811','1196','29400');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132812','1196','29401');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132813','1196','29402');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132814','1196','29403');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132815','1194','29404');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132816','1193','29405');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132817','1193','29406');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132818','1193','29407');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132819','1193','29408');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132820','1193','29409');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132821','1193','29410');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132822','1193','29411');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132823','1193','29412');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132824','1193','29413');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132825','1194','29414');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132826','1197','29415');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132827','1193','29416');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132828','1193','29417');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132829','1193','29418');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132830','1193','29419');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132831','1193','29420');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132832','1199','29421');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132833','1195','29422');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132834','1194','29423');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132835','1194','29424');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132836','1194','29425');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132837','1193','29426');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132838','1193','29427');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132839','1195','29428');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132840','1201','29450');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132841','1201','29451');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132842','1128','28978');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132843','1128','28979');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132844','1128','28980');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132845','1128','28981');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132846','1128','28982');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132847','1128','28983');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132848','1128','28984');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132849','1128','28985');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132850','1128','28986');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132851','1130','28987');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132852','1130','28988');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132853','1130','28989');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132854','1130','28990');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132855','1130','28991');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132856','1130','28992');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132857','1132','28993');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132858','1132','28994');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132859','1132','28995');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132860','1132','28996');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132861','1132','28997');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132862','1132','28998');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132863','1132','28999');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132864','1132','29000');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132865','1132','29001');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132866','1134','29002');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132867','1134','29003');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132868','1134','29004');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132869','1134','29005');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132870','1134','29006');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132871','1134','29007');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132872','1130','29017');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132873','1130','29018');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132874','1130','29019');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132875','1130','29020');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132876','1130','29021');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132877','1130','29022');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132878','1130','29023');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132879','1130','29024');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132880','1130','29025');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132881','1130','29026');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132882','1134','29034');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132883','1134','29035');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132884','1134','29036');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132885','1134','29037');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132886','1134','29038');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132887','1134','29039');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132888','1134','29040');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132889','1134','29041');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132890','1134','29042');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132891','1134','29043');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132892','1130','29048');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132893','1134','29049');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132894','1211','36579');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132895','1216','36580');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132896','1202','29454');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132897','1202','29455');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132898','1202','29456');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132899','1202','29457');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132900','1202','29458');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132901','1202','29459');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132902','1203','29460');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132903','1203','29461');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132904','1203','29462');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132905','1203','29463');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132906','1203','29466');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132907','1203','29467');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132908','1203','29468');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132909','1203','29469');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132910','1203','29470');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132911','1209','29472');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132912','1207','29473');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132913','1207','29474');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132914','1207','29475');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132915','1207','29476');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132916','1207','29477');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132917','1208','29478');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132918','1202','30137');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132919','1202','31325');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132920','1203','31326');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132921','1203','31327');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132922','1212','29480');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132923','1212','29481');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132924','1212','29482');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132925','1212','29483');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132926','1212','29484');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132927','1212','29485');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132928','1213','29486');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132929','1213','29487');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132930','1213','29488');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132931','1213','29489');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132932','1213','29492');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132933','1213','29493');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132934','1213','29494');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132935','1213','29495');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132936','1213','29496');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132937','1219','29498');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132938','1217','29499');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132939','1217','29500');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132940','1217','29501');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132941','1217','29502');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132942','1217','29503');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132943','1218','29504');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132944','1212','30138');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132945','1212','31328');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132946','1213','31329');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132947','1213','31330');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132948','1203','31331');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132949','1213','31332');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132950','1310','30425');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132951','1311','30426');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132952','1252','36601');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132953','1257','36602');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132954','1243','29561');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132955','1243','29562');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132956','1243','29563');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132957','1243','29564');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132958','1243','29565');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132959','1243','29566');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132960','1244','29567');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132961','1244','29568');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132962','1244','29569');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132963','1244','29570');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132964','1244','29573');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132965','1244','29574');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132966','1244','29575');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132967','1244','29576');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132968','1244','29577');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132969','1250','29579');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132970','1248','29580');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132971','1248','29581');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132972','1248','29582');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132973','1248','29583');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132974','1248','29584');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132975','1249','29585');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132976','1243','30139');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132977','1243','31343');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132978','1244','31344');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132979','1244','31345');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132980','1253','29587');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132981','1253','29588');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132982','1253','29589');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132983','1253','29590');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132984','1253','29591');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132985','1253','29592');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132986','1254','29593');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132987','1254','29594');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132988','1254','29595');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132989','1254','29596');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132990','1254','29599');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132991','1254','29600');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132992','1254','29601');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132993','1254','29602');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132994','1254','29603');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132995','1242','29605');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132996','1258','29606');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132997','1258','29607');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132998','1258','29608');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('132999','1258','29609');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133000','1258','29610');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133001','1259','29611');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133002','1253','30140');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133003','1253','31346');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133004','1254','31347');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133005','1254','31348');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133006','1244','31349');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133007','1254','31350');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133008','1312','30429');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133009','1313','30430');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133010','1493','33568');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133011','1493','33569');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133012','1493','33570');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133013','1492','33571');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133014','1492','33572');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133015','1492','33574');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133016','1492','33575');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133017','1492','33576');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133018','1492','33577');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133019','1492','33578');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133020','1493','33579');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133021','1493','33580');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133022','1493','33581');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133023','1493','33582');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133024','1493','33583');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133025','1493','33584');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133026','1493','33585');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133027','1493','33589');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133028','1493','33590');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133029','1493','33591');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133030','1493','33592');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133031','1493','33593');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133032','1493','33594');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133033','1493','33595');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133034','1492','34083');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133035','1493','33602');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133036','1493','33603');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133037','1493','33604');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133038','1493','33605');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133039','1493','33606');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133040','1492','33607');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133041','1493','33608');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133042','1493','33609');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133043','1493','33610');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133044','1493','33611');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133045','1493','33612');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133046','1493','33613');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133047','1493','33614');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133048','1493','33615');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133049','1493','33616');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133050','1493','33617');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133051','1493','33618');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133052','1495','33619');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133053','1495','33620');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133054','1495','33621');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133055','1494','33622');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133056','1494','33623');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133057','1494','33625');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133058','1494','33626');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133059','1494','33627');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133060','1494','33628');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133061','1494','33629');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133062','1495','33630');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133063','1495','33631');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133064','1495','33632');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133065','1495','33633');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133066','1495','33634');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133067','1495','33635');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133068','1495','33636');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133069','1495','33640');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133070','1495','33641');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133071','1495','33642');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133072','1495','33643');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133073','1495','33644');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133074','1495','33645');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133075','1495','33646');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133076','1494','34084');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133077','1495','33653');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133078','1495','33654');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133079','1495','33655');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133080','1495','33656');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133081','1495','33657');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133082','1494','33658');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133083','1495','33659');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133084','1495','33660');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133085','1495','33661');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133086','1495','33662');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133087','1495','33663');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133088','1495','33664');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133089','1495','33665');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133090','1495','33666');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133091','1495','33667');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133092','1495','33668');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133093','1495','33669');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133094','1497','33670');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133095','1497','33671');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133096','1497','33672');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133097','1496','33673');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133098','1496','33674');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133099','1496','33676');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133100','1496','33677');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133101','1496','33678');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133102','1496','33679');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133103','1496','33680');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133104','1497','33681');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133105','1497','33682');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133106','1497','33683');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133107','1497','33684');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133108','1497','33685');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133109','1497','33686');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133110','1497','33687');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133111','1497','33691');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133112','1497','33692');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133113','1497','33693');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133114','1497','33694');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133115','1497','33695');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133116','1497','33696');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133117','1497','33697');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133118','1496','34085');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133119','1497','33704');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133120','1497','33705');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133121','1497','33706');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133122','1497','33707');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133123','1497','33708');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133124','1496','33709');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133125','1497','33710');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133126','1497','33711');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133127','1497','33712');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133128','1497','33713');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133129','1497','33714');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133130','1497','33715');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133131','1497','33716');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133132','1497','33717');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133133','1497','33718');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133134','1497','33719');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133135','1497','33720');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133136','1499','33721');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133137','1499','33722');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133138','1499','33723');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133139','1498','33724');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133140','1498','33725');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133141','1498','33727');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133142','1498','33728');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133143','1498','33729');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133144','1498','33730');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133145','1498','33731');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133146','1499','33732');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133147','1499','33733');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133148','1499','33734');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133149','1499','33735');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133150','1499','33736');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133151','1499','33737');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133152','1499','33738');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133153','1499','33742');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133154','1499','33743');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133155','1499','33744');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133156','1499','33745');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133157','1499','33746');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133158','1499','33747');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133159','1499','33748');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133160','1498','34086');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133161','1499','33755');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133162','1499','33756');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133163','1499','33757');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133164','1499','33758');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133165','1499','33759');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133166','1498','33760');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133167','1499','33761');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133168','1499','33762');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133169','1499','33763');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133170','1499','33764');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133171','1499','33765');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133172','1499','33766');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133173','1499','33767');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133174','1499','33768');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133175','1499','33769');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133176','1499','33770');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133177','1499','33771');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133178','1501','33772');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133179','1501','33773');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133180','1501','33774');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133181','1500','33775');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133182','1500','33776');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133183','1500','33778');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133184','1500','33779');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133185','1500','33780');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133186','1500','33781');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133187','1500','33782');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133188','1501','33783');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133189','1501','33784');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133190','1501','33785');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133191','1501','33786');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133192','1501','33787');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133193','1501','33788');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133194','1501','33789');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133195','1501','33793');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133196','1501','33794');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133197','1501','33795');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133198','1501','33796');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133199','1501','33797');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133200','1501','33798');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133201','1501','33799');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133202','1500','34087');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133203','1501','33806');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133204','1501','33807');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133205','1501','33808');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133206','1501','33809');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133207','1501','33810');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133208','1500','33811');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133209','1501','33812');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133210','1501','33813');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133211','1501','33814');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133212','1501','33815');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133213','1501','33816');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133214','1501','33817');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133215','1501','33818');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133216','1501','33819');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133217','1501','33820');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133218','1501','33821');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133219','1501','33822');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133220','1503','33823');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133221','1503','33824');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133222','1503','33825');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133223','1502','33826');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133224','1502','33827');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133225','1502','33829');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133226','1502','33830');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133227','1502','33831');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133228','1502','33832');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133229','1502','33833');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133230','1503','33834');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133231','1503','33835');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133232','1503','33836');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133233','1503','33837');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133234','1503','33838');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133235','1503','33839');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133236','1503','33840');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133237','1503','33844');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133238','1503','33845');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133239','1503','33846');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133240','1503','33847');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133241','1503','33848');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133242','1503','33849');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133243','1503','33850');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133244','1502','34088');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133245','1503','33857');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133246','1503','33858');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133247','1503','33859');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133248','1503','33860');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133249','1503','33861');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133250','1502','33862');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133251','1503','33863');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133252','1503','33864');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133253','1503','33865');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133254','1503','33866');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133255','1503','33867');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133256','1503','33868');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133257','1503','33869');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133258','1503','33870');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133259','1503','33871');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133260','1503','33872');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133261','1503','33873');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133262','1505','33874');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133263','1505','33875');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133264','1505','33876');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133265','1504','33877');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133266','1504','33878');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133267','1504','33880');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133268','1504','33881');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133269','1504','33882');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133270','1504','33883');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133271','1504','33884');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133272','1505','33885');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133273','1505','33886');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133274','1505','33887');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133275','1505','33888');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133276','1505','33889');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133277','1505','33890');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133278','1505','33891');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133279','1505','33895');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133280','1505','33896');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133281','1505','33897');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133282','1505','33898');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133283','1505','33899');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133284','1505','33900');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133285','1505','33901');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133286','1504','34089');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133287','1505','33908');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133288','1505','33909');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133289','1505','33910');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133290','1505','33911');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133291','1505','33912');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133292','1504','33913');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133293','1505','33914');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133294','1505','33915');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133295','1505','33916');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133296','1505','33917');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133297','1505','33918');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133298','1505','33919');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133299','1505','33920');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133300','1505','33921');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133301','1505','33922');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133302','1505','33923');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133303','1505','33924');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133304','1489','33433');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133305','1489','33434');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133306','1488','33435');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133307','1488','33436');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133308','1488','33438');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133309','1488','33439');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133310','1488','33440');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133311','1488','33441');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133312','1488','33442');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133313','1489','33443');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133314','1489','33444');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133315','1489','33445');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133316','1489','33446');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133317','1489','33447');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133318','1489','33448');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133319','1489','33449');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133320','1489','33453');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133321','1489','33454');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133322','1489','33455');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133323','1489','33456');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133324','1489','33457');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133325','1489','33458');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133326','1489','33459');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133327','1489','33925');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133328','1488','34090');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133329','1489','33465');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133330','1489','33466');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133331','1489','33467');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133332','1489','33468');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133333','1489','33469');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133334','1488','33470');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133335','1489','33471');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133336','1489','33472');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133337','1489','33473');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133338','1489','33474');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133339','1489','33475');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133340','1489','33476');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133341','1489','33477');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133342','1489','33478');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133343','1489','33927');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133344','1489','33928');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133345','1489','33929');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133346','1507','33930');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133347','1507','33931');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133348','1507','33932');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133349','1506','33933');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133350','1506','33934');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133351','1506','33936');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133352','1506','33937');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133353','1506','33938');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133354','1506','33939');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133355','1506','33940');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133356','1507','33941');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133357','1507','33942');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133358','1507','33943');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133359','1507','33944');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133360','1507','33945');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133361','1507','33946');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133362','1507','33947');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133363','1507','33951');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133364','1507','33952');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133365','1507','33953');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133366','1507','33954');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133367','1507','33955');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133368','1507','33956');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133369','1507','33957');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133370','1506','34091');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133371','1507','33964');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133372','1507','33965');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133373','1507','33966');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133374','1507','33967');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133375','1507','33968');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133376','1506','33969');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133377','1507','33970');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133378','1507','33971');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133379','1507','33972');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133380','1507','33973');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133381','1507','33974');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133382','1507','33975');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133383','1507','33976');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133384','1507','33977');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133385','1507','33978');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133386','1507','33979');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133387','1507','33980');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133388','1509','33981');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133389','1509','33982');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133390','1509','33983');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133391','1508','33984');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133392','1508','33985');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133393','1508','33987');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133394','1508','33988');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133395','1508','33989');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133396','1508','33990');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133397','1508','33991');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133398','1509','33992');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133399','1509','33993');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133400','1509','33994');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133401','1509','33995');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133402','1509','33996');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133403','1509','33997');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133404','1509','33998');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133405','1509','34002');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133406','1509','34003');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133407','1509','34004');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133408','1509','34005');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133409','1509','34006');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133410','1509','34007');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133411','1509','34008');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133412','1508','34092');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133413','1509','34015');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133414','1509','34016');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133415','1509','34017');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133416','1509','34018');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133417','1509','34019');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133418','1508','34020');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133419','1509','34021');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133420','1509','34022');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133421','1509','34023');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133422','1509','34024');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133423','1509','34025');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133424','1509','34026');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133425','1509','34027');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133426','1509','34028');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133427','1509','34029');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133428','1509','34030');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133429','1509','34031');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133430','1511','34032');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133431','1511','34033');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133432','1511','34034');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133433','1510','34035');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133434','1510','34036');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133435','1510','34038');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133436','1510','34039');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133437','1510','34040');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133438','1510','34041');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133439','1510','34042');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133440','1511','34043');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133441','1511','34044');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133442','1511','34045');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133443','1511','34046');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133444','1511','34047');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133445','1511','34048');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133446','1511','34049');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133447','1511','34053');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133448','1511','34054');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133449','1511','34055');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133450','1511','34056');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133451','1511','34057');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133452','1511','34058');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133453','1511','34059');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133454','1510','34093');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133455','1511','34066');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133456','1511','34067');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133457','1511','34068');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133458','1511','34069');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133459','1511','34070');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133460','1510','34071');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133461','1511','34072');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133462','1511','34073');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133463','1511','34074');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133464','1511','34075');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133465','1511','34076');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133466','1511','34077');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133467','1511','34078');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133468','1511','34079');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133469','1511','34080');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133470','1511','34081');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133471','1511','34082');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133472','1424','32776');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133473','1424','32777');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133474','1424','32778');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133475','1424','32779');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133476','1491','33479');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133477','1490','33480');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133478','1491','33481');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133479','1491','33482');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133480','1491','33483');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133481','1491','33484');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133482','1491','33485');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133483','1491','33486');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133484','1491','33487');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133485','1490','33488');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133486','1490','33489');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133487','1491','33490');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133488','1490','33491');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133489','1491','33492');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133490','1490','33493');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133491','1490','33494');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133492','1490','33495');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133493','1491','33496');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133494','1491','33497');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133495','1491','33498');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133496','1491','33499');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133497','1490','33500');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133498','1490','33501');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133499','1491','33502');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133500','1491','33503');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133501','1490','33504');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133502','1490','33505');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133503','1490','33506');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133504','1490','33507');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133505','1490','33508');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133506','1490','33509');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133507','1491','33510');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133508','1491','33511');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133509','1490','33512');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133510','1491','33545');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133511','1491','33551');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133512','1491','33552');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133513','1491','33553');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133514','1491','33559');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133515','1491','33560');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133516','1491','33561');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133517','1491','33562');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133518','1416','32612');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133519','1416','32613');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133520','1416','32614');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133521','1416','32615');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133522','1325','30685');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133523','1616','34946');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133524','1616','34947');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133525','1616','34948');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133526','1616','34949');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133527','1616','34950');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133528','1621','34951');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133529','1616','34952');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133530','1621','34953');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133531','1614','34964');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133532','1614','34965');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133533','1614','34966');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133534','1615','34967');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133535','1619','34982');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133536','1619','34983');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133537','1619','34984');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133538','1619','34985');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133539','1619','34986');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133540','1620','34987');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133541','1622','34988');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133542','1622','34989');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133543','1622','34990');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133544','1622','34991');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133545','1622','34992');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133546','1617','34993');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133547','1617','34994');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133548','1621','34995');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133549','1623','34996');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133550','1623','34997');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133551','1623','34998');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133552','1277','30066');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133553','1277','30067');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133554','1277','30068');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133555','1277','30069');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133556','1277','30070');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133557','1276','30071');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133558','1271','30072');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133559','1274','30073');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133560','1274','30074');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133561','1273','30075');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133562','1275','30076');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133563','1275','30077');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133564','1275','30078');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133565','1275','30079');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133566','1278','30080');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133567','1278','30081');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133568','1278','30082');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133569','1272','30083');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133570','1272','30084');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133571','1272','30085');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133572','1635','35041');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133573','1635','35042');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133574','1636','35043');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133575','1636','35044');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133576','1636','35045');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133577','1635','35046');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133578','1635','35047');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133579','1635','35048');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133580','1639','35049');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133581','1636','35050');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133582','1639','35051');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133583','1635','35052');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133584','1639','35053');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133585','1633','35061');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133586','1633','35062');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133587','1633','35063');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133588','1634','35064');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133589','1634','35065');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133590','1637','35066');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133591','1637','35067');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133592','1637','35068');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133593','1637','35069');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133594','1637','35070');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133595','1637','35071');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133596','1638','35072');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133597','1640','35073');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133598','1640','35074');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133599','1641','35075');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133600','1641','35076');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133601','1641','35077');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133602','1641','35078');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133603','1641','35079');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133604','1641','35080');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133605','1653','35123');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133606','1653','35124');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133607','1654','35125');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133608','1654','35126');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133609','1654','35127');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133610','1653','35128');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133611','1653','35129');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133612','1653','35130');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133613','1657','35131');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133614','1654','35132');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133615','1657','35133');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133616','1653','35134');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133617','1657','35135');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133618','1651','35143');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133619','1651','35144');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133620','1651','35145');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133621','1652','35146');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133622','1652','35147');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133623','1655','35148');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133624','1655','35149');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133625','1655','35150');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133626','1655','35151');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133627','1655','35152');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133628','1655','35153');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133629','1656','35154');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133630','1658','35155');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133631','1658','35156');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133632','1659','35157');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133633','1659','35158');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133634','1659','35159');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133635','1659','35160');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133636','1659','35161');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133637','1659','35162');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133638','1671','35205');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133639','1671','35206');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133640','1672','35207');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133641','1672','35208');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133642','1672','35209');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133643','1671','35210');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133644','1671','35211');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133645','1671','35212');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133646','1675','35213');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133647','1672','35214');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133648','1675','35215');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133649','1671','35216');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133650','1675','35217');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133651','1669','35225');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133652','1669','35226');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133653','1669','35227');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133654','1670','35228');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133655','1670','35229');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133656','1673','35230');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133657','1673','35231');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133658','1673','35232');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133659','1673','35233');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133660','1673','35234');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133661','1673','35235');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133662','1674','35236');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133663','1676','35237');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133664','1676','35238');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133665','1677','35239');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133666','1677','35240');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133667','1677','35241');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133668','1677','35242');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133669','1677','35243');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133670','1677','35244');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133671','1689','35287');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133672','1689','35288');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133673','1690','35289');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133674','1690','35290');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133675','1690','35291');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133676','1689','35292');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133677','1689','35293');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133678','1689','35294');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133679','1693','35295');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133680','1690','35296');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133681','1693','35297');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133682','1689','35298');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133683','1693','35299');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133684','1687','35307');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133685','1687','35308');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133686','1687','35309');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133687','1688','35310');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133688','1688','35311');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133689','1691','35312');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133690','1691','35313');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133691','1691','35314');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133692','1691','35315');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133693','1691','35316');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133694','1691','35317');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133695','1692','35318');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133696','1694','35319');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133697','1694','35320');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133698','1695','35321');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133699','1695','35322');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133700','1695','35323');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133701','1695','35324');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133702','1695','35325');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133703','1695','35326');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133704','1070','28341');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133705','1073','28342');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133706','1073','28344');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133707','1073','28345');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133708','1073','30141');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133709','1076','28354');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133710','1076','28355');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133711','1076','28356');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133712','1076','28357');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133713','1075','28358');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133714','1072','28359');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133715','1072','28360');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133716','1074','28361');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133717','1074','28362');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133718','1074','28363');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133719','1074','28364');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133720','1074','28365');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133721','1074','28366');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133722','1074','28367');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133723','1077','28368');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133724','1077','28369');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133725','1077','28370');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133726','1077','28371');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133727','1077','28372');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133728','1077','28373');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133729','1071','28374');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133730','1071','28375');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133731','1071','28376');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133732','1698','35327');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133733','1698','35328');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133734','1699','35329');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133735','1699','35330');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133736','1698','35331');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133737','1698','35332');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133738','1698','35333');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133739','1704','35334');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133740','1703','35335');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133741','1703','35336');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133742','1698','35337');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133743','1703','35338');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133744','1696','35353');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133745','1696','35354');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133746','1696','35355');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133747','1696','35356');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133748','1697','35357');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133749','1700','35358');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133750','1701','35359');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133751','1701','35360');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133752','1701','35361');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133753','1701','35362');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133754','1701','35363');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133755','1701','35364');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133756','1702','35365');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133757','1704','35366');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133758','1704','35367');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133759','1704','35368');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133760','1704','35369');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133761','1704','35370');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133762','1704','35371');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133763','1704','35372');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133764','1704','35373');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133765','1704','35374');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133766','1704','35375');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133767','1704','35376');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133768','1704','35377');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133769','1704','35378');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133770','1704','35379');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133771','1704','35380');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133772','1705','35381');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133773','1705','35382');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133774','1705','35383');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133775','1708','35384');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133776','1708','35385');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133777','1709','35386');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133778','1709','35387');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133779','1708','35388');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133780','1708','35389');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133781','1708','35390');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133782','1714','35391');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133783','1713','35392');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133784','1713','35393');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133785','1708','35394');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133786','1713','35395');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133787','1706','35410');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133788','1706','35411');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133789','1706','35412');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133790','1706','35413');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133791','1707','35414');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133792','1710','35415');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133793','1711','35416');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133794','1711','35417');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133795','1711','35418');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133796','1711','35419');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133797','1711','35420');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133798','1711','35421');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133799','1712','35422');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133800','1714','35423');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133801','1714','35424');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133802','1714','35425');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133803','1714','35426');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133804','1714','35427');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133805','1714','35428');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133806','1714','35429');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133807','1714','35430');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133808','1714','35431');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133809','1714','35432');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133810','1714','35433');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133811','1714','35434');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133812','1714','35435');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133813','1714','35436');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133814','1714','35437');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133815','1715','35438');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133816','1715','35439');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133817','1715','35440');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133818','1718','35441');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133819','1718','35442');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133820','1719','35443');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133821','1719','35444');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133822','1718','35445');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133823','1718','35446');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133824','1718','35447');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133825','1724','35448');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133826','1723','35449');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133827','1723','35450');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133828','1718','35451');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133829','1723','35452');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133830','1716','35467');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133831','1716','35468');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133832','1716','35469');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133833','1716','35470');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133834','1717','35471');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133835','1720','35472');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133836','1721','35473');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133837','1721','35474');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133838','1721','35475');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133839','1721','35476');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133840','1721','35477');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133841','1721','35478');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133842','1722','35479');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133843','1724','35480');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133844','1724','35481');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133845','1724','35482');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133846','1724','35483');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133847','1724','35484');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133848','1724','35485');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133849','1724','35486');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133850','1724','35487');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133851','1724','35488');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133852','1724','35489');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133853','1724','35490');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133854','1724','35491');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133855','1724','35492');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133856','1724','35493');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133857','1724','35494');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133858','1725','35495');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133859','1725','35496');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133860','1725','35497');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133861','1728','35498');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133862','1728','35499');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133863','1729','35500');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133864','1729','35501');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133865','1728','35502');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133866','1728','35503');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133867','1728','35504');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133868','1734','35505');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133869','1733','35506');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133870','1733','35507');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133871','1728','35508');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133872','1733','35509');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133873','1726','35524');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133874','1726','35525');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133875','1726','35526');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133876','1726','35527');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133877','1727','35528');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133878','1730','35529');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133879','1731','35530');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133880','1731','35531');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133881','1731','35532');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133882','1731','35533');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133883','1731','35534');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133884','1731','35535');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133885','1732','35536');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133886','1734','35537');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133887','1734','35538');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133888','1734','35539');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133889','1734','35540');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133890','1734','35541');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133891','1734','35542');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133892','1734','35543');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133893','1734','35544');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133894','1734','35545');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133895','1734','35546');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133896','1734','35547');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133897','1734','35548');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133898','1734','35549');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133899','1734','35550');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133900','1734','35551');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133901','1735','35552');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133902','1735','35553');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133903','1735','35554');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133904','1085','28388');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133905','1082','28390');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133906','1082','28391');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133907','1079','29994');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133908','1085','28404');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133909','1085','28405');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133910','1085','28406');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133911','1085','28407');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133912','1085','28408');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133913','1085','28409');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133914','1084','28411');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133915','1081','28412');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133916','1080','28413');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133917','1080','28414');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133918','1080','28415');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133919','1080','28416');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133920','1083','28417');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133921','1083','28418');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133922','1083','28419');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133923','1083','28420');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133924','1083','28421');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133925','1083','28422');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133926','1086','28423');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133927','1086','28424');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133928','1086','28425');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133929','1085','32732');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133930','1085','32733');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133931','1085','32734');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133932','1085','32735');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133933','1085','32736');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133934','1085','32737');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133935','1085','32738');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133936','1085','32739');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133937','1085','32740');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133938','1095','28465');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133939','1097','28466');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133940','1097','28467');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133941','1100','28474');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133942','1100','28475');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133943','1100','28476');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133944','1099','28477');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133945','1096','28478');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133946','1096','28479');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133947','1098','28480');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133948','1098','28481');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133949','1104','28495');
INSERT INTO items_applications (itemappid,applicationid,itemid) values ('133950','1103','28496');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1','1','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2','1','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('3','2','0','not available');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('4','2','1','available');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('5','2','2','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('13','6','1','Other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('14','6','2','OK');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('15','6','3','Degraded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('17','7','1','Other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('18','7','2','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('19','7','3','OK');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('20','7','4','NonCritical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('21','7','5','Critical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('22','7','6','NonRecoverable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('23','5','1','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('24','5','2','batteryNormal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('25','5','3','batteryLow');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('26','4','1','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('27','4','2','notInstalled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('28','4','3','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('29','4','4','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('30','4','5','highTemperature');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('31','4','6','replaceImmediately');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('32','4','7','lowCapacity');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('33','3','0','Running');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('34','3','1','Paused');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('35','3','3','Pause pending');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('36','3','4','Continue pending');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('37','3','5','Stop pending');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('38','3','6','Stopped');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('39','3','7','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('40','3','255','No such service');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('41','3','2','Start pending');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('49','9','1','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('50','9','2','running');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('51','9','3','warning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('52','9','4','testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('53','9','5','down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('61','8','1','up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('62','8','2','down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('63','8','3','testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('64','8','4','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('65','8','5','dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('66','8','6','notPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('67','8','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('68','10','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('69','11','1','up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('70','11','2','down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('71','11','3','testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('72','12','0','poweredOff');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('73','12','1','poweredOn');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('74','12','2','suspended');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('75','13','0','gray');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('76','13','1','green');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('77','13','2','yellow');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('78','13','3','red');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('79','14','0','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('80','14','1','in maintenance');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('81','14','2','no data collection');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('82','15','0','Normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('83','15','1','Low memory');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('84','16','0','Automatic');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('85','16','1','Automatic delayed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('86','16','2','Manual');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('87','16','3','Disabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('88','16','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('89','17','100','Continue');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('90','17','101','Switching Protocols');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('91','17','102','Processing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('92','17','200','OK');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('93','17','201','Created');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('94','17','202','Accepted');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('95','17','203','Non-Authoritative Information');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('96','17','204','No Content');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('97','17','205','Reset Content');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('98','17','206','Partial Content');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('99','17','207','Multi-Status');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('100','17','208','Already Reported');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('101','17','226','IM Used');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('102','17','300','Multiple Choices');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('103','17','301','Moved Permanently');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('104','17','302','Found');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('105','17','303','See Other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('106','17','304','Not Modified');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('107','17','305','Use Proxy');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('108','17','306','Switch Proxy');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('109','17','307','Temporary Redirect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('110','17','308','Permanent Redirect/Resume Incomplete');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('111','17','400','Bad Request');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('112','17','401','Unauthorized');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('113','17','402','Payment Required');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('114','17','403','Forbidden');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('115','17','404','Not Found');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('116','17','405','Method Not Allowed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('117','17','406','Not Acceptable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('118','17','407','Proxy Authentication Required');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('119','17','408','Request Timeout');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('120','17','409','Conflict');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('121','17','410','Gone');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('122','17','411','Length Required');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('123','17','412','Precondition Failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('124','17','413','Payload Too Large');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('125','17','414','Request-URI Too Long');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('126','17','415','Unsupported Media Type');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('127','17','416','Requested Range Not Satisfiable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('128','17','417','Expectation Failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('129','17','418','I''m a Teapot');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('130','17','419','Authentication Timeout');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('131','17','420','Method Failure/Enhance Your Calm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('132','17','421','Misdirected Request');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('133','17','422','Unprocessable Entity');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('134','17','423','Locked');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('135','17','424','Failed Dependency');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('136','17','426','Upgrade Required');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('137','17','428','Precondition Required');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('138','17','429','Too Many Requests');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('139','17','431','Request Header Fields Too Large');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('140','17','440','Login Timeout');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('141','17','444','No Response');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('142','17','449','Retry With');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('143','17','450','Blocked by Windows Parental Controls');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('144','17','451','Unavailable for Legal Reasons/Redirect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('145','17','494','Request Header Too Large');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('146','17','495','Cert Error');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('147','17','496','No Cert');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('148','17','497','HTTP to HTTPS');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('149','17','498','Token Expired/Invalid');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('150','17','499','Client Closed Request/Token Required');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('151','17','500','Internal Server Error');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('152','17','501','Not Implemented');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('153','17','502','Bad Gateway');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('154','17','503','Service Unavailable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('155','17','504','Gateway Timeout');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('156','17','505','HTTP Version Not Supported');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('157','17','506','Variant Also Negotiates');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('158','17','507','Insufficient Storage');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('159','17','508','Loop Detected');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('160','17','509','Bandwidth Limit Exceeded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('161','17','510','Not Extended');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('162','17','511','Network Authentication Required');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('163','17','520','Unknown Error');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('164','17','598','Network Read Timeout Error');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('165','17','599','Network Connect Timeout Error');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('166','18','1','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('167','18','2','unavailable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('168','18','3','nonoperational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('169','19','1','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('170','19','2','halfDuplex');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('171','19','3','fullDuplex');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('172','20','1','up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('173','20','2','down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('175','20','4','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('176','20','5','dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('177','20','6','notPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('178','20','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('179','21','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('180','21','2','regular1822');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('181','21','3','hdh1822');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('182','21','4','ddnX25');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('183','21','5','rfc877x25');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('184','21','6','ethernetCsmacd');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('185','21','7','iso88023Csmacd');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('186','21','8','iso88024TokenBus');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('187','21','9','iso88025TokenRing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('188','21','10','iso88026Man');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('189','21','11','starLan');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('190','21','12','proteon10Mbit');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('191','21','13','proteon80Mbit');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('192','21','14','hyperchannel');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('193','21','15','fddi');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('194','21','16','lapb');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('195','21','17','sdlc');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('196','21','18','ds1');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('197','21','19','e1');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('198','21','20','basicISDN');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('199','21','21','primaryISDN');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('200','21','22','propPointToPointSerial');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('201','21','23','ppp');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('202','21','24','softwareLoopback');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('203','21','25','eon');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('204','21','26','ethernet3Mbit');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('205','21','27','nsip');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('206','21','28','slip');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('207','21','29','ultra');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('208','21','30','ds3');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('209','21','31','sip');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('210','21','32','frameRelay');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('211','21','33','rs232');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('212','21','34','para');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('213','21','35','arcnet');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('214','21','36','arcnetPlus');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('215','21','37','atm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('216','21','38','miox25');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('217','21','39','sonet');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('218','21','40','x25ple');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('219','21','41','iso88022llc');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('220','21','42','localTalk');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('221','21','43','smdsDxi');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('222','21','44','frameRelayService');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('223','21','45','v35');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('224','21','46','hssi');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('225','21','47','hippi');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('226','21','48','modem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('227','21','49','aal5');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('228','21','50','sonetPath');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('229','21','51','sonetVT');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('230','21','52','smdsIcip');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('231','21','53','propVirtual');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('232','21','54','propMultiplexor');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('233','21','55','ieee80212');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('234','21','56','fibreChannel');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('235','21','57','hippiInterface');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('236','21','58','frameRelayInterconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('237','21','59','aflane8023');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('238','21','60','aflane8025');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('239','21','61','cctEmul');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('240','21','62','fastEther');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('241','21','63','isdn');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('242','21','64','v11');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('243','21','65','v36');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('244','21','66','g703at64k');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('245','21','67','g703at2mb');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('246','21','68','qllc');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('247','21','69','fastEtherFX');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('248','21','70','channel');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('249','21','71','ieee80211');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('250','21','72','ibm370parChan');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('251','21','73','escon');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('252','21','74','dlsw');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('253','21','75','isdns');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('254','21','76','isdnu');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('255','21','77','lapd');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('256','21','78','ipSwitch');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('257','21','79','rsrb');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('258','21','80','atmLogical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('259','21','81','ds0');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('260','21','82','ds0Bundle');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('261','21','83','bsc');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('262','21','84','async');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('263','21','85','cnr');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('264','21','86','iso88025Dtr');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('265','21','87','eplrs');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('266','21','88','arap');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('267','21','89','propCnls');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('268','21','90','hostPad');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('269','21','91','termPad');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('270','21','92','frameRelayMPI');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('271','21','93','x213');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('272','21','94','adsl');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('273','21','95','radsl');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('274','21','96','sdsl');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('275','21','97','vdsl');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('276','21','98','iso88025CRFPInt');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('277','21','99','myrinet');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('278','21','100','voiceEM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('279','21','101','voiceFXO');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('280','21','102','voiceFXS');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('281','21','103','voiceEncap');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('282','21','104','voiceOverIp');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('283','21','105','atmDxi');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('284','21','106','atmFuni');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('285','21','107','atmIma');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('286','21','108','pppMultilinkBundle');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('287','21','109','ipOverCdlc');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('288','21','110','ipOverClaw');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('289','21','111','stackToStack');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('290','21','112','virtualIpAddress');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('291','21','113','mpc');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('292','21','114','ipOverAtm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('293','21','115','iso88025Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('294','21','116','tdlc');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('295','21','117','gigabitEthernet');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('296','21','118','hdlc');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('297','21','119','lapf');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('298','21','120','v37');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('299','21','121','x25mlp');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('300','21','122','x25huntGroup');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('301','21','123','trasnpHdlc');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('302','21','124','interleave');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('303','21','125','fast');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('304','21','126','ip');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('305','21','127','docsCableMaclayer');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('306','21','128','docsCableDownstream');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('307','21','129','docsCableUpstream');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('308','21','130','a12MppSwitch');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('309','21','131','tunnel');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('310','21','132','coffee');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('311','21','133','ces');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('312','21','134','atmSubInterface');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('313','21','135','l2vlan');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('314','21','136','l3ipvlan');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('315','21','137','l3ipxvlan');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('316','21','138','digitalPowerline');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('317','21','139','mediaMailOverIp');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('318','21','140','dtm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('319','21','141','dcn');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('320','21','142','ipForward');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('321','21','143','msdsl');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('322','21','144','ieee1394');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('323','21','145','if-gsn');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('324','21','146','dvbRccMacLayer');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('325','21','147','dvbRccDownstream');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('326','21','148','dvbRccUpstream');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('327','21','149','atmVirtual');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('328','21','150','mplsTunnel');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('329','21','151','srp');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('330','21','152','voiceOverAtm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('331','21','153','voiceOverFrameRelay');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('332','21','154','idsl');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('333','21','155','compositeLink');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('334','21','156','ss7SigLink');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('335','21','157','propWirelessP2P');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('336','21','158','frForward');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('337','21','159','rfc1483');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('338','21','160','usb');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('339','21','161','ieee8023adLag');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('340','21','162','bgppolicyaccounting');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('341','21','163','frf16MfrBundle');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('342','21','164','h323Gatekeeper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('343','21','165','h323Proxy');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('344','21','166','mpls');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('345','21','167','mfSigLink');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('346','21','168','hdsl2');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('347','21','169','shdsl');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('348','21','170','ds1FDL');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('349','21','171','pos');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('350','21','172','dvbAsiIn');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('351','21','173','dvbAsiOut');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('352','21','174','plc');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('353','21','175','nfas');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('354','21','176','tr008');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('355','21','177','gr303RDT');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('356','21','178','gr303IDT');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('357','21','179','isup');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('358','21','180','propDocsWirelessMaclayer');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('359','21','181','propDocsWirelessDownstream');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('360','21','182','propDocsWirelessUpstream');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('361','21','183','hiperlan2');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('362','21','184','propBWAp2Mp');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('363','21','185','sonetOverheadChannel');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('364','21','186','digitalWrapperOverheadChannel');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('365','21','187','aal2');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('366','21','188','radioMAC');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('367','21','189','atmRadio');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('368','21','190','imt');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('369','21','191','mvl');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('370','21','192','reachDSL');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('371','21','193','frDlciEndPt');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('372','21','194','atmVciEndPt');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('373','21','195','opticalChannel');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('374','21','196','opticalTransport');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('375','21','197','propAtm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('376','21','198','voiceOverCable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('377','21','199','infiniband');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('378','21','200','teLink');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('379','21','201','q2931');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('380','21','202','virtualTg');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('381','21','203','sipTg');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('382','21','204','sipSig');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('383','21','205','docsCableUpstreamChannel');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('384','21','206','econet');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('385','21','207','pon155');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('386','21','208','pon622');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('387','21','209','bridge');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('388','21','210','linegroup');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('389','21','211','voiceEMFGD');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('390','21','212','voiceFGDEANA');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('391','21','213','voiceDID');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('392','21','214','mpegTransport');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('393','21','215','sixToFour');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('394','21','216','gtp');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('395','21','217','pdnEtherLoop1');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('396','21','218','pdnEtherLoop2');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('397','21','219','opticalChannelGroup');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('398','21','220','homepna');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('399','21','221','gfp');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('400','21','222','ciscoISLvlan');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('401','21','223','actelisMetaLOOP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('402','21','224','fcipLink');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('403','21','225','rpr');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('404','21','226','qam');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('405','21','227','lmp');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('406','21','228','cblVectaStar');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('407','21','229','docsCableMCmtsDownstream');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('408','21','230','adsl2');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('409','21','231','macSecControlledIF');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('410','21','232','macSecUncontrolledIF');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('411','21','233','aviciOpticalEther');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('412','21','234','atmbond');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('413','21','235','voiceFGDOS');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('414','21','236','mocaVersion1');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('415','21','237','ieee80216WMAN');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('416','21','238','adsl2plus');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('417','21','239','dvbRcsMacLayer');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('418','21','240','dvbTdm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('419','21','241','dvbRcsTdma');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('420','21','242','x86Laps');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('421','21','243','wwanPP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('422','21','244','wwanPP2');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('423','21','245','voiceEBS');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('424','21','246','ifPwType');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('425','21','247','ilan');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('426','21','248','pip');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('427','21','249','aluELP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('428','21','250','gpon');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('429','21','251','vdsl2');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('430','21','252','capwapDot11Profile');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('431','21','253','capwapDot11Bss');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('432','21','254','capwapWtpVirtualRadio');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('433','21','255','bits');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('434','21','256','docsCableUpstreamRfPort');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('435','21','257','cableDownstreamRfPort');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('436','21','258','vmwareVirtualNic');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('437','21','259','ieee802154');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('438','21','260','otnOdu');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('439','21','261','otnOtu');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('440','21','262','ifVfiType');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('441','21','263','g9981');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('442','21','264','g9982');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('443','21','265','g9983');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('444','21','266','aluEpon');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('445','21','267','aluEponOnu');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('446','21','268','aluEponPhysicalUni');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('447','21','269','aluEponLogicalLink');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('448','21','270','aluGponOnu');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('449','21','271','aluGponPhysicalUni');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('450','21','272','vmwareNicTeam');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('451','21','277','docsOfdmDownstream');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('452','21','278','docsOfdmaUpstream');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('453','21','279','gfast');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('454','21','280','sdci');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('455','21','281','xboxWireless');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('456','21','282','fastdsl');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('457','21','283','docsCableScte55d1FwdOob');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('458','21','284','docsCableScte55d1RetOob');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('459','21','285','docsCableScte55d2DsOob');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('460','21','286','docsCableScte55d2UsOob');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('461','21','287','docsCableNdf');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('462','21','288','docsCableNdr');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('463','21','289','ptm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('464','21','290','ghn');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('465','22','0','not available');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('466','22','1','available');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('468','23','1','deviceStateUnknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('469','23','2','deviceNotEquipped');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('470','23','3','deviceStateOk');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('471','23','4','deviceStateFailed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('472','23','5','deviceStateOutOfService');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('473','24','1','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('474','24','2','faulty');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('475','24','3','below-min');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('476','24','4','nominal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('477','24','5','above-max');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('478','24','6','absent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('479','25','1','online');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('480','25','2','offline');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('481','25','3','testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('482','25','4','faulty');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('483','26','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('484','26','2','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('485','26','3','failure');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('486','27','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('487','27','2','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('488','27','3','failure');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('489','28','1','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('490','28','2','warning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('491','28','3','critical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('492','28','4','shutdown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('493','28','5','notPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('494','28','6','notFunctioning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('495','29','1','true - on');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('496','29','2','false - off');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('497','30','1','up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('498','30','2','down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('499','30','3','absent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('500','31','1','up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('501','31','2','down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('502','31','3','absent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('503','32','1','noexist');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('504','32','2','existnopower');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('505','32','3','existreadypower');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('506','32','4','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('507','32','5','powerbutabnormal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('508','32','6','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('509','33','0','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('510','33','1','working');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('511','33','2','fail');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('512','33','3','speed-0');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('513','33','4','speed-low');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('514','33','5','speed-middle');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('515','33','6','speed-high');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('516','34','0','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('517','34','1','lowVoltage');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('518','34','2','overCurrent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('519','34','3','working');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('520','34','4','fail');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('521','34','5','connect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('522','34','6','disconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('523','35','1','true');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('524','35','2','false');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('525','36','1','true - on');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('526','36','2','false - off');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('527','37','1','alarm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('528','37','2','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('529','38','1','notPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('530','38','2','presentOK');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('531','38','3','presentNotOK');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('532','38','4','presentPowerOff');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('533','39','1','notSupported');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('534','39','2','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('535','39','3','postFailure');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('536','39','4','entityAbsent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('543','39','11','poeError');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('550','40','1','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('551','40','2','bad');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('552','40','3','warning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('553','40','4','good');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('554','40','5','notPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('555','41','1','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('556','41','2','abnormal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('557','42','1','online');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('558','42','2','operational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('559','42','3','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('560','42','4','offline');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('561','43','1','invalid');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('562','43','2','bad');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('563','43','3','warning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('564','43','4','good');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('565','43','5','disabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('566','44','1','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('567','44','2','disabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('568','44','3','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('569','44','4','warning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('570','44','5','standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('571','44','6','engaged');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('572','44','7','redundant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('573','44','8','notPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('574','45','1','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('575','45','2','high');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('576','45','3','excessivelyHigh');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('577','45','4','low');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('578','45','5','excessivelyLow');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('579','45','6','noSensor');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('580','45','7','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('581','46','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('582','46','2','off');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('583','46','3','on - RedAlarm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('584','47','1','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('585','47','2','running');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('586','47','3','ready');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('587','47','4','reset');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('588','47','5','runningAtFullSpeed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('589','47','6','down or off');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('590','47','7','standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('591','48','1','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('592','48','2','disabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('593','48','3','enabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('594','48','4','testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('595','49','1','operational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('596','49','2','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('597','49','3','powering');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('598','49','4','notpowering');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('599','49','5','notpresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('600','50','1','operational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('601','50','2','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('602','50','3','powering');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('603','50','4','notpowering');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('604','50','5','notpresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('605','51','1','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('606','51','2','warning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('607','51','3','critical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('608','51','4','shutdown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('609','51','5','notpresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('610','51','6','notoperational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('611','52','0','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('612','52','1','abnormal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('613','53','0','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('614','53','1','abnormal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('615','53','2','not available');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('616','54','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('617','54','2','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('618','54','3','degraded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('619','54','4','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('620','55','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('621','55','2','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('622','55','3','system');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('623','55','4','systemBoard');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('624','55','5','ioBoard');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('625','55','6','cpu');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('626','55','7','memory');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('627','55','8','storage');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('628','55','9','removableMedia');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('629','55','10','powerSupply');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('630','55','11','ambient');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('631','55','12','chassis');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('632','55','13','bridgeCard');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('633','56','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('634','56','2','ida');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('635','56','3','idaExpansion');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('636','56','4','ida-2');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('637','56','5','smart');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('638','56','6','smart-2e');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('639','56','7','smart-2p');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('640','56','8','smart-2sl');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('641','56','9','smart-3100es');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('642','56','10','smart-3200');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('643','56','11','smart-2dh');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('644','56','12','smart-221');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('645','56','13','sa-4250es');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('646','56','14','sa-4200');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('647','56','15','sa-integrated');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('648','56','16','sa-431');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('649','56','17','sa-5300');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('650','56','18','raidLc2');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('651','56','19','sa-5i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('652','56','20','sa-532');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('653','56','21','sa-5312');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('654','56','22','sa-641');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('655','56','23','sa-642');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('656','56','24','sa-6400');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('657','56','25','sa-6400em');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('658','56','26','sa-6i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('659','56','27','sa-generic');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('660','56','29','sa-p600');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('661','56','30','sa-p400');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('662','56','31','sa-e200');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('663','56','32','sa-e200i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('664','56','33','sa-p400i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('665','56','34','sa-p800');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('666','56','35','sa-e500');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('667','56','36','sa-p700m');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('668','56','37','sa-p212');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('669','56','38','sa-p410');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('670','56','39','sa-p410i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('671','56','40','sa-p411');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('672','56','41','sa-b110i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('673','56','42','sa-p712m');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('674','56','43','sa-p711m');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('675','56','44','sa-p812');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('676','57','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('677','57','2','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('678','57','3','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('679','57','4','predictiveFailure');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('680','58','0','nonRecoverable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('681','58','2','critical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('682','58','4','nonCritical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('683','58','255','normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('684','59','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('685','59','2','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('686','59','3','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('687','59','4','nonCritical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('688','59','5','critical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('689','59','6','nonRecoverable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('690','60','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('691','60','2','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('692','60','3','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('693','60','4','nonCriticalUpper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('694','60','5','criticalUpper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('695','60','6','nonRecoverableUpper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('696','60','7','nonCriticalLower');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('697','60','8','criticalLower');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('698','60','9','nonRecoverableLower');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('699','60','10','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('700','61','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('701','61','2','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('702','61','3','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('703','61','4','nonCritical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('704','61','5','critical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('705','61','6','nonRecoverable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('706','62','0','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('707','62','1','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('708','63','1','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('709','63','2','HDD');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('710','63','3','SSD');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('711','64','1','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('712','64','2','Ready');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('713','64','3','Failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('714','64','4','Degraded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('715','64','5','Missing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('716','64','6','Charging');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('717','64','7','Below threshold');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('718','65','1','Other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('719','65','2','RAID-0');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('720','65','3','RAID-1');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('721','65','4','RAID-5');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('722','65','5','RAID-6');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('723','65','6','RAID-10');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('724','65','7','RAID-50');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('725','65','8','RAID-60');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('726','65','9','Concatenated RAID 1');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('727','65','10','Concatenated RAID 5');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('728','66','1','Not applicable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('729','66','2','Reconstructing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('730','66','3','Resynching');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('731','66','4','Initializing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('732','66','5','Background init');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('733','67','1','Write Through');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('734','67','2','Write Back');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('735','67','3','Force Write Back');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('736','68','1','No Read Ahead');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('737','68','2','Read Ahead');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('738','68','3','Adaptive Read Ahead');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('739','69','1','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('740','69','2','Online');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('741','69','3','Failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('742','69','4','Degraded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('743','70','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('744','70','2','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('745','70','3','replaceDrive');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('746','70','4','replaceDriveSSDWearOut');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('747','71','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('748','71','2','invalid');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('749','71','3','enabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('750','71','4','tmpDisabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('751','71','5','permDisabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('752','71','6','cacheModFlashMemNotAttached');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('753','71','7','cacheModDegradedFailsafeSpeed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('754','71','8','cacheModCriticalFailure');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('755','71','9','cacheReadCacheNotMapped');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('756','72','1','Other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('757','72','2','Ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('758','72','3','Recharging');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('759','72','4','Failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('760','72','5','Degraded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('761','72','6','Not Present');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('762','72','7','Capacitor failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('763','73','1','Other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('764','73','2','rotatingPlatters');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('765','73','3','solidState');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('766','74','0','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('767','74','2','none');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('768','74','3','RAID-1/RAID-10');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('769','74','4','RAID-4');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('770','74','5','RAID-5');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('771','74','7','RAID-6');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('772','74','8','RAID-50');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('773','74','9','RAID-60');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('774','74','10','RAID-1 ADM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('775','74','11','RAID-10 ADM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('776','75','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('777','75','2','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('778','75','3','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('779','75','4','unconfigured');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('780','75','5','recovering');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('781','75','6','readyForRebuild');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('782','75','7','rebuilding');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('783','75','8','wrongDrive');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('784','75','9','badConnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('785','75','10','overheating');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('786','75','11','shutdown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('787','75','12','expanding');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('788','75','13','notAvailable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('789','75','14','queuedForExpansion');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('790','75','15','multipathAccessDegraded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('791','75','16','erasing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('792','75','17','predictiveSpareRebuildReady');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('793','75','18','rapidParityInitInProgress');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('794','75','19','rapidParityInitPending');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('795','75','20','noAccessEncryptedNoCntlrKey');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('796','75','21','unencryptedToEncryptedInProgress');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('797','75','22','newLogDrvKeyRekeyInProgress');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('798','75','23','noAccessEncryptedCntlrEncryptnNotEnbld');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('799','75','24','unencryptedToEncryptedNotStarted');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('800','75','25','newLogDrvKeyRekeyRequestReceived');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('801','56','45','sw-1210m');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('802','56','46','sa-p220i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('803','56','47','sa-p222');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('804','56','48','sa-p420');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('805','56','49','sa-p420i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('806','56','50','sa-p421');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('807','56','51','sa-b320i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('808','56','52','sa-p822');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('809','56','53','sa-p721m');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('810','56','54','sa-b120i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('811','56','55','hps-1224');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('812','56','56','hps-1228');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('813','56','57','hps-1228m');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('814','56','58','sa-p822se');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('815','56','59','hps-1224e');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('816','56','60','hps-1228e');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('817','56','61','hps-1228em');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('818','56','62','sa-p230i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('819','56','63','sa-p430i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('820','56','64','sa-p430');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('821','56','65','sa-p431');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('822','56','66','sa-p731m');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('823','56','67','sa-p830i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('824','56','68','sa-p830');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('825','56','69','sa-p831');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('826','56','70','sa-p530');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('827','56','71','sa-p531');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('828','56','72','sa-p244br');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('829','56','73','sa-p246br');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('830','56','74','sa-p440');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('831','56','75','sa-p440ar');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('832','56','76','sa-p441');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('833','56','77','sa-p741m');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('834','56','78','sa-p840');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('835','56','79','sa-p841');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('836','56','80','sh-h240ar');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('837','56','81','sh-h244br');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('838','56','82','sh-h240');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('839','56','83','sh-h241');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('840','56','84','sa-b140i');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('841','56','85','sh-generic');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('842','56','88','sa-p840ar');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('843','76','0','Master');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('844','76','1','Standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('845','77','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('846','77','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('847','77','2','Master');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('848','78','0','from KA9Q: NET/ROM pseudo');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('849','78','1','Ethernet');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('850','78','2','Experimental Ethernet');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('851','78','3','AX.25 Level 2');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('852','78','4','PROnet token ring');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('853','78','5','Chaosnet');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('854','78','6','IEEE 802.2 Ethernet/TR/TB');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('855','78','7','ARCnet');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('856','78','8','APPLEtalk');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('857','78','15','Frame Relay DLCI');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('858','78','19','ATM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('859','78','23','Metricom STRIP (new IANA id)');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('860','78','24','IEEE 1394 IPv4 - RFC 2734');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('861','78','27','EUI-64');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('862','78','32','InfiniBand');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('863','78','256','ARPHRD_SLIP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('864','78','257','ARPHRD_CSLIP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('865','78','258','ARPHRD_SLIP6');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('866','78','259','ARPHRD_CSLIP6');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('867','78','260','Notional KISS type');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('868','78','264','ARPHRD_ADAPT');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('869','78','270','ARPHRD_ROSE');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('870','78','271','CCITT X.25');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('871','78','272','Boards with X.25 in firmware');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('872','78','280','Controller Area Network');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('873','78','512','ARPHRD_PPP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('874','78','513','Cisco HDLC');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('875','78','516','LAPB');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('876','78','517','Digital''s DDCMP protocol');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('877','78','518','Raw HDLC');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('878','78','519','Raw IP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('879','78','768','IPIP tunnel');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('880','78','769','IP6IP6 tunnel');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('881','78','770','Frame Relay Access Device');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('882','78','771','SKIP vif');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('883','78','772','Loopback device');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('884','78','773','Localtalk device');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('885','78','774','Fiber Distributed Data Interface');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('886','78','775','AP1000 BIF');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('887','78','776','sit0 device - IPv6-in-IPv4');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('888','78','777','IP over DDP tunneller');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('889','78','778','GRE over IP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('890','78','779','PIMSM register interface');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('891','78','780','High Performance Parallel Interface');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('892','78','781','Nexus 64Mbps Ash');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('893','78','782','Acorn Econet');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('894','78','783','Linux-IrDA');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('895','78','784','Point to point fibrechannel');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('896','78','785','Fibrechannel arbitrated loop');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('897','78','786','Fibrechannel public loop');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('898','78','787','Fibrechannel fabric');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('899','78','800','Magic type ident for TR');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('900','78','801','IEEE 802.11');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('901','78','802','IEEE 802.11 + Prism2 header');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('902','78','803','IEEE 802.11 + radiotap header');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('903','78','804','ARPHRD_IEEE802154');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('904','78','805','IEEE 802.15.4 network monitor');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('905','78','820','PhoNet media type');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('906','78','821','PhoNet pipe header');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('907','78','822','CAIF media type');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('908','78','823','GRE over IPv6');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('909','78','824','Netlink header');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('910','78','825','IPv6 over LoWPAN');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('911','78','826','Vsock monitor header');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('912','79','0','Ethernet 802.3');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('913','79','1','Token Ring 802.5');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('914','79','2','Fiber Distributed Data Interface (FDDI)');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('915','79','3','Wide Area Network (WAN)');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('916','79','4','LocalTalk');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('917','79','5','Ethernet using DIX header format');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('918','79','6','ARCNET');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('919','79','7','ARCNET (878.2)');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('920','79','8','ATM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('921','79','9','Wireless');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('922','79','10','Infrared Wireless');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('923','79','11','Bpc');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('924','79','12','CoWan');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('925','79','13','1394');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('926','80','1','Other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('927','80','2','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('928','80','3','Running/Full Power');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('929','80','4','Warning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('930','80','5','In Test');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('931','80','6','Not Applicable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('932','80','7','Power Off');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('933','80','8','Off Line');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('934','80','9','Off Duty');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('935','80','10','Degraded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('936','80','11','Not Installed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('937','80','12','Install Error');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('938','80','13','Power Save - Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('939','80','14','Power Save - Low Power Mode');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('940','80','15','Power Save - Standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('941','80','16','Power Cycle');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('942','80','17','Power Save - Warning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('943','80','18','Paused');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('944','80','19','Not Ready');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('945','80','20','Not Configured');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('946','80','21','Quiesced');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('947','81','0','Disconnected');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('948','81','1','Connecting');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('949','81','2','Connected');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('950','81','3','Disconnecting');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('951','81','4','Hardware Not Present');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('952','81','5','Hardware Disabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('953','81','6','Hardware Malfunction');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('954','81','7','Media Disconnected');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('955','81','8','Authenticating');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('956','81','9','Authentication Succeeded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('957','81','10','Authentication Failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('958','81','11','Invalid Address');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('959','81','12','Credentials Required');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('960','82','0','Failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('961','82','1','Ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('962','83','0','Ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('963','83','1','Alarm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('965','84','0','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('966','84','1','operable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('967','84','2','inoperable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('968','84','3','degraded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('969','84','4','poweredOff');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('970','84','5','powerProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('971','84','6','removed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('972','84','7','voltageProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('973','84','8','thermalProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('974','84','9','performanceProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('975','84','10','accessibilityProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('976','84','11','identityUnestablishable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('977','84','12','biosPostTimeout');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('978','84','13','disabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('979','84','14','malformedFru');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('980','84','15','backplanePortProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('981','84','16','chassisIntrusion');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('982','84','51','fabricConnProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('983','84','52','fabricUnsupportedConn');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('984','84','81','config');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('985','84','82','equipmentProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('986','84','83','decommissioning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('987','84','84','chassisLimitExceeded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('988','84','100','notSupported');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('989','84','101','discovery');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('990','84','102','discoveryFailed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('991','84','103','identify');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('992','84','104','postFailure');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('993','84','105','upgradeProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('994','84','106','peerCommProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('995','84','107','autoUpgrade');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('996','84','108','linkActivateBlocked');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('997','85','0','indeterminate');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('998','85','1','unassociated');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('999','85','10','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1000','85','11','discovery');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1001','85','12','config');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1002','85','13','unconfig');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1003','85','14','powerOff');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1004','85','15','restart');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1005','85','20','maintenance');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1006','85','21','test');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1007','85','29','computeMismatch');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1008','85','30','computeFailed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1009','85','31','degraded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1010','85','32','discoveryFailed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1011','85','33','configFailure');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1012','85','34','unconfigFailed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1013','85','35','testFailed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1014','85','36','maintenanceFailed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1015','85','40','removed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1016','85','41','disabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1017','85','50','inaccessible');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1018','85','60','thermalProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1019','85','61','powerProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1020','85','62','voltageProblem');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1021','85','63','inoperable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1022','85','101','decommissioning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1023','85','201','biosRestore');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1024','85','202','cmosReset');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1025','85','203','diagnostics');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1026','85','204','diagnosticsFailed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1027','85','210','pendingReboot');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1028','85','211','pendingReassociation');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1029','85','212','svnicNotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1030','86','0','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1031','86','1','online');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1032','86','2','unconfiguredGood');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1033','86','3','globalHotSpare');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1034','86','4','dedicatedHotSpare');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1035','86','5','jbod');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1036','86','6','offline');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1037','86','7','rebuilding');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1038','86','8','copyback');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1039','86','9','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1040','86','10','unconfiguredBad');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1041','86','11','predictiveFailure');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1042','86','12','disabledForRemoval');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1043','86','13','foreignConfiguration');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1044','86','14','zeroing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1045','86','15','good');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1046','86','16','bad');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1047','86','17','lockedForeignConfiguration');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1048','87','0','unspecified');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1049','87','1','simple');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1050','87','2','mirror');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1051','87','3','stripe');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1052','87','4','raid');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1053','87','5','stripeParity');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1054','87','6','stripeDualParity');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1055','87','7','mirrorStripe');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1056','87','8','stripeParityStripe');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1057','87','9','stripeDualParityStripe');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1058','88','0','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1059','88','1','empty');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1060','88','10','equipped');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1061','88','11','missing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1062','88','12','mismatch');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1063','88','13','equippedNotPrimary');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1064','88','14','equippedSlave');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1065','88','15','mismatchSlave');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1066','88','16','missingSlave');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1067','88','20','equippedIdentityUnestablishable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1068','88','21','mismatchIdentityUnestablishable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1069','88','22','equippedWithMalformedFru');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1070','88','30','inaccessible');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1071','88','40','unauthorized');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1072','88','100','notSupported');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1073','88','101','equippedUnsupported');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1074','88','102','equippedDiscNotStarted');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1075','88','103','equippedDiscInProgress');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1076','88','104','equippedDiscError');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1077','88','105','equippedDiscUnknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1078','39','21','stackError');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1079','39','22','stackPortBlocked');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1080','39','23','stackPortFailed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1081','39','31','sfpRecvError');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1082','39','32','sfpSendError');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1083','39','33','sfpBothError');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1084','39','41','fanError');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1085','39','51','psuError');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1086','39','61','rpsError');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1087','39','71','moduleFaulty');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1088','39','81','sensorError');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1089','39','91','hardwareFaulty');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1091','89','0','Error');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1092','89','1','Ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1093','90','0','No');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1094','90','1','Yes');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1095','91','-1 B','Undefined');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1096','92','- 1s','Inactive');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1097','93','0','False');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1098','93','1','True');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1099','94','0','green');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1100','94','1','yellow');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1101','94','2','red');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1102','94','255','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1103','95','0','False');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1104','95','1','True');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1105','96','0','Failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1106','96','1','Ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1107','97','0','No');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1108','97','1','Yes');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1109','98','1','Uninitialized');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1110','98','2','Initialized');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1111','98','3','Running');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1112','98','4','Disabling');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1113','98','5','Disabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1114','98','6','Shutdown Pending');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1115','98','7','Delete Pending');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1116','99','0','ONLINE');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1117','99','1','RESTORING');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1118','99','2','RECOVERING');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1119','99','3','RECOVERY_PENDING');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1120','99','4','SUSPECT');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1121','99','5','EMERGENCY');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1122','99','6','OFFLINE');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1123','99','7','COPYING');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1124','99','10','OFFLINE_SECONDARY');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1125','100','0','Disconnected');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1126','100','1','Connected');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1127','101','0','Not joined');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1128','101','1','Joined, standalone instance');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1129','101','2','Joined, failover cluster instance');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1130','102','0','Pending failover');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1131','102','1','Pending');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1132','102','2','Online');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1133','102','3','Offline');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1134','102','4','Failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1135','102','5','Failed, no quorum');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1136','102','6','Replica is not local');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1137','103','0','In progress');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1138','103','1','Online');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1139','103','2','Replica is not local');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1140','104','0','Resolving');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1141','104','1','Primary');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1142','104','2','Secondary');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1143','105','0','Resumed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1144','105','1','Suspended');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1145','106','0','Not healthy');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1146','106','1','Partially healthy');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1147','106','2','Healthy');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1148','107','0','No');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1149','107','1','Yes');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1150','108','0','Suspended');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1151','108','1','Disconnected from the other partner');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1152','108','2','Synchronizing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1153','108','3','Pending Failover');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1154','108','4','Synchronized');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1155','108','5','The partners are not synchronized. Failover is not possible now.');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1156','108','6','The partners are synchronized. Failover is potentially possible.');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1157','108','7','Database is inaccessible or is not mirrored');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1158','109','0','Database is inaccessible or is not mirrored');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1159','109','1','Principal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1160','109','2','Mirror');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1161','110','0','Unknown state');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1162','110','1','Off [asynchronous]');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1163','110','2','Full [synchronous]');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1164','110','3','Database is inaccessible or is not mirrored');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1165','111','0','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1166','111','1','Connected');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1167','111','2','Disconnected');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1168','111','3','No witness exists');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1169','112','0','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1170','112','1','Mounted');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1171','112','2','Read Only');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1172','112','3','Read-Write');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1173','112','4','Read Only with Apply');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1174','113','0','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1175','113','1','Snapshot standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1176','113','2','Logical standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1177','113','3','Physical standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1178','113','4','Primary');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1179','113','5','Far sync');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1180','114','0','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1181','114','1','Started');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1182','114','2','Mounted');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1183','114','3','Open');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1184','114','4','Open migrate');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1185','115','0','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1186','115','1','Primary');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1187','115','2','Secondary');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1188','116','0','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1189','116','1','Stopped');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1190','116','2','Started');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1191','116','3','Failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1192','117','0','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1193','117','1','Online');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1194','117','2','Offline');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1195','117','3','Read-Only');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1196','118','0','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1197','118','1','Error');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1198','118','2','Deferred');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1199','118','3','Valid');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1200','119','0','No');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1201','119','1','Yes');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1202','120','0','NOARCHIVELOG');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1203','120','1','ARCHIVELOG');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1204','120','2','MANUAL');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1205','121','0','HEALTH_OK');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1206','121','1','HEALTH_WARN');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1207','121','2','HEALTH_ERR');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1208','122','0','Inactive');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1209','122','1','Active');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1211','123','0','Start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1212','123','1','NightCheck');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1213','123','2','Disconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1214','123','3','Night');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1215','123','4','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1216','123','5','BulkMppt');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1217','123','6','Absorption');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1218','123','7','Float');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1219','123','8','Equalize');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1220','123','9','Slave');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1221','123','10','Fixed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1222','124','0','Start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1223','124','1','Normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1224','124','2','LvdWarning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1225','124','3','Lvd');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1226','124','4','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1227','124','5','Disconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1228','124','6','NormalOff');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1229','124','7','Override');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1230','124','8','NotUsed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1231','125','0','Start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1232','125','1','NightCheck');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1233','125','2','Disconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1234','125','3','Night');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1235','125','4','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1236','125','5','Bulk');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1237','125','6','Pwm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1238','125','7','Float');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1239','125','8','Equalize');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1240','126','0','Start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1241','126','1','Normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1242','126','2','LvdWarning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1243','126','3','Lvd');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1244','126','4','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1245','126','5','Disconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1246','126','6','NormalOff');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1247','126','7','Override');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1248','126','8','NotUsed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1249','127','0','Not set');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1250','127','1','Set');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1251','128','0','Start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1252','128','1','NightCheck');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1253','128','2','Disconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1254','128','3','Night');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1255','128','4','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1256','128','5','BulkMppt');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1257','128','6','Pwm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1258','128','7','Float');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1259','128','8','Equalize');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1260','129','0','Start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1261','129','1','Normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1262','129','2','LvdWarning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1263','129','3','Lvd');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1264','129','4','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1265','129','5','Disconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1266','129','6','NormalOff');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1267','129','7','Override');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1268','129','8','NotUsed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1269','130','0','Start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1270','130','1','LoadOn');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1271','130','2','LvdWarning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1272','130','3','LowVoltageDisconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1273','130','4','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1274','130','5','Disconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1275','130','6','NormalOff');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1276','130','7','UnknownState');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1277','130','8','Standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1278','131','0','Start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1279','131','1','NightCheck');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1280','131','2','Disconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1281','131','3','Night');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1282','131','4','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1283','131','5','Mppt');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1284','131','6','Absorption');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1285','131','7','Float');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1286','131','8','Equalize');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1287','131','9','Slave');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1288','131','10','Fixed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1289','132','0','Start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1290','132','1','NightCheck');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1291','132','2','Disconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1292','132','3','Night');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1293','132','4','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1294','132','5','Mppt');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1295','132','6','Absorption');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1296','132','7','Float');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1297','132','8','Equalize');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1298','132','9','Slave');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1299','133','0','Start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1300','133','1','NightCheck');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1301','133','2','Disconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1302','133','3','Night');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1303','133','4','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1304','133','5','Bulk');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1305','133','6','Absorption');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1306','133','7','Float');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1307','133','8','Equalize');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1308','134','0','Start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1309','134','1','Normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1310','134','2','LvdWarning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1311','134','3','Lvd');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1312','134','4','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1313','134','5','Disconnect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1314','134','6','LvdWarning1');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1315','134','7','OverrideLvd');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1316','134','8','Equalize');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1317','135','0','Charge');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1318','135','1','LoadControl');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1319','135','2','Diversion');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1320','135','3','Lighting');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1321','136','0','Passive');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1322','136','1','Active');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1323','137','0','Dismounted');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1324','137','1','Mounted');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1325','137','2','Healthy');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1327','138','1','No');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1328','138','2','Yes');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1329','139','1','OK');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1330','139','2','Partially discharged');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1331','139','3','Fully discharged');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1332','139','4','Not present');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1333','139','5','Near end of life');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1334','139','6','At end of life');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1335','139','7','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1336','139','8','Overcharged');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1337','139','9','Fully charged');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1338','140','1','OK');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1339','140','2','Unknown reason');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1340','140','3','Disabled by operator');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1341','140','4','Interconnect offline');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1342','140','5','Disabled by partner');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1343','140','6','Takeover failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1344','140','7','Mailbox is in degraded state');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1345','140','8','Partner mailbox is in uninitialised state');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1346','140','9','Mailbox version mismatch');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1347','140','10','NVRAM size mismatch');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1348','140','11','Kernel version mismatch');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1349','140','12','Partner is in booting stage');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1350','140','13','Disk shelf is too hot');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1351','140','14','Partner is performing revert');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1352','140','15','Node is performing revert');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1353','140','16','Same time partner is also trying to take us over');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1354','140','17','Already in takenover mode');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1355','140','18','NVRAM log unsynchronized');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1356','140','19','State of backup mailbox is doubtful');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1357','141','1','Not configured');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1358','141','2','Enabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1359','141','3','Disabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1360','141','4','Takeover by partner disabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1361','141','5','This node dead');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1362','142','0','Undef');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1363','142','1','Off');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1364','142','2','UP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1365','142','3','DOWN');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1366','143','0','Healthy');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1367','143','1','Degraded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1368','144','0','False');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1369','144','1','True');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1370','145','0','Undef');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1371','145','1','Cluster');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1372','145','2','Data');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1373','145','3','Node-MGMT');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1374','145','4','Intercluster');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1375','145','5','Cluster-MGMT');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1376','146','0','Physical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1377','146','1','IF-group');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1378','146','2','VLAN');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1379','146','3','Undef');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1380','147','0','Undef');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1381','147','1','Auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1382','147','2','10 Mb/s');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1383','147','3','100 Mb/s');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1384','147','4','10 Gb/s');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1385','147','5','100 Gb/s');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1387','148','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1388','148','2','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1389','148','3','degraded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1390','148','4','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1392','149','0','Normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1393','149','1','Master');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1394','149','2','Slave');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1395','150','0','Undefined');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1396','150','1','Normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1397','150','2','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1398','150','3','Pre-fail');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1399','150','4','Partially broken');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1400','150','5','Degraded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1401','150','6','Bad sectors found');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1402','150','7','Bit errors found');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1403','150','8','Consistent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1404','150','9','Inconsistent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1405','150','10','Busy');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1406','150','11','No input');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1407','150','12','Low battery');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1408','150','13','Single link fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1409','150','14','Invalid');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1410','150','15','Write protect');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1411','151','1','Normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1412','151','2','Faulty');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1413','151','3','Unformatted');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1414','151','4','Formatting');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1415','152','0','Undefined');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1416','152','1','Normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1417','152','2','Running');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1418','152','3','Not running');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1419','152','4','Not existed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1420','152','5','Sleep in high temperature');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1421','152','6','Starting');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1422','152','7','Power failure rotection');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1423','152','8','Spin down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1424','152','9','Started');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1425','152','10','Link Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1426','152','11','Link Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1427','152','12','Powering on');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1428','152','13','Powered off');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1429','152','14','Pre-copy');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1430','152','15','Copyback');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1431','152','16','Reconstruction');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1432','152','17','Expansion');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1433','152','18','Unformatted');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1434','152','19','Formatting');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1435','152','20','Unmapped');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1436','152','21','Initial synchronizing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1437','152','22','Consistent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1438','152','23','Synchronizing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1439','152','24','Synchronized');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1440','152','25','Unsynchronized');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1441','152','26','Split');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1442','152','27','Online');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1443','152','28','Offline');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1444','152','29','Locked');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1445','152','30','Enabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1446','152','31','Disabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1447','152','32','Balancing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1448','152','33','To be recovered');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1449','152','34','Interrupted');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1450','152','35','Invalid');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1451','152','36','Not start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1452','152','37','Queuing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1453','152','38','Stopped');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1454','152','39','Copying');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1455','152','40','Completed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1456','152','41','Paused');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1457','152','42','Reverse synchronizing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1458','152','43','Activated');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1459','152','44','Restore');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1460','152','45','Inactive');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1461','152','46','Idle');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1462','152','47','Powering off');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1463','152','48','Charging');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1464','152','49','Charging completed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1465','152','50','Discharging');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1466','152','51','Upgrading');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1467','152','52','Power Lost');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1468','152','53','Initializing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1469','152','54','Apply change');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1470','152','55','Online disable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1471','152','56','Offline disable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1472','152','57','Online frozen');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1473','152','58','Offline frozen');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1474','152','59','Closed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1475','152','60','Removing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1476','152','61','In service');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1477','152','62','Out of service');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1478','152','63','Running normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1479','152','64','Running fail');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1480','152','65','Running success');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1481','152','66','Running success');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1482','152','67','Running failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1483','152','68','Waiting');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1484','152','69','Canceling');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1485','152','70','Canceled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1486','152','71','About to synchronize');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1487','152','72','Synchronizing data');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1488','152','73','Failed to synchronize');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1489','152','74','Fault');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1490','152','75','Migrating');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1491','152','76','Migrated');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1492','152','77','Activating');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1493','152','78','Deactivating');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1494','152','79','Start failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1495','152','80','Stop failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1496','152','81','Decommissioning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1497','152','82','Decommissioned');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1498','152','83','Recommissioning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1499','152','84','Replacing node');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1500','152','85','Scheduling');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1501','152','86','Pausing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1502','152','87','Suspending');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1503','152','88','Suspended');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1504','152','89','Overload');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1505','152','90','To be switch');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1506','152','91','Switching');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1507','152','92','To be cleanup');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1508','152','93','Forced start');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1509','152','94','Error');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1510','152','95','Job completed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1511','152','96','Partition Migrating');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1512','152','97','Mount');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1513','152','98','Umount');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1514','152','99','INSTALLING');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1515','152','100','To Be Synchronized');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1516','152','101','Connecting');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1517','152','102','Service Switching');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1518','152','103','Power-on failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1519','152','104','REPAIRING');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1520','152','105','abnormal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1521','152','106','Deleting');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1522','152','107','Modifying');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1523','152','108','Running(clearing data)');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1524','152','109','Running(synchronizing data)');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1525','82','2','Error');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1526','153','0','False');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1527','153','1','True');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1528','154','0','STARTUP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1529','154','1','PRIMARY');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1530','154','2','SECONDARY');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1531','154','3','RECOVERING');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1532','154','5','STARTUP2');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1533','154','6','UNKNOWN');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1534','154','7','ARBITER');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1535','154','8','DOWN');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1536','154','9','ROLLBACK');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1537','154','10','REMOVED');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1539','155','1','Normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1540','155','2','Warning');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1541','155','3','Critical');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1542','155','4','Not applicable');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1543','156','1','no Battery Needs Replacing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1544','156','2','battery Needs Replacing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1545','157','1','no Transfer');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1546','157','2','High Line Voltage');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1547','157','3','Brownout');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1548','157','4','Blackout');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1549','157','5','Small Momentary Sag');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1550','157','6','Deep Momentary Sag');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1551','157','7','Small Momentary Spike');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1552','157','8','Large Momentary Spike');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1553','157','9','Self Test');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1554','157','10','Rate of Voltage Change');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1555','158','1','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1556','158','2','Normal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1557','158','3','Low');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1558','158','4','In Fault Condition');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1559','159','1','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1560','159','2','Online');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1561','159','3','On Battery');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1562','159','4','On Smart Boost');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1563','159','5','Timed Sleeping');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1564','159','6','Software Bypass');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1565','159','7','Off');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1566','159','8','Rebooting');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1567','159','9','Switched Bypass');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1568','159','10','Hardware Failure Bypass');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1569','159','11','Sleeping Until Power Return');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1570','159','12','On Smart Trim');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1571','159','13','Eco Mode');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1572','159','14','Hot Standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1573','159','15','On Battery Test');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1574','159','16','Emergency Static Bypass');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1575','159','17','Static Bypass Standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1576','159','18','Power Saving Mode');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1577','159','19','Spot Mode');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1578','159','20','E-Conversion');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1579','159','21','Charger Spotmode');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1580','159','22','Inverter Spotmode');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1581','159','23','Active Load');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1582','159','24','Battery Discharge Spotmode');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1583','159','25','Inverter Standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1584','159','26','Charger Only');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1585','160','0','False');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1586','160','1','True');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1587','161','0','Failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1588','161','1','Succeeded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1589','161','2','Retry');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1590','161','3','Canceled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1591','161','4','Running');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1592','161','5','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1594','162','0','not available');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1595','162','1','available');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1596','162','2','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1597','163','1','Empty');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1598','163','2','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1599','163','3','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1600','163','4','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1601','163','5','Standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1602','164','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1603','164','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1604','164','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1605','164','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1606','164','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1607','164','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1608','165','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1609','165','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1610','165','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1611','166','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1612','166','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1613','166','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1614','167','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1615','167','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1616','167','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1617','167','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1618','167','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1619','167','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1620','167','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1621','168','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1622','168','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1623','168','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1624','168','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1625','168','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1626','168','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1627','169','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1628','169','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1629','169','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1630','170','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1631','170','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1632','170','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1633','171','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1634','171','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1635','171','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1636','171','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1637','171','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1638','171','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1639','171','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1640','172','1','OK with DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1641','172','2','OK without DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1642','172','3','nonoperational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1643','173','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1644','173','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1645','173','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1646','173','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1647','173','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1648','173','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1649','174','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1650','174','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1651','174','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1652','175','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1653','175','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1654','175','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1655','176','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1656','176','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1657','176','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1658','176','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1659','176','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1660','176','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1661','176','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1662','177','1','OK with DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1663','177','2','OK without DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1664','177','3','nonoperational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1665','178','1','Empty');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1666','178','2','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1667','178','3','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1668','178','4','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1669','178','5','Standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1670','179','1','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1671','179','101','msc1000G');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1672','179','102','alc1248G_51');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1673','179','103','alc1248G_53');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1674','179','104','slc1248G_22');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1675','179','105','vlc1224G_41');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1676','179','106','msc1024G');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1677','179','107','alc1272G_51');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1678','179','108','vop1248G_61_SIP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1679','179','109','msc1000GA');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1680','179','110','vlc1324G_51');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1681','179','111','msc1224G');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1682','179','112','vop1248G_61_H248');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1683','179','113','vlc1348G_51');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1684','179','114','elc1220G_55');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1685','179','115','msc1024GA');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1686','179','116','vlc1324G_53');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1687','179','117','ima1408G_81');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1688','179','118','vlc1424G_56');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1689','179','119','slc1348G_22');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1690','179','120','vlc1348G_53');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1691','179','121','alc1372G_51');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1692','179','122','msc1024GB');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1693','179','123','msc1224GB');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1694','179','124','vop1372G_61_H248');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1695','180','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1696','180','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1697','180','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1698','180','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1699','180','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1700','180','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1701','181','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1702','181','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1703','181','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1704','182','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1705','182','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1706','182','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1707','183','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1708','183','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1709','183','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1710','183','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1711','183','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1712','183','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1713','183','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1714','184','1','Empty');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1715','184','2','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1716','184','3','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1717','184','4','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1718','184','5','Standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1719','185','1','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1720','185','101','msc1000G');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1721','185','102','alc1248G_51');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1722','185','103','alc1248G_53');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1723','185','104','slc1248G_22');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1724','185','105','vlc1224G_41');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1725','185','106','msc1024G');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1726','185','107','alc1272G_51');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1727','185','108','vop1248G_61_SIP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1728','185','109','msc1000GA');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1729','185','110','vlc1324G_51');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1730','185','111','msc1224G');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1731','185','112','vop1248G_61_H248');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1732','185','113','vlc1348G_51');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1733','185','114','elc1220G_55');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1734','185','115','msc1024GA');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1735','185','116','vlc1324G_53');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1736','185','117','ima1408G_81');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1737','185','118','vlc1424G_56');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1738','185','119','slc1348G_22');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1739','185','120','vlc1348G_53');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1740','185','121','alc1372G_51');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1741','185','122','msc1024GB');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1742','185','123','msc1224GB');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1743','185','124','vop1372G_61_H248');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1744','186','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1745','186','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1746','186','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1747','186','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1748','186','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1749','186','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1750','187','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1751','187','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1752','187','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1753','188','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1754','188','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1755','188','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1756','189','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1757','189','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1758','189','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1759','189','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1760','189','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1761','189','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1762','189','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1763','190','1','Empty');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1764','190','2','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1765','190','3','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1766','190','4','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1767','190','5','Standby');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1768','191','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1769','191','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1770','191','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1771','191','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1772','191','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1773','191','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1774','192','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1775','192','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1776','192','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1777','193','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1778','193','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1779','193','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1780','194','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1781','194','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1782','194','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1783','194','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1784','194','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1785','194','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1786','194','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1787','195','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1788','195','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1789','195','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1790','195','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1791','195','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1792','195','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1793','196','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1794','196','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1795','196','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1796','197','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1797','197','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1798','197','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1799','198','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1800','198','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1801','198','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1802','198','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1803','198','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1804','198','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1805','198','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1806','199','1','OK with DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1807','199','2','OK without DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1808','199','3','nonoperational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1809','200','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1810','200','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1811','200','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1812','200','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1813','200','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1814','200','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1815','201','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1816','201','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1817','201','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1818','202','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1819','202','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1820','202','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1821','203','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1822','203','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1823','203','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1824','203','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1825','203','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1826','203','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1827','203','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1828','204','1','OK with DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1829','204','2','OK without DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1830','204','3','nonoperational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1831','205','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1832','205','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1833','205','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1834','205','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1835','205','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1836','205','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1837','206','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1838','206','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1839','206','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1840','207','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1841','207','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1842','207','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1843','208','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1844','208','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1845','208','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1846','208','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1847','208','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1848','208','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1849','208','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1850','209','1','OK with DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1851','209','2','OK without DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1852','209','3','nonoperational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1853','210','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1854','210','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1855','210','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1856','210','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1857','210','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1858','210','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1859','211','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1860','211','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1861','211','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1862','212','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1863','212','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1864','212','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1865','213','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1866','213','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1867','213','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1868','213','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1869','213','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1870','213','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1871','213','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1872','214','1','OK with DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1873','214','2','OK without DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1874','214','3','nonoperational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1875','215','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1876','215','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1877','215','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1878','215','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1879','215','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1880','215','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1881','216','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1882','216','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1883','216','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1884','217','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1885','217','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1886','217','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1887','218','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1888','218','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1889','218','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1890','218','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1891','218','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1892','218','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1893','218','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1894','219','1','OK with DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1895','219','2','OK without DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1896','219','3','nonoperational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1897','220','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1898','220','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1899','220','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1900','220','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1901','220','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1902','220','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1903','220','6','10G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1904','220','7','12G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1905','220','8','40G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1906','220','9','1G auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1907','221','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1908','221','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1909','221','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1910','221','3','XFP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1911','221','4','CX4');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1912','222','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1913','222','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1914','222','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1915','223','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1916','223','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1917','223','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1918','223','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1919','223','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1920','223','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1921','223','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1922','224','1','OK with DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1923','224','2','OK without DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1924','224','3','nonoperational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1925','225','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1926','225','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1927','225','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1928','225','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1929','225','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1930','225','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1931','225','6','10G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1932','225','7','12G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1933','225','8','40G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1934','225','9','1G auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1935','226','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1936','226','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1937','226','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1938','226','3','XFP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1939','226','4','CX4');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1940','227','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1941','227','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1942','227','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1943','228','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1944','228','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1945','228','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1946','228','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1947','228','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1948','228','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1949','228','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1950','229','1','OK with DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1951','229','2','OK without DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1952','229','3','nonoperational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1953','230','0','auto');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1954','230','1','10M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1955','230','2','10M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1956','230','3','100M half');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1957','230','4','100M full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1958','230','5','1G full');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1959','231','0','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1960','231','1','Cooper');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1961','231','2','Fiber');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1962','231','3','XFP');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1963','231','4','CX4');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1964','232','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1965','232','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1966','232','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1967','233','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1968','233','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1969','233','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1970','233','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1971','233','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1972','233','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1973','233','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1974','234','1','OK with DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1975','234','2','OK without DDM');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1976','234','3','nonoperational');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1978','235','0','unspecified');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1979','235','1','hdd');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1980','235','2','ssd');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1981','235','3','nvme');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1987','236','1','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1988','236','2','ok');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1989','236','3','generalFailure');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1990','236','4','linkFailure');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1991','237','0','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1992','237','1','loaded');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1993','237','2','error');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1994','237','3','masked');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1995','238','0','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1996','238','1','active');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1997','238','2','reloading');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1998','238','3','inactive');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('1999','238','4','failed');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2000','238','5','activating');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2001','238','6','deactivating');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2002','239','0','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2003','239','1','enabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2004','239','2','enabled-runtime');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2005','239','3','linked');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2006','239','4','linked-runtime');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2007','239','5','masked');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2008','239','6','masked-runtime');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2009','239','7','static');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2010','239','8','disabled');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2011','239','9','invalid');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2012','240','0','bad');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2013','240','1','good');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2014','240','2','notpresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2015','241','1','none');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2016','241','2','minimum');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2017','241','3','nominal');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2018','241','4','dedicated');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2019','241','5','custom');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2020','242','0','none');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2021','242','1','txrx');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2022','242','2','tx');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2023','242','3','rx');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2028','22','2','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2029','243','0','-');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2030','243','1','Y');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2031','244','1','none');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2032','244','2','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2033','244','3','hmacMd5');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2034','244','4','hmacSha');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2035','245','1','none');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2036','245','2','des');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2037','245','3','des3');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2038','245','4','rc4');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2039','245','5','rc5');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2040','245','6','idea');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2041','245','7','cast');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2042','245','8','blowfish');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2043','245','9','aes');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2044','246','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2045','246','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2046','246','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2047','247','1','Up');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2048','247','2','Down');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2049','247','3','Testing');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2050','247','4','Unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2051','247','5','Dormant');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2052','247','6','NotPresent');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2053','247','7','lowerLayerDown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2054','248','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2055','248','2','ipsec');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2056','248','3','l2tp');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2057','248','4','l2tpoveripsxe');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2058','248','5','pptp');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2059','248','6','l2f');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2060','248','7','ssl');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2061','249','1','none');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2062','249','2','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2063','249','3','radius');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2064','249','4','tacacsplus');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2065','249','5','kerberos');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2066','249','6','local');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2067','249','7','ldap');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2068','249','8','ntlm');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2069','249','9','sdi');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2070','250','1','other');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2071','250','2','unknown');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2072','250','3','chassis');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2073','250','4','backplane');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2074','250','5','container');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2075','250','6','powerSupply');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2076','250','7','fan');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2077','250','8','sensor');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2078','250','9','module');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2079','250','10','port');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2080','250','11','stack');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2081','250','12','cpu');
INSERT INTO mappings (mappingid,valuemapid,value,newvalue) values ('2082','20','3','testing');
INSERT INTO sysmaps (sysmapid,name,width,height,backgroundid,label_type,label_location,highlight,expandproblem,markelements,show_unack,grid_size,grid_show,grid_align,label_format,label_type_host,label_type_hostgroup,label_type_trigger,label_type_map,label_type_image,label_string_host,label_string_hostgroup,label_string_trigger,label_string_map,label_string_image,iconmapid,expand_macros,severity_min,userid,private,show_suppressed) values ('1','Local network','680','200',NULL,'0','0','1','1','1','0','50','1','1','0','2','2','2','2','2','','','','','',NULL,'1','0','1','0','0');
INSERT INTO sysmaps_elements (selementid,sysmapid,elementid,elementtype,iconid_off,iconid_on,label,label_location,x,y,iconid_disabled,iconid_maintenance,elementsubtype,areatype,width,height,viewtype,use_iconmap,application) values ('1','1','10084','0','185',NULL,'{HOST.NAME}
{HOST.CONN}','0','111','61',NULL,NULL,'0','0','200','200','0','0','');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('135','22868','22867');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('136','22869','22867');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('137','22870','22867');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('138','22871','22867');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('139','22872','22867');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('142','22908','22907');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('143','22909','22907');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('144','22910','22907');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('145','22911','22907');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('146','22912','22907');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('147','22945','22944');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('148','22946','22944');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('149','22948','22947');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('150','22949','22947');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('151','22950','22947');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('152','22951','22947');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('153','22952','22947');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('154','22985','22984');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('155','22986','22984');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('156','22988','22987');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('157','22989','22987');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('158','22990','22987');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('159','22991','22987');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('160','22992','22987');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('161','23025','23024');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('162','23026','23024');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('163','23028','23027');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('164','23029','23027');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('165','23030','23027');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('166','23031','23027');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('167','23032','23027');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('170','23068','23067');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('171','23069','23067');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('172','23070','23067');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('173','23071','23067');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('174','23072','23067');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('189','23073','23540');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('190','23074','23540');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('191','23075','23329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('192','23076','23329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('776','27032','27031');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('812','27079','27078');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('813','27080','27078');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('814','27081','27078');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('815','27082','27078');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('816','27083','27078');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('817','27084','27078');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('818','27085','27078');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('819','27086','27078');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('820','27087','27078');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('830','27099','27098');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('831','27100','27098');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('832','27101','27098');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('833','27102','27098');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('834','27103','27098');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('835','27104','27098');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('836','27105','27098');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('837','27106','27098');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('838','27107','27098');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('848','27119','27118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('849','27120','27118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('850','27121','27118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('851','27122','27118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('852','27123','27118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('853','27124','27118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('854','27125','27118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('855','27126','27118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('856','27127','27118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('875','27181','27180');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('876','27182','27180');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('877','27183','27180');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('878','27184','27180');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('879','27185','27180');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('880','27186','27180');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('881','27187','27180');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('882','27188','27180');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('883','27189','27180');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('884','27191','27190');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('885','27212','27209');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('886','27213','27210');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('887','27214','27211');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('888','27216','27215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('889','27217','27215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('890','27218','27215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('891','27219','27215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('892','27220','27215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('893','27221','27215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('894','27222','27215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('895','27223','27215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('896','27224','27215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('898','27246','27242');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('899','27247','27242');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('900','27248','27243');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('901','27249','27244');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('902','27250','27244');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('903','27252','27251');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('904','27253','27251');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('905','27254','27251');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('906','27255','27251');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('907','27256','27251');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('908','27257','27251');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('909','27258','27251');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('910','27259','27251');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('911','27260','27251');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('912','27273','27272');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('913','27274','27272');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('914','27275','27272');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('915','27276','27272');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('916','27277','27272');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('917','27278','27272');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('918','27279','27272');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('919','27280','27272');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('920','27281','27272');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('921','27312','27302');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('922','27313','27303');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('923','27314','27304');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('924','27315','27306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('925','27316','27307');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('926','27317','27308');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('927','27318','27309');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('928','27319','27310');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('929','27320','27311');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('930','27322','27321');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('931','27323','27321');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('932','27324','27321');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('933','27325','27321');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('934','27326','27321');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('935','27327','27321');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('936','27328','27321');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('937','27329','27321');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('938','27330','27321');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('939','27332','27331');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('950','27415','27390');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('951','27416','27390');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('952','27417','27391');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('954','27419','27393');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('955','27420','27394');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('956','27421','27394');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('957','27422','27395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('958','27423','27396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('960','27425','27397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('961','27426','27397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('962','27427','27398');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('963','27428','27399');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('964','27429','27400');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('965','27430','27400');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('966','27431','27401');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('967','27432','27402');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('978','27443','27409');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('979','27444','27409');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('980','27445','27410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('981','27446','27411');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('982','27447','27411');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('983','27448','27412');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('984','27449','27413');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('985','27451','27450');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('986','27452','27450');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('987','27453','27450');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('988','27454','27450');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('989','27455','27450');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('990','27456','27450');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('991','27457','27450');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('992','27458','27450');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('993','27459','27450');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('994','27461','27460');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('996','27478','27473');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('997','27479','27474');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('998','27480','27475');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('999','27481','27476');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1000','27482','27476');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1001','27483','27476');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1002','27484','27476');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1003','27485','27476');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1004','27487','27486');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1005','27488','27486');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1006','27489','27486');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1007','27490','27486');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1008','27491','27486');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1009','27492','27486');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1010','27493','27486');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1011','27494','27486');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1012','27495','27486');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1014','27517','27513');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1015','27518','27514');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1016','27519','27515');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1017','27521','27520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1018','27522','27520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1019','27523','27520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1020','27524','27520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1021','27525','27520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1022','27526','27520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1023','27527','27520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1024','27528','27520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1025','27529','27520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1026','27531','27530');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1028','27553','27549');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1029','27554','27550');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1030','27555','27551');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1031','27557','27556');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1032','27558','27556');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1033','27559','27556');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1034','27560','27556');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1035','27561','27556');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1036','27562','27556');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1037','27563','27556');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1038','27564','27556');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1039','27565','27556');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1040','27567','27566');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1042','27591','27587');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1044','27593','27588');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1045','27594','27589');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1046','27595','27589');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1057','27620','27619');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1058','27621','27619');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1059','27622','27619');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1060','27623','27619');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1061','27624','27619');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1062','27625','27619');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1063','27626','27619');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1064','27627','27619');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1065','27628','27619');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1066','27630','27629');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1067','27643','27642');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1068','27644','27642');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1069','27645','27642');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1070','27646','27642');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1071','27647','27642');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1072','27648','27642');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1073','27649','27642');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1074','27650','27642');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1075','27651','27642');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1076','27653','27652');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1078','27671','27665');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1079','27672','27666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1080','27673','27667');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1081','27674','27668');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1082','27675','27669');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1083','27676','27669');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1084','27677','27669');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1085','27678','27669');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1086','27679','27669');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1107','27723','27722');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1108','27724','27722');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1109','27725','27722');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1110','27726','27722');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1111','27727','27722');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1112','27728','27722');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1113','27729','27722');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1114','27730','27722');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1115','27731','27722');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1116','27733','27732');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1117','27748','27745');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1118','27749','27745');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1119','27750','27745');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1120','27751','27745');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1122','27753','27745');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1123','27754','27746');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1124','27755','27747');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1125','27757','27756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1126','27758','27756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1127','27759','27756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1128','27760','27756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1129','27761','27756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1130','27762','27756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1131','27763','27756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1132','27764','27756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1133','27765','27756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1134','27783','27779');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1135','27784','27779');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1136','27785','27780');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1137','27786','27781');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1138','27787','27782');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1139','27789','27788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1140','27790','27788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1141','27791','27788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1142','27792','27788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1143','27793','27788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1144','27794','27788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1145','27795','27788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1146','27796','27788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1147','27797','27788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1148','27799','27798');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1151','27821','27816');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1152','27822','27817');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1153','27823','27818');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1183','27873','27872');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1184','27874','27872');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1185','27875','27872');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1186','27876','27872');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1187','27877','27872');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1188','27878','27872');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1189','27879','27872');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1190','27880','27872');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1191','27881','27872');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1192','27904','27901');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1193','27905','27902');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1194','27906','27903');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1195','27907','27903');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1196','27908','27903');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1197','27910','27909');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1198','27911','27909');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1199','27912','27909');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1200','27913','27909');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1201','27914','27909');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1202','27915','27909');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1203','27916','27909');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1204','27917','27909');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1205','27918','27909');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1206','27940','27937');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1207','27941','27937');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1208','27942','27938');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1209','27943','27939');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1210','27945','27944');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1211','27946','27944');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1212','27947','27944');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1213','27948','27944');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1214','27949','27944');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1215','27950','27944');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1216','27951','27944');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1217','27952','27944');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1218','27953','27944');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1219','27955','27954');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1220','27977','27976');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1221','27978','27976');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1222','27979','27976');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1223','27980','27976');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1224','27981','27976');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1225','27982','27976');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1226','27983','27976');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1227','27984','27976');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1228','27985','27976');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1229','28003','28001');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1231','28006','28005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1232','28007','28005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1233','28008','28005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1234','28009','28005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1235','28010','28005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1236','28011','28005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1237','28012','28005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1238','28013','28005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1239','28014','28005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1285','28119','28118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1286','28120','28118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1287','28121','28118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1288','28122','28118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1289','28123','28118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1290','28124','28118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1291','28125','28118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1292','28126','28118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1293','28127','28118');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1294','28129','28128');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1295','28150','28144');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1298','28153','28145');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1299','28154','28146');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1300','28155','28147');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1301','28156','28148');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1302','28157','28149');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1303','28158','28149');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1326','28200','28196');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1327','28201','28196');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1328','28202','28197');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1329','28203','28197');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1330','28204','28198');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1331','28205','28198');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1332','28206','28199');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1333','28208','28207');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1334','28215','28212');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1335','28216','28213');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1336','28217','28214');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1337','28218','28214');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1338','28220','28219');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1340','28222','28219');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1341','28224','28223');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1342','28225','28223');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1343','28226','28223');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1344','28227','28223');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1345','28228','28223');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1346','28229','28223');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1347','28230','28223');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1348','28231','28223');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1349','28232','28223');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1350','28246','28244');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1351','28247','28245');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1352','28281','28280');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1353','28294','28293');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1354','28295','28293');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1355','28296','28293');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1356','28297','28293');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1357','28298','28293');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1358','28299','28293');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1359','28300','28293');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1360','28301','28293');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1361','28302','28293');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1375','28323','28306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1376','28324','28306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1377','28325','28307');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1378','28326','28307');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1379','28327','28308');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1380','28328','28308');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1381','28329','28309');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1382','28354','28346');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1383','28355','28346');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1384','28356','28347');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1385','28357','28347');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1386','28358','28348');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1387','28359','28349');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1388','28360','28349');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1389','28361','28350');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1390','28362','28350');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1391','28363','28350');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1392','28364','28350');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1393','28365','28350');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1394','28366','28350');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1395','28367','28350');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1396','28368','28351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1397','28369','28351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1398','28370','28351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1399','28371','28351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1400','28372','28351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1401','28373','28351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1402','28374','28352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1403','28375','28352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1404','28376','28353');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1405','28404','28392');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1406','28405','28392');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1407','28406','28393');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1408','28407','28394');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1409','28408','28395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1410','28409','28396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1412','28411','28398');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1413','28412','28399');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1414','28413','28400');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1415','28414','28400');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1416','28415','28401');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1417','28416','28401');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1418','28417','28402');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1419','28418','28402');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1420','28419','28402');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1421','28420','28402');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1422','28421','28402');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1423','28422','28402');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1424','28423','28403');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1425','28424','28403');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1426','28425','28403');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1435','28474','28468');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1436','28475','28469');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1437','28476','28470');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1438','28477','28471');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1439','28478','28472');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1440','28479','28472');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1441','28480','28473');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1442','28481','28473');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1443','28495','28493');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1444','28496','28494');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1454','28712','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1455','28713','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1456','28714','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1457','28715','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1458','28716','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1459','28717','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1460','28718','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1461','28719','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1462','28720','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1463','28721','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1464','28722','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1465','28723','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1466','28724','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1467','28725','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1468','28726','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1469','28727','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1470','28728','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1471','28729','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1472','28730','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1473','28731','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1474','28732','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1475','28733','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1476','28734','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1477','28735','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1478','28736','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1479','28737','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1480','28738','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1481','28739','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1482','28740','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1483','28741','28711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1490','28798','28797');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1491','28799','28797');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1492','28800','28797');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1493','28801','28797');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1494','28802','28797');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1495','28803','28797');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1501','28894','27815');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1502','28950','28948');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1503','28951','28949');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1504','28952','28949');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1505','28953','28949');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1506','28954','28949');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1507','28956','28955');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1508','28969','28968');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1509','28970','28968');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1510','28971','28968');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1511','28972','28968');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1512','28973','28968');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1513','28974','28968');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1514','28975','28968');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1515','28976','28968');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1516','28977','28968');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1517','29014','29008');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1518','29015','29008');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1519','29016','29008');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1520','29017','29009');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1521','29018','29009');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1522','29019','29009');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1523','29020','29009');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1524','29021','29009');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1525','29022','29009');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1526','29023','29009');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1527','29024','29009');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1528','29025','29009');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1529','29026','29009');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1530','29027','29010');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1531','29028','29010');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1532','29029','29010');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1533','29030','29010');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1534','29031','29011');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1535','29032','29011');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1536','29033','29011');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1537','29034','29012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1538','29035','29012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1539','29036','29012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1540','29037','29012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1541','29038','29012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1542','29039','29012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1543','29040','29012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1544','29041','29012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1545','29042','29012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1546','29043','29012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1547','29044','29013');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1548','29045','29013');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1549','29046','29013');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1550','29047','29013');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1551','29048','29009');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1552','29049','29012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1566','29078','29077');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1567','29079','29077');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1568','29080','29077');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1569','29081','29077');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1570','29082','29077');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1571','29083','29077');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1572','29084','29077');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1573','29085','29077');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1574','29086','29077');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1575','29210','29201');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1576','29211','29201');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1577','29212','29201');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1578','29213','29201');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1581','29216','29203');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1582','29217','29203');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1583','29218','29203');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1584','29219','29203');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1585','29220','29203');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1586','29221','29203');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1587','29222','29203');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1588','29223','29203');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1589','29224','29204');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1590','29225','29204');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1591','29226','29204');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1592','29227','29204');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1595','29230','29206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1596','29231','29206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1597','29232','29206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1598','29233','29206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1599','29234','29206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1600','29235','29206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1601','29236','29206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1602','29237','29206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1603','29238','29207');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1604','29239','29207');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1605','29240','29207');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1606','29241','29207');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1609','29244','29209');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1610','29245','29209');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1611','29246','29209');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1612','29247','29209');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1613','29248','29209');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1614','29249','29209');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1615','29250','29209');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1616','29251','29209');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1635','29355','29349');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1636','29356','29349');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1637','29357','29349');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1638','29358','29349');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1641','29361','29351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1642','29362','29351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1643','29363','29351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1644','29364','29351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1645','29365','29351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1646','29366','29351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1647','29367','29351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1648','29368','29351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1649','29369','29352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1650','29370','29352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1651','29371','29352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1652','29372','29352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1655','29375','29354');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1656','29376','29354');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1657','29377','29354');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1658','29378','29354');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1659','29379','29354');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1660','29380','29354');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1661','29381','29354');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1662','29382','29354');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1675','29432','29430');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1676','29433','29430');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1677','29434','29431');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1678','29435','29431');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1679','29436','29429');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1680','29437','29429');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1681','29438','29429');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1682','29439','29429');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1683','29440','29429');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1684','29441','29429');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1685','29442','29429');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1686','29443','29429');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1687','29444','29429');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1688','29445','29430');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1689','29446','29430');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1690','29447','29430');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1691','29448','29431');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1692','29449','29431');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1693','29450','29431');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1694','29451','29431');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1695','29452','29431');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1696','29453','29431');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1697','29512','29506');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1698','29513','29506');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1699','29514','29506');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1706','29521','29509');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1707','29522','29509');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1708','29523','29509');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1729','29619','29613');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1730','29620','29613');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1731','29621','29613');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1738','29628','29616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1739','29629','29616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1740','29630','29616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1777','29720','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1778','29721','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1779','29722','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1780','29723','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1781','29724','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1782','29725','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1783','29726','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1784','29727','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1785','29728','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1786','29729','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1787','29730','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1788','29731','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1789','29732','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1790','29733','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1791','29734','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1792','29735','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1793','29736','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1794','29737','29703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1795','29787','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1796','29788','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1797','29789','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1798','29790','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1799','29791','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1800','29792','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1801','29793','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1802','29794','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1803','29795','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1804','29796','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1805','29797','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1806','29798','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1807','29799','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1808','29800','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1809','29801','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1810','29802','29785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1811','29803','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1812','29804','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1813','29805','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1814','29806','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1815','29807','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1816','29808','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1817','29809','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1818','29810','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1819','29811','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1820','29812','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1821','29813','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1822','29814','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1823','29815','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1824','29816','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1825','29817','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1826','29818','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1827','29819','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1828','29820','29786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1829','30027','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1830','30028','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1831','30029','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1832','30030','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1833','30031','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1834','30032','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1835','30033','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1836','30034','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1837','30035','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1838','30036','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1839','30037','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1840','30038','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1841','30039','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1842','30040','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1843','30041','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1844','30042','30026');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1845','30066','30057');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1846','30067','30057');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1847','30068','30057');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1848','30069','30057');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1849','30070','30058');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1850','30071','30059');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1851','30072','30060');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1852','30073','30060');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1853','30074','30060');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1854','30075','30061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1855','30076','30062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1856','30077','30062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1857','30078','30062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1858','30079','30062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1859','30080','30063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1860','30081','30063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1861','30082','30063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1862','30083','30064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1863','30084','30064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1864','30085','30065');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1865','30091','30090');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1866','30092','30090');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1867','30101','27390');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1868','30102','27397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1869','30103','27409');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1870','30104','28219');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1871','30105','27473');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1872','30107','27512');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1873','30108','27548');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1874','30110','27587');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1875','30111','27587');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1876','30112','27665');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1877','30113','28145');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1878','30114','28145');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1879','30115','28145');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1880','30116','27745');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1881','30118','27815');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1882','30129','30127');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1883','30130','30128');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1884','30131','28002');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1885','30157','30147');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1886','30158','30147');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1887','30159','30147');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1888','30160','30148');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1889','30161','30148');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1890','30162','30148');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1891','30163','30149');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1892','30164','30149');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1893','30165','30149');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1894','30166','30150');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1895','30167','30150');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1896','30168','30150');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1903','30175','30153');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1904','30176','30153');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1905','30177','30153');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1906','30178','30154');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1907','30179','30154');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1908','30180','30154');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1909','30181','30155');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1910','30182','30155');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1911','30183','30155');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1912','30184','30156');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1913','30185','30156');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1914','30186','30156');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1983','30344','30337');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1984','30345','30337');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1985','30346','30337');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1986','30347','30337');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1987','30348','30338');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1988','30349','30338');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1989','30350','30338');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1990','30351','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1991','30352','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1992','30353','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1993','30354','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1994','30355','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1995','30356','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1996','30357','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1997','30358','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1998','30359','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('1999','30360','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2000','30361','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2001','30362','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2002','30363','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2003','30364','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2004','30365','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2005','30366','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2006','30367','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2007','30368','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2008','30369','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2009','30370','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2010','30371','30339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2011','30372','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2012','30373','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2013','30374','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2014','30375','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2015','30376','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2016','30377','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2017','30378','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2018','30379','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2019','30380','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2020','30381','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2021','30382','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2022','30383','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2023','30384','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2024','30385','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2025','30386','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2026','30387','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2027','30388','30340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2028','30389','30341');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2029','30390','30341');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2030','30391','30341');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2031','30392','30341');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2032','30393','30341');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2033','30394','30341');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2034','30395','30341');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2035','30396','30342');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2036','30397','30343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2037','30398','30343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2038','30399','30343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2039','30400','30343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2040','30401','30343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2041','30402','30343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2042','30403','30343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2043','30404','30343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2056','30425','30423');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2057','30426','30424');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2058','30429','30427');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2059','30430','30428');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2060','30474','30472');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2061','30475','30473');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2062','30476','30473');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2063','30477','30473');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2064','30478','30473');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2065','30522','30520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2066','30523','30521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2067','30524','30521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2068','30525','30521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2069','30526','30521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2070','30573','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2071','30574','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2072','30575','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2073','30576','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2074','30577','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2075','30578','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2076','30579','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2077','30580','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2078','30581','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2079','30582','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2080','30583','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2081','30584','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2082','30585','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2083','30586','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2084','30587','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2085','30588','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2086','30589','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2087','30590','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2088','30591','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2089','30592','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2090','30593','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2091','30594','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2092','30595','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2093','30596','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2094','30597','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2095','30598','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2096','30599','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2097','30600','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2098','30601','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2099','30602','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2100','30603','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2101','30604','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2102','30605','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2103','30606','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2104','30607','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2105','30608','30571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2106','30609','30572');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2107','30610','30572');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2108','30680','30678');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2109','30681','30679');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2110','30682','30679');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2111','30683','30679');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2112','30684','30679');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2113','30688','30686');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2114','30689','30687');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2115','30714','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2116','30715','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2117','30716','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2118','30717','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2119','30718','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2120','30719','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2121','30720','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2122','30721','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2123','30722','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2124','30723','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2125','30724','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2126','30725','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2127','30726','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2128','30727','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2129','30728','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2130','30729','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2131','30730','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2132','30731','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2133','30732','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2134','30733','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2135','30734','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2136','30735','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2137','30736','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2138','30737','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2139','30738','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2140','30739','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2141','30740','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2142','30741','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2143','30742','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2144','30743','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2145','30744','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2146','30745','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2147','30746','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2148','30747','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2149','30748','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2150','30749','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2151','30750','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2152','30751','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2153','30752','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2154','30753','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2155','30754','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2156','30755','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2157','30756','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2158','30757','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2159','30758','30713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2214','30877','30874');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2215','30878','30874');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2216','30879','30874');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2217','30880','30875');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2218','30881','30875');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2219','30882','30875');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2220','30883','30875');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2221','30884','30875');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2222','30885','30875');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2223','30886','30875');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2224','30887','30875');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2225','30888','30875');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2226','30889','30875');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2227','30890','30875');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2228','30891','30875');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2229','30892','30876');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2230','30893','30876');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2231','30894','30876');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2232','30895','30876');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2233','30917','30916');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2234','30918','30916');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2235','30919','30916');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2236','30920','30916');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2237','30921','30916');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2238','30922','30916');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2239','30963','30961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2240','30964','30962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2241','30965','30962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2242','30966','30962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2243','30967','30962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2244','31006','31005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2245','31007','31005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2246','31008','31005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2247','31009','31005');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2248','31048','31047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2249','31049','31047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2250','31050','31047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2251','31051','31047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2252','31128','31122');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2253','31129','31124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2254','31130','31125');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2256','31132','31127');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2257','31133','31122');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2258','31134','31122');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2259','31135','31122');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2260','31136','31122');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2261','31137','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2262','31138','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2263','31139','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2264','31140','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2265','31141','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2266','31142','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2267','31143','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2268','31144','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2269','31145','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2270','31146','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2271','31147','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2272','31148','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2273','31149','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2274','31150','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2275','31151','31124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2276','31152','31124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2277','31153','31124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2278','31154','31125');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2279','31155','31125');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2280','31156','31125');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2281','31157','31125');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2282','31158','31125');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2285','31161','31127');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2286','31162','31127');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2287','31163','31127');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2288','31164','31127');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2289','31165','31127');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2290','31166','31127');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2291','31167','31127');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2292','31241','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2293','31242','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2294','31243','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2295','31244','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2296','31245','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2297','31246','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2298','31247','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2299','31248','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2300','31249','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2301','31250','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2302','31251','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2303','31252','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2304','31253','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2305','31254','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2306','31255','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2307','31256','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2308','31257','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2309','31258','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2310','31259','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2311','31260','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2312','31261','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2313','31262','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2314','31263','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2315','31264','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2316','31265','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2317','31266','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2318','31267','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2319','31268','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2320','31269','31240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2321','31276','31273');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2322','31277','31273');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2323','31278','31273');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2324','31279','31274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2325','31280','31274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2326','31281','31274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2327','31282','31275');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2328','31283','31275');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2329','31284','31275');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2330','31285','31273');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2331','31286','31273');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2332','31287','31273');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2333','31288','31273');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2334','31289','31273');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2335','31290','31273');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2336','31291','31274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2337','31292','31274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2338','31293','31274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2339','31294','31274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2340','31295','31274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2341','31296','31274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2342','31297','31275');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2343','31298','31275');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2344','31299','31275');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2345','31300','31275');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2346','31301','31275');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2347','31302','31275');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2348','31307','31305');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2349','31308','31305');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2350','31309','31305');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2351','31310','31306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2352','31311','31306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2353','31312','31306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2354','31313','31305');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2355','31314','31305');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2356','31315','31305');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2357','31316','31305');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2358','31317','31305');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2359','31318','31305');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2360','31319','31306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2361','31320','31306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2362','31321','31306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2363','31322','31306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2364','31323','31306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2365','31324','31306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2366','31335','31333');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2367','31336','31333');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2368','31337','31333');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2369','31338','31333');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2370','31339','31334');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2371','31340','31334');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2372','31341','31334');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2373','31342','31334');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2374','31353','31351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2375','31354','31351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2376','31355','31351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2377','31356','31351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2378','31357','31352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2379','31358','31352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2380','31359','31352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2381','31360','31352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2434','31605','31597');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2435','31606','31598');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2436','31607','31598');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2437','31608','31598');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2438','31609','31598');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2439','31610','31601');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2440','31611','31601');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2441','31612','31601');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2442','31613','31601');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2443','31614','31602');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2444','31615','31602');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2445','31616','31602');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2446','31617','31602');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2447','31618','31603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2448','31619','31603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2449','31620','31603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2450','31621','31603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2451','31622','31604');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2452','31623','31604');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2453','31624','31604');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2454','31625','31604');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2455','31711','31706');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2456','31712','31706');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2457','31713','31706');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2458','31714','31707');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2459','31715','31707');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2460','31716','31707');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2461','31717','31707');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2462','31718','31708');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2463','31719','31708');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2464','31720','31708');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2465','31721','31709');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2466','31722','31710');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2467','31723','31710');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2468','31724','31710');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2469','31725','31710');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2470','31726','31710');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2472','31790','31787');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2473','31791','31788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2474','31792','31788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2475','31793','31788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2476','31794','31788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2477','31795','31788');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2478','31796','31789');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2479','31797','31789');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2480','31798','31789');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2481','31799','31789');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2482','31853','31851');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2483','31854','31851');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2484','31855','31851');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2485','31856','31851');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2486','31857','31851');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2487','31858','31851');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2497','31965','31964');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2498','31966','31964');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2499','31967','31964');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2500','31968','31964');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2510','32003','31852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2511','32004','31852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2512','32005','31852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2513','32006','31852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2514','32007','31852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2515','32008','31852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2516','32009','31852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2517','32010','31852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2518','32011','31852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2519','32048','32046');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2520','32049','32047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2521','32050','32046');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2522','32051','32046');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2523','32052','32046');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2524','32053','32046');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2525','32054','32046');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2526','32055','32046');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2527','32056','32046');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2528','32057','32046');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2529','32058','32046');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2530','32059','32046');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2531','32060','32047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2532','32061','32047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2533','32062','32047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2534','32063','32047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2535','32064','32047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2536','32065','32047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2537','32066','32047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2538','32067','32047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2539','32068','32047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2540','32069','32047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2541','32070','32047');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2542','32136','32133');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2543','32137','32134');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2544','32138','32135');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2545','32139','32135');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2546','32144','32140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2547','32145','32141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2548','32146','32141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2549','32147','32141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2550','32148','32141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2551','32149','32141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2552','32150','32142');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2553','32151','32142');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2554','32152','32142');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2555','32153','32142');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2556','32154','32142');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2557','32155','32143');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2558','32156','32143');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2559','32157','32143');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2560','32195','32193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2561','32196','32193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2562','32197','32193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2563','32198','32193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2564','32199','32193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2565','32200','32193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2566','32201','32194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2567','32202','32194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2568','32203','32194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2569','32204','32194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2570','32205','32194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2571','32206','32194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2572','32275','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2573','32276','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2574','32277','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2575','32278','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2576','32279','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2577','32280','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2578','32281','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2579','32282','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2580','32283','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2581','32284','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2582','32285','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2583','32286','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2584','32287','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2585','32288','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2586','32289','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2587','32290','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2588','32291','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2589','32292','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2590','32293','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2591','32294','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2592','32295','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2593','32296','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2594','32297','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2595','32298','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2596','32299','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2597','32300','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2598','32301','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2599','32302','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2600','32303','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2601','32304','32274');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2602','32307','32306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2603','32330','32329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2604','32350','32349');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2605','32373','32372');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2606','32382','32381');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2607','32401','32400');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2608','32420','32419');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2609','32436','32430');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2610','32437','32431');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2611','32438','32431');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2612','32439','32432');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2613','32440','32432');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2614','32441','32433');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2615','32442','32434');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2616','32443','32434');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2617','32444','32435');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2618','32445','31333');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2619','32446','31333');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2620','32447','31333');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2621','32448','31333');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2622','32449','31334');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2623','32450','31334');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2624','32451','31334');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2625','32452','31334');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2626','32453','31351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2627','32454','31351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2628','32455','31351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2629','32456','31351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2630','32457','31352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2631','32458','31352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2632','32459','31352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2633','32460','31352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2634','32465','32463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2635','32466','32463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2636','32467','32463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2637','32468','32463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2638','32469','32463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2639','32470','32463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2640','32471','32463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2641','32472','32463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2642','32473','32463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2643','32474','32464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2644','32475','32464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2645','32476','32464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2646','32477','32464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2647','32478','32464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2648','32479','32464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2649','32480','32464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2650','32481','32464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2651','32482','32464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2652','32483','32464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2653','32484','32464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2654','32485','32464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2655','32498','32495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2656','32499','32495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2657','32500','32496');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2658','32501','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2659','32502','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2660','32503','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2661','32504','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2662','32505','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2663','32506','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2664','32507','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2665','32508','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2666','32509','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2667','32510','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2668','32511','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2669','32512','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2670','32513','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2671','32514','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2672','32515','32497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2673','32528','32525');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2674','32529','32525');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2675','32530','32526');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2676','32531','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2677','32532','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2678','32533','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2679','32534','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2680','32535','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2681','32536','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2682','32537','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2683','32538','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2684','32539','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2685','32540','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2686','32541','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2687','32542','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2688','32543','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2689','32544','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2690','32545','32527');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2691','32554','32553');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2692','32555','32553');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2693','32556','32553');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2694','32557','32553');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2695','32558','32553');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2696','32559','30473');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2697','32568','32567');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2698','32569','32567');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2699','32570','32567');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2700','32571','32567');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2701','32572','32567');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2702','32573','30679');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2703','32582','30521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2704','32583','32581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2705','32584','32581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2706','32585','32581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2707','32586','32581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2708','32587','32581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2709','32588','31710');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2710','32589','31710');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2713','32598','32597');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2714','32599','32597');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2715','32600','32597');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2716','32621','32616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2717','32622','32616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2718','32623','32616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2719','32624','32616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2720','32625','32616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2721','32626','32616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2722','32627','32616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2723','32628','32616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2724','32629','32616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2725','32630','32616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2726','32631','32616');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2727','32632','32617');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2728','32633','32618');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2729','32634','32618');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2730','32635','32618');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2731','32636','32618');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2732','32637','32618');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2733','32638','32618');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2734','32639','32619');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2735','32640','32619');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2736','32641','32620');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2737','32642','32620');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2738','32643','32620');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2739','32644','32620');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2740','32645','32620');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2741','32646','32620');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2742','32647','32620');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2743','32648','32620');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2744','32649','32620');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2745','32650','32620');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2746','32651','32620');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2747','32652','32620');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2748','32663','32653');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2749','32664','32653');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2750','32665','32653');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2751','32666','32653');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2752','32667','32653');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2753','32668','32653');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2754','32669','32653');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2755','32670','32653');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2756','32671','32653');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2757','32672','32654');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2758','32673','32654');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2759','32674','32654');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2760','32675','32654');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2761','32676','32655');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2762','32677','32655');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2763','32678','32655');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2764','32679','32655');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2765','32680','32655');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2766','32681','32655');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2767','32682','32655');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2768','32683','32655');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2769','32684','32655');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2770','32685','32655');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2771','32686','32655');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2772','32687','32656');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2773','32688','32656');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2774','32689','32656');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2775','32690','32656');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2776','32691','32656');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2777','32692','32656');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2778','32693','32656');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2779','32694','32656');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2780','32695','32656');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2781','32696','32656');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2782','32697','32657');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2783','32698','32657');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2784','32699','32657');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2785','32700','32657');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2786','32701','32657');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2787','32702','32658');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2788','32703','32658');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2789','32704','32658');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2790','32705','32659');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2791','32706','32659');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2793','32708','32659');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2794','32709','32660');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2795','32710','32660');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2796','32711','32660');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2797','32712','32660');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2798','32713','32660');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2799','32714','32660');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2800','32715','32660');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2801','32716','32660');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2802','32717','32661');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2803','32718','32661');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2804','32719','32661');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2805','32720','32661');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2806','32721','32661');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2807','32722','32662');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2808','32723','32662');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2809','32724','32662');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2810','32725','32662');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2811','32726','32662');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2812','32727','32662');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2813','32728','32662');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2814','32729','32662');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2815','32730','32662');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2816','32732','28392');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2817','32733','28393');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2818','32734','28394');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2819','32735','28397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2820','32736','28397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2821','32737','28395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2822','32738','28396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2823','32739','32731');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2824','32740','32731');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2825','32744','32742');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2826','32745','32743');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2827','32746','32743');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2828','32747','32743');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2829','32748','32743');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2830','32749','32743');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2831','32750','32743');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2832','32751','32743');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2833','32752','32743');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2834','32756','32754');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2835','32757','32755');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2836','32758','32755');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2837','32759','32755');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2838','32760','32755');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2839','32761','32755');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2840','32762','32755');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2841','32763','32755');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2842','32764','32755');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2843','32788','32780');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2844','32789','32780');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2845','32790','32781');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2846','32791','32781');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2847','32792','32781');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2848','32793','32781');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2849','32794','32781');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2850','32795','32782');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2851','32796','32782');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2852','32797','32782');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2853','32798','32782');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2854','32799','32783');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2855','32800','32783');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2856','32801','32783');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2857','32802','32784');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2858','32803','32784');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2859','32804','32785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2860','32805','32785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2861','32806','32785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2862','32807','32785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2863','32808','32785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2864','32809','32785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2865','32810','32785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2866','32811','32785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2867','32812','32785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2868','32813','32785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2869','32814','32785');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2870','32815','32786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2871','32816','32786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2872','32817','32786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2873','32818','32786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2874','32819','32786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2875','32820','32786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2876','32821','32786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2877','32822','32786');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2878','32823','32787');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2879','32824','32787');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2880','32825','32787');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2881','32826','32787');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2882','32827','32787');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2883','32828','32787');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2884','32884','32880');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2885','32885','32881');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2886','32886','32882');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2887','32887','32882');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2888','32888','32882');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2889','32889','32882');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2890','32890','32882');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2891','32891','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2892','32892','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2893','32893','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2894','32894','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2895','32895','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2896','32896','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2897','32897','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2898','32898','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2899','32899','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2900','32900','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2901','32901','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2902','32902','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2903','32903','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2904','32904','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2905','32905','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2906','32906','32879');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2907','32907','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2908','32908','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2909','32909','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2910','32910','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2911','32911','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2912','32912','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2913','32913','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2914','32914','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2915','32915','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2916','32916','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2917','32917','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2918','32918','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2919','32919','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2920','32920','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2921','32921','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2922','32922','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2923','32923','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2924','32924','32883');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2925','32976','32972');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2926','32977','32973');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2927','32978','32974');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2928','32979','32974');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2929','32980','32974');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2930','32981','32974');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2931','32982','32974');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2932','32983','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2933','32984','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2934','32985','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2935','32986','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2936','32987','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2937','32988','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2938','32989','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2939','32990','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2940','32991','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2941','32992','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2942','32993','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2943','32994','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2944','32995','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2945','32996','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2946','32997','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2947','32998','32971');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2948','32999','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2949','33000','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2950','33001','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2951','33002','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2952','33003','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2953','33004','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2954','33005','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2955','33006','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2956','33007','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2957','33008','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2958','33009','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2959','33010','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2960','33011','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2961','33012','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2962','33013','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2963','33014','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2964','33015','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2965','33016','32975');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2966','33065','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2967','33066','33062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2968','33067','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2969','33068','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2970','33069','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2971','33070','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2972','33071','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2973','33072','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2974','33073','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2975','33074','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2976','33075','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2977','33076','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2978','33077','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2979','33078','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2980','33079','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2981','33080','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2982','33081','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2983','33082','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2984','33083','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2985','33084','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2986','33085','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2987','33086','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2988','33087','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2989','33088','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2990','33089','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2991','33090','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2992','33091','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2993','33092','33061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2994','33093','33062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2995','33094','33062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2996','33095','33062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2997','33096','33062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2998','33097','33062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('2999','33098','33062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3000','33099','33062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3001','33100','33062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3002','33101','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3003','33102','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3004','33103','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3005','33104','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3006','33105','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3007','33106','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3008','33107','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3009','33108','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3010','33109','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3011','33110','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3012','33111','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3013','33112','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3014','33113','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3015','33114','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3016','33115','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3017','33116','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3018','33117','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3019','33118','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3020','33119','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3021','33120','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3022','33121','33063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3023','33122','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3024','33123','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3025','33124','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3026','33125','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3027','33126','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3028','33127','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3029','33128','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3030','33129','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3031','33130','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3032','33131','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3033','33132','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3034','33133','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3035','33134','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3036','33135','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3037','33136','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3038','33137','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3039','33138','33064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3040','33177','33174');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3041','33178','33175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3042','33179','33174');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3043','33180','33174');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3044','33181','33174');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3045','33182','33174');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3046','33183','33174');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3047','33184','33174');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3048','33185','33174');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3049','33186','33174');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3050','33187','33175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3051','33188','33175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3052','33189','33175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3053','33190','33175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3054','33191','33175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3055','33192','33175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3056','33193','33175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3057','33194','31126');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3058','33195','31126');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3059','33196','31126');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3060','33219','33211');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3061','33220','33212');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3062','33221','33213');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3063','33222','33214');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3064','33223','33214');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3065','33224','33214');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3066','33225','33215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3067','33226','33215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3068','33227','33215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3069','33228','33215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3070','33229','33215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3071','33230','33215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3072','33231','33215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3073','33232','33215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3074','33233','33215');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3075','33234','33216');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3076','33235','33217');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3077','33236','33218');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3078','33237','33218');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3079','33260','33252');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3080','33261','33253');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3081','33262','33254');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3082','33263','33255');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3083','33264','33255');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3084','33265','33255');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3085','33266','33256');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3086','33267','33256');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3087','33268','33256');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3088','33269','33256');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3089','33270','33256');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3090','33271','33256');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3091','33272','33256');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3092','33273','33256');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3093','33274','33256');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3094','33275','33257');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3095','33276','33258');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3096','33277','33259');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3097','33278','33259');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3098','33301','33293');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3099','33302','33294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3100','33303','33295');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3101','33304','33296');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3102','33305','33296');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3103','33306','33296');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3104','33307','33297');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3105','33308','33297');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3106','33309','33297');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3107','33310','33297');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3108','33311','33297');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3109','33312','33297');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3110','33313','33297');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3111','33314','33297');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3112','33315','33297');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3113','33316','33298');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3114','33317','33299');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3115','33318','33300');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3116','33319','33300');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3117','33342','33334');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3118','33343','33335');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3119','33344','33336');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3120','33345','33337');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3121','33346','33337');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3122','33347','33337');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3123','33348','33338');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3124','33349','33338');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3125','33350','33338');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3126','33351','33338');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3127','33352','33338');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3128','33353','33338');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3129','33354','33338');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3130','33355','33338');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3131','33356','33338');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3132','33357','33339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3133','33358','33340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3134','33359','33341');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3135','33360','33341');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3136','33383','33375');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3137','33384','33376');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3138','33385','33377');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3139','33386','33378');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3140','33387','33378');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3141','33388','33378');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3142','33389','33379');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3143','33390','33379');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3144','33391','33379');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3145','33392','33379');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3146','33393','33379');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3147','33394','33379');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3148','33395','33379');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3149','33396','33379');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3150','33397','33379');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3151','33398','33380');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3152','33399','33381');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3153','33400','33382');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3154','33401','33382');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3155','33417','33414');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3156','33418','33414');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3157','33419','33414');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3158','33420','33414');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3159','33421','33414');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3160','33422','33414');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3161','33423','33414');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3162','33424','33414');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3163','33425','33414');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3164','33426','33415');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3165','33427','33415');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3166','33428','33415');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3167','33429','33416');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3168','33430','33416');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3169','33431','33416');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3170','33465','33460');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3171','33466','33461');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3172','33467','33461');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3173','33468','33461');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3174','33469','33461');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3175','33470','33461');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3176','33471','33462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3177','33472','33462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3178','33473','33462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3179','33474','33463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3180','33475','33463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3181','33476','33463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3182','33477','33464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3183','33478','33464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3184','33522','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3185','33523','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3186','33524','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3187','33525','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3188','33526','33513');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3189','33527','33514');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3190','33528','33515');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3191','33529','33516');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3192','33530','33516');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3193','33531','33516');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3194','33532','33516');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3195','33533','33517');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3196','33534','33517');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3197','33535','33517');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3198','33536','33517');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3199','33537','33517');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3200','33538','33517');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3201','33539','33518');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3202','33540','33519');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3203','33541','33519');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3204','33542','33520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3205','33543','33520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3206','33544','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3207','33545','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3208','33546','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3209','33547','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3210','33548','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3211','33549','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3212','33550','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3213','33551','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3214','33552','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3215','33553','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3216','33554','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3217','33555','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3218','33556','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3219','33557','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3220','33558','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3221','33559','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3222','33560','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3223','33561','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3224','33562','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3225','33563','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3226','33564','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3227','33565','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3228','33566','33521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3229','33602','33596');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3230','33603','33597');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3231','33604','33597');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3232','33605','33597');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3233','33606','33597');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3234','33607','33597');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3235','33608','33598');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3236','33609','33598');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3237','33610','33598');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3238','33611','33599');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3239','33612','33599');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3240','33613','33599');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3241','33614','33600');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3242','33615','33600');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3243','33616','33601');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3244','33617','33601');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3245','33618','33601');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3246','33653','33647');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3247','33654','33648');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3248','33655','33648');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3249','33656','33648');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3250','33657','33648');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3251','33658','33648');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3252','33659','33649');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3253','33660','33649');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3254','33661','33649');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3255','33662','33650');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3256','33663','33650');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3257','33664','33650');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3258','33665','33651');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3259','33666','33651');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3260','33667','33652');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3261','33668','33652');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3262','33669','33652');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3263','33704','33698');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3264','33705','33699');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3265','33706','33699');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3266','33707','33699');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3267','33708','33699');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3268','33709','33699');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3269','33710','33700');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3270','33711','33700');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3271','33712','33700');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3272','33713','33701');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3273','33714','33701');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3274','33715','33701');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3275','33716','33702');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3276','33717','33702');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3277','33718','33703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3278','33719','33703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3279','33720','33703');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3280','33755','33749');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3281','33756','33750');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3282','33757','33750');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3283','33758','33750');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3284','33759','33750');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3285','33760','33750');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3286','33761','33751');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3287','33762','33751');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3288','33763','33751');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3289','33764','33752');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3290','33765','33752');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3291','33766','33752');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3292','33767','33753');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3293','33768','33753');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3294','33769','33754');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3295','33770','33754');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3296','33771','33754');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3297','33806','33800');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3298','33807','33801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3299','33808','33801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3300','33809','33801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3301','33810','33801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3302','33811','33801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3303','33812','33802');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3304','33813','33802');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3305','33814','33802');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3306','33815','33803');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3307','33816','33803');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3308','33817','33803');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3309','33818','33804');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3310','33819','33804');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3311','33820','33805');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3312','33821','33805');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3313','33822','33805');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3314','33857','33851');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3315','33858','33852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3316','33859','33852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3317','33860','33852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3318','33861','33852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3319','33862','33852');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3320','33863','33853');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3321','33864','33853');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3322','33865','33853');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3323','33866','33854');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3324','33867','33854');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3325','33868','33854');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3326','33869','33855');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3327','33870','33855');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3328','33871','33856');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3329','33872','33856');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3330','33873','33856');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3331','33908','33902');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3332','33909','33903');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3333','33910','33903');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3334','33911','33903');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3335','33912','33903');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3336','33913','33903');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3337','33914','33904');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3338','33915','33904');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3339','33916','33904');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3340','33917','33905');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3341','33918','33905');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3342','33919','33905');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3343','33920','33906');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3344','33921','33906');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3345','33922','33907');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3346','33923','33907');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3347','33924','33907');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3348','33927','33926');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3349','33928','33926');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3350','33929','33926');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3351','33964','33958');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3352','33965','33959');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3353','33966','33959');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3354','33967','33959');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3355','33968','33959');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3356','33969','33959');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3357','33970','33960');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3358','33971','33960');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3359','33972','33960');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3360','33973','33961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3361','33974','33961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3362','33975','33961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3363','33976','33962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3364','33977','33962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3365','33978','33963');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3366','33979','33963');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3367','33980','33963');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3368','34015','34009');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3369','34016','34010');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3370','34017','34010');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3371','34018','34010');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3372','34019','34010');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3373','34020','34010');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3374','34021','34011');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3375','34022','34011');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3376','34023','34011');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3377','34024','34012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3378','34025','34012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3379','34026','34012');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3380','34027','34013');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3381','34028','34013');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3382','34029','34014');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3383','34030','34014');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3384','34031','34014');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3385','34066','34060');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3386','34067','34061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3387','34068','34061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3388','34069','34061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3389','34070','34061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3390','34071','34061');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3391','34072','34062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3392','34073','34062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3393','34074','34062');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3394','34075','34063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3395','34076','34063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3396','34077','34063');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3397','34078','34064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3398','34079','34064');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3399','34080','34065');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3400','34081','34065');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3401','34082','34065');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3402','34101','34099');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3403','34102','34099');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3404','34103','34099');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3405','34104','34100');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3406','34105','34100');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3407','34127','34123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3408','34128','34123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3409','34129','34123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3410','34130','34123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3411','34131','34123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3412','34132','34123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3414','34134','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3415','34135','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3416','34136','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3417','34137','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3418','34138','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3419','34139','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3420','34140','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3421','34141','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3422','34142','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3423','34143','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3424','34144','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3425','34145','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3426','34146','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3427','34147','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3428','34148','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3429','34149','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3430','34150','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3431','34151','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3432','34152','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3433','34153','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3434','34154','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3435','34155','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3436','34156','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3437','34157','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3438','34158','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3439','34159','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3440','34160','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3441','34161','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3442','34162','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3443','34163','34124');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3444','34164','34125');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3445','34165','34125');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3446','34166','34125');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3447','34167','34125');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3448','34168','34126');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3449','34169','34126');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3450','34170','34126');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3451','34171','34126');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3452','34172','34126');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3453','34176','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3454','34177','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3455','34178','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3456','34179','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3457','34180','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3458','34181','31123');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3459','34182','34175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3460','34183','34175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3461','34184','34175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3462','34185','34175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3463','34186','34175');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3464','34221','34217');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3465','34222','34217');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3466','34223','34217');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3467','34224','34217');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3468','34225','34217');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3469','34226','34217');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3470','34227','34217');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3471','34228','34217');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3472','34229','34217');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3473','34230','34217');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3474','34231','34217');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3475','34232','34218');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3476','34233','34218');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3477','34234','34218');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3478','34235','34218');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3479','34236','34218');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3480','34237','34219');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3481','34238','34220');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3482','34255','34249');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3483','34256','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3484','34257','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3485','34258','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3486','34259','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3487','34260','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3488','34261','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3489','34262','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3490','34263','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3491','34264','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3492','34265','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3493','34266','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3494','34267','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3495','34268','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3496','34269','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3497','34270','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3498','34271','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3499','34272','34250');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3500','34273','34251');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3501','34274','34252');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3502','34275','34252');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3503','34276','34252');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3504','34277','34252');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3505','34278','34252');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3506','34279','34252');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3507','34280','34252');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3508','34281','34253');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3509','34282','34254');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3510','34297','34293');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3511','34298','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3512','34299','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3513','34300','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3514','34301','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3515','34302','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3516','34303','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3517','34304','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3518','34305','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3519','34306','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3520','34307','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3521','34308','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3522','34309','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3523','34310','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3524','34311','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3525','34312','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3526','34313','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3527','34314','34294');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3528','34315','34295');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3529','34316','34296');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3530','34333','34324');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3531','34334','34325');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3532','34335','34326');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3533','34336','34327');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3534','34337','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3535','34338','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3536','34339','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3537','34340','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3538','34341','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3539','34342','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3540','34343','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3541','34344','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3542','34345','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3543','34346','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3544','34347','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3545','34348','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3546','34349','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3547','34350','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3548','34351','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3549','34352','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3550','34353','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3551','34354','34328');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3552','34355','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3553','34356','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3554','34357','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3555','34358','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3556','34359','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3557','34360','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3558','34361','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3559','34362','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3560','34363','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3561','34364','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3562','34365','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3563','34366','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3564','34367','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3565','34368','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3566','34369','34329');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3567','34370','34330');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3568','34371','34330');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3569','34372','34330');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3570','34373','34330');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3571','34374','34330');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3572','34375','34330');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3573','34376','34330');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3574','34377','34330');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3575','34378','34330');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3576','34379','34330');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3577','34380','34330');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3578','34381','34330');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3579','34382','34331');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3580','34383','34332');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3581','34400','34391');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3582','34401','34392');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3583','34402','34393');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3584','34403','34394');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3585','34404','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3586','34405','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3587','34406','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3588','34407','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3589','34408','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3590','34409','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3591','34410','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3592','34411','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3593','34412','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3594','34413','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3595','34414','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3596','34415','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3597','34416','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3598','34417','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3599','34418','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3600','34419','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3601','34420','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3602','34421','34395');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3603','34422','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3604','34423','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3605','34424','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3606','34425','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3607','34426','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3608','34427','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3609','34428','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3610','34429','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3611','34430','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3612','34431','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3613','34432','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3614','34433','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3615','34434','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3616','34435','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3617','34436','34396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3618','34437','34397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3619','34438','34397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3620','34439','34397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3621','34440','34397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3622','34441','34397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3623','34442','34397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3624','34443','34397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3625','34444','34397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3626','34445','34397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3627','34446','34397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3628','34447','34397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3629','34448','34397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3630','34449','34398');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3631','34450','34399');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3632','34466','34461');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3633','34467','34462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3634','34468','34462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3635','34469','34462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3636','34470','34462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3637','34471','34462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3638','34472','34462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3639','34473','34462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3640','34474','34462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3641','34475','34462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3642','34476','34462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3643','34477','34462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3644','34478','34463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3645','34479','34463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3646','34480','34463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3647','34481','34463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3648','34482','34463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3649','34483','34464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3650','34484','34465');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3651','34498','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3652','34499','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3653','34500','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3654','34501','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3655','34502','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3656','34503','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3657','34504','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3658','34505','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3659','34506','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3660','34507','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3661','34508','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3662','34509','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3663','34510','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3664','34511','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3665','34512','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3666','34513','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3667','34514','34495');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3668','34515','34496');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3669','34516','34497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3670','34517','34497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3671','34518','34497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3672','34519','34497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3673','34520','34497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3674','34521','34497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3675','34522','34497');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3676','34539','34533');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3677','34540','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3678','34541','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3679','34542','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3680','34543','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3681','34544','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3682','34545','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3683','34546','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3684','34547','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3685','34548','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3686','34549','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3687','34550','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3688','34551','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3689','34552','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3690','34553','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3691','34554','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3692','34555','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3693','34556','34534');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3694','34557','34535');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3695','34558','34536');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3696','34559','34536');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3697','34560','34536');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3698','34561','34536');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3699','34562','34536');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3700','34563','34536');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3701','34564','34536');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3702','34565','34537');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3703','34566','34538');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3704','34583','34577');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3705','34584','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3706','34585','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3707','34586','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3708','34587','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3709','34588','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3710','34589','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3711','34590','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3712','34591','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3713','34592','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3714','34593','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3715','34594','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3716','34595','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3717','34596','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3718','34597','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3719','34598','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3720','34599','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3721','34600','34578');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3722','34601','34579');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3723','34602','34580');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3724','34603','34580');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3725','34604','34580');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3726','34605','34580');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3727','34606','34580');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3728','34607','34580');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3729','34608','34580');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3730','34609','34581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3731','34610','34582');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3732','34627','34621');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3733','34628','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3734','34629','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3735','34630','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3736','34631','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3737','34632','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3738','34633','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3739','34634','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3740','34635','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3741','34636','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3742','34637','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3743','34638','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3744','34639','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3745','34640','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3746','34641','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3747','34642','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3748','34643','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3749','34644','34622');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3750','34645','34623');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3751','34646','34624');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3752','34647','34624');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3753','34648','34624');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3754','34649','34624');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3755','34650','34624');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3756','34651','34624');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3757','34652','34624');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3758','34653','34625');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3759','34654','34626');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3760','34671','34665');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3761','34672','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3762','34673','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3763','34674','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3764','34675','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3765','34676','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3766','34677','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3767','34678','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3768','34679','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3769','34680','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3770','34681','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3771','34682','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3772','34683','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3773','34684','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3774','34685','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3775','34686','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3776','34687','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3777','34688','34666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3778','34689','34667');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3779','34690','34668');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3780','34691','34668');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3781','34692','34668');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3782','34693','34668');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3783','34694','34668');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3784','34695','34668');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3785','34696','34668');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3786','34697','34669');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3787','34698','34670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3788','34716','34710');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3789','34717','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3790','34718','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3791','34719','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3792','34720','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3793','34721','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3794','34722','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3795','34723','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3796','34724','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3797','34725','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3798','34726','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3799','34727','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3800','34728','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3801','34729','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3802','34730','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3803','34731','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3804','34732','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3805','34733','34711');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3806','34734','34712');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3807','34735','34713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3808','34736','34713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3809','34737','34713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3810','34738','34713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3811','34739','34713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3812','34740','34713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3813','34741','34713');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3814','34742','34714');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3815','34743','34715');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3816','34761','34755');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3817','34762','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3818','34763','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3819','34764','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3820','34765','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3821','34766','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3822','34767','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3823','34768','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3824','34769','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3825','34770','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3826','34771','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3827','34772','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3828','34773','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3829','34774','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3830','34775','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3831','34776','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3832','34777','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3833','34778','34756');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3834','34779','34757');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3835','34780','34758');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3836','34781','34758');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3837','34782','34758');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3838','34783','34758');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3839','34784','34758');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3840','34785','34758');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3841','34786','34758');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3842','34787','34759');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3843','34788','34760');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3844','34806','34799');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3845','34807','34800');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3846','34808','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3847','34809','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3848','34810','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3849','34811','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3850','34812','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3851','34813','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3852','34814','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3853','34815','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3854','34816','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3855','34817','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3856','34818','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3857','34819','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3858','34820','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3859','34821','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3860','34822','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3861','34823','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3862','34824','34801');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3863','34825','34802');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3864','34826','34803');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3865','34827','34803');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3866','34828','34803');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3867','34829','34803');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3868','34830','34803');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3869','34831','34803');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3870','34832','34803');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3871','34833','34804');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3872','34834','34805');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3873','34867','34859');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3874','34868','34859');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3875','34869','34859');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3876','34870','34859');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3877','34871','34859');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3878','34872','34859');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3879','34873','34859');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3880','34874','34859');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3881','34875','34859');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3882','34876','34859');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3883','34877','34860');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3884','34878','34860');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3885','34879','34860');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3886','34880','34860');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3887','34881','34860');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3888','34882','34860');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3889','34883','34860');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3890','34884','34860');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3891','34885','34860');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3892','34886','34860');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3893','34887','34860');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3894','34888','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3895','34889','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3896','34890','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3897','34891','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3898','34892','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3899','34893','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3900','34894','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3901','34895','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3902','34896','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3903','34897','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3904','34898','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3905','34899','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3906','34900','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3907','34901','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3908','34902','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3909','34903','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3910','34904','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3911','34905','34861');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3912','34906','34862');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3913','34907','34862');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3914','34908','34862');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3915','34909','34863');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3916','34910','34863');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3917','34911','34863');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3918','34912','34863');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3919','34913','34863');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3920','34914','34863');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3921','34915','34863');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3922','34916','34863');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3923','34917','34863');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3924','34918','34863');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3925','34919','34863');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3926','34920','34864');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3927','34921','34864');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3928','34922','34864');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3929','34923','34864');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3930','34924','34864');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3931','34925','34864');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3932','34926','34864');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3933','34927','34864');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3934','34928','34864');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3935','34929','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3936','34930','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3937','34931','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3938','34932','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3939','34933','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3940','34934','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3941','34935','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3942','34936','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3943','34937','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3944','34938','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3945','34939','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3946','34940','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3947','34941','34865');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3948','34942','34866');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3949','34943','34866');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3950','34964','34954');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3951','34965','34955');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3952','34966','34955');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3953','34967','34956');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3954','34968','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3955','34969','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3956','34970','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3957','34971','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3958','34972','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3959','34973','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3960','34974','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3961','34975','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3962','34976','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3963','34977','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3964','34978','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3965','34979','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3966','34980','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3967','34981','34957');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3968','34982','34958');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3969','34983','34958');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3970','34984','34958');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3971','34985','34958');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3972','34986','34958');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3973','34987','34959');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3974','34988','34960');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3975','34989','34961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3976','34990','34961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3977','34991','34961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3978','34992','34961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3979','34993','34962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3980','34994','34962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3981','34995','34962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3982','34996','34963');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3983','34997','34963');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('3984','34998','34963');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4013','35061','35054');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4014','35062','35055');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4015','35063','35055');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4016','35064','35056');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4017','35065','35056');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4018','35066','35057');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4019','35067','35057');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4020','35068','35057');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4021','35069','35057');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4022','35070','35057');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4023','35071','35057');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4024','35072','35058');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4025','35073','35059');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4026','35074','35059');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4027','35075','35060');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4028','35076','35060');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4029','35077','35060');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4030','35078','35060');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4031','35079','35060');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4032','35080','35060');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4061','35143','35136');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4062','35144','35137');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4063','35145','35137');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4064','35146','35138');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4065','35147','35138');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4066','35148','35139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4067','35149','35139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4068','35150','35139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4069','35151','35139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4070','35152','35139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4071','35153','35139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4072','35154','35140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4073','35155','35141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4074','35156','35141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4075','35157','35142');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4076','35158','35142');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4077','35159','35142');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4078','35160','35142');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4079','35161','35142');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4080','35162','35142');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4109','35225','35218');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4110','35226','35219');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4111','35227','35219');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4112','35228','35220');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4113','35229','35220');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4114','35230','35221');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4115','35231','35221');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4116','35232','35221');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4117','35233','35221');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4118','35234','35221');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4119','35235','35221');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4120','35236','35222');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4121','35237','35223');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4122','35238','35223');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4123','35239','35224');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4124','35240','35224');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4125','35241','35224');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4126','35242','35224');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4127','35243','35224');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4128','35244','35224');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4157','35307','35300');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4158','35308','35301');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4159','35309','35301');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4160','35310','35302');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4161','35311','35302');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4162','35312','35303');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4163','35313','35303');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4164','35314','35303');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4165','35315','35303');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4166','35316','35303');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4167','35317','35303');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4168','35318','35304');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4169','35319','35305');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4170','35320','35305');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4171','35321','35306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4172','35322','35306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4173','35323','35306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4174','35324','35306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4175','35325','35306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4176','35326','35306');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4177','35353','35339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4178','35354','35339');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4179','35355','35340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4180','35356','35340');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4181','35357','35341');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4182','35358','35342');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4183','35359','35343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4184','35360','35343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4185','35361','35343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4186','35362','35343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4187','35363','35343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4188','35364','35343');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4189','35365','35344');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4190','35366','35345');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4191','35367','35345');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4192','35368','35346');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4193','35369','35346');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4194','35370','35347');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4195','35371','35347');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4196','35372','35347');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4197','35373','35348');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4198','35374','35348');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4199','35375','35349');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4200','35376','35349');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4201','35377','35350');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4202','35378','35350');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4203','35379','35351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4204','35380','35351');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4205','35381','35352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4206','35382','35352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4207','35383','35352');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4208','35410','35396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4209','35411','35396');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4210','35412','35397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4211','35413','35397');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4212','35414','35398');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4213','35415','35399');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4214','35416','35400');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4215','35417','35400');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4216','35418','35400');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4217','35419','35400');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4218','35420','35400');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4219','35421','35400');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4220','35422','35401');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4221','35423','35402');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4222','35424','35402');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4223','35425','35403');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4224','35426','35403');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4225','35427','35404');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4226','35428','35404');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4227','35429','35404');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4228','35430','35405');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4229','35431','35405');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4230','35432','35406');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4231','35433','35406');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4232','35434','35407');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4233','35435','35407');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4234','35436','35408');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4235','35437','35408');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4236','35438','35409');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4237','35439','35409');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4238','35440','35409');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4239','35467','35453');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4240','35468','35453');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4241','35469','35454');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4242','35470','35454');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4243','35471','35455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4244','35472','35456');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4245','35473','35457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4246','35474','35457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4247','35475','35457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4248','35476','35457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4249','35477','35457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4250','35478','35457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4251','35479','35458');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4252','35480','35459');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4253','35481','35459');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4254','35482','35460');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4255','35483','35460');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4256','35484','35461');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4257','35485','35461');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4258','35486','35461');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4259','35487','35462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4260','35488','35462');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4261','35489','35463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4262','35490','35463');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4263','35491','35464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4264','35492','35464');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4265','35493','35465');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4266','35494','35465');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4267','35495','35466');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4268','35496','35466');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4269','35497','35466');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4270','35524','35510');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4271','35525','35510');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4272','35526','35511');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4273','35527','35511');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4274','35528','35512');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4275','35529','35513');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4276','35530','35514');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4277','35531','35514');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4278','35532','35514');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4279','35533','35514');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4280','35534','35514');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4281','35535','35514');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4282','35536','35515');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4283','35537','35516');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4284','35538','35516');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4285','35539','35517');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4286','35540','35517');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4287','35541','35518');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4288','35542','35518');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4289','35543','35518');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4290','35544','35519');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4291','35545','35519');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4292','35546','35520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4293','35547','35520');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4294','35548','35521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4295','35549','35521');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4296','35550','35522');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4297','35551','35522');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4298','35552','35523');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4299','35553','35523');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4300','35554','35523');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4301','35560','35558');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4302','35561','35559');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4303','35562','35558');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4304','35563','35558');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4305','35564','35558');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4306','35565','35558');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4307','35566','35559');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4308','35567','35559');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4309','35578','35568');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4310','35579','35568');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4311','35580','35568');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4312','35581','35568');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4313','35582','35568');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4314','35583','35568');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4315','35584','35568');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4316','35585','35568');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4317','35586','35568');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4318','35587','35569');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4319','35588','35569');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4320','35589','35569');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4321','35590','35569');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4322','35591','35570');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4323','35592','35570');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4324','35593','35570');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4325','35594','35570');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4326','35595','35570');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4327','35596','35570');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4328','35597','35570');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4329','35598','35570');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4330','35599','35570');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4331','35600','35570');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4332','35601','35570');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4333','35602','35571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4334','35603','35571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4335','35604','35571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4336','35605','35571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4337','35606','35571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4338','35607','35571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4339','35608','35571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4340','35609','35571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4341','35610','35571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4342','35611','35571');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4343','35612','35572');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4344','35613','35572');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4345','35614','35572');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4346','35615','35572');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4347','35616','35572');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4348','35617','35573');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4349','35618','35573');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4350','35619','35573');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4351','35620','35574');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4352','35621','35574');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4354','35623','35574');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4355','35624','35575');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4356','35625','35575');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4357','35626','35575');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4358','35627','35575');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4359','35628','35575');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4360','35629','35575');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4361','35630','35575');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4362','35631','35575');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4363','35632','35576');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4364','35633','35576');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4365','35634','35576');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4366','35635','35576');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4367','35636','35576');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4368','35637','35577');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4369','35638','35577');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4370','35639','35577');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4371','35640','35577');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4372','35641','35577');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4373','35642','35577');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4374','35643','35577');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4375','35644','35577');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4376','35645','35577');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4377','35679','35664');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4378','35680','35665');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4379','35681','35665');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4380','35682','35666');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4381','35683','35667');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4382','35684','35667');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4383','35685','35668');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4384','35686','35669');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4385','35687','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4386','35688','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4387','35689','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4388','35690','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4389','35691','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4390','35692','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4391','35693','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4392','35694','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4393','35695','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4394','35696','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4395','35697','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4396','35698','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4397','35699','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4398','35700','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4399','35701','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4400','35702','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4401','35703','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4402','35704','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4403','35705','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4404','35706','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4405','35707','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4406','35708','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4407','35709','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4408','35710','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4409','35711','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4410','35712','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4411','35713','35670');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4412','35714','35671');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4413','35715','35671');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4414','35716','35671');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4415','35717','35672');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4416','35718','35672');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4417','35719','35672');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4418','35720','35672');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4419','35721','35672');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4420','35722','35673');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4421','35723','35673');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4422','35724','35673');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4423','35725','35673');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4424','35726','35673');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4425','35727','35673');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4426','35728','35674');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4427','35729','35674');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4428','35730','35674');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4429','35731','35674');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4430','35732','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4431','35733','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4432','35734','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4433','35735','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4434','35736','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4435','35737','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4436','35738','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4437','35739','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4438','35740','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4439','35741','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4440','35742','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4441','35743','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4442','35744','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4443','35745','35675');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4444','35746','35676');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4445','35747','35676');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4446','35748','35676');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4447','35749','35676');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4448','35750','35676');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4449','35751','35676');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4450','35752','35676');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4451','35753','35676');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4452','35754','35677');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4453','35755','35677');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4454','35756','35677');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4455','35757','35677');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4456','35758','35677');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4457','35759','35677');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4458','35760','35677');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4459','35761','35677');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4460','35762','35678');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4461','35763','35678');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4462','35764','35678');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4463','35765','35678');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4464','35766','35678');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4465','35767','35678');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4466','35768','35678');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4467','35769','35678');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4468','35770','35678');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4469','35771','35678');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4470','35786','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4471','35787','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4472','35788','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4473','35789','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4474','35790','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4475','35791','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4476','35792','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4477','35793','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4478','35794','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4479','35795','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4480','35796','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4481','35797','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4482','35798','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4483','35799','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4484','35800','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4485','35801','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4486','35802','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4487','35803','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4488','35804','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4489','35805','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4490','35806','30193');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4491','35807','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4492','35808','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4493','35809','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4494','35810','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4495','35811','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4496','35812','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4497','35813','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4498','35814','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4499','35815','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4500','35816','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4501','35817','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4502','35818','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4503','35819','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4504','35820','30194');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4505','35821','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4506','35822','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4507','35823','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4508','35824','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4509','35825','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4510','35826','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4511','35827','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4512','35828','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4513','35829','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4514','35830','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4515','35831','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4516','35832','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4517','35833','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4518','35834','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4519','35835','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4520','35836','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4521','35837','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4522','35838','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4523','35839','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4524','35840','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4525','35841','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4526','35842','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4527','35843','30195');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4528','35845','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4529','35846','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4530','35847','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4531','35848','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4532','35849','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4533','35850','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4534','35851','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4535','35852','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4536','35853','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4537','35854','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4538','35855','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4539','35856','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4540','35857','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4541','35858','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4542','35859','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4543','35860','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4544','35861','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4545','35862','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4546','35863','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4547','35864','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4548','35865','30236');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4549','35866','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4550','35867','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4551','35868','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4552','35869','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4553','35870','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4554','35871','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4555','35872','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4556','35873','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4557','35874','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4558','35875','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4559','35876','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4560','35877','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4561','35878','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4562','35879','30237');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4563','35880','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4564','35881','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4565','35882','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4566','35883','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4567','35884','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4568','35885','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4569','35886','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4570','35887','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4571','35888','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4572','35889','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4573','35890','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4574','35891','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4575','35892','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4576','35893','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4577','35894','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4578','35895','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4579','35896','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4580','35897','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4581','35898','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4582','35899','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4583','35900','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4584','35901','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4585','35902','30238');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4586','35914','35909');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4587','35915','35910');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4588','35916','35910');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4589','35917','35910');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4590','35918','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4591','35919','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4592','35920','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4593','35921','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4594','35922','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4595','35923','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4596','35924','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4597','35925','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4598','35926','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4599','35927','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4600','35928','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4601','35929','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4602','35930','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4603','35931','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4604','35932','35911');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4605','35933','35912');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4606','35934','35912');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4607','35935','35912');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4608','35936','35912');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4609','35937','35912');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4610','35938','35912');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4611','35939','35912');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4612','35940','35912');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4613','35941','35913');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4614','35942','35913');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4615','35943','35913');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4616','35944','35913');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4617','35945','35913');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4618','35946','35913');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4619','35947','35913');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4620','35948','35913');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4621','35949','35913');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4622','35950','35913');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4623','35965','35961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4624','35966','35961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4625','35967','35961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4626','35968','35961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4627','35969','35961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4628','35970','35961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4629','35971','35961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4630','35972','35961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4631','35973','35961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4632','35974','35961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4633','35975','35961');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4634','35976','35962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4635','35977','35962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4636','35978','35962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4637','35979','35962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4638','35980','35962');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4639','35981','35963');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4640','35982','35964');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4641','35999','35993');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4642','36000','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4643','36001','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4644','36002','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4645','36003','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4646','36004','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4647','36005','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4648','36006','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4649','36007','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4650','36008','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4651','36009','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4652','36010','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4653','36011','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4654','36012','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4655','36013','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4656','36014','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4657','36015','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4658','36016','35994');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4659','36017','35995');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4660','36018','35996');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4661','36019','35996');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4662','36020','35996');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4663','36021','35996');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4664','36022','35996');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4665','36023','35996');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4666','36024','35996');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4667','36025','35997');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4668','36026','35998');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4669','36041','36037');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4670','36042','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4671','36043','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4672','36044','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4673','36045','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4674','36046','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4675','36047','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4676','36048','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4677','36049','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4678','36050','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4679','36051','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4680','36052','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4681','36053','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4682','36054','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4683','36055','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4684','36056','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4685','36057','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4686','36058','36038');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4687','36059','36039');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4688','36060','36040');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4689','36077','36068');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4690','36078','36069');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4691','36079','36070');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4692','36080','36071');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4693','36081','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4694','36082','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4695','36083','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4696','36084','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4697','36085','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4698','36086','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4699','36087','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4700','36088','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4701','36089','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4702','36090','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4703','36091','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4704','36092','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4705','36093','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4706','36094','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4707','36095','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4708','36096','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4709','36097','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4710','36098','36072');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4711','36099','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4712','36100','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4713','36101','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4714','36102','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4715','36103','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4716','36104','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4717','36105','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4718','36106','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4719','36107','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4720','36108','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4721','36109','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4722','36110','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4723','36111','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4724','36112','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4725','36113','36073');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4726','36114','36074');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4727','36115','36074');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4728','36116','36074');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4729','36117','36074');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4730','36118','36074');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4731','36119','36074');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4732','36120','36074');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4733','36121','36074');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4734','36122','36074');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4735','36123','36074');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4736','36124','36074');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4737','36125','36074');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4738','36126','36075');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4739','36127','36076');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4740','36144','36135');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4741','36145','36136');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4742','36146','36137');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4743','36147','36138');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4744','36148','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4745','36149','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4746','36150','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4747','36151','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4748','36152','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4749','36153','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4750','36154','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4751','36155','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4752','36156','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4753','36157','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4754','36158','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4755','36159','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4756','36160','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4757','36161','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4758','36162','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4759','36163','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4760','36164','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4761','36165','36139');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4762','36166','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4763','36167','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4764','36168','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4765','36169','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4766','36170','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4767','36171','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4768','36172','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4769','36173','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4770','36174','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4771','36175','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4772','36176','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4773','36177','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4774','36178','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4775','36179','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4776','36180','36140');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4777','36181','36141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4778','36182','36141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4779','36183','36141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4780','36184','36141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4781','36185','36141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4782','36186','36141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4783','36187','36141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4784','36188','36141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4785','36189','36141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4786','36190','36141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4787','36191','36141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4788','36192','36141');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4789','36193','36142');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4790','36194','36143');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4791','36210','36205');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4792','36211','36206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4793','36212','36206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4794','36213','36206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4795','36214','36206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4796','36215','36206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4797','36216','36206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4798','36217','36206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4799','36218','36206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4800','36219','36206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4801','36220','36206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4802','36221','36206');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4803','36222','36207');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4804','36223','36207');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4805','36224','36207');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4806','36225','36207');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4807','36226','36207');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4808','36227','36208');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4809','36228','36209');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4810','36242','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4811','36243','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4812','36244','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4813','36245','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4814','36246','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4815','36247','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4816','36248','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4817','36249','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4818','36250','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4819','36251','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4820','36252','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4821','36253','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4822','36254','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4823','36255','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4824','36256','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4825','36257','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4826','36258','36239');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4827','36259','36240');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4828','36260','36241');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4829','36261','36241');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4830','36262','36241');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4831','36263','36241');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4832','36264','36241');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4833','36265','36241');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4834','36266','36241');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4835','36283','36277');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4836','36284','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4837','36285','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4838','36286','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4839','36287','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4840','36288','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4841','36289','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4842','36290','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4843','36291','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4844','36292','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4845','36293','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4846','36294','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4847','36295','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4848','36296','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4849','36297','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4850','36298','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4851','36299','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4852','36300','36278');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4853','36301','36279');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4854','36302','36280');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4855','36303','36280');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4856','36304','36280');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4857','36305','36280');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4858','36306','36280');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4859','36307','36280');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4860','36308','36280');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4861','36309','36281');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4862','36310','36282');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4863','36327','36321');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4864','36328','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4865','36329','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4866','36330','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4867','36331','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4868','36332','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4869','36333','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4870','36334','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4871','36335','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4872','36336','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4873','36337','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4874','36338','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4875','36339','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4876','36340','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4877','36341','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4878','36342','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4879','36343','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4880','36344','36322');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4881','36345','36323');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4882','36346','36324');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4883','36347','36324');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4884','36348','36324');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4885','36349','36324');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4886','36350','36324');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4887','36351','36324');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4888','36352','36324');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4889','36353','36325');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4890','36354','36326');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4891','36371','36365');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4892','36372','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4893','36373','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4894','36374','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4895','36375','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4896','36376','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4897','36377','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4898','36378','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4899','36379','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4900','36380','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4901','36381','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4902','36382','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4903','36383','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4904','36384','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4905','36385','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4906','36386','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4907','36387','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4908','36388','36366');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4909','36389','36367');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4910','36390','36368');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4911','36391','36368');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4912','36392','36368');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4913','36393','36368');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4914','36394','36368');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4915','36395','36368');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4916','36396','36368');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4917','36397','36369');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4918','36398','36370');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4919','36415','36409');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4920','36416','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4921','36417','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4922','36418','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4923','36419','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4924','36420','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4925','36421','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4926','36422','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4927','36423','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4928','36424','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4929','36425','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4930','36426','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4931','36427','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4932','36428','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4933','36429','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4934','36430','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4935','36431','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4936','36432','36410');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4937','36433','36411');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4938','36434','36412');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4939','36435','36412');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4940','36436','36412');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4941','36437','36412');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4942','36438','36412');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4943','36439','36412');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4944','36440','36412');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4945','36441','36413');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4946','36442','36414');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4947','36460','36454');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4948','36461','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4949','36462','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4950','36463','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4951','36464','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4952','36465','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4953','36466','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4954','36467','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4955','36468','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4956','36469','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4957','36470','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4958','36471','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4959','36472','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4960','36473','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4961','36474','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4962','36475','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4963','36476','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4964','36477','36455');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4965','36478','36456');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4966','36479','36457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4967','36480','36457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4968','36481','36457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4969','36482','36457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4970','36483','36457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4971','36484','36457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4972','36485','36457');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4973','36486','36458');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4974','36487','36459');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4975','36505','36499');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4976','36506','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4977','36507','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4978','36508','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4979','36509','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4980','36510','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4981','36511','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4982','36512','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4983','36513','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4984','36514','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4985','36515','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4986','36516','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4987','36517','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4988','36518','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4989','36519','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4990','36520','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4991','36521','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4992','36522','36500');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4993','36523','36501');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4994','36524','36502');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4995','36525','36502');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4996','36526','36502');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4997','36527','36502');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4998','36528','36502');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('4999','36529','36502');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5000','36530','36502');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5001','36531','36503');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5002','36532','36504');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5003','36550','36543');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5004','36551','36544');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5005','36552','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5006','36553','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5007','36554','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5008','36555','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5009','36556','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5010','36557','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5011','36558','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5012','36559','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5013','36560','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5014','36561','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5015','36562','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5016','36563','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5017','36564','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5018','36565','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5019','36566','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5020','36567','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5021','36568','36545');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5022','36569','36546');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5023','36570','36547');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5024','36571','36547');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5025','36572','36547');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5026','36573','36547');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5027','36574','36547');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5028','36575','36547');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5029','36576','36547');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5030','36577','36548');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5031','36578','36549');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5032','36583','36581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5033','36584','36581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5034','36585','36581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5035','36586','36581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5036','36587','36581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5037','36588','36581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5038','36589','36582');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5039','36590','36582');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5040','36591','36582');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5041','36592','36582');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5042','36593','36582');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5043','36594','36582');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5044','36595','36581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5045','36596','36581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5046','36597','36581');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5047','36598','36582');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5048','36599','36582');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5049','36600','36582');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5050','36605','36603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5051','36606','36603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5052','36607','36603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5053','36608','36603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5054','36609','36603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5055','36610','36603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5056','36611','36604');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5057','36612','36604');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5058','36613','36604');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5059','36614','36604');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5060','36615','36604');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5061','36616','36604');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5062','36617','36603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5063','36618','36603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5064','36619','36603');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5065','36620','36604');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5066','36621','36604');
INSERT INTO item_discovery (itemdiscoveryid,itemid,parent_itemid) values ('5067','36622','36604');
INSERT INTO host_discovery (hostid,parent_hostid,parent_itemid) values ('10331',NULL,'31599');
INSERT INTO host_discovery (hostid,parent_hostid,parent_itemid) values ('10332',NULL,'31600');
INSERT INTO host_discovery (hostid,parent_hostid,parent_itemid) values ('10364',NULL,'33173');
INSERT INTO host_discovery (hostid,parent_hostid,parent_itemid) values ('10365',NULL,'33176');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('19','345','179');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('166','799','780');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('167','803','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('168','803','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('169','804','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('170','805','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('171','811','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('172','812','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('173','813','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('174','820','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('175','821','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('176','822','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('177','823','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('178','824','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('179','825','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('180','836','826');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('181','837','827');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('182','838','826');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('183','839','827');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('184','840','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('185','840','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('186','841','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('187','842','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('191','846','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('192','847','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('193','856','848');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('194','857','849');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('195','858','852');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('196','859','853');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('197','860','854');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('198','861','855');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('205','868','848');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('206','869','851');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('207','870','852');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('208','871','853');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('209','872','854');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('210','873','855');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('211','874','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('212','874','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('213','875','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('214','876','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('215','883','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('216','884','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('217','885','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('218','892','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('219','892','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('220','893','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('221','894','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('222','901','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('223','901','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('224','902','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('225','903','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('230','913','782');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('231','913','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('232','914','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('233','915','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('234','916','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('235','916','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('236','917','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('237','918','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('243','934','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('244','934','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('245','935','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('246','936','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('247','942','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('248','943','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('249','944','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('250','949','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('251','949','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('252','950','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('253','951','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('263','969','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('264','970','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('265','971','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('266','977','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('267','978','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('268','979','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('269','986','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('270','986','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('271','987','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('272','988','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('273','992','782');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('274','993','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('275','994','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('294','1028','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('295','1028','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('296','1029','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('297','1030','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('305','1048','852');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('306','1049','855');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('307','1050','854');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('308','1051','853');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('309','1052','848');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('310','1053','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('311','1054','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('312','1055','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('313','1057','1056');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('314','1058','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('315','1059','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('316','1060','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('317','1058','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('318','1069','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('319','1070','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('320','1078','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('321','1079','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('324','1094','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('325','1095','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('326','1101','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('327','1102','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('328','1125','771');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('329','1126','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('330','1127','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('331','1125','784');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('332','1132','1128');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('333','1133','1129');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('334','1133','1131');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('335','1134','1130');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('336','1135','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('337','1136','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('342','1141','786');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('343','1152','1142');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('344','1153','1143');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('345','1154','1144');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('346','1155','1145');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('347','1156','1146');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('348','1157','1147');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('349','1158','1148');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('350','1159','1149');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('351','1160','1150');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('352','1161','1151');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('353','1162','1152');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('354','1163','1153');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('355','1164','1154');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('356','1165','1155');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('357','1166','1156');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('358','1167','1157');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('359','1168','1158');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('360','1169','1159');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('361','1170','1160');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('362','1171','1161');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('364','1183','1173');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('365','1184','1174');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('366','1185','1175');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('367','1186','1176');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('368','1187','1177');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('369','1188','1178');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('370','1189','1179');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('371','1190','1180');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('372','1191','1181');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('373','1192','1182');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('374','1212','1202');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('375','1213','1203');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('376','1214','1204');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('377','1215','1205');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('379','1216','1211');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('380','1217','1207');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('381','1218','1208');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('382','1219','1209');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('383','1220','1210');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('384','1225','1221');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('385','1226','1221');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('386','1227','1222');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('387','1228','1221');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('388','1229','1222');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('389','1230','1221');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('390','1231','1222');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('391','1232','1221');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('392','1233','1222');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('393','1234','1221');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('394','1235','1222');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('395','1236','1221');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('396','1237','1222');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('397','1238','1221');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('399','1161','1222');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('400','1219','1222');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('402','1240','1225');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('403','1241','1223');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('404','1242','1224');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('405','1253','1243');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('406','1254','1244');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('407','1255','1245');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('408','1256','1246');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('410','1257','1252');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('411','1258','1248');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('412','1259','1249');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('413','1260','1251');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('414','1242','1250');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('415','1269','1223');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('416','1192','1224');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('417','1270','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('418','1271','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('423','1286','1283');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('424','1287','1284');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('425','1288','1285');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('429','1292','1286');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('430','1293','1287');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('431','1294','1288');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('432','1295','1286');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('433','1296','1287');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('434','1297','1288');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('438','1311','1310');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('439','1313','1312');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('440','999','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('441','1000','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('442','998','782');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('443','1413','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('444','1414','799');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('445','1421','800');
INSERT INTO application_template (application_templateid,applicationid,templateid) values ('446','1422','799');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('4','22867','8','{#FSTYPE}','@File systems for discovery');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('5','22907','8','{#FSTYPE}','@File systems for discovery');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('6','22944','8','{#IFNAME}','@Network interfaces for discovery');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('7','22947','8','{#FSTYPE}','@File systems for discovery');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('8','22984','8','{#IFNAME}','@Network interfaces for discovery');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('9','22987','8','{#FSTYPE}','@File systems for discovery');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('10','23024','8','{#IFNAME}','@Network interfaces for discovery');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('11','23027','8','{#FSTYPE}','@File systems for discovery');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('12','23067','8','{#FSTYPE}','@File systems for discovery');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('15','23329','8','{#IFNAME}','@Network interfaces for discovery');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('16','23540','8','{#IFNAME}','@Network interfaces for discovery');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('217','27031','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('218','27031','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('229','27078','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('230','27078','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('233','27098','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('234','27098','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('237','27118','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('238','27118','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('243','27180','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('244','27180','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('245','27190','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('246','27190','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('247','27209','8','{#TEMP_SENSOR}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('248','27210','8','{#SNMPVALUE}','[^1]');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('249','27211','8','{#ENT_SN}','.+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('250','27215','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('251','27215','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('253','27242','8','{#SENSOR_TYPE}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('254','27243','8','{#SENSOR_TYPE}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('255','27244','8','{#SENSOR_TYPE}','2');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('256','27251','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('257','27251','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('258','27272','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('259','27272','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('260','27321','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('261','27321','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('262','27331','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('263','27331','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('266','27393','8','{#ENT_SN}','.+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('267','27393','8','{#ENT_CLASS}','[^3]');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('268','27399','8','{#ENT_SN}','.+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('269','27399','8','{#ENT_CLASS}','[^3]');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('272','27410','8','{#ENT_SN}','.+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('273','27410','8','{#ENT_CLASS}','[^3]');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('274','27450','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('275','27450','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('276','27460','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('277','27460','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('278','27486','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('279','27486','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('280','27520','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('281','27520','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('282','27530','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('283','27530','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('284','27550','8','{#STATUS}','[^0]');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('285','27551','8','{#STATUS}','[^0]');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('286','27556','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('287','27556','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('288','27566','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('289','27566','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('294','27619','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('295','27619','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('296','27629','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('297','27629','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('298','27642','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('299','27642','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('300','27652','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('301','27652','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('302','27665','8','{#SNMPVALUE}','^(MODULE|Module) (LEVEL|level)1$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('303','27665','8','{#SNMPVALUE}','(Fabric|FABRIC) (.+) (Module|MODULE)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('304','27666','8','{#SNMPVALUE}','^(MODULE|Module) (LEVEL|level)1$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('305','27666','8','{#SNMPVALUE}','(Fabric|FABRIC) (.+) (Module|MODULE)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('306','27666','8','{#SNMPVALUE}','(T|t)emperature.*(s|S)ensor');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('307','27667','8','{#ENT_CLASS}','7');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('308','27668','8','{#ENT_CLASS}','6');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('309','27669','8','{#ENT_CLASS}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('323','27722','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('324','27722','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('325','27732','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('326','27732','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('327','27745','8','{#ENT_NAME}','MPU.*');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('328','27746','8','{#ENT_CLASS}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('329','27756','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('330','27756','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('331','27779','8','{#SENSOR_TYPE}','2');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('332','27780','8','{#ENT_CLASS}','2');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('333','27788','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('334','27788','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('335','27798','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('336','27798','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('337','27815','8','{#SNMPVALUE}','Routing Engine.*');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('338','27816','8','{#SNMPVALUE}','[^0]+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('350','27872','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('351','27872','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('352','27903','8','{#STORAGE_TYPE}','.+4$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('353','27903','8','{#STORAGE_TYPE}','.+hrStorageFixedDisk');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('354','27909','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('355','27909','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('356','27944','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('357','27944','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('358','27954','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('359','27954','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('360','27976','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('361','27976','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('362','28005','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('363','28005','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('378','28118','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('379','28118','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('380','28128','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('381','28128','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('382','28144','8','{#SENSOR_TYPE}','8');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('383','28144','8','{#SENSOR_PRECISION}','0');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('384','28146','8','{#ENT_CLASS}','.+8.3.2$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('385','28146','8','{#ENT_STATUS}','(1|2|3|4)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('386','28147','8','{#ENT_CLASS}','.+8.3.1$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('387','28147','8','{#ENT_STATUS}','(1|2|3|4)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('388','28148','8','{#ENT_CLASS}','.+8.3.3$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('389','28148','8','{#ENT_STATUS}','(1|2|3|4)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('390','28149','8','{#ENT_CLASS}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('397','28196','8','{#SENSOR_TYPE}','8');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('398','28196','8','{#SENSOR_PRECISION}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('399','28197','8','{#SNMPVALUE}','10');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('400','28198','8','{#ENT_CLASS}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('401','28199','8','{#ENT_CLASS}','6');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('402','28207','8','{#ENT_SN}','.+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('403','28207','8','{#ENT_CLASS}','[^3]');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('404','28223','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('405','28223','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('407','27098','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('408','27180','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('409','27215','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('410','27251','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('411','27272','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('412','27321','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('413','27450','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('414','27486','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('415','27520','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('416','27556','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('417','27642','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('418','27722','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('419','27756','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('420','27788','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('421','27872','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('422','27909','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('423','27944','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('425','28118','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('427','28223','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('430','28005','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('431','27078','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('432','27619','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('433','27976','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('434','27118','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('436','28280','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('437','28280','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('438','28293','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('439','28293','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('440','28293','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('448','28306','8','{#SENSOR_TYPE}','8');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('449','28306','8','{#SENSOR_PRECISION}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('450','28307','8','{#SENSOR_TYPE}','10');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('451','28308','8','{#ENT_CLASS}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('452','28309','8','{#ENT_CLASS}','6');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('453','28346','8','{#SENSOR_LOCALE}','.*CPU.*');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('454','28347','8','{#SENSOR_LOCALE}','.*Inlet Temp.*');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('455','28349','8','{#TYPE}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('456','28392','8','{#SENSOR_LOCALE}','(4|8|9|12|13)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('457','28393','8','{#SNMPINDEX}','0\.1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('458','28393','8','{#SENSOR_LOCALE}','11');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('459','28394','8','{#SENSOR_LOCALE}','6');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('460','28395','8','{#SENSOR_LOCALE}','7');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('461','28396','8','{#SENSOR_LOCALE}','10');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('462','28397','8','{#SENSOR_LOCALE}','5');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('466','28468','8','{#SNMPVALUE}','(DIMM|PSU|PCH|RAID|RR|PCI).*');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('467','28469','8','{#SNMPVALUE}','Ambient.*');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('468','28470','8','{#SNMPVALUE}','CPU [0-9]* Temp');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('469','28493','8','{#SNMPVALUE}','[1-9]+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('470','28493','8','{#SENSOR_DESCR}','.*Temp.*');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('471','28494','8','{#SNMPVALUE}','[1-9]+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('472','28494','8','{#SENSOR_DESCR}','FAN.*');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('474','28711','8','{#DBNAME}','{$PG.LLD.FILTER.DBNAME}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('475','28948','9','{#DBNAME}','information_schema');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('476','28955','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('477','28955','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('478','28968','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('479','28968','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('480','28968','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('481','29008','8','{#DEVNAME}','{$VFS.DEV.DEVNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('482','29008','9','{#DEVNAME}','{$VFS.DEV.DEVNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('483','29010','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('484','29010','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('485','29010','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('486','29010','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('487','29011','8','{#DEVNAME}','{$VFS.DEV.DEVNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('488','29011','9','{#DEVNAME}','{$VFS.DEV.DEVNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('489','29013','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('490','29013','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('491','29013','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('492','29013','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('497','29077','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('498','29077','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('499','29077','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('500','29201','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('501','29201','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('502','29201','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('503','29201','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('506','29203','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('507','29203','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('508','29204','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('509','29204','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('510','29204','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('511','29204','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('514','29206','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('515','29206','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('516','29207','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('517','29207','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('518','29207','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('519','29207','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('522','29209','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('523','29209','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('524','29349','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('525','29349','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('526','29349','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('527','29349','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('530','29351','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('531','29351','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('532','29352','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('533','29352','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('534','29352','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('535','29352','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('538','29354','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('539','29354','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('540','29429','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('541','29429','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('542','29429','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('543','29429','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('544','29429','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('545','29429','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('546','29430','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('547','29430','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('548','29430','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('549','29430','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('550','29430','8','{#FSNAME}','{$VFS.FS.FSDEVICE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('551','29430','9','{#FSDEVICE}','{$VFS.FS.FSDEVICE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('552','29431','8','{#DEVNAME}','{$VFS.DEV.DEVNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('553','29431','9','{#DEVNAME}','{$VFS.DEV.DEVNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('554','29506','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('555','29506','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('556','29506','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('557','29506','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('558','29506','8','{#FSDRIVETYPE}','{$VFS.FS.FSDRIVETYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('559','29506','9','{#FSDRIVETYPE}','{$VFS.FS.FSDRIVETYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('572','29509','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('573','29509','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('574','29509','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('575','29509','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('576','29509','8','{#FSDRIVETYPE}','{$VFS.FS.FSDRIVETYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('577','29509','9','{#FSDRIVETYPE}','{$VFS.FS.FSDRIVETYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('590','29613','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('591','29613','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('592','29613','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('593','29613','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('594','29613','8','{#FSDRIVETYPE}','{$VFS.FS.FSDRIVETYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('595','29613','9','{#FSDRIVETYPE}','{$VFS.FS.FSDRIVETYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('608','29616','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('609','29616','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('610','29616','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('611','29616','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('612','29616','8','{#FSDRIVETYPE}','{$VFS.FS.FSDRIVETYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('613','29616','9','{#FSDRIVETYPE}','{$VFS.FS.FSDRIVETYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('628','29703','8','{#QUEUE}','{$RABBITMQ.LLD.FILTER.QUEUE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('629','29703','9','{#QUEUE}','{$RABBITMQ.LLD.FILTER.QUEUE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('630','29703','8','{#NODE}','{$RABBITMQ.CLUSTER.NAME}@{HOST.NAME}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('631','29785','8','{#EXCHANGE}','{$RABBITMQ.LLD.FILTER.EXCHANGE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('632','29785','9','{#EXCHANGE}','{$RABBITMQ.LLD.FILTER.EXCHANGE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('633','29786','8','{#QUEUE}','{$RABBITMQ.LLD.FILTER.QUEUE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('634','29786','9','{#QUEUE}','{$RABBITMQ.LLD.FILTER.QUEUE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('635','29786','8','{#NODE}','{$RABBITMQ.CLUSTER.NAME}@{HOST.NAME}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('645','27098','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('646','27098','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('647','27098','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('648','27098','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('649','27098','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('650','27098','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('651','27098','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('652','27098','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('653','27098','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('654','27180','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('655','27180','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('656','27180','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('657','27180','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('658','27180','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('659','27180','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('660','27180','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('661','27180','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('662','27180','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('663','27215','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('664','27215','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('665','27215','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('666','27215','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('667','27215','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('668','27215','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('669','27215','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('670','27215','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('671','27215','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('672','27251','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('673','27251','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('674','27251','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('675','27251','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('676','27251','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('677','27251','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('678','27251','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('679','27251','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('680','27251','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('681','27272','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('682','27272','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('683','27272','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('684','27272','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('685','27272','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('686','27272','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('687','27272','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('688','27272','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('689','27272','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('690','27321','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('691','27321','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('692','27321','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('693','27321','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('694','27321','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('695','27321','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('696','27321','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('697','27321','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('698','27321','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('699','27450','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('700','27450','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('701','27450','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('702','27450','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('703','27450','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('704','27450','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('705','27450','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('706','27450','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('707','27450','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('708','27486','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('709','27486','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('710','27486','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('711','27486','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('712','27486','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('713','27486','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('714','27486','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('715','27486','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('716','27486','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('717','27520','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('718','27520','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('719','27520','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('720','27520','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('721','27520','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('722','27520','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('723','27520','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('724','27520','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('725','27520','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('726','27556','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('727','27556','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('728','27556','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('729','27556','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('730','27556','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('731','27556','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('732','27556','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('733','27556','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('734','27556','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('735','27642','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('736','27642','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('737','27642','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('738','27642','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('739','27642','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('740','27642','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('741','27642','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('742','27642','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('743','27642','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('744','27722','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('745','27722','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('746','27722','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('747','27722','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('748','27722','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('749','27722','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('750','27722','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('751','27722','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('752','27722','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('753','27756','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('754','27756','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('755','27756','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('756','27756','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('757','27756','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('758','27756','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('759','27756','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('760','27756','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('761','27756','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('762','27788','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('763','27788','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('764','27788','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('765','27788','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('766','27788','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('767','27788','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('768','27788','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('769','27788','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('770','27788','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('771','27872','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('772','27872','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('773','27872','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('774','27872','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('775','27872','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('776','27872','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('777','27872','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('778','27872','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('779','27872','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('780','27909','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('781','27909','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('782','27909','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('783','27909','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('784','27909','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('785','27909','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('786','27909','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('787','27909','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('788','27909','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('789','27944','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('790','27944','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('791','27944','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('792','27944','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('793','27944','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('794','27944','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('795','27944','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('796','27944','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('797','27944','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('798','28118','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('799','28118','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('800','28118','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('801','28118','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('802','28118','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('803','28118','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('804','28118','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('805','28118','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('806','28118','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('816','28223','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('817','28223','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('818','28223','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('819','28223','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('820','28223','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('821','28223','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('822','28223','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('823','28223','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('824','28223','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('825','28293','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('826','28293','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('827','28293','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('828','28293','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('829','28293','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('830','28293','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('831','28293','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('832','28293','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('833','28293','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('834','28968','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('835','28968','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('836','28968','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('837','28968','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('838','28968','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('839','28968','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('840','28968','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('841','28968','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('842','28968','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('857','28005','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('858','28005','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('859','28005','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('860','28005','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('861','28005','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('862','28005','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('863','28005','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('864','27078','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('865','27078','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('866','27078','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('867','27078','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('868','27078','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('869','27078','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('870','27078','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('871','27619','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('872','27619','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('873','27619','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('874','27619','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('875','27619','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('876','27619','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('877','27619','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('878','27976','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('879','27976','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('880','27976','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('881','27976','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('882','27976','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('883','27976','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('884','27976','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('885','27118','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('886','27118','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('887','27118','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('888','27118','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('889','27118','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('890','27118','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('891','27118','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('892','27118','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('893','27118','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('894','29077','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('895','29077','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('896','29077','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('897','29077','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('898','29077','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('899','29077','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('900','29077','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('901','29077','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('902','29077','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('903','30026','8','{#EXCHANGE}','{$RABBITMQ.LLD.FILTER.EXCHANGE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('904','30026','9','{#EXCHANGE}','{$RABBITMQ.LLD.FILTER.EXCHANGE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('905','30147','8','{#MEMTYPE}','{$MEMORY.TYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('906','30147','9','{#MEMTYPE}','{$MEMORY.TYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('907','30147','8','{#MEMNAME}','{$MEMORY.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('908','30147','9','{#MEMNAME}','{$MEMORY.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('909','30148','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('910','30148','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('911','30148','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('912','30148','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('913','30149','8','{#MEMTYPE}','{$MEMORY.TYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('914','30149','9','{#MEMTYPE}','{$MEMORY.TYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('915','30149','8','{#MEMNAME}','{$MEMORY.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('916','30149','9','{#MEMNAME}','{$MEMORY.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('917','30150','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('918','30150','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('919','30150','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('920','30150','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('929','30153','8','{#MEMTYPE}','{$MEMORY.TYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('930','30153','9','{#MEMTYPE}','{$MEMORY.TYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('931','30153','8','{#MEMNAME}','{$MEMORY.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('932','30153','9','{#MEMNAME}','{$MEMORY.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('933','30154','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('934','30154','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('935','30154','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('936','30154','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('937','30155','8','{#MEMTYPE}','{$MEMORY.TYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('938','30155','9','{#MEMTYPE}','{$MEMORY.TYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('939','30155','8','{#MEMNAME}','{$MEMORY.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('940','30155','9','{#MEMNAME}','{$MEMORY.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('941','30156','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('942','30156','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('943','30156','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('944','30156','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('945','30193','8','{#SVNAME}','BACKEND');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('946','30194','8','{#SVNAME}','FRONTEND');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('947','30195','9','{#SVNAME}','FRONTEND|BACKEND');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('948','30236','8','{#SVNAME}','BACKEND');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('949','30237','8','{#SVNAME}','FRONTEND');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('950','30238','9','{#SVNAME}','FRONTEND|BACKEND');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('951','30338','8','{#DB}','{$REDIS.LLD.FILTER.DB.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('952','30338','9','{#DB}','{$REDIS.LLD.FILTER.DB.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('969','30423','8','{#SERVICE.NAME}','{$SERVICE.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('970','30423','9','{#SERVICE.NAME}','{$SERVICE.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('971','30423','8','{#SERVICE.STARTUPNAME}','{$SERVICE.STARTUPNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('972','30423','9','{#SERVICE.STARTUPNAME}','{$SERVICE.STARTUPNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('973','30424','8','{#SERVICE.NAME}','{$SERVICE.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('974','30424','9','{#SERVICE.NAME}','{$SERVICE.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('975','30424','8','{#SERVICE.STARTUPNAME}','{$SERVICE.STARTUPNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('976','30424','9','{#SERVICE.STARTUPNAME}','{$SERVICE.STARTUPNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('977','30427','8','{#SERVICE.NAME}','{$SERVICE.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('978','30427','9','{#SERVICE.NAME}','{$SERVICE.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('979','30427','8','{#SERVICE.STARTUPNAME}','{$SERVICE.STARTUPNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('980','30427','9','{#SERVICE.STARTUPNAME}','{$SERVICE.STARTUPNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('981','30428','8','{#SERVICE.NAME}','{$SERVICE.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('982','30428','9','{#SERVICE.NAME}','{$SERVICE.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('983','30428','8','{#SERVICE.STARTUPNAME}','{$SERVICE.STARTUPNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('984','30428','9','{#SERVICE.STARTUPNAME}','{$SERVICE.STARTUPNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('985','30472','9','{#DBNAME}','information_schema');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('986','30520','9','{#DATABASE}','information_schema');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('987','30571','8','{#NAME}','{$DOCKER.LLD.FILTER.CONTAINER.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('988','30571','9','{#NAME}','{$DOCKER.LLD.FILTER.CONTAINER.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('989','30572','8','{#NAME}','{$DOCKER.LLD.FILTER.IMAGE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('990','30572','9','{#NAME}','{$DOCKER.LLD.FILTER.IMAGE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('991','30678','9','{#DATABASE}','information_schema');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('992','30686','9','{#SENSOR_READING_TYPE}','threshold');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('993','30686','8','{#SENSOR_TYPE}','{$IPMI.SENSOR_TYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('994','30686','9','{#SENSOR_TYPE}','{$IPMI.SENSOR_TYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('995','30687','8','{#SENSOR_READING_TYPE}','threshold');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('996','30687','8','{#SENSOR_TYPE}','{$IPMI.SENSOR_TYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('997','30687','9','{#SENSOR_TYPE}','{$IPMI.SENSOR_TYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1004','30193','8','{#MODE}','http|tcp');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1005','30194','8','{#MODE}','http|tcp');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1006','30195','8','{#MODE}','http|tcp');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1013','30236','8','{#MODE}','http|tcp');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1014','30237','8','{#MODE}','http|tcp');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1015','30238','8','{#MODE}','http|tcp');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1016','30874','8','{#NAME}','{$CLICKHOUSE.LLD.FILTER.DICT.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1017','30874','9','{#NAME}','{$CLICKHOUSE.LLD.FILTER.DICT.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1018','30875','8','{#DB}','{$CLICKHOUSE.LLD.FILTER.DB.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1019','30875','9','{#DB}','{$CLICKHOUSE.LLD.FILTER.DB.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1020','30876','8','{#DB}','{$CLICKHOUSE.LLD.FILTER.DB.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1021','30876','9','{#DB}','{$CLICKHOUSE.LLD.FILTER.DB.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1022','30961','9','{#GRPC.CODE}','{$ETCD.GRPC_CODE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1023','30961','8','{#GRPC.CODE}','{$ETCD.GRPC_CODE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1024','31005','9','{#APPPOOL}','{$IIS.APPPOOL.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1025','31005','8','{#APPPOOL}','{$IIS.APPPOOL.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1026','31047','9','{#APPPOOL}','{$IIS.APPPOOL.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1027','31047','8','{#APPPOOL}','{$IIS.APPPOOL.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1028','31123','8','{#DBNAME}','{$MSSQL.DBNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1029','31123','9','{#DBNAME}','{$MSSQL.DBNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1030','31240','8','{#DBNAME}','{$PG.LLD.FILTER.DBNAME}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1031','31273','8','{#DEVTYPE}','disk');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1032','31273','8','{#DEVNAME}','{$VFS.DEV.DEVNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1033','31273','9','{#DEVNAME}','{$VFS.DEV.DEVNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1034','31274','8','{#DEVTYPE}','disk');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1035','31274','8','{#DEVNAME}','{$VFS.DEV.DEVNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1036','31274','9','{#DEVNAME}','{$VFS.DEV.DEVNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1037','31275','8','{#DEVTYPE}','disk');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1038','31275','8','{#DEVNAME}','{$VFS.DEV.DEVNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1039','31275','9','{#DEVNAME}','{$VFS.DEV.DEVNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1040','31305','8','{#DEVTYPE}','disk');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1041','31305','8','{#DEVNAME}','{$VFS.DEV.DEVNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1042','31305','9','{#DEVNAME}','{$VFS.DEV.DEVNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1043','31306','8','{#DEVTYPE}','disk');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1044','31306','8','{#DEVNAME}','{$VFS.DEV.DEVNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1045','31306','9','{#DEVNAME}','{$VFS.DEV.DEVNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1046','31333','8','{#DEVNAME}','{$VFS.DEV.DEVNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1047','31333','9','{#DEVNAME}','{$VFS.DEV.DEVNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1048','31334','8','{#DEVNAME}','{$VFS.DEV.DEVNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1049','31334','9','{#DEVNAME}','{$VFS.DEV.DEVNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1050','31351','8','{#DEVNAME}','{$VFS.DEV.DEVNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1051','31351','9','{#DEVNAME}','{$VFS.DEV.DEVNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1052','31352','8','{#DEVNAME}','{$VFS.DEV.DEVNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1053','31352','9','{#DEVNAME}','{$VFS.DEV.DEVNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1084','31707','8','{#DBNAME}','{$ORACLE.DBNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1085','31707','9','{#DBNAME}','{$ORACLE.DBNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1086','31709','8','{#DBNAME}','{$ORACLE.DBNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1087','31709','9','{#DBNAME}','{$ORACLE.DBNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1088','31710','8','{#TABLESPACE}','{$ORACLE.TABLESPACE.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1089','31710','9','{#TABLESPACE}','{$ORACLE.TABLESPACE.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1090','31788','8','{#IFTYPE}','^71$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1091','31788','8','{#IFADMINSTATUS}','^1$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1092','31789','8','{#IFTYPE}','^1$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1093','31964','8','{#IFTYPE}','^1$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1094','31964','8','{#IFNAME}','{$IFNAME.LTEMODEM.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1095','31789','8','{#IFNAME}','{$IFNAME.WIFI.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1096','32133','8','{#JMXTOPIC}','{$KAFKA.TOPIC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1097','32133','9','{#JMXTOPIC}','{$KAFKA.TOPIC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1098','32134','8','{#JMXTOPIC}','{$KAFKA.TOPIC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1099','32134','9','{#JMXTOPIC}','{$KAFKA.TOPIC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1100','32135','8','{#JMXTOPIC}','{$KAFKA.TOPIC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1101','32135','9','{#JMXTOPIC}','{$KAFKA.TOPIC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1102','32140','8','{#JMXATTR}','^name$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1103','32141','8','{#JMXNAME}','{$TOMCAT.LLD.FILTER.MATCHES:"GlobalRequesProcessor"}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1104','32141','9','{#JMXNAME}','{$TOMCAT.LLD.FILTER.NOT_MATCHES:"GlobalRequesProcessor"}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1105','32142','8','{#JMXHOST}','{$TOMCAT.LLD.FILTER.MATCHES:"Manager"}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1106','32142','9','{#JMXHOST}','{$TOMCAT.LLD.FILTER.NOT_MATCHES:"Manager"}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1107','32143','8','{#JMXNAME}','{$TOMCAT.LLD.FILTER.MATCHES:"ThreadPool"}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1108','32143','9','{#JMXNAME}','{$TOMCAT.LLD.FILTER.NOT_MATCHES:"ThreadPool"}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1109','32274','8','{#JMXKEYSPACE}','{$CASSANDRA.KEY_SPACE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1110','32274','9','{#JMXKEYSPACE}','{$CASSANDRA.KEY_SPACE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1111','32306','8','{#SENSOR_TYPE}','3|4');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1112','32463','8','{#JMXDESTINATIONNAME}','{$ACTIVEMQ.LLD.FILTER.DESTINATION.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1113','32463','9','{#JMXDESTINATIONNAME}','{$ACTIVEMQ.LLD.FILTER.DESTINATION.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1114','32464','8','{#JMXBROKERNAME}','{$ACTIVEMQ.LLD.FILTER.BROKER.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1115','32464','9','{#JMXBROKERNAME}','{$ACTIVEMQ.LLD.FILTER.BROKER.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1116','32597','8','{#APPLICATION}','{$PG.LLD.FILTER.APPLICATION}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1117','32618','8','{#FSTYPE}','{$FAS3220.FS.TYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1118','32618','9','{#FSTYPE}','{$FAS3220.FS.TYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1119','32618','8','{#FSNAME}','{$FAS3220.FS.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1120','32618','9','{#FSNAME}','{$FAS3220.FS.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1121','32620','8','{#TYPE}','{$FAS3220.NET.PORT.TYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1122','32620','9','{#TYPE}','{$FAS3220.NET.PORT.TYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1123','32620','8','{#ROLE}','{$FAS3220.NET.PORT.ROLE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1124','32620','9','{#TYPE}','{$FAS3220.NET.PORT.ROLE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1125','32620','8','{#IFNAME}','{$FAS3220.NET.PORT.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1126','32620','9','{#IFNAME}','{$FAS3220.NET.PORT.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1127','32653','8','{#JMXNAME}','{$IGNITE.LLD.FILTER.CACHE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1128','32653','9','{#JMXNAME}','{$IGNITE.LLD.FILTER.CACHE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1129','32654','8','{#JMXNAME}','{$IGNITE.LLD.FILTER.THREAD.POOL.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1130','32654','9','{#JMXNAME}','{$IGNITE.LLD.FILTER.THREAD.POOL.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1131','32655','8','{#JMXNAME}','{$IGNITE.LLD.FILTER.DATA.REGION.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1132','32655','9','{#JMXNAME}','{$IGNITE.LLD.FILTER.DATA.REGION.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1133','32662','8','{#JMXGROUP}','{$IGNITE.LLD.FILTER.CACHE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1134','32662','9','{#JMXGROUP}','{$IGNITE.LLD.FILTER.CACHE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1135','32731','8','{#SENSOR_LOCALE}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1136','32879','8','{#EXCHANGE}','{$RABBITMQ.LLD.FILTER.EXCHANGE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1137','32879','9','{#EXCHANGE}','{$RABBITMQ.LLD.FILTER.EXCHANGE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1138','32883','8','{#QUEUE}','{$RABBITMQ.LLD.FILTER.QUEUE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1139','32883','9','{#QUEUE}','{$RABBITMQ.LLD.FILTER.QUEUE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1140','32883','8','{#NODE}','{$RABBITMQ.CLUSTER.NAME}@{HOST.NAME}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1141','32971','8','{#EXCHANGE}','{$RABBITMQ.LLD.FILTER.EXCHANGE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1142','32971','9','{#EXCHANGE}','{$RABBITMQ.LLD.FILTER.EXCHANGE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1143','32975','8','{#QUEUE}','{$RABBITMQ.LLD.FILTER.QUEUE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1144','32975','9','{#QUEUE}','{$RABBITMQ.LLD.FILTER.QUEUE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1145','32975','8','{#NODE}','{$RABBITMQ.CLUSTER.NAME}@{HOST.NAME}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1146','33061','8','{#DBNAME}','{$MONGODB.LLD.FILTER.DB.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1147','33061','9','{#DBNAME}','{$MONGODB.LLD.FILTER.DB.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1148','33061','8','{#COLLECTION}','{$MONGODB.LLD.FILTER.COLLECTION.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1149','33061','9','{#COLLECTION}','{$MONGODB.LLD.FILTER.COLLECTION.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1150','33062','8','{#DBNAME}','{$MONGODB.LLD.FILTER.DB.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1151','33062','9','{#DBNAME}','{$MONGODB.LLD.FILTER.DB.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1152','33174','8','{#DBNAME}','{$MONGODB.LLD.FILTER.DB.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1153','33174','9','{#DBNAME}','{$MONGODB.LLD.FILTER.DB.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1154','33174','8','{#COLLECTION}','{$MONGODB.LLD.FILTER.COLLECTION.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1155','33174','9','{#COLLECTION}','{$MONGODB.LLD.FILTER.COLLECTION.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1156','33175','8','{#DBNAME}','{$MONGODB.LLD.FILTER.DB.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1157','33175','9','{#DBNAME}','{$MONGODB.LLD.FILTER.DB.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1158','33212','8','{#ENT_SN}','.+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1159','33212','8','{#ENT_CLASS}','[^3]');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1160','33215','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1161','33215','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1162','33215','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1163','33215','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1164','33215','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1165','33215','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1166','33215','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1167','33215','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1168','33215','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1169','33215','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1170','33215','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1171','33215','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1172','33216','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1173','33216','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1174','33253','8','{#ENT_SN}','.+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1175','33253','8','{#ENT_CLASS}','[^3]');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1176','33256','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1177','33256','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1178','33256','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1179','33256','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1180','33256','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1181','33256','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1182','33256','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1183','33256','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1184','33256','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1185','33256','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1186','33256','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1187','33256','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1188','33257','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1189','33257','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1190','33294','8','{#ENT_SN}','.+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1191','33294','8','{#ENT_CLASS}','[^3]');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1192','33297','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1193','33297','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1194','33297','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1195','33297','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1196','33297','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1197','33297','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1198','33297','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1199','33297','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1200','33297','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1201','33297','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1202','33297','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1203','33297','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1204','33298','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1205','33298','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1206','33335','8','{#ENT_SN}','.+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1207','33335','8','{#ENT_CLASS}','[^3]');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1208','33338','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1209','33338','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1210','33338','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1211','33338','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1212','33338','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1213','33338','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1214','33338','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1215','33338','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1216','33338','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1217','33338','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1218','33338','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1219','33338','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1220','33339','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1221','33339','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1222','33376','8','{#ENT_SN}','.+');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1223','33376','8','{#ENT_CLASS}','[^3]');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1224','33379','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1225','33379','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1226','33379','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1227','33379','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1228','33379','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1229','33379','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1230','33379','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1231','33379','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1232','33379','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1233','33379','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1234','33379','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1235','33379','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1236','33380','8','{#IFOPERSTATUS}','1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1237','33380','8','{#SNMPVALUE}','(2|3)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1238','33414','8','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1239','33414','9','{#IFADMINSTATUS}','{$NET.IF.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1240','33414','8','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1241','33414','9','{#IFOPERSTATUS}','{$NET.IF.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1242','33414','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1243','33414','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1244','33414','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1245','33414','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1246','33414','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1247','33414','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1248','33414','8','{#IFTYPE}','{$NET.IF.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1249','33414','9','{#IFTYPE}','{$NET.IF.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1250','33415','8','{#FSTYPE}','{$VFS.FS.FSTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1251','33415','9','{#FSTYPE}','{$VFS.FS.FSTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1252','33415','8','{#FSNAME}','{$VFS.FS.FSNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1253','33415','9','{#FSNAME}','{$VFS.FS.FSNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1254','33416','8','{#MEMTYPE}','{$MEMORY.TYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1255','33416','9','{#MEMTYPE}','{$MEMORY.TYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1256','33416','8','{#MEMNAME}','{$MEMORY.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1257','33416','9','{#MEMNAME}','{$MEMORY.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1258','33461','9','{#CARTRIDGE_STATUS}','^$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1259','33597','9','{#CARTRIDGE_STATUS}','^$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1260','33648','9','{#CARTRIDGE_STATUS}','^$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1261','33699','9','{#CARTRIDGE_STATUS}','^$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1262','33750','9','{#CARTRIDGE_STATUS}','^$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1263','33801','9','{#CARTRIDGE_STATUS}','^$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1264','33852','9','{#CARTRIDGE_STATUS}','^$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1265','33903','9','{#CARTRIDGE_STATUS}','^$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1266','33959','9','{#CARTRIDGE_STATUS}','^$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1267','34010','9','{#CARTRIDGE_STATUS}','^$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1268','34061','9','{#CARTRIDGE_STATUS}','^$');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1269','34099','8','{#SERVER}','{$WILDFLY.SERVER.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1270','34099','9','{#SERVER}','{$WILDFLY.SERVER.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1271','34100','8','{#DEPLOYMENT}','{$WILDFLY.DEPLOYMENT.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1272','34100','9','{#DEPLOYMENT}','{$WILDFLY.DEPLOYMENT.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1273','34126','8','{#DEPLOYMENT}','{$WILDFLY.DEPLOYMENT.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1274','34126','9','{#DEPLOYMENT}','{$WILDFLY.DEPLOYMENT.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1275','34175','8','{#JOBNAME}','{$MSSQL.JOB.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1276','34175','9','{#JOBNAME}','{$MSSQL.JOB.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1277','34217','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1278','34217','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1279','34217','8','{#ZYXEL.IF.NAME}','adsl');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1280','34218','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1281','34218','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1282','34218','8','{#ZYXEL.IF.NAME}','enet');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1283','34250','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1284','34250','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1285','34250','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1286','34250','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1287','34251','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1288','34251','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1289','34252','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1290','34252','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1291','34294','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1292','34294','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1293','34294','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1294','34294','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1295','34328','8','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1296','34328','9','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1297','34328','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1298','34328','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1299','34328','8','{#ZYXEL.IF.NAME}','adsl');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1300','34329','8','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1301','34329','9','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1302','34329','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1303','34329','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1304','34329','8','{#ZYXEL.IF.NAME}','enet');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1305','34330','8','{#ZYXEL.SLOTSTATUS}','{$ZYXEL.LLD.FILTER.SLOT.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1306','34330','9','{#ZYXEL.SLOTSTATUS}','{$ZYXEL.LLD.FILTER..SLOT.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1307','34395','8','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1308','34395','9','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1309','34395','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1310','34395','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1311','34395','8','{#ZYXEL.IF.NAME}','adsl');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1312','34396','8','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1313','34396','9','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1314','34396','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1315','34396','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1316','34396','8','{#ZYXEL.IF.NAME}','enet');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1317','34397','8','{#ZYXEL.SLOTSTATUS}','{$ZYXEL.LLD.FILTER.SLOT.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1318','34397','9','{#ZYXEL.SLOTSTATUS}','{$ZYXEL.LLD.FILTER..SLOT.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1319','34462','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1320','34462','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1321','34462','8','{#ZYXEL.IF.NAME}','adsl');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1322','34463','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1323','34463','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1324','34463','8','{#ZYXEL.IF.NAME}','enet');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1325','34495','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1326','34495','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1327','34495','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1328','34495','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1329','34496','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1330','34496','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1331','34497','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1332','34497','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1333','34534','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1334','34534','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1335','34534','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1336','34534','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1337','34535','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1338','34535','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1339','34536','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1340','34536','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1341','34578','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1342','34578','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1343','34578','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1344','34578','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1345','34579','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1346','34579','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1347','34580','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1348','34580','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1349','34622','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1350','34622','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1351','34622','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1352','34622','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1353','34623','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1354','34623','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1355','34624','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1356','34624','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1357','34666','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1358','34666','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1359','34666','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1360','34666','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1361','34667','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1362','34667','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1363','34668','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1364','34668','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1365','34711','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1366','34711','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1367','34711','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1368','34711','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1369','34712','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1370','34712','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1371','34713','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1372','34713','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1373','34756','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1374','34756','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1375','34756','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1376','34756','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1377','34757','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1378','34757','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1379','34758','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1380','34758','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1381','34801','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1382','34801','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1383','34801','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1384','34801','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1385','34802','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1386','34802','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1387','34803','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1388','34803','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1389','34859','8','{#NAME}','{$NGINX.LLD.FILTER.HTTP.LOCATION.ZONE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1390','34859','9','{#NAME}','{$NGINX.LLD.FILTER.HTTP.LOCATION.ZONE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1391','34860','8','{#NAME}','{$NGINX.LLD.FILTER.HTTP.ZONE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1392','34860','9','{#NAME}','{$NGINX.LLD.FILTER.HTTP.ZONE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1393','34861','8','{#UPSTREAM}','{$NGINX.LLD.FILTER.HTTP.UPSTREAM.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1394','34861','9','{#UPSTREAM}','{$NGINX.LLD.FILTER.HTTP.UPSTREAM.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1395','34862','8','{#NAME}','{$NGINX.LLD.FILTER.HTTP.UPSTREAM.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1396','34862','9','{#NAME}','{$NGINX.LLD.FILTER.HTTP.UPSTREAM.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1397','34863','8','{#NAME}','{$NGINX.LLD.FILTER.RESOLVER.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1398','34863','9','{#NAME}','{$NGINX.LLD.FILTER.RESOLVER.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1399','34864','8','{#NAME}','{$NGINX.LLD.FILTER.STREAM.ZONE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1400','34864','9','{#NAME}','{$NGINX.LLD.FILTER.STREAM.ZONE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1401','34865','8','{#UPSTREAM}','{$NGINX.LLD.FILTER.STREAM.UPSTREAM.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1402','34865','9','{#UPSTREAM}','{$NGINX.LLD.FILTER.STREAM.UPSTREAM.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1403','34866','8','{#NAME}','{$NGINX.LLD.FILTER.STREAM.UPSTREAM.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1404','34866','9','{#NAME}','{$NGINX.LLD.FILTER.STREAM.UPSTREAM.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1405','34957','8','{#IFADMINSTATUS}','{$NET.IFADMINSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1406','34957','9','{#IFADMINSTATUS}','{$NET.IFADMINSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1407','34957','8','{#IFOPERSTATUS}','{$NET.IFOPERSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1408','34957','9','{#IFOPERSTATUS}','{$NET.IFOPERSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1409','34957','8','{#IFNAME}','{$NET.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1410','34957','9','{#IFNAME}','{$NET.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1411','34957','8','{#IFDESCR}','{$NET.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1412','34957','9','{#IFDESCR}','{$NET.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1413','34957','8','{#IFALIAS}','{$NET.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1414','34957','9','{#IFALIAS}','{$NET.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1415','34957','8','{#IFTYPE}','{$NET.IFTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1416','34957','9','{#IFTYPE}','{$NET.IFTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1417','35056','8','{#TYPE}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1418','35138','8','{#TYPE}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1419','35220','8','{#TYPE}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1420','35302','8','{#TYPE}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1421','35345','8','{#SNMPINDEX}','0\.1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1422','35345','8','{#SENSOR_LOCALE}','11');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1423','35346','8','{#SENSOR_LOCALE}','6');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1424','35347','8','{#SENSOR_LOCALE}','(4|8|9|12|13)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1425','35348','8','{#SENSOR_LOCALE}','5');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1426','35349','8','{#SENSOR_LOCALE}','7');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1427','35350','8','{#SENSOR_LOCALE}','10');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1428','35351','8','{#SENSOR_LOCALE}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1429','35402','8','{#SNMPINDEX}','0\.1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1430','35402','8','{#SENSOR_LOCALE}','11');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1431','35403','8','{#SENSOR_LOCALE}','6');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1432','35404','8','{#SENSOR_LOCALE}','(4|8|9|12|13)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1433','35405','8','{#SENSOR_LOCALE}','5');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1434','35406','8','{#SENSOR_LOCALE}','7');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1435','35407','8','{#SENSOR_LOCALE}','10');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1436','35408','8','{#SENSOR_LOCALE}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1437','35459','8','{#SNMPINDEX}','0\.1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1438','35459','8','{#SENSOR_LOCALE}','11');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1439','35460','8','{#SENSOR_LOCALE}','6');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1440','35461','8','{#SENSOR_LOCALE}','(4|8|9|12|13)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1441','35462','8','{#SENSOR_LOCALE}','5');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1442','35463','8','{#SENSOR_LOCALE}','7');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1443','35464','8','{#SENSOR_LOCALE}','10');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1444','35465','8','{#SENSOR_LOCALE}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1445','35516','8','{#SNMPINDEX}','0\.1');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1446','35516','8','{#SENSOR_LOCALE}','11');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1447','35517','8','{#SENSOR_LOCALE}','6');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1448','35518','8','{#SENSOR_LOCALE}','(4|8|9|12|13)');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1449','35519','8','{#SENSOR_LOCALE}','5');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1450','35520','8','{#SENSOR_LOCALE}','7');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1451','35521','8','{#SENSOR_LOCALE}','10');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1452','35522','8','{#SENSOR_LOCALE}','3');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1453','35558','8','{#UNIT.ACTIVESTATE}','{$SYSTEMD.ACTIVESTATE.SERVICE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1454','35558','9','{#UNIT.ACTIVESTATE}','{$SYSTEMD.ACTIVESTATE.SERVICE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1455','35558','8','{#UNIT.UNITFILESTATE}','{$SYSTEMD.UNITFILESTATE.SERVICE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1456','35558','9','{#UNIT.UNITFILESTATE}','{$SYSTEMD.UNITFILESTATE.SERVICE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1457','35558','9','{#UNIT.NAME}','{$SYSTEMD.NAME.SERVICE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1458','35558','8','{#UNIT.NAME}','{$SYSTEMD.NAME.SERVICE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1459','35559','8','{#UNIT.ACTIVESTATE}','{$SYSTEMD.ACTIVESTATE.SOCKET.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1460','35559','9','{#UNIT.ACTIVESTATE}','{$SYSTEMD.ACTIVESTATE.SOCKET.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1461','35559','8','{#UNIT.UNITFILESTATE}','{$SYSTEMD.UNITFILESTATE.SOCKET.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1462','35559','9','{#UNIT.UNITFILESTATE}','{$SYSTEMD.UNITFILESTATE.SOCKET.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1463','35559','9','{#UNIT.NAME}','{$SYSTEMD.NAME.SOCKET.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1464','35559','8','{#UNIT.NAME}','{$SYSTEMD.NAME.SOCKET.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1465','35568','8','{#JMXNAME}','{$GRIDGAIN.LLD.FILTER.CACHE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1466','35568','9','{#JMXNAME}','{$GRIDGAIN.LLD.FILTER.CACHE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1467','35569','8','{#JMXNAME}','{$GRIDGAIN.LLD.FILTER.THREAD.POOL.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1468','35569','9','{#JMXNAME}','{$GRIDGAIN.LLD.FILTER.THREAD.POOL.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1469','35570','8','{#JMXNAME}','{$GRIDGAIN.LLD.FILTER.DATA.REGION.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1470','35570','9','{#JMXNAME}','{$GRIDGAIN.LLD.FILTER.DATA.REGION.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1471','35577','8','{#JMXGROUP}','{$GRIDGAIN.LLD.FILTER.CACHE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1472','35577','9','{#JMXGROUP}','{$GRIDGAIN.LLD.FILTER.CACHE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1473','35672','8','{#PART.NAME}','{$BIGIP.LLD.FILTER.PART.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1474','35672','9','{#PART.NAME}','{$BIGIP.LLD.FILTER.PART.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1475','35911','8','{#CISCO.IF.NAME}','{$CISCO.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1476','35911','9','{#CISCO.IF.NAME}','{$CISCO.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1477','35911','8','{#CISCO.IF.STATUS.ADMIN}','{$CISCO.LLD.FILTER.IF.ADMIN.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1478','35911','9','{#CISCO.IF.STATUS.ADMIN}','{$CISCO.LLD.FILTER.IF.ADMIN.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1479','35911','8','{#CISCO.IF.DESC}','{$CISCO.LLD.FILTER.IF.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1480','35911','9','{#CISCO.IF.DESC}','{$CISCO.LLD.FILTER.IF.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1481','35961','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1482','35961','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1483','35961','8','{#ZYXEL.IF.NAME}','adsl');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1484','35962','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1485','35962','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1486','35962','8','{#ZYXEL.IF.NAME}','enet');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1487','35994','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1488','35994','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1489','35994','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1490','35994','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1491','35995','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1492','35995','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1493','35996','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1494','35996','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1495','36038','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1496','36038','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1497','36038','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1498','36038','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1499','36072','8','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1500','36072','9','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1501','36072','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1502','36072','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1503','36072','8','{#ZYXEL.IF.NAME}','adsl');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1504','36073','8','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1505','36073','9','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1506','36073','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1507','36073','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1508','36073','8','{#ZYXEL.IF.NAME}','enet');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1509','36074','8','{#ZYXEL.SLOTSTATUS}','{$ZYXEL.LLD.FILTER.SLOT.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1510','36074','9','{#ZYXEL.SLOTSTATUS}','{$ZYXEL.LLD.FILTER.SLOT.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1511','36139','8','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1512','36139','9','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1513','36139','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1514','36139','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1515','36139','8','{#ZYXEL.IF.NAME}','adsl');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1516','36140','8','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1517','36140','9','{#ZYXEL.IF.DESC}','{$ZYXEL.LLD.FILTER.IF.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1518','36140','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1519','36140','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1520','36140','8','{#ZYXEL.IF.NAME}','enet');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1521','36141','8','{#ZYXEL.SLOTSTATUS}','{$ZYXEL.LLD.FILTER.SLOT.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1522','36141','9','{#ZYXEL.SLOTSTATUS}','{$ZYXEL.LLD.FILTER.SLOT.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1523','36206','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1524','36206','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1525','36206','8','{#ZYXEL.IF.NAME}','adsl');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1526','36207','8','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1527','36207','9','{#ZYXEL.IF.LINKSTATUS}','{$ZYXEL.LLD.FILTER.IF.LINKSTATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1528','36207','8','{#ZYXEL.IF.NAME}','enet');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1529','36239','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1530','36239','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1531','36239','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1532','36239','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1533','36240','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1534','36240','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1535','36241','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1536','36241','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1537','36278','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1538','36278','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1539','36278','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1540','36278','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1541','36279','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1542','36279','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1543','36280','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1544','36280','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1545','36322','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1546','36322','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1547','36322','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1548','36322','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1549','36323','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1550','36323','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1551','36324','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1552','36324','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1553','36366','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1554','36366','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1555','36366','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1556','36366','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1557','36367','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1558','36367','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1559','36368','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1560','36368','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1561','36410','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1562','36410','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1563','36410','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1564','36410','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1565','36411','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1566','36411','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1567','36412','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1568','36412','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1569','36455','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1570','36455','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1571','36455','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1572','36455','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1573','36456','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1574','36456','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1575','36457','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1576','36457','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1577','36500','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1578','36500','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1579','36500','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1580','36500','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1581','36501','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1582','36501','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1583','36502','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1584','36502','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1585','36545','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1586','36545','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.NAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1587','36545','8','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1588','36545','9','{#ZYXEL.IF.LINKUPTYPE}','{$ZYXEL.LLD.FILTER.IF.LINKUPTYPE.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1589','36546','8','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1590','36546','9','{#ZYXEL.SFP.DESCRIPTION}','{$ZYXEL.LLD.FILTER.SFPDDM.DESC.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1591','36547','8','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1592','36547','9','{#ZYXEL.SFP.STATUS}','{$ZYXEL.LLD.FILTER.SFP.STATUS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1593','36581','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1594','36581','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1595','36581','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1596','36581','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1597','36581','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1598','36581','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1599','36582','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1600','36582','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1601','36582','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1602','36582','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1603','36582','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1604','36582','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1605','36603','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1606','36603','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1607','36603','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1608','36603','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1609','36603','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1610','36603','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1611','36604','8','{#IFNAME}','{$NET.IF.IFNAME.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1612','36604','9','{#IFNAME}','{$NET.IF.IFNAME.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1613','36604','8','{#IFDESCR}','{$NET.IF.IFDESCR.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1614','36604','9','{#IFDESCR}','{$NET.IF.IFDESCR.NOT_MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1615','36604','8','{#IFALIAS}','{$NET.IF.IFALIAS.MATCHES}');
INSERT INTO item_condition (item_conditionid,itemid,operator,macro,value) values ('1616','36604','9','{#IFALIAS}','{$NET.IF.IFALIAS.NOT_MATCHES}');
INSERT INTO item_rtdata (itemid) values ('10073');
INSERT INTO item_rtdata (itemid) values ('10074');
INSERT INTO item_rtdata (itemid) values ('10075');
INSERT INTO item_rtdata (itemid) values ('10076');
INSERT INTO item_rtdata (itemid) values ('10077');
INSERT INTO item_rtdata (itemid) values ('10078');
INSERT INTO item_rtdata (itemid) values ('23252');
INSERT INTO item_rtdata (itemid) values ('23253');
INSERT INTO item_rtdata (itemid) values ('23255');
INSERT INTO item_rtdata (itemid) values ('23256');
INSERT INTO item_rtdata (itemid) values ('23257');
INSERT INTO item_rtdata (itemid) values ('23258');
INSERT INTO item_rtdata (itemid) values ('23259');
INSERT INTO item_rtdata (itemid) values ('23260');
INSERT INTO item_rtdata (itemid) values ('23261');
INSERT INTO item_rtdata (itemid) values ('23262');
INSERT INTO item_rtdata (itemid) values ('23264');
INSERT INTO item_rtdata (itemid) values ('23265');
INSERT INTO item_rtdata (itemid) values ('23266');
INSERT INTO item_rtdata (itemid) values ('23267');
INSERT INTO item_rtdata (itemid) values ('23268');
INSERT INTO item_rtdata (itemid) values ('23269');
INSERT INTO item_rtdata (itemid) values ('23270');
INSERT INTO item_rtdata (itemid) values ('23271');
INSERT INTO item_rtdata (itemid) values ('23272');
INSERT INTO item_rtdata (itemid) values ('23273');
INSERT INTO item_rtdata (itemid) values ('23274');
INSERT INTO item_rtdata (itemid) values ('23275');
INSERT INTO item_rtdata (itemid) values ('23276');
INSERT INTO item_rtdata (itemid) values ('23277');
INSERT INTO item_rtdata (itemid) values ('23287');
INSERT INTO item_rtdata (itemid) values ('23288');
INSERT INTO item_rtdata (itemid) values ('23327');
INSERT INTO item_rtdata (itemid) values ('23328');
INSERT INTO item_rtdata (itemid) values ('23620');
INSERT INTO item_rtdata (itemid) values ('23625');
INSERT INTO item_rtdata (itemid) values ('23628');
INSERT INTO item_rtdata (itemid) values ('23635');
INSERT INTO item_rtdata (itemid) values ('23662');
INSERT INTO item_rtdata (itemid) values ('23664');
INSERT INTO item_rtdata (itemid) values ('25367');
INSERT INTO item_rtdata (itemid) values ('25371');
INSERT INTO item_rtdata (itemid) values ('25667');
INSERT INTO item_rtdata (itemid) values ('25668');
INSERT INTO item_rtdata (itemid) values ('28249');
INSERT INTO item_rtdata (itemid) values ('28534');
INSERT INTO item_rtdata (itemid) values ('28536');
INSERT INTO item_rtdata (itemid) values ('28538');
INSERT INTO item_rtdata (itemid) values ('29161');
INSERT INTO item_rtdata (itemid) values ('29162');
INSERT INTO item_rtdata (itemid) values ('29163');
INSERT INTO item_rtdata (itemid) values ('29164');
INSERT INTO item_rtdata (itemid) values ('29165');
INSERT INTO item_rtdata (itemid) values ('29166');
INSERT INTO item_rtdata (itemid) values ('29167');
INSERT INTO item_rtdata (itemid) values ('29168');
INSERT INTO item_rtdata (itemid) values ('29169');
INSERT INTO item_rtdata (itemid) values ('29170');
INSERT INTO item_rtdata (itemid) values ('29171');
INSERT INTO item_rtdata (itemid) values ('29172');
INSERT INTO item_rtdata (itemid) values ('29173');
INSERT INTO item_rtdata (itemid) values ('29174');
INSERT INTO item_rtdata (itemid) values ('29175');
INSERT INTO item_rtdata (itemid) values ('29176');
INSERT INTO item_rtdata (itemid) values ('29177');
INSERT INTO item_rtdata (itemid) values ('29178');
INSERT INTO item_rtdata (itemid) values ('29179');
INSERT INTO item_rtdata (itemid) values ('29180');
INSERT INTO item_rtdata (itemid) values ('29181');
INSERT INTO item_rtdata (itemid) values ('29182');
INSERT INTO item_rtdata (itemid) values ('29184');
INSERT INTO item_rtdata (itemid) values ('29185');
INSERT INTO item_rtdata (itemid) values ('29186');
INSERT INTO item_rtdata (itemid) values ('29187');
INSERT INTO item_rtdata (itemid) values ('29188');
INSERT INTO item_rtdata (itemid) values ('29189');
INSERT INTO item_rtdata (itemid) values ('29190');
INSERT INTO item_rtdata (itemid) values ('29191');
INSERT INTO item_rtdata (itemid) values ('29192');
INSERT INTO item_rtdata (itemid) values ('29193');
INSERT INTO item_rtdata (itemid) values ('29194');
INSERT INTO item_rtdata (itemid) values ('29195');
INSERT INTO item_rtdata (itemid) values ('29196');
INSERT INTO item_rtdata (itemid) values ('29197');
INSERT INTO item_rtdata (itemid) values ('29200');
INSERT INTO item_rtdata (itemid) values ('29207');
INSERT INTO item_rtdata (itemid) values ('29209');
INSERT INTO item_rtdata (itemid) values ('29557');
INSERT INTO item_rtdata (itemid) values ('29823');
INSERT INTO item_rtdata (itemid) values ('31272');
INSERT INTO item_rtdata (itemid) values ('31275');
INSERT INTO item_rtdata (itemid) values ('34196');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('2','28711',NULL,'PostgreSQL: DB {#DBNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('3','29008',NULL,'Disk {#DEVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('4','29010',NULL,'Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('7','29201',NULL,'Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('9','29203',NULL,'Interface {#IFNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('16','29349',NULL,'Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('18','29351',NULL,'Interface {#IFNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('22','29430',NULL,'Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('23','29431',NULL,'Disk {#DEVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('24','29429',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('25','29506',NULL,'Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('31','29613',NULL,'Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('38','29703',NULL,'RabbitMQ: Queue "{#VHOST}/{#QUEUE}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('39','29785',NULL,'RabbitMQ: Exchange "{#VHOST}/{#EXCHANGE}/{#TYPE}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('40','29786',NULL,'RabbitMQ: Queue "{#VHOST}/{#QUEUE}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('43','27031',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('58','27098',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('83','27078',NULL,'Interface {#IFDESCR}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('86','27118',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('88','30026',NULL,'RabbitMQ: Exchange "{#VHOST}/{#EXCHANGE}/{#TYPE}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('89','30148',NULL,'Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('100','30338',NULL,'Redis: DB {#DB}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('101','30342',NULL,'Redis: Slave {#SLAVE_IP}:{#SLAVE_PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('104','30571',NULL,'Docker: Container {#NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('105','30572',NULL,'Docker: Image {#NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('106','30686',NULL,'IPMI {#SENSOR_TYPE}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('107','30687',NULL,'IPMI {#SENSOR_TYPE}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('108','30713',NULL,'ES {#ES.NODE}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('115','30874',NULL,'ClickHouse: Dictionary "{#NAME}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('116','30875',NULL,'ClickHouse: "{#DB}.{#TABLE}" replica status');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('117','30876',NULL,'ClickHouse: DB "{#DB}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('118','30876',NULL,'ClickHouse: Table "{#DB}.{#TABLE}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('119','30962',NULL,'Etcd peer {#ETCD.PEER}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('120','31005',NULL,'{#APPPOOL}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('121','31047',NULL,'{#APPPOOL}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('122','31122',NULL,'MSSQL Availability Group ''{#GROUP_NAME}''');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('123','31123',NULL,'MSSQL Database ''{#DBNAME}''');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('124','31124',NULL,'MSSQL Available Group ''{#GROUP_NAME}'' Local DB ''{#DBNAME}''');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('125','31125',NULL,'MSSQL Mirroring ''{#DBNAME}''');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('127','31127',NULL,'MSSQL Available Group ''{#GROUP_NAME}'' Replica ''{#REPLICA_NAME}''');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('128','31240',NULL,'PostgreSQL: DB {#DBNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('129','31273',NULL,'Disk {#DEVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('132','31305',NULL,'Disk {#DEVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('134','31333',NULL,'Disk {#DEVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('136','31351',NULL,'Disk {#DEVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('147','31706',NULL,'Oracle Archivelog');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('148','31707',NULL,'Oracle {#TYPE}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('149','31708',NULL,'Oracle ASM');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('150','31709',NULL,'Oracle PDB');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('151','31710',NULL,'Oracle {#CONTENTS} Tablespaces. {#TABLESPACE}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('153','31788',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('154','31789',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('157','31964',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('162','31852',NULL,'Ceph CRUSH [{#CRUSHRULE}] Pool');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('163','32046',NULL,'Hadoop DataNode {#HOSTNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('164','32047',NULL,'Hadoop NodeManager {#HOSTNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('165','32133',NULL,'Kafka topic [{#JMXTOPIC}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('166','32134',NULL,'Kafka topic [{#JMXTOPIC}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('167','32135',NULL,'Kafka topic [{#JMXTOPIC}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('168','32140',NULL,'Tomcat: ProtocolHandler {#JMXVALUE}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('169','32141',NULL,'Tomcat: {#JMXTYPE} {#JMXNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('170','32142',NULL,'Tomcat: Context {#JMXHOST}{#JMXCONTEXT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('171','32143',NULL,'Tomcat: {#JMXTYPE} {#JMXNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('172','32193',NULL,'Zookeeper {#TYPE} {#CLIENT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('173','32274',NULL,'Cassandra table {#JMXKEYSPACE}.{#JMXSCOPE}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('174','31851',NULL,'Ceph {#HOST} OSD [{#CLASS}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('175','32463',NULL,'{#JMXBROKERNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('176','32464',NULL,'{#JMXBROKERNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('177','32497',NULL,'Database {#INSTANCE}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('178','32527',NULL,'Database {#INSTANCE}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('179','32597',NULL,'PostgreSQL: Application {#APPLICATION}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('180','32616',NULL,'Node {#NODE.NAME} Health');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('181','32616',NULL,'Node {#NODE.NAME} Inventory');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('182','32617',NULL,'Node {#NODE.NAME} CPU');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('183','32618',NULL,'{#VSERVER}{#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('184','32619',NULL,'Node {#NODE.NAME} HA');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('185','32620',NULL,'{#IFDESCR}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('186','32653',NULL,'Ignite [{#JMXIGNITEINSTANCENAME}]: Cache group [{#JMXNAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('187','32654',NULL,'Ignite [{#JMXIGNITEINSTANCENAME}]: Thread pool [{#JMXNAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('188','32655',NULL,'Ignite [{#JMXIGNITEINSTANCENAME}]: Data region [{#JMXNAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('189','32656',NULL,'Ignite instance [{#JMXIGNITEINSTANCENAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('190','32657',NULL,'Ignite instance [{#JMXIGNITEINSTANCENAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('191','32658',NULL,'Ignite instance [{#JMXIGNITEINSTANCENAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('192','32659',NULL,'Ignite instance [{#JMXIGNITEINSTANCENAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('193','32660',NULL,'Ignite instance [{#JMXIGNITEINSTANCENAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('194','32661',NULL,'Ignite instance [{#JMXIGNITEINSTANCENAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('195','32662',NULL,'Ignite [{#JMXIGNITEINSTANCENAME}]: Cache group [{#JMXGROUP}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('196','32742',NULL,'{#DISKTYPE} {#NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('197','32743',NULL,'{#DISKTYPE} {#NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('198','32754',NULL,'{#DISKTYPE} {#NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('199','32755',NULL,'{#DISKTYPE} {#NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('200','32780',NULL,'BBU {#ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('201','32781',NULL,'Controller {#ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('202','32782',NULL,'Disk {#MODEL}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('203','32782',NULL,'Disk {#NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('204','32783',NULL,'Enclosure {#NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('205','32784',NULL,'FAN {#ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('206','32785',NULL,'LUN {#NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('207','32786',NULL,'Node {#NODE}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('208','32787',NULL,'Pool {#MODEL}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('209','32787',NULL,'Pool {#NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('210','32879',NULL,'RabbitMQ: Exchange "{#VHOST}/{#EXCHANGE}/{#TYPE}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('211','32883',NULL,'RabbitMQ: Queue "{#VHOST}/{#QUEUE}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('212','32971',NULL,'RabbitMQ: Exchange "{#VHOST}/{#EXCHANGE}/{#TYPE}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('213','32975',NULL,'RabbitMQ: Queue "{#VHOST}/{#QUEUE}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('214','33061',NULL,'MongoDB: {#DBNAME}.{#COLLECTION}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('215','33062',NULL,'MongoDB: {#DBNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('216','33063',NULL,'MongoDB Replica Set: {#RS_NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('217','33174',NULL,'MongoDB sharded cluster: {#DBNAME}.{#COLLECTION}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('218','33175',NULL,'MongoDB sharded cluster: {#DBNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('219','31126',NULL,'MSSQL Available Group ''{#GROUP_NAME}'' Non-Local DB ''{#DBNAME}''');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('220','33215',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('221','33216',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('222','33256',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('223','33257',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('224','33297',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('225','33298',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('226','33338',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('227','33339',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('228','33379',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('229','33380',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('230','33414',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('231','33415',NULL,'Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('232','33521',NULL,'Volume "{#VOLUMENAME}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('233','33513',NULL,'Chassis "{#ID}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('234','33514',NULL,'Node "{#NODENAME}" disks');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('235','33515',NULL,'Chassis "{#CHASSISID}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('236','33516',NULL,'SVM "{#SVMNAME}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('237','33517',NULL,'Node "{#NODENAME}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('238','33518',NULL,'Node "{#NODENAME}" Ethernet ports');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('239','33519',NULL,'Node "{#NODENAME}" FC ports');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('240','33520',NULL,'SVM "{#SVMNAME}"');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('241','34099',NULL,'WildFly domain: Server [{#SERVER}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('242','34100',NULL,'WildFly deployment [{#DEPLOYMENT}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('243','34123',NULL,'WildFly datasource [{#JMX_DATA_SOURCE}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('244','34124',NULL,'WildFly datasource [{#JMX_DATA_SOURCE}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('245','34125',NULL,'WildFly listener [{#SERVER}.{#HTTP_LISTENER}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('246','34126',NULL,'WildFly deployment [{#DEPLOYMENT}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('247','34175',NULL,'MSSQL Job ''{#JOBNAME}''');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('248','34217',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('249','34218',NULL,'Port {#ZYXEL.IF.NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('250','34250',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('251','34251',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('252','34252',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('253','34294',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('254','34324',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('255','34325',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('256','34327',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('257','34328',NULL,'Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('258','34329',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('259','34330',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('260','34331',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('261','34332',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('262','34391',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('263','34392',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('264','34394',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('265','34395',NULL,'Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('266','34396',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('267','34397',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('268','34398',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('269','34399',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('270','34462',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('271','34463',NULL,'Port {#ZYXEL.IF.NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('272','34495',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('273','34496',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('274','34497',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('275','34534',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('276','34535',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('277','34536',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('278','34578',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('279','34579',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('280','34580',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('281','34622',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('282','34623',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('283','34624',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('284','34666',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('285','34667',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('286','34668',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('287','34711',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('288','34712',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('289','34713',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('290','34756',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('291','34757',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('292','34758',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('293','34801',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('294','34802',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('295','34803',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('296','34859',NULL,'Nginx: HTTP location zone [{#NAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('297','34860',NULL,'Nginx: HTTP zone [{#NAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('298','34861',NULL,'Nginx: HTTP upstream [{#UPSTREAM}] peer [{#PEER}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('299','34862',NULL,'Nginx: HTTP upstream [{#NAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('300','34863',NULL,'Nginx: Resolver [{#NAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('301','34864',NULL,'Nginx: Stream zone [{#NAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('302','34865',NULL,'Nginx: Stream upstream [{#UPSTREAM}] peer [{#PEER}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('303','34866',NULL,'Nginx: Stream upstream [{#NAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('304','34957',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('305','35558',NULL,'Systemd service: {#UNIT.NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('306','35559',NULL,'Systemd socket: {#UNIT.NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('307','35568',NULL,'GridGain [{#JMXIGNITEINSTANCENAME}]: Cache group [{#JMXNAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('308','35569',NULL,'GridGain [{#JMXIGNITEINSTANCENAME}]: Thread pool [{#JMXNAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('309','35570',NULL,'GridGain [{#JMXIGNITEINSTANCENAME}]: Data region [{#JMXNAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('310','35571',NULL,'GridGain instance [{#JMXIGNITEINSTANCENAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('311','35572',NULL,'GridGain instance [{#JMXIGNITEINSTANCENAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('312','35573',NULL,'GridGain instance [{#JMXIGNITEINSTANCENAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('313','35574',NULL,'GridGain instance [{#JMXIGNITEINSTANCENAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('314','35575',NULL,'GridGain instance [{#JMXIGNITEINSTANCENAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('315','35576',NULL,'GridGain instance [{#JMXIGNITEINSTANCENAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('316','35577',NULL,'GridGain [{#JMXIGNITEINSTANCENAME}]: Cache group [{#JMXGROUP}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('317','35672',NULL,'Mount point [{#PART.NAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('318','35675',NULL,'Interface [{#IF.NAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('319','35676',NULL,'Node [{#NODE.NAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('320','35677',NULL,'Pool [{#POOL.NAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('321','35678',NULL,'Virtual server [{#VSERVER.NAME}]');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('322','30194',NULL,'HAProxy frontend {#PXNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('323','30193',NULL,'HAProxy backend {#PXNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('324','30195',NULL,'HAProxy {#PXNAME} {#SVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('325','30237',NULL,'HAProxy frontend {#PXNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('326','30236',NULL,'HAProxy backend {#PXNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('327','30238',NULL,'HAProxy {#PXNAME} {#SVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('328','35911',NULL,'{#CISCO.IF.NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('329','35912',NULL,'{#CISCO.ASAV.PHYS.NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('330','35913',NULL,'{#CISCO.CRAS.USER}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('331','35961',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('332','35962',NULL,'Port {#ZYXEL.IF.NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('333','35994',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('334','35995',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('335','35996',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('336','36038',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('337','36068',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('338','36069',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('339','36071',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('340','36072',NULL,'Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('341','36073',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('342','36074',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('343','36075',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('344','36076',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('345','36135',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('346','36136',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('347','36138',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('348','36139',NULL,'Slot {#ZYXEL.SLOT.ID} Port {#ZYXEL.PORTID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('349','36140',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('350','36141',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('351','36142',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('352','36143',NULL,'Slot {#ZYXEL.SLOT.ID}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('353','36206',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('354','36207',NULL,'Port {#ZYXEL.IF.NAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('355','36239',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('356','36240',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('357','36241',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('358','36278',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('359','36279',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('360','36280',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('361','36322',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('362','36323',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('363','36324',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('364','36366',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('365','36367',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('366','36368',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('367','36410',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('368','36411',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('369','36412',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('370','36455',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('371','36456',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('372','36457',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('373','36500',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('374','36501',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('375','36502',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('376','36545',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('377','36546',NULL,'Port {#ZYXEL.SFP.PORT}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('378','36547',NULL,'Port {#SNMPINDEX}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('379','36581',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('381','36603',NULL,'Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('5','29011','3','Disk {#DEVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('6','29013','4','Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('10','29204','7','Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('12','29206','9','Interface {#IFNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('19','29352','16','Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('21','29354','18','Interface {#IFNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('27','29509','25','Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('33','29616','31','Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('44','27190','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('45','27331','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('46','27460','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('47','27530','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('48','27566','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('49','27629','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('50','27652','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('51','27732','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('52','27798','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('53','27954','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('54','28128','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('55','28280','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('56','28955','43','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('59','27180','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('60','27215','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('61','27251','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('62','27272','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('63','27321','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('64','27450','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('65','27486','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('66','27520','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('67','27556','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('68','27642','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('69','27722','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('70','27756','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('71','27788','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('72','27872','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('73','27909','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('74','27944','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('75','28118','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('77','28223','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('78','28293','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('79','28968','58','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('82','28005','83','Interface {#IFDESCR}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('84','27619','83','Interface {#IFDESCR}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('85','27976','83','Interface {#IFDESCR}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('87','29077','86','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('90','30150','89','Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('130','31274','129','Disk {#DEVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('133','31306','132','Disk {#DEVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('135','31334','134','Disk {#DEVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('137','31352','136','Disk {#DEVNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('380','36582','379','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('382','36604','381','Interface {#IFNAME}({#IFALIAS})');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('13','29207','10','Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('15','29209','12','Interface {#IFNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('92','30154','90','Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('93','30156','90','Filesystem {#FSNAME}');
INSERT INTO application_prototype (application_prototypeid,itemid,templateid,name) values ('131','31275','130','Disk {#DEVNAME}');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2','2','28712');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('3','2','28715');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('4','2','28716');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('5','2','28717');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('6','2','28718');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('7','2','28719');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('8','2','28720');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('9','2','28721');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('10','2','28722');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('11','2','28723');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('12','2','28724');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('13','2','28725');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('14','2','28726');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('15','2','28727');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('16','2','28728');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('17','2','28729');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('18','2','28730');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('19','2','28731');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('20','2','28732');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('21','2','28733');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('22','2','28734');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('23','2','28735');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('24','2','28736');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('25','2','28737');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('26','2','28738');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('27','2','28739');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('28','2','28740');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('29','2','28741');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('30','3','29014');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('31','3','29015');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('32','3','29016');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('33','4','29027');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('34','4','29028');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('35','4','29029');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('36','4','29030');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('37','5','29031');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('38','5','29032');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('39','5','29033');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('40','6','29044');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('41','6','29045');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('42','6','29046');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('43','6','29047');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('44','7','29210');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('45','7','29211');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('46','7','29212');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('47','7','29213');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('50','9','29216');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('51','9','29217');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('52','9','29218');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('53','9','29219');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('54','9','29220');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('55','9','29221');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('56','9','29222');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('57','9','29223');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('58','10','29224');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('59','10','29225');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('60','10','29226');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('61','10','29227');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('64','12','29230');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('65','12','29231');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('66','12','29232');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('67','12','29233');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('68','12','29234');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('69','12','29235');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('70','12','29236');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('71','12','29237');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('72','13','29238');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('73','13','29239');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('74','13','29240');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('75','13','29241');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('78','15','29244');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('79','15','29245');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('80','15','29246');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('81','15','29247');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('82','15','29248');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('83','15','29249');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('84','15','29250');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('85','15','29251');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('98','16','29355');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('99','16','29356');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('100','16','29357');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('101','16','29358');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('104','18','29361');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('105','18','29362');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('106','18','29363');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('107','18','29364');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('108','18','29365');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('109','18','29366');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('110','18','29367');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('111','18','29368');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('112','19','29369');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('113','19','29370');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('114','19','29371');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('115','19','29372');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('118','21','29375');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('119','21','29376');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('120','21','29377');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('121','21','29378');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('122','21','29379');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('123','21','29380');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('124','21','29381');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('125','21','29382');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('134','22','29432');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('135','22','29433');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('136','23','29434');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('137','23','29435');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('138','24','29436');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('139','24','29437');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('140','24','29438');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('141','24','29439');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('142','24','29440');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('143','24','29441');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('144','24','29442');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('145','24','29443');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('146','24','29444');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('147','22','29445');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('148','22','29446');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('149','22','29447');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('150','23','29448');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('151','23','29449');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('152','23','29452');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('153','23','29453');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('154','25','29512');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('155','25','29513');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('156','25','29514');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('163','27','29521');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('164','27','29522');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('165','27','29523');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('186','31','29619');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('187','31','29620');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('188','31','29621');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('195','33','29628');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('196','33','29629');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('197','33','29630');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('234','38','29720');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('235','38','29721');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('236','38','29722');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('237','38','29723');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('238','38','29724');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('239','38','29725');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('240','38','29726');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('241','38','29727');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('242','38','29728');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('243','38','29729');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('244','38','29730');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('245','38','29731');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('246','38','29732');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('247','38','29733');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('248','38','29734');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('249','38','29735');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('250','38','29736');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('251','38','29737');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('252','39','29787');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('253','39','29788');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('254','39','29789');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('255','39','29790');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('256','39','29791');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('257','39','29792');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('258','39','29793');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('259','39','29794');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('260','39','29795');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('261','39','29796');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('262','39','29797');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('263','39','29798');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('264','39','29799');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('265','39','29800');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('266','39','29801');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('267','39','29802');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('268','40','29803');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('269','40','29804');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('270','40','29805');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('271','40','29806');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('272','40','29807');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('273','40','29808');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('274','40','29809');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('275','40','29810');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('276','40','29811');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('277','40','29812');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('278','40','29813');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('279','40','29814');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('280','40','29815');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('281','40','29816');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('282','40','29817');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('283','40','29818');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('284','40','29819');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('285','40','29820');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('288','43','27032');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('289','44','27191');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('290','45','27332');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('291','46','27461');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('292','47','27531');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('293','48','27567');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('294','49','27630');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('295','50','27653');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('296','51','27733');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('297','52','27799');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('298','53','27955');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('299','54','28129');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('300','55','28281');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('301','56','28956');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('311','58','27099');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('312','58','27100');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('313','58','27101');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('314','58','27102');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('315','58','27103');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('316','58','27104');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('317','58','27105');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('318','58','27106');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('319','58','27107');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('320','59','27181');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('321','59','27182');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('322','59','27183');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('323','59','27184');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('324','59','27185');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('325','59','27186');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('326','59','27187');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('327','59','27188');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('328','59','27189');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('329','60','27216');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('330','60','27217');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('331','60','27218');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('332','60','27219');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('333','60','27220');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('334','60','27221');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('335','60','27222');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('336','60','27223');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('337','60','27224');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('338','61','27252');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('339','61','27253');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('340','61','27254');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('341','61','27255');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('342','61','27256');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('343','61','27257');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('344','61','27258');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('345','61','27259');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('346','61','27260');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('347','62','27273');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('348','62','27274');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('349','62','27275');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('350','62','27276');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('351','62','27277');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('352','62','27278');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('353','62','27279');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('354','62','27280');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('355','62','27281');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('356','63','27322');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('357','63','27323');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('358','63','27324');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('359','63','27325');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('360','63','27326');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('361','63','27327');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('362','63','27328');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('363','63','27329');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('364','63','27330');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('365','64','27451');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('366','64','27452');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('367','64','27453');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('368','64','27454');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('369','64','27455');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('370','64','27456');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('371','64','27457');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('372','64','27458');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('373','64','27459');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('374','65','27487');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('375','65','27488');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('376','65','27489');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('377','65','27490');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('378','65','27491');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('379','65','27492');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('380','65','27493');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('381','65','27494');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('382','65','27495');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('383','66','27521');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('384','66','27522');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('385','66','27523');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('386','66','27524');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('387','66','27525');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('388','66','27526');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('389','66','27527');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('390','66','27528');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('391','66','27529');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('392','67','27557');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('393','67','27558');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('394','67','27559');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('395','67','27560');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('396','67','27561');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('397','67','27562');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('398','67','27563');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('399','67','27564');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('400','67','27565');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('401','68','27643');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('402','68','27644');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('403','68','27645');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('404','68','27646');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('405','68','27647');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('406','68','27648');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('407','68','27649');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('408','68','27650');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('409','68','27651');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('410','69','27723');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('411','69','27724');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('412','69','27725');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('413','69','27726');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('414','69','27727');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('415','69','27728');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('416','69','27729');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('417','69','27730');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('418','69','27731');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('419','70','27757');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('420','70','27758');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('421','70','27759');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('422','70','27760');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('423','70','27761');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('424','70','27762');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('425','70','27763');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('426','70','27764');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('427','70','27765');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('428','71','27789');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('429','71','27790');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('430','71','27791');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('431','71','27792');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('432','71','27793');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('433','71','27794');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('434','71','27795');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('435','71','27796');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('436','71','27797');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('437','72','27873');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('438','72','27874');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('439','72','27875');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('440','72','27876');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('441','72','27877');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('442','72','27878');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('443','72','27879');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('444','72','27880');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('445','72','27881');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('446','73','27910');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('447','73','27911');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('448','73','27912');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('449','73','27913');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('450','73','27914');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('451','73','27915');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('452','73','27916');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('453','73','27917');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('454','73','27918');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('455','74','27945');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('456','74','27946');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('457','74','27947');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('458','74','27948');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('459','74','27949');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('460','74','27950');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('461','74','27951');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('462','74','27952');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('463','74','27953');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('464','75','28119');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('465','75','28120');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('466','75','28121');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('467','75','28122');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('468','75','28123');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('469','75','28124');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('470','75','28125');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('471','75','28126');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('472','75','28127');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('482','77','28224');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('483','77','28225');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('484','77','28226');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('485','77','28227');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('486','77','28228');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('487','77','28229');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('488','77','28230');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('489','77','28231');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('490','77','28232');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('491','78','28294');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('492','78','28295');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('493','78','28296');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('494','78','28297');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('495','78','28298');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('496','78','28299');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('497','78','28300');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('498','78','28301');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('499','78','28302');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('500','79','28969');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('501','79','28970');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('502','79','28971');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('503','79','28972');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('504','79','28973');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('505','79','28974');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('506','79','28975');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('507','79','28976');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('508','79','28977');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('527','82','28006');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('528','82','28007');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('529','82','28008');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('530','82','28009');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('531','82','28010');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('532','82','28011');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('533','82','28012');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('534','82','28013');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('535','82','28014');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('536','83','27079');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('537','83','27080');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('538','83','27081');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('539','83','27082');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('540','83','27083');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('541','83','27084');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('542','83','27085');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('543','83','27086');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('544','83','27087');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('545','84','27620');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('546','84','27621');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('547','84','27622');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('548','84','27623');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('549','84','27624');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('550','84','27625');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('551','84','27626');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('552','84','27627');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('553','84','27628');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('554','85','27977');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('555','85','27978');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('556','85','27979');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('557','85','27980');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('558','85','27981');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('559','85','27982');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('560','85','27983');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('561','85','27984');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('562','85','27985');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('563','86','27119');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('564','86','27120');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('565','86','27121');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('566','86','27122');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('567','86','27123');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('568','86','27124');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('569','86','27125');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('570','86','27126');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('571','86','27127');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('572','87','29078');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('573','87','29079');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('574','87','29080');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('575','87','29081');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('576','87','29082');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('577','87','29083');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('578','87','29084');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('579','87','29085');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('580','87','29086');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('581','88','30027');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('582','88','30028');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('583','88','30029');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('584','88','30030');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('585','88','30031');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('586','88','30032');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('587','88','30033');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('588','88','30034');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('589','88','30035');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('590','88','30036');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('591','88','30037');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('592','88','30038');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('593','88','30039');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('594','88','30040');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('595','88','30041');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('596','88','30042');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('597','89','30160');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('598','89','30161');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('599','89','30162');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('600','90','30166');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('601','90','30167');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('602','90','30168');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('606','92','30178');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('607','92','30179');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('608','92','30180');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('609','93','30184');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('610','93','30185');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('611','93','30186');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('680','100','30348');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('681','100','30349');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('682','100','30350');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('683','101','30396');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('690','104','30573');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('691','104','30574');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('692','104','30575');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('693','104','30576');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('694','104','30577');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('695','104','30578');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('696','104','30579');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('697','104','30580');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('698','104','30581');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('699','104','30582');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('700','104','30583');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('701','104','30584');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('702','104','30585');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('703','104','30586');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('704','104','30587');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('705','104','30588');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('706','104','30589');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('707','104','30590');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('708','104','30591');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('709','104','30592');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('710','104','30593');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('711','104','30594');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('712','104','30595');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('713','104','30596');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('714','104','30597');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('715','104','30598');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('716','104','30599');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('717','104','30600');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('718','104','30601');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('719','104','30602');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('720','104','30603');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('721','104','30604');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('722','104','30605');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('723','104','30606');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('724','104','30607');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('725','104','30608');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('726','105','30609');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('727','105','30610');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('728','106','30688');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('729','107','30689');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('730','108','30714');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('731','108','30715');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('732','108','30716');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('733','108','30717');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('734','108','30718');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('735','108','30720');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('736','108','30721');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('737','108','30722');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('738','108','30723');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('739','108','30724');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('740','108','30725');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('741','108','30726');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('742','108','30727');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('743','108','30728');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('744','108','30729');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('745','108','30730');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('746','108','30731');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('747','108','30732');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('748','108','30733');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('749','108','30734');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('750','108','30735');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('751','108','30736');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('752','108','30737');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('753','108','30738');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('754','108','30740');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('755','108','30741');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('756','108','30742');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('757','108','30745');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('758','108','30748');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('759','108','30749');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('760','108','30750');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('761','108','30751');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('762','108','30752');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('763','108','30753');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('764','108','30755');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('765','108','30757');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('766','108','30758');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('821','115','30877');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('822','115','30878');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('823','115','30879');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('824','116','30880');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('825','116','30881');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('826','116','30882');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('827','116','30883');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('828','116','30884');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('829','116','30885');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('830','116','30886');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('831','116','30887');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('832','116','30888');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('833','116','30889');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('834','116','30890');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('835','116','30891');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('836','117','30892');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('837','118','30893');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('838','118','30894');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('839','118','30895');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('840','119','30964');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('841','119','30965');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('842','119','30966');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('843','119','30967');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('844','120','31006');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('845','120','31007');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('846','120','31008');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('847','120','31009');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('848','121','31048');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('849','121','31049');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('850','121','31050');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('851','121','31051');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('852','122','31133');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('853','122','31134');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('854','122','31135');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('855','122','31136');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('856','123','31137');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('857','123','31138');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('858','123','31139');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('859','123','31140');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('860','123','31141');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('861','123','31142');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('862','123','31143');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('863','123','31144');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('864','123','31145');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('865','123','31146');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('866','123','31147');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('867','123','31148');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('868','123','31149');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('869','123','31150');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('870','124','31151');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('871','124','31152');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('872','124','31153');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('873','125','31154');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('874','125','31155');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('875','125','31156');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('876','125','31157');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('877','125','31158');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('880','127','31161');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('881','127','31162');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('882','127','31163');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('883','127','31164');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('884','127','31165');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('885','127','31166');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('886','127','31167');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('887','128','31241');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('888','128','31242');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('889','128','31243');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('890','128','31244');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('891','128','31245');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('892','128','31246');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('893','128','31247');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('894','128','31248');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('895','128','31249');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('896','128','31250');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('897','128','31251');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('898','128','31252');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('899','128','31253');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('900','128','31254');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('901','128','31255');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('902','128','31256');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('903','128','31257');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('904','128','31258');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('905','128','31259');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('906','128','31260');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('907','128','31261');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('908','128','31262');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('909','128','31263');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('910','128','31264');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('911','128','31265');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('912','128','31266');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('913','128','31267');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('914','128','31268');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('915','128','31269');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('916','129','31276');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('917','129','31277');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('918','130','31279');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('919','130','31280');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('920','131','31282');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('921','131','31283');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('922','129','31285');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('923','129','31286');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('924','129','31288');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('925','129','31289');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('926','130','31291');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('927','130','31292');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('928','130','31294');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('929','130','31295');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('930','131','31297');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('931','131','31298');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('932','131','31300');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('933','131','31301');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('934','132','31307');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('935','132','31308');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('936','133','31310');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('937','133','31311');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('938','132','31313');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('939','132','31314');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('940','132','31316');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('941','132','31317');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('942','133','31319');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('943','133','31320');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('944','133','31322');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('945','133','31323');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('946','134','31335');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('947','134','31336');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('948','134','31337');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('949','134','31338');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('950','135','31339');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('951','135','31340');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('952','135','31341');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('953','135','31342');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('954','136','31353');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('955','136','31354');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('956','136','31355');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('957','136','31356');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('958','137','31357');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('959','137','31358');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('960','137','31359');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('961','137','31360');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1014','147','31711');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1015','147','31712');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1016','147','31713');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1017','148','31714');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1018','148','31715');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1019','148','31716');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1020','148','31717');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1021','149','31718');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1022','149','31719');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1023','149','31720');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1024','150','31721');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1025','151','31722');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1026','151','31723');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1027','151','31724');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1028','151','31725');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1029','151','31726');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1032','153','31791');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1033','153','31792');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1034','153','31793');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1035','153','31794');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1036','153','31795');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1037','154','31796');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1038','154','31797');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1039','154','31798');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1040','154','31799');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1056','157','31965');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1057','157','31966');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1058','157','31967');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1059','157','31968');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1069','162','32003');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1070','162','32004');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1071','162','32005');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1072','162','32006');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1073','162','32007');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1074','162','32008');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1075','162','32009');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1076','162','32010');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1077','162','32011');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1078','163','32050');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1079','163','32051');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1080','163','32052');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1081','163','32053');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1082','163','32054');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1083','163','32055');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1084','163','32056');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1085','163','32057');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1086','163','32058');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1087','163','32059');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1088','164','32060');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1089','164','32061');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1090','164','32062');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1091','164','32063');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1092','164','32064');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1093','164','32065');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1094','164','32066');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1095','164','32067');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1096','164','32068');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1097','164','32069');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1098','164','32070');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1099','165','32136');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1100','166','32137');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1101','167','32138');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1102','167','32139');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1103','168','32144');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1104','169','32145');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1105','169','32146');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1106','169','32147');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1107','169','32148');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1108','169','32149');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1109','170','32150');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1110','170','32151');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1111','170','32152');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1112','170','32153');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1113','170','32154');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1114','171','32155');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1115','171','32156');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1116','171','32157');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1117','172','32195');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1118','172','32196');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1119','172','32197');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1120','172','32198');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1121','172','32199');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1122','172','32200');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1123','173','32275');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1124','173','32276');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1125','173','32277');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1126','173','32278');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1127','173','32279');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1128','173','32280');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1129','173','32281');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1130','173','32282');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1131','173','32283');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1132','173','32284');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1133','173','32285');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1134','173','32286');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1135','173','32287');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1136','173','32288');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1137','173','32289');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1138','173','32290');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1139','173','32291');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1140','173','32292');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1141','173','32293');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1142','173','32294');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1143','173','32295');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1144','173','32296');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1145','173','32297');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1146','173','32298');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1147','173','32299');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1148','173','32300');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1149','173','32301');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1150','173','32302');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1151','173','32303');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1152','173','32304');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1153','174','31853');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1154','174','31854');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1155','174','31855');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1156','174','31856');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1157','174','31857');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1158','174','31858');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1159','134','32445');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1160','134','32446');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1161','134','32447');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1162','134','32448');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1163','135','32449');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1164','135','32450');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1165','135','32451');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1166','135','32452');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1167','136','32453');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1168','136','32454');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1169','136','32455');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1170','136','32456');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1171','137','32457');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1172','137','32458');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1173','137','32459');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1174','137','32460');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1175','175','32465');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1176','175','32466');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1177','175','32467');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1178','175','32468');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1179','175','32469');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1180','175','32470');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1181','175','32471');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1182','175','32472');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1183','175','32473');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1184','176','32474');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1185','176','32475');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1186','176','32476');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1187','176','32477');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1188','176','32478');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1189','176','32479');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1190','176','32480');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1191','176','32481');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1192','176','32482');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1193','176','32483');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1194','176','32484');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1195','176','32485');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1196','177','32501');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1197','177','32502');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1198','177','32503');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1199','177','32504');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1200','177','32505');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1201','177','32506');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1202','177','32507');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1203','177','32508');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1204','177','32509');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1205','177','32510');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1206','177','32511');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1207','177','32512');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1208','177','32513');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1209','177','32514');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1210','177','32515');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1211','178','32531');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1212','178','32532');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1213','178','32533');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1214','178','32534');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1215','178','32535');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1216','178','32536');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1217','178','32537');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1218','178','32538');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1219','178','32539');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1220','178','32540');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1221','178','32541');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1222','178','32542');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1223','178','32543');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1224','178','32544');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1225','178','32545');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1226','151','32588');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1227','151','32589');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1230','179','32598');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1231','179','32599');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1232','179','32600');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1233','180','32621');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1234','180','32622');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1235','180','32623');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1236','180','32624');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1237','180','32625');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1238','180','32626');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1239','181','32627');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1240','181','32628');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1241','180','32629');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1242','181','32630');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1243','180','32631');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1244','182','32632');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1245','183','32633');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1246','183','32634');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1247','183','32635');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1248','183','32636');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1249','183','32637');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1250','183','32638');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1251','184','32639');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1252','184','32640');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1253','185','32641');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1254','185','32642');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1255','185','32643');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1256','185','32644');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1257','185','32645');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1258','185','32646');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1259','185','32647');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1260','185','32648');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1261','185','32649');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1262','185','32650');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1263','185','32651');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1264','185','32652');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1265','186','32663');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1266','186','32664');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1267','186','32665');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1268','186','32666');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1269','186','32667');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1270','186','32668');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1271','186','32669');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1272','186','32670');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1273','186','32671');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1274','187','32672');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1275','187','32673');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1276','187','32674');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1277','187','32675');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1278','188','32676');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1279','188','32677');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1280','188','32678');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1281','188','32679');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1282','188','32680');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1283','188','32681');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1284','188','32682');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1285','188','32683');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1286','188','32684');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1287','188','32685');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1288','188','32686');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1289','189','32687');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1290','189','32688');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1291','189','32689');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1292','189','32690');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1293','189','32691');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1294','189','32692');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1295','189','32693');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1296','189','32694');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1297','189','32695');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1298','189','32696');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1299','190','32697');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1300','190','32698');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1301','190','32699');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1302','190','32700');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1303','190','32701');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1304','191','32702');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1305','191','32703');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1306','191','32704');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1307','192','32705');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1308','192','32706');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1310','192','32708');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1311','193','32709');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1312','193','32710');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1313','193','32711');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1314','193','32712');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1315','193','32713');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1316','193','32714');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1317','193','32715');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1318','193','32716');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1319','194','32717');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1320','194','32718');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1321','194','32719');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1322','194','32720');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1323','194','32721');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1324','195','32722');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1325','195','32723');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1326','195','32724');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1327','195','32725');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1328','195','32726');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1329','195','32727');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1330','195','32728');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1331','195','32729');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1332','195','32730');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1333','196','32744');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1334','197','32745');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1335','197','32746');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1336','197','32747');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1337','197','32748');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1338','197','32749');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1339','197','32750');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1340','197','32751');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1341','197','32752');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1342','198','32756');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1343','199','32757');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1344','199','32758');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1345','199','32759');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1346','199','32760');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1347','199','32761');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1348','199','32762');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1349','199','32763');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1350','199','32764');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1351','200','32788');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1352','200','32789');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1353','201','32790');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1354','201','32791');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1355','201','32792');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1356','201','32793');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1357','201','32794');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1358','202','32795');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1359','203','32796');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1360','202','32797');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1361','202','32798');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1362','204','32799');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1363','204','32800');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1364','204','32801');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1365','205','32802');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1366','205','32803');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1367','206','32804');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1368','206','32805');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1369','206','32806');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1370','206','32807');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1371','206','32808');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1372','206','32809');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1373','206','32810');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1374','206','32811');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1375','206','32812');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1376','206','32813');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1377','206','32814');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1378','207','32815');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1379','207','32816');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1380','207','32817');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1381','207','32818');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1382','207','32819');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1383','207','32820');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1384','207','32821');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1385','207','32822');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1386','208','32823');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1387','208','32824');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1388','209','32825');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1389','208','32826');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1390','208','32827');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1391','208','32828');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1392','210','32891');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1393','210','32892');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1394','210','32893');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1395','210','32894');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1396','210','32895');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1397','210','32896');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1398','210','32897');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1399','210','32898');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1400','210','32899');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1401','210','32900');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1402','210','32901');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1403','210','32902');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1404','210','32903');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1405','210','32904');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1406','210','32905');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1407','210','32906');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1408','211','32907');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1409','211','32908');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1410','211','32909');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1411','211','32910');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1412','211','32911');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1413','211','32912');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1414','211','32913');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1415','211','32914');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1416','211','32915');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1417','211','32916');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1418','211','32917');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1419','211','32918');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1420','211','32919');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1421','211','32920');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1422','211','32921');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1423','211','32922');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1424','211','32923');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1425','211','32924');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1426','212','32983');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1427','212','32984');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1428','212','32985');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1429','212','32986');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1430','212','32987');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1431','212','32988');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1432','212','32989');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1433','212','32990');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1434','212','32991');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1435','212','32992');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1436','212','32993');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1437','212','32994');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1438','212','32995');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1439','212','32996');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1440','212','32997');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1441','212','32998');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1442','213','32999');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1443','213','33000');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1444','213','33001');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1445','213','33002');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1446','213','33003');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1447','213','33004');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1448','213','33005');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1449','213','33006');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1450','213','33007');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1451','213','33008');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1452','213','33009');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1453','213','33010');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1454','213','33011');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1455','213','33012');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1456','213','33013');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1457','213','33014');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1458','213','33015');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1459','213','33016');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1460','214','33067');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1461','214','33068');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1462','214','33069');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1463','214','33070');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1464','214','33071');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1465','214','33072');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1466','214','33073');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1467','214','33074');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1468','214','33075');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1469','214','33076');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1470','214','33077');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1471','214','33078');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1472','214','33079');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1473','214','33080');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1474','214','33081');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1475','214','33082');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1476','214','33083');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1477','214','33084');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1478','214','33085');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1479','214','33086');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1480','214','33087');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1481','214','33088');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1482','214','33089');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1483','214','33090');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1484','214','33091');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1485','214','33092');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1486','215','33093');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1487','215','33094');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1488','215','33095');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1489','215','33096');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1490','215','33097');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1491','215','33098');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1492','215','33099');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1493','215','33100');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1494','216','33101');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1495','216','33102');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1496','216','33103');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1497','216','33104');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1498','216','33105');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1499','216','33106');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1500','216','33107');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1501','216','33108');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1502','216','33109');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1503','216','33110');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1504','216','33111');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1505','216','33112');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1506','216','33113');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1507','216','33114');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1508','216','33115');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1509','216','33116');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1510','216','33117');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1511','216','33118');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1512','216','33119');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1513','216','33120');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1514','216','33121');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1515','217','33179');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1516','217','33180');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1517','217','33181');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1518','217','33182');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1519','217','33183');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1520','217','33184');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1521','217','33185');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1522','217','33186');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1523','218','33187');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1524','218','33188');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1525','218','33189');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1526','218','33190');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1527','218','33191');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1528','218','33192');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1529','218','33193');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1530','219','33195');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1531','219','33196');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1532','220','33225');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1533','220','33226');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1534','220','33227');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1535','220','33228');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1536','220','33229');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1537','220','33230');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1538','220','33231');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1539','220','33232');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1540','220','33233');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1541','221','33234');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1542','222','33266');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1543','222','33267');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1544','222','33268');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1545','222','33269');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1546','222','33270');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1547','222','33271');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1548','222','33272');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1549','222','33273');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1550','222','33274');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1551','223','33275');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1552','224','33307');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1553','224','33308');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1554','224','33309');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1555','224','33310');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1556','224','33311');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1557','224','33312');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1558','224','33313');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1559','224','33314');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1560','224','33315');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1561','225','33316');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1562','226','33348');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1563','226','33349');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1564','226','33350');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1565','226','33351');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1566','226','33352');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1567','226','33353');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1568','226','33354');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1569','226','33355');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1570','226','33356');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1571','227','33357');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1572','228','33389');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1573','228','33390');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1574','228','33391');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1575','228','33392');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1576','228','33393');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1577','228','33394');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1578','228','33395');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1579','228','33396');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1580','228','33397');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1581','229','33398');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1582','230','33417');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1583','230','33418');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1584','230','33419');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1585','230','33420');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1586','230','33421');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1587','230','33422');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1588','230','33423');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1589','230','33424');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1590','230','33425');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1591','231','33426');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1592','231','33427');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1593','231','33428');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1594','232','33522');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1595','232','33523');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1596','232','33524');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1597','232','33525');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1598','233','33526');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1599','234','33527');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1600','235','33528');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1601','236','33529');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1602','236','33530');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1603','236','33531');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1604','236','33532');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1605','237','33533');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1606','237','33534');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1607','237','33535');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1608','237','33536');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1609','237','33537');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1610','237','33538');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1611','238','33539');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1612','239','33540');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1613','239','33541');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1614','240','33542');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1615','240','33543');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1616','232','33544');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1617','232','33546');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1618','232','33547');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1619','232','33548');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1620','232','33549');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1621','232','33550');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1622','232','33554');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1623','232','33555');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1624','232','33556');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1625','232','33557');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1626','232','33558');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1627','232','33563');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1628','232','33564');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1629','232','33565');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1630','232','33566');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1631','241','34101');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1632','241','34102');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1633','241','34103');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1634','242','34104');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1635','242','34105');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1636','243','34127');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1637','243','34128');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1638','243','34129');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1639','243','34130');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1640','243','34131');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1641','243','34132');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1643','244','34134');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1644','244','34135');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1645','244','34136');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1646','244','34137');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1647','244','34138');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1648','244','34139');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1649','244','34140');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1650','244','34141');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1651','244','34142');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1652','244','34143');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1653','244','34144');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1654','244','34145');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1655','244','34146');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1656','244','34147');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1657','244','34148');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1658','244','34149');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1659','244','34150');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1660','244','34151');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1661','244','34152');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1662','244','34153');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1663','244','34154');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1664','244','34155');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1665','244','34156');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1666','244','34157');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1667','244','34158');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1668','244','34159');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1669','244','34160');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1670','244','34161');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1671','244','34162');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1672','244','34163');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1673','245','34164');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1674','245','34165');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1675','245','34166');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1676','245','34167');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1677','246','34168');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1678','246','34169');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1679','246','34170');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1680','246','34171');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1681','246','34172');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1682','123','34176');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1683','123','34177');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1684','123','34178');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1685','123','34179');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1686','123','34180');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1687','123','34181');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1688','247','34182');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1689','247','34183');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1690','247','34184');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1691','247','34185');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1692','247','34186');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1693','248','34221');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1694','248','34222');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1695','248','34223');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1696','248','34224');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1697','248','34225');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1698','248','34226');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1699','248','34227');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1700','248','34228');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1701','248','34229');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1702','248','34230');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1703','248','34231');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1704','249','34232');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1705','249','34233');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1706','249','34234');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1707','249','34235');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1708','249','34236');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1709','250','34256');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1710','250','34257');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1711','250','34258');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1712','250','34259');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1713','250','34260');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1714','250','34261');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1715','250','34262');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1716','250','34263');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1717','250','34264');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1718','250','34265');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1719','250','34266');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1720','250','34267');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1721','250','34268');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1722','250','34269');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1723','250','34270');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1724','250','34271');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1725','250','34272');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1726','251','34273');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1727','252','34274');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1728','252','34275');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1729','252','34276');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1730','252','34277');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1731','252','34278');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1732','252','34279');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1733','252','34280');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1734','253','34298');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1735','253','34299');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1736','253','34300');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1737','253','34301');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1738','253','34302');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1739','253','34303');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1740','253','34304');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1741','253','34305');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1742','253','34306');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1743','253','34307');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1744','253','34308');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1745','253','34309');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1746','253','34310');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1747','253','34311');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1748','253','34312');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1749','253','34313');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1750','253','34314');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1751','254','34333');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1752','255','34334');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1753','256','34336');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1754','257','34337');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1755','257','34338');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1756','257','34339');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1757','257','34340');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1758','257','34341');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1759','257','34342');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1760','257','34343');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1761','257','34344');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1762','257','34345');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1763','257','34346');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1764','257','34347');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1765','257','34348');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1766','257','34349');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1767','257','34350');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1768','257','34351');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1769','257','34352');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1770','257','34353');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1771','257','34354');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1772','258','34355');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1773','258','34356');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1774','258','34357');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1775','258','34358');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1776','258','34359');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1777','258','34360');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1778','258','34361');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1779','258','34362');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1780','258','34363');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1781','258','34364');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1782','258','34365');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1783','258','34366');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1784','258','34367');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1785','258','34368');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1786','258','34369');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1787','259','34370');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1788','259','34371');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1789','259','34372');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1790','259','34373');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1791','259','34374');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1792','259','34375');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1793','259','34376');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1794','259','34377');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1795','259','34378');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1796','259','34379');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1797','259','34380');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1798','259','34381');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1799','260','34382');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1800','261','34383');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1801','262','34400');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1802','263','34401');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1803','264','34403');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1804','265','34404');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1805','265','34405');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1806','265','34406');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1807','265','34407');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1808','265','34408');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1809','265','34409');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1810','265','34410');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1811','265','34411');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1812','265','34412');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1813','265','34413');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1814','265','34414');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1815','265','34415');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1816','265','34416');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1817','265','34417');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1818','265','34418');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1819','265','34419');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1820','265','34420');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1821','265','34421');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1822','266','34422');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1823','266','34423');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1824','266','34424');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1825','266','34425');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1826','266','34426');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1827','266','34427');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1828','266','34428');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1829','266','34429');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1830','266','34430');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1831','266','34431');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1832','266','34432');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1833','266','34433');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1834','266','34434');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1835','266','34435');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1836','266','34436');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1837','267','34437');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1838','267','34438');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1839','267','34439');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1840','267','34440');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1841','267','34441');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1842','267','34442');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1843','267','34443');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1844','267','34444');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1845','267','34445');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1846','267','34446');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1847','267','34447');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1848','267','34448');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1849','268','34449');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1850','269','34450');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1851','270','34467');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1852','270','34468');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1853','270','34469');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1854','270','34470');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1855','270','34471');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1856','270','34472');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1857','270','34473');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1858','270','34474');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1859','270','34475');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1860','270','34476');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1861','270','34477');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1862','271','34478');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1863','271','34479');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1864','271','34480');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1865','271','34481');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1866','271','34482');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1867','272','34498');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1868','272','34499');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1869','272','34500');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1870','272','34501');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1871','272','34502');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1872','272','34503');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1873','272','34504');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1874','272','34505');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1875','272','34506');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1876','272','34507');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1877','272','34508');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1878','272','34509');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1879','272','34510');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1880','272','34511');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1881','272','34512');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1882','272','34513');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1883','272','34514');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1884','273','34515');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1885','274','34516');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1886','274','34517');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1887','274','34518');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1888','274','34519');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1889','274','34520');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1890','274','34521');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1891','274','34522');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1892','275','34540');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1893','275','34541');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1894','275','34542');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1895','275','34543');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1896','275','34544');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1897','275','34545');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1898','275','34546');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1899','275','34547');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1900','275','34548');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1901','275','34549');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1902','275','34550');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1903','275','34551');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1904','275','34552');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1905','275','34553');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1906','275','34554');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1907','275','34555');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1908','275','34556');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1909','276','34557');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1910','277','34558');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1911','277','34559');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1912','277','34560');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1913','277','34561');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1914','277','34562');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1915','277','34563');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1916','277','34564');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1917','278','34584');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1918','278','34585');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1919','278','34586');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1920','278','34587');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1921','278','34588');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1922','278','34589');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1923','278','34590');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1924','278','34591');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1925','278','34592');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1926','278','34593');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1927','278','34594');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1928','278','34595');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1929','278','34596');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1930','278','34597');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1931','278','34598');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1932','278','34599');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1933','278','34600');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1934','279','34601');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1935','280','34602');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1936','280','34603');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1937','280','34604');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1938','280','34605');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1939','280','34606');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1940','280','34607');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1941','280','34608');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1942','281','34628');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1943','281','34629');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1944','281','34630');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1945','281','34631');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1946','281','34632');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1947','281','34633');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1948','281','34634');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1949','281','34635');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1950','281','34636');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1951','281','34637');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1952','281','34638');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1953','281','34639');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1954','281','34640');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1955','281','34641');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1956','281','34642');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1957','281','34643');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1958','281','34644');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1959','282','34645');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1960','283','34646');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1961','283','34647');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1962','283','34648');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1963','283','34649');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1964','283','34650');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1965','283','34651');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1966','283','34652');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1967','284','34672');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1968','284','34673');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1969','284','34674');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1970','284','34675');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1971','284','34676');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1972','284','34677');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1973','284','34678');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1974','284','34679');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1975','284','34680');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1976','284','34681');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1977','284','34682');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1978','284','34683');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1979','284','34684');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1980','284','34685');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1981','284','34686');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1982','284','34687');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1983','284','34688');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1984','285','34689');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1985','286','34690');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1986','286','34691');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1987','286','34692');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1988','286','34693');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1989','286','34694');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1990','286','34695');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1991','286','34696');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1992','287','34717');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1993','287','34718');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1994','287','34719');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1995','287','34720');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1996','287','34721');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1997','287','34722');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1998','287','34723');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('1999','287','34724');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2000','287','34725');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2001','287','34726');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2002','287','34727');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2003','287','34728');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2004','287','34729');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2005','287','34730');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2006','287','34731');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2007','287','34732');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2008','287','34733');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2009','288','34734');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2010','289','34735');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2011','289','34736');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2012','289','34737');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2013','289','34738');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2014','289','34739');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2015','289','34740');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2016','289','34741');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2017','290','34762');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2018','290','34763');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2019','290','34764');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2020','290','34765');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2021','290','34766');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2022','290','34767');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2023','290','34768');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2024','290','34769');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2025','290','34770');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2026','290','34771');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2027','290','34772');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2028','290','34773');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2029','290','34774');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2030','290','34775');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2031','290','34776');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2032','290','34777');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2033','290','34778');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2034','291','34779');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2035','292','34780');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2036','292','34781');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2037','292','34782');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2038','292','34783');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2039','292','34784');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2040','292','34785');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2041','292','34786');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2042','293','34808');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2043','293','34809');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2044','293','34810');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2045','293','34811');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2046','293','34812');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2047','293','34813');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2048','293','34814');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2049','293','34815');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2050','293','34816');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2051','293','34817');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2052','293','34818');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2053','293','34819');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2054','293','34820');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2055','293','34821');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2056','293','34822');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2057','293','34823');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2058','293','34824');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2059','294','34825');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2060','295','34826');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2061','295','34827');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2062','295','34828');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2063','295','34829');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2064','295','34830');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2065','295','34831');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2066','295','34832');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2067','296','34867');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2068','296','34868');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2069','296','34869');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2070','296','34870');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2071','296','34871');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2072','296','34872');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2073','296','34873');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2074','296','34874');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2075','296','34875');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2076','296','34876');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2077','297','34877');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2078','297','34878');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2079','297','34879');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2080','297','34880');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2081','297','34881');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2082','297','34882');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2083','297','34883');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2084','297','34884');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2085','297','34885');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2086','297','34886');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2087','297','34887');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2088','298','34888');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2089','298','34889');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2090','298','34890');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2091','298','34891');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2092','298','34892');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2093','298','34893');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2094','298','34894');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2095','298','34895');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2096','298','34896');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2097','298','34897');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2098','298','34898');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2099','298','34899');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2100','298','34900');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2101','298','34901');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2102','298','34902');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2103','298','34903');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2104','298','34904');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2105','298','34905');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2106','299','34906');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2107','299','34907');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2108','299','34908');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2109','300','34909');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2110','300','34910');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2111','300','34911');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2112','300','34912');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2113','300','34913');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2114','300','34914');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2115','300','34915');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2116','300','34916');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2117','300','34917');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2118','300','34918');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2119','300','34919');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2120','301','34920');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2121','301','34921');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2122','301','34922');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2123','301','34923');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2124','301','34924');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2125','301','34925');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2126','301','34926');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2127','301','34927');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2128','301','34928');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2129','302','34929');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2130','302','34930');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2131','302','34931');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2132','302','34932');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2133','302','34933');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2134','302','34934');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2135','302','34935');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2136','302','34936');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2137','302','34937');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2138','302','34938');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2139','302','34939');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2140','302','34940');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2141','302','34941');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2142','303','34942');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2143','303','34943');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2144','304','34968');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2145','304','34969');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2146','304','34970');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2147','304','34971');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2148','304','34972');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2149','304','34973');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2150','304','34974');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2151','304','34975');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2152','304','34976');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2153','304','34977');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2154','304','34978');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2155','304','34979');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2156','304','34980');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2157','304','34981');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2158','305','35562');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2159','305','35563');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2160','305','35564');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2161','305','35565');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2162','306','35566');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2163','306','35567');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2164','307','35578');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2165','307','35579');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2166','307','35580');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2167','307','35581');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2168','307','35582');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2169','307','35583');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2170','307','35584');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2171','307','35585');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2172','307','35586');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2173','308','35587');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2174','308','35588');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2175','308','35589');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2176','308','35590');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2177','309','35591');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2178','309','35592');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2179','309','35593');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2180','309','35594');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2181','309','35595');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2182','309','35596');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2183','309','35597');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2184','309','35598');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2185','309','35599');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2186','309','35600');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2187','309','35601');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2188','310','35602');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2189','310','35603');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2190','310','35604');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2191','310','35605');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2192','310','35606');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2193','310','35607');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2194','310','35608');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2195','310','35609');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2196','310','35610');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2197','310','35611');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2198','311','35612');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2199','311','35613');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2200','311','35614');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2201','311','35615');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2202','311','35616');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2203','312','35617');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2204','312','35618');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2205','312','35619');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2206','313','35620');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2207','313','35621');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2209','313','35623');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2210','314','35624');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2211','314','35625');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2212','314','35626');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2213','314','35627');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2214','314','35628');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2215','314','35629');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2216','314','35630');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2217','314','35631');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2218','315','35632');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2219','315','35633');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2220','315','35634');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2221','315','35635');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2222','315','35636');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2223','316','35637');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2224','316','35638');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2225','316','35639');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2226','316','35640');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2227','316','35641');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2228','316','35642');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2229','316','35643');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2230','316','35644');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2231','316','35645');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2232','317','35717');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2233','317','35718');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2234','317','35719');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2235','317','35720');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2236','317','35721');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2237','318','35732');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2238','318','35733');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2239','318','35734');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2240','318','35735');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2241','318','35736');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2242','318','35737');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2243','318','35738');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2244','318','35739');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2245','318','35740');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2246','318','35741');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2247','318','35742');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2248','318','35743');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2249','318','35744');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2250','318','35745');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2251','319','35746');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2252','319','35747');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2253','319','35748');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2254','319','35749');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2255','319','35750');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2256','319','35751');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2257','319','35752');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2258','319','35753');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2259','320','35754');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2260','320','35755');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2261','320','35756');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2262','320','35757');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2263','320','35758');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2264','320','35759');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2265','320','35760');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2266','320','35761');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2267','321','35762');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2268','321','35763');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2269','321','35764');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2270','321','35765');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2271','321','35766');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2272','321','35767');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2273','321','35768');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2274','321','35769');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2275','321','35770');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2276','321','35771');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2277','322','35786');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2278','323','35787');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2279','323','35788');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2280','323','35789');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2281','323','35790');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2282','323','35791');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2283','323','35792');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2284','323','35793');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2285','323','35794');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2286','323','35795');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2287','323','35796');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2288','323','35797');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2289','323','35798');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2290','323','35799');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2291','323','35800');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2292','323','35801');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2293','323','35802');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2294','323','35803');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2295','323','35804');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2296','323','35805');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2297','323','35806');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2298','322','35807');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2299','322','35808');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2300','322','35809');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2301','322','35810');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2302','322','35811');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2303','322','35812');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2304','322','35813');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2305','322','35814');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2306','322','35815');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2307','322','35816');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2308','322','35817');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2309','322','35818');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2310','322','35819');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2311','322','35820');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2312','324','35821');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2313','324','35822');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2314','324','35823');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2315','324','35824');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2316','324','35825');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2317','324','35826');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2318','324','35827');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2319','324','35828');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2320','324','35829');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2321','324','35830');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2322','324','35831');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2323','324','35832');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2324','324','35833');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2325','324','35834');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2326','324','35835');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2327','324','35836');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2328','324','35837');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2329','324','35838');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2330','324','35839');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2331','324','35840');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2332','324','35841');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2333','324','35842');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2334','324','35843');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2335','325','35845');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2336','326','35846');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2337','326','35847');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2338','326','35848');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2339','326','35849');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2340','326','35850');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2341','326','35851');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2342','326','35852');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2343','326','35853');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2344','326','35854');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2345','326','35855');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2346','326','35856');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2347','326','35857');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2348','326','35858');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2349','326','35859');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2350','326','35860');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2351','326','35861');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2352','326','35862');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2353','326','35863');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2354','326','35864');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2355','326','35865');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2356','325','35866');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2357','325','35867');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2358','325','35868');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2359','325','35869');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2360','325','35870');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2361','325','35871');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2362','325','35872');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2363','325','35873');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2364','325','35874');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2365','325','35875');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2366','325','35876');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2367','325','35877');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2368','325','35878');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2369','325','35879');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2370','327','35880');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2371','327','35881');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2372','327','35882');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2373','327','35883');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2374','327','35884');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2375','327','35885');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2376','327','35886');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2377','327','35887');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2378','327','35888');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2379','327','35889');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2380','327','35890');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2381','327','35891');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2382','327','35892');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2383','327','35893');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2384','327','35894');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2385','327','35895');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2386','327','35896');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2387','327','35897');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2388','327','35898');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2389','327','35899');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2390','327','35900');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2391','327','35901');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2392','327','35902');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2393','328','35918');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2394','328','35919');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2395','328','35920');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2396','328','35921');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2397','328','35922');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2398','328','35923');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2399','328','35924');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2400','328','35925');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2401','328','35926');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2402','328','35927');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2403','328','35928');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2404','328','35929');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2405','328','35930');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2406','328','35931');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2407','328','35932');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2408','329','35933');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2409','329','35934');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2410','329','35935');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2411','329','35936');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2412','329','35937');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2413','329','35938');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2414','329','35939');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2415','329','35940');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2416','330','35941');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2417','330','35942');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2418','330','35943');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2419','330','35944');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2420','330','35945');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2421','330','35946');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2422','330','35947');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2423','330','35948');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2424','330','35949');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2425','330','35950');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2426','331','35965');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2427','331','35966');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2428','331','35967');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2429','331','35968');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2430','331','35969');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2431','331','35970');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2432','331','35971');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2433','331','35972');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2434','331','35973');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2435','331','35974');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2436','331','35975');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2437','332','35976');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2438','332','35977');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2439','332','35978');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2440','332','35979');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2441','332','35980');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2442','333','36000');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2443','333','36001');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2444','333','36002');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2445','333','36003');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2446','333','36004');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2447','333','36005');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2448','333','36006');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2449','333','36007');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2450','333','36008');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2451','333','36009');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2452','333','36010');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2453','333','36011');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2454','333','36012');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2455','333','36013');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2456','333','36014');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2457','333','36015');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2458','333','36016');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2459','334','36017');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2460','335','36018');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2461','335','36019');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2462','335','36020');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2463','335','36021');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2464','335','36022');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2465','335','36023');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2466','335','36024');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2467','336','36042');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2468','336','36043');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2469','336','36044');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2470','336','36045');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2471','336','36046');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2472','336','36047');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2473','336','36048');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2474','336','36049');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2475','336','36050');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2476','336','36051');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2477','336','36052');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2478','336','36053');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2479','336','36054');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2480','336','36055');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2481','336','36056');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2482','336','36057');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2483','336','36058');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2484','337','36077');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2485','338','36078');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2486','339','36080');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2487','340','36081');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2488','340','36082');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2489','340','36083');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2490','340','36084');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2491','340','36085');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2492','340','36086');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2493','340','36087');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2494','340','36088');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2495','340','36089');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2496','340','36090');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2497','340','36091');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2498','340','36092');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2499','340','36093');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2500','340','36094');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2501','340','36095');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2502','340','36096');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2503','340','36097');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2504','340','36098');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2505','341','36099');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2506','341','36100');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2507','341','36101');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2508','341','36102');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2509','341','36103');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2510','341','36104');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2511','341','36105');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2512','341','36106');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2513','341','36107');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2514','341','36108');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2515','341','36109');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2516','341','36110');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2517','341','36111');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2518','341','36112');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2519','341','36113');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2520','342','36114');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2521','342','36115');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2522','342','36116');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2523','342','36117');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2524','342','36118');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2525','342','36119');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2526','342','36120');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2527','342','36121');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2528','342','36122');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2529','342','36123');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2530','342','36124');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2531','342','36125');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2532','343','36126');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2533','344','36127');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2534','345','36144');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2535','346','36145');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2536','347','36147');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2537','348','36148');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2538','348','36149');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2539','348','36150');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2540','348','36151');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2541','348','36152');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2542','348','36153');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2543','348','36154');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2544','348','36155');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2545','348','36156');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2546','348','36157');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2547','348','36158');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2548','348','36159');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2549','348','36160');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2550','348','36161');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2551','348','36162');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2552','348','36163');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2553','348','36164');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2554','348','36165');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2555','349','36166');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2556','349','36167');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2557','349','36168');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2558','349','36169');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2559','349','36170');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2560','349','36171');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2561','349','36172');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2562','349','36173');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2563','349','36174');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2564','349','36175');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2565','349','36176');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2566','349','36177');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2567','349','36178');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2568','349','36179');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2569','349','36180');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2570','350','36181');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2571','350','36182');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2572','350','36183');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2573','350','36184');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2574','350','36185');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2575','350','36186');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2576','350','36187');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2577','350','36188');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2578','350','36189');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2579','350','36190');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2580','350','36191');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2581','350','36192');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2582','351','36193');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2583','352','36194');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2584','353','36211');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2585','353','36212');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2586','353','36213');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2587','353','36214');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2588','353','36215');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2589','353','36216');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2590','353','36217');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2591','353','36218');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2592','353','36219');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2593','353','36220');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2594','353','36221');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2595','354','36222');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2596','354','36223');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2597','354','36224');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2598','354','36225');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2599','354','36226');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2600','355','36242');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2601','355','36243');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2602','355','36244');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2603','355','36245');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2604','355','36246');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2605','355','36247');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2606','355','36248');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2607','355','36249');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2608','355','36250');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2609','355','36251');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2610','355','36252');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2611','355','36253');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2612','355','36254');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2613','355','36255');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2614','355','36256');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2615','355','36257');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2616','355','36258');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2617','356','36259');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2618','357','36260');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2619','357','36261');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2620','357','36262');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2621','357','36263');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2622','357','36264');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2623','357','36265');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2624','357','36266');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2625','358','36284');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2626','358','36285');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2627','358','36286');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2628','358','36287');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2629','358','36288');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2630','358','36289');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2631','358','36290');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2632','358','36291');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2633','358','36292');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2634','358','36293');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2635','358','36294');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2636','358','36295');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2637','358','36296');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2638','358','36297');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2639','358','36298');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2640','358','36299');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2641','358','36300');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2642','359','36301');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2643','360','36302');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2644','360','36303');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2645','360','36304');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2646','360','36305');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2647','360','36306');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2648','360','36307');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2649','360','36308');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2650','361','36328');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2651','361','36329');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2652','361','36330');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2653','361','36331');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2654','361','36332');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2655','361','36333');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2656','361','36334');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2657','361','36335');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2658','361','36336');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2659','361','36337');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2660','361','36338');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2661','361','36339');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2662','361','36340');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2663','361','36341');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2664','361','36342');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2665','361','36343');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2666','361','36344');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2667','362','36345');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2668','363','36346');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2669','363','36347');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2670','363','36348');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2671','363','36349');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2672','363','36350');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2673','363','36351');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2674','363','36352');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2675','364','36372');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2676','364','36373');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2677','364','36374');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2678','364','36375');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2679','364','36376');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2680','364','36377');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2681','364','36378');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2682','364','36379');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2683','364','36380');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2684','364','36381');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2685','364','36382');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2686','364','36383');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2687','364','36384');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2688','364','36385');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2689','364','36386');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2690','364','36387');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2691','364','36388');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2692','365','36389');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2693','366','36390');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2694','366','36391');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2695','366','36392');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2696','366','36393');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2697','366','36394');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2698','366','36395');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2699','366','36396');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2700','367','36416');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2701','367','36417');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2702','367','36418');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2703','367','36419');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2704','367','36420');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2705','367','36421');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2706','367','36422');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2707','367','36423');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2708','367','36424');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2709','367','36425');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2710','367','36426');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2711','367','36427');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2712','367','36428');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2713','367','36429');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2714','367','36430');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2715','367','36431');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2716','367','36432');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2717','368','36433');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2718','369','36434');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2719','369','36435');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2720','369','36436');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2721','369','36437');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2722','369','36438');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2723','369','36439');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2724','369','36440');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2725','370','36461');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2726','370','36462');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2727','370','36463');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2728','370','36464');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2729','370','36465');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2730','370','36466');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2731','370','36467');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2732','370','36468');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2733','370','36469');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2734','370','36470');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2735','370','36471');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2736','370','36472');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2737','370','36473');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2738','370','36474');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2739','370','36475');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2740','370','36476');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2741','370','36477');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2742','371','36478');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2743','372','36479');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2744','372','36480');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2745','372','36481');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2746','372','36482');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2747','372','36483');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2748','372','36484');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2749','372','36485');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2750','373','36506');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2751','373','36507');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2752','373','36508');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2753','373','36509');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2754','373','36510');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2755','373','36511');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2756','373','36512');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2757','373','36513');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2758','373','36514');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2759','373','36515');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2760','373','36516');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2761','373','36517');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2762','373','36518');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2763','373','36519');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2764','373','36520');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2765','373','36521');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2766','373','36522');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2767','374','36523');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2768','375','36524');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2769','375','36525');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2770','375','36526');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2771','375','36527');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2772','375','36528');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2773','375','36529');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2774','375','36530');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2775','376','36552');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2776','376','36553');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2777','376','36554');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2778','376','36555');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2779','376','36556');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2780','376','36557');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2781','376','36558');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2782','376','36559');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2783','376','36560');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2784','376','36561');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2785','376','36562');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2786','376','36563');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2787','376','36564');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2788','376','36565');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2789','376','36566');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2790','376','36567');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2791','376','36568');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2792','377','36569');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2793','378','36570');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2794','378','36571');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2795','378','36572');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2796','378','36573');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2797','378','36574');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2798','378','36575');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2799','378','36576');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2800','379','36583');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2801','379','36584');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2802','379','36585');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2803','379','36586');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2804','379','36587');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2805','379','36588');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2806','380','36589');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2807','380','36590');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2808','380','36591');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2809','380','36592');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2810','380','36593');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2811','380','36594');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2812','379','36595');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2813','379','36596');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2814','379','36597');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2815','380','36598');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2816','380','36599');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2817','380','36600');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2818','381','36605');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2819','381','36606');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2820','381','36607');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2821','381','36608');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2822','381','36609');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2823','381','36610');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2824','382','36611');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2825','382','36612');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2826','382','36613');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2827','382','36614');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2828','382','36615');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2829','382','36616');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2830','381','36617');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2831','381','36618');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2832','381','36619');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2833','382','36620');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2834','382','36621');
INSERT INTO item_application_prototype (item_application_prototypeid,application_prototypeid,itemid) values ('2835','382','36622');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23300','28909','1','5','(Server version)\s+(.+)
\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23301','28909','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23302','28910','1','21','return value.search(/is alive/)>0?1:0','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23303','28910','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23304','28914','1','11','/resultset/row[field/text()=''Innodb_buffer_pool_reads'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23305','28915','1','11','/resultset/row[field/text()=''Innodb_buffer_pool_read_requests'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23306','28916','1','11','/resultset/row[field/text()=''Innodb_row_lock_time'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23307','28916','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23308','28916','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23309','28917','1','11','/resultset/row[field/text()=''Innodb_row_lock_time_max'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23310','28917','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23311','28917','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23312','28918','1','11','/resultset/row[field/text()=''Innodb_row_lock_waits'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23313','28919','1','11','/resultset/row[field/text()=''Max_used_connections'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23314','28920','1','11','/resultset/row[field/text()=''Questions'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23315','28920','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23316','28921','1','11','/resultset/row[field/text()=''Queries'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23317','28921','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23318','28922','1','11','/resultset/row[field/text()=''Slow_queries'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23319','28922','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23320','28923','1','11','/resultset/row[field/text()=''Threads_cached'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23321','28924','1','11','/resultset/row[field/text()=''Threads_connected'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23322','28925','1','11','/resultset/row[field/text()=''Threads_created'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23323','28926','1','11','/resultset/row[field/text()=''Threads_running'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23324','28927','1','11','/resultset/row[field/text()=''Uptime'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23325','28928','1','11','/resultset/row[field/text()=''Innodb_buffer_pool_pages_total'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23326','28929','1','11','/resultset/row[field/text()=''Aborted_clients'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23327','28929','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23328','28930','1','11','/resultset/row[field/text()=''Innodb_buffer_pool_pages_free'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23329','28931','1','11','/resultset/row[field/text()=''Connections'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23330','28931','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23331','28932','1','11','/resultset/row[field/text()=''Bytes_received'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23332','28932','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23333','28933','1','11','/resultset/row[field/text()=''Bytes_sent'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23334','28933','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23335','28934','1','11','/resultset/row[field/text()=''Com_delete'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23336','28934','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23337','28935','1','11','/resultset/row[field/text()=''Com_insert'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23338','28935','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23339','28936','1','11','/resultset/row[field/text()=''Com_select'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23340','28936','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23341','28937','1','11','/resultset/row[field/text()=''Com_update'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23342','28937','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23343','28938','1','11','/resultset/row[field/text()=''Connection_errors_accept'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23344','28939','1','11','/resultset/row[field/text()=''Aborted_connects'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23345','28939','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23346','28940','1','11','/resultset/row[field/text()=''Connection_errors_internal'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23347','28940','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23348','28941','1','11','/resultset/row[field/text()=''Connection_errors_max_connections'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23349','28941','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23350','28942','1','11','/resultset/row[field/text()=''Connection_errors_peer_address'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23351','28942','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23352','28943','1','11','/resultset/row[field/text()=''Connection_errors_select'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23353','28943','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23354','28944','1','11','/resultset/row[field/text()=''Connection_errors_tcpwrap'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23355','28944','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23356','28945','1','11','/resultset/row[field/text()=''Created_tmp_disk_tables'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23357','28946','1','11','/resultset/row[field/text()=''Created_tmp_files'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23358','28947','1','11','/resultset/row[field/text()=''Created_tmp_tables'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23359','28948','1','21','arr = value.split(''\n'')
s = []
for (var i in arr) {
   s.push({"{#DBNAME}": arr[i]})
}
return JSON.stringify(s)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23360','28948','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23361','28949','1','21','var a = value.match(/Master_Host.*>(.*)<.*/)
if (a) {
  s = [{"{#MASTERHOST}": a[1]}]
} 
else {
  s = []
}
return JSON.stringify(s)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23362','28949','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23363','28950','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23364','28952','1','11','/resultset/row/field[@name=''Seconds_Behind_Master'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23365','28952','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23366','28952','3','15','null','3','Replication is not performed.');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23367','28953','1','11','/resultset/row/field[@name=''Slave_IO_Running'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23368','28953','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23369','28954','1','11','/resultset/row/field[@name=''Slave_SQL_Running'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('23370','28954','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61214','28743','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61215','30896','1','21','// Convert Apache status to JSON
var lines = value.split(''\n'');
var output = {},
    workers = {
        ''_'': 0, ''S'': 0, ''R'': 0, ''W'': 0,
        ''K'': 0, ''D'': 0, ''C'': 0, ''L'': 0,
        ''G'': 0, ''I'': 0, ''.'': 0
    };

// Get all "Key: Value" pairs as an object
for (var i = 0; i < lines.length; i++) {
    var line = lines[i].match(/([A-z0-9 ]+): (.*)/);

    if (line !== null) {
        output[line[1]] = isNaN(line[2]) ? line[2] : Number(line[2]);
    }
}

// Multiversion metrics
output.ServerUptimeSeconds = output.ServerUptimeSeconds || output.Uptime;
output.ServerVersion = output.Server || output.ServerVersion;

// Parse "Scoreboard" to get worker count.
if (typeof output.Scoreboard === ''string'') {
    for (var i = 0; i < output.Scoreboard.length; i++) {
        var char = output.Scoreboard[i];

        workers[char]++;
    }
}

// Add worker data to the output
output.Workers = {
    waiting: workers[''_''], starting: workers[''S''], reading: workers[''R''],
    sending: workers[''W''], keepalive: workers[''K''], dnslookup: workers[''D''],
    closing: workers[''C''], logging: workers[''L''], finishing: workers[''G''],
    cleanup: workers[''I''], slot: workers[''.'']
};

// Return JSON string
return JSON.stringify(output);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61216','30897','1','12','$.Workers.reading','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61217','30898','1','12','$.Workers.waiting','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61218','30899','1','12','$.Workers.starting','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61219','30900','1','12','$.Workers.slot','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61220','30901','1','12','$.Workers.sending','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61221','30902','1','12','$["Total kBytes"]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61222','30902','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61223','30903','1','12','$["Total kBytes"]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61224','30903','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61225','30903','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61226','30904','1','12','$.Workers.keepalive','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61227','30905','1','12','$.Workers.finishing','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61228','30906','1','12','$.Workers.dnslookup','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61229','30907','1','12','$.Workers.closing','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61230','30908','1','12','$.Workers.cleanup','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61231','30909','1','12','$.IdleWorkers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61232','30910','1','12','$.BusyWorkers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61233','30911','1','12','$.ServerVersion','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61234','30911','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61235','30912','1','12','$.ServerUptimeSeconds','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61236','30913','1','12','$["Total Accesses"]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61237','30913','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61238','30914','1','12','$["Total Accesses"]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61239','30915','1','12','$.Workers.logging','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61240','30916','1','21','return JSON.stringify(JSON.parse(value).ServerMPM === ''event''
    ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61241','30916','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61242','30917','1','12','$.BytesPerReq','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61243','30918','1','12','$.ConnsAsyncClosing','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61244','30919','1','12','$.ConnsAsyncKeepAlive','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61245','30920','1','12','$.ConnsAsyncWriting','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61246','30921','1','12','$.ConnsTotal','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61247','30922','1','12','$.Processes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61248','28775','1','21','// Convert Apache status to JSON
var lines = value.split(''\n'');
var output = {},
    workers = {
        ''_'': 0, ''S'': 0, ''R'': 0, ''W'': 0,
        ''K'': 0, ''D'': 0, ''C'': 0, ''L'': 0,
        ''G'': 0, ''I'': 0, ''.'': 0
    };

// Get all "Key: Value" pairs as an object
for (var i = 0; i < lines.length; i++) {
    var line = lines[i].match(/([A-z0-9 ]+): (.*)/);

    if (line !== null) {
        output[line[1]] = isNaN(line[2]) ? line[2] : Number(line[2]);
    }
}

// Multiversion metrics
output.ServerUptimeSeconds = output.ServerUptimeSeconds || output.Uptime;
output.ServerVersion = output.Server || output.ServerVersion;

// Parse "Scoreboard" to get worker count.
if (typeof output.Scoreboard === ''string'') {
    for (var i = 0; i < output.Scoreboard.length; i++) {
        var char = output.Scoreboard[i];

        workers[char]++;
    }
}

// Add worker data to the output
output.Workers = {
    waiting: workers[''_''], starting: workers[''S''], reading: workers[''R''],
    sending: workers[''W''], keepalive: workers[''K''], dnslookup: workers[''D''],
    closing: workers[''C''], logging: workers[''L''], finishing: workers[''G''],
    cleanup: workers[''I''], slot: workers[''.'']
};

// Return JSON string
return JSON.stringify(output);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61249','28776','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61250','28778','1','12','$.Workers.starting','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61251','28779','1','12','$.Workers.slot','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61252','28780','1','12','$.Workers.sending','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61253','28781','1','12','$.Workers.reading','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61254','28782','1','12','$.Workers.logging','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61255','28783','1','12','$.Workers.keepalive','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61256','28784','1','12','$.Workers.cleanup','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61257','28785','1','12','$.Workers.finishing','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61258','28786','1','12','$.Workers.closing','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61259','28787','1','12','$.Workers.dnslookup','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61260','28788','1','12','$.IdleWorkers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61261','28789','1','12','$.BusyWorkers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61262','28790','1','12','$.ServerVersion','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61263','28790','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61264','28791','1','12','$.ServerUptimeSeconds','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61265','28792','1','12','$["Total Accesses"]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61266','28793','1','12','$["Total Accesses"]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61267','28793','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61268','28794','1','12','$["Total kBytes"]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61269','28794','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61270','28794','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61271','28795','1','12','$["Total kBytes"]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61272','28795','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61273','28796','1','12','$.Workers.waiting','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61274','28797','1','21','return JSON.stringify(JSON.parse(value).ServerMPM === ''event''
    ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61275','28797','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61276','28798','1','12','$.ConnsAsyncClosing','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61277','28799','1','12','$.ConnsAsyncKeepAlive','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61278','28800','1','12','$.ConnsAsyncWriting','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61279','28801','1','12','$.ConnsTotal','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61280','28802','1','12','$.BytesPerReq','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61281','28803','1','12','$.Processes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61282','31803','1','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61283','31805','1','12','$.num_osd_up','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61284','31805','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61285','31806','1','12','$.pg_states.undersized','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61286','31807','1','12','$.pg_states.clean','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61287','31808','1','12','$.pg_states.degraded','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61288','31809','1','12','$.pg_states.inconsistent','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61289','31810','1','12','$.pg_states.peering','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61290','31811','1','12','$.pg_states.recovering','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61291','31812','1','12','$.pg_states.recovery_wait','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61292','31813','1','12','$.pg_states.remapped','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61293','31814','1','12','$.pg_states.scrubbing','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61294','31815','1','12','$.pg_states.unknown','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61295','31816','1','12','$.pg_states.backfill_wait','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61296','31817','1','12','$.num_osd','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61297','31817','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61298','31818','1','12','$.rd_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61299','31818','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61300','31819','1','12','$.rd_ops','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61301','31820','1','12','$.num_mon','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61302','31820','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61303','31821','1','12','$.total_avail_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61304','31822','1','12','$.total_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61305','31823','1','12','$.total_objects','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61306','31824','1','12','$.total_used_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61307','31825','1','12','$.wr_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61308','31825','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61309','31826','1','12','$.pg_states.backfilling','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61310','31827','1','12','$.pg_states.backfill_toofull','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61311','31828','1','12','$.num_pg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61312','31828','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61313','31829','1','12','$.osd_latency_apply.min','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61314','31830','1','12','$.num_pg_temp','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61315','31831','1','12','$.num_pools','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61316','31832','1','12','$.osd_backfillfull_ratio','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61317','31832','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61318','31833','1','12','$.osd_fill.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61319','31834','1','12','$.osd_fill.max','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61320','31835','1','12','$.osd_fill.min','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61321','31836','1','12','$.osd_full_ratio','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61322','31836','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61323','31837','1','12','$.osd_latency_apply.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61324','31838','1','12','$.osd_latency_apply.max','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61325','31839','1','12','$.osd_latency_commit.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61326','31840','1','12','$.pg_states.active','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61327','31841','1','12','$.osd_latency_commit.max','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61328','31842','1','12','$.osd_latency_commit.min','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61329','31843','1','12','$.osd_nearfull_ratio','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61330','31843','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61331','31844','1','12','$.osd_pgs.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61332','31845','1','12','$.osd_pgs.max','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61333','31846','1','12','$.osd_pgs.min','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61334','31847','1','12','$.num_osd_in','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61335','31847','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61336','31848','1','12','$.min_mon_release_name','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61337','31848','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61338','31849','1','12','$.overall_status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61339','31849','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61340','31850','1','12','$.wr_ops','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61341','31850','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61342','31853','1','12','$.osds.{#OSDNAME}.osd_fill','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61343','31854','1','12','$.osds.{#OSDNAME}.in','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61344','31854','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61345','31855','1','12','$.osds.{#OSDNAME}.osd_latency_apply','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61346','31856','1','12','$.osds.{#OSDNAME}.osd_latency_commit','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61347','31857','1','12','$.osds.{#OSDNAME}.num_pgs','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61348','31858','1','12','$.osds.{#OSDNAME}.up','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61349','31858','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61350','32003','1','12','$.pools["{#POOLNAME}"].bytes_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61351','32004','1','12','$.pools["{#POOLNAME}"].max_avail','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61352','32005','1','12','$.pools["{#POOLNAME}"].objects','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61353','32006','1','12','$.pools["{#POOLNAME}"].percent_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61354','32007','1','12','$.pools["{#POOLNAME}"].rd_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61355','32007','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61356','32008','1','12','$.pools["{#POOLNAME}"].rd_ops','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61357','32008','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61358','32009','1','12','$.pools["{#POOLNAME}"].stored_raw','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61359','32010','1','12','$.pools["{#POOLNAME}"].wr_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61360','32010','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61361','32011','1','12','$.pools["{#POOLNAME}"].wr_ops','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61362','32011','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61363','30530','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61364','30532','1','12','$.Architecture','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61365','30532','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61366','30533','1','12','$.LiveRestoreEnabled','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61367','30533','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61368','30533','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61369','30534','1','12','$.LoggingDriver','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61370','30534','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61371','30535','1','12','$.MemoryLimit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61372','30535','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61373','30535','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61374','30536','1','12','$.MemTotal','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61375','30537','1','12','$.Name','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61376','30538','1','12','$.NCPU','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61377','30539','1','12','$.NFd','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61378','30540','1','12','$.NEventsListener','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61379','30541','1','12','$.KernelVersion','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61380','30541','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61381','30542','1','12','$.OomKillDisable','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61382','30542','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61383','30542','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61384','30543','1','12','$.OperatingSystem','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61385','30543','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61386','30544','1','12','$.OSType','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61387','30544','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61388','30545','1','12','$.PidsLimit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61389','30545','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61390','30545','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61391','30546','1','12','$.DockerRootDir','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61392','30546','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61393','30547','1','12','$.ServerVersion','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61394','30547','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61395','30548','1','12','$.SwapLimit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61396','30548','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61397','30548','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61398','30549','1','12','$.LayersSize','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61399','30550','1','12','$.IPv4Forwarding','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61400','30550','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61401','30550','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61402','30551','1','12','$.KernelMemory','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61403','30551','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61404','30551','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61405','30552','1','12','$.CPUSet','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61406','30552','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61407','30552','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61408','30553','1','12','$.Containers[*].SizeRw.sum()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61409','30554','1','12','$.ContainersPaused','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61410','30555','1','12','$.ContainersRunning','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61411','30556','1','12','$.ContainersStopped','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61412','30557','1','12','$.Containers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61413','30558','1','12','$.CpuCfsPeriod','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61414','30558','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61415','30558','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61416','30559','1','12','$.CpuCfsQuota','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61417','30559','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61418','30559','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61419','30560','1','12','$.CPUShares','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61420','30560','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61421','30560','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61422','30561','1','12','$.KernelMemoryTCP','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61423','30561','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61424','30561','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61425','30562','1','12','$.Debug','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61426','30562','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61427','30562','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61428','30563','1','12','$.DefaultRuntime','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61429','30563','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61430','30564','1','12','$.Driver','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61431','30564','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61432','30565','1','12','$.NGoroutines','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61433','30566','1','12','$.Images[*].Size.sum()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61434','30567','1','12','$.length()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61435','30568','1','12','$.Images','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61436','30569','1','12','$.CgroupDriver','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61437','30569','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61438','30570','1','12','$.Volumes[*].UsageData.Size.sum()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61439','30575','1','12','$.cpu_stats.online_cpus','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61440','30576','1','12','$.memory_stats.commitbytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61441','30577','1','12','$.memory_stats.commitpeakbytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61442','30578','1','12','$.memory_stats.max_usage','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61443','30579','1','12','$.memory_stats.privateworkingset','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61444','30580','1','12','$.memory_stats.usage','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61445','30581','1','12','$.Created','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61446','30581','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61447','30582','1','12','$.cpu_stats.cpu_usage.total_usage','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61448','30582','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61449','30582','3','1','1.0E-9','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61450','30583','1','12','$.networks[*].rx_bytes.sum()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61451','30583','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61452','30584','1','12','$.networks[*].rx_dropped.sum()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61453','30584','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61454','30585','1','12','$.networks[*].rx_errors.sum()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61455','30585','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61456','30586','1','12','$.networks[*].rx_packets.sum()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61457','30586','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61458','30587','1','12','$.networks[*].tx_bytes.sum()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61459','30587','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61460','30588','1','12','$.networks[*].tx_dropped.sum()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61461','30588','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61462','30589','1','12','$.networks[*].tx_errors.sum()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61463','30589','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61464','30590','1','12','$.cpu_stats.cpu_usage.usage_in_usermode','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61465','30590','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61466','30590','3','1','1.0E-9','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61467','30591','1','12','$.cpu_stats.throttling_data.periods','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61468','30592','1','12','$.State.FinishedAt','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61469','30592','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61470','30593','1','12','$.State.OOMKilled','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61471','30593','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61472','30594','1','12','$[?(@.Names[0] == "{#NAME}")].Image.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61473','30594','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61474','30595','1','12','$.RestartCount','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61475','30596','1','12','$.State.StartedAt','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61476','30596','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61477','30597','1','12','$.State.Dead','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61478','30597','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61479','30598','1','12','$.State.Error','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61480','30598','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61481','30599','1','12','$.State.ExitCode','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61482','30599','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61483','30600','1','12','$.State.Paused','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61484','30600','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61485','30601','1','12','$.cpu_stats.throttling_data.throttled_time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61486','30601','2','1','1.0E-9','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61487','30602','1','12','$.State.Pid','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61488','30602','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61489','30603','1','12','$.State.Restarting','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61490','30603','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61491','30604','1','12','$.State.Running','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61492','30604','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61493','30605','1','12','$.State.Status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61494','30605','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61495','30606','1','12','$.cpu_stats.cpu_usage.usage_in_kernelmode','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61496','30606','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61497','30606','3','1','1.0E-9','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61498','30607','1','12','$.cpu_stats.throttling_data.throttled_periods','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61499','30608','1','12','$.networks[*].tx_packets.sum()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61500','30608','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61501','30609','1','12','$[?(@.Id == "{#ID}")].Created.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61502','30609','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61503','30610','1','12','$[?(@.Id == "{#ID}")].Size.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61504','30690','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61505','30695','1','12','$.indices.docs.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61506','30695','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61507','30696','1','12','$.nodes.jvm.max_uptime_in_millis','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61508','30696','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61509','30697','1','12','$.nodes.fs.total_in_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61510','30697','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61511','30698','1','12','$.nodes.fs.available_in_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61512','30698','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61513','30699','1','12','$.nodes.count.master','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61514','30699','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61515','30700','1','12','$.nodes.count.ingest','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61516','30700','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61517','30701','1','12','$.nodes.count.data','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61518','30701','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61519','30702','1','12','$.delayed_unassigned_shards','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61520','30703','1','12','$.indices.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61521','30703','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61522','30704','1','12','$.task_max_waiting_in_queue_millis','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61523','30704','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61524','30705','1','12','$.status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61525','30705','2','21','var state = [''green'', ''yellow'', ''red''];

return state.indexOf(value.trim()) === -1 ? 255 : state.indexOf(value.trim());
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61526','30705','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61527','30706','1','12','$.relocating_shards','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61528','30707','1','12','$.number_of_pending_tasks','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61529','30708','1','12','$.number_of_nodes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61530','30708','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61531','30709','1','12','$.number_of_data_nodes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61532','30709','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61533','30710','1','12','$.initializing_shards','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61534','30711','1','12','$.active_shards_percent_as_number','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61535','30711','2','21','return (100 - value)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61536','30712','1','12','$.unassigned_shards','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61537','30713','1','12','$.nodes.[*]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61538','30713','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61539','30718','1','12','$..[?(@.name==''{#ES.NODE}'')].thread_pool.refresh.active.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61540','30719','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.search.query_total.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61541','30719','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61542','30720','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.search.query_total.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61543','30720','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61544','30721','1','12','$..[?(@.name==''{#ES.NODE}'')].jvm.mem.heap_committed_in_bytes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61545','30721','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61546','30722','1','12','$..[?(@.name==''{#ES.NODE}'')].jvm.mem.heap_max_in_bytes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61547','30722','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61548','30723','1','12','$..[?(@.name==''{#ES.NODE}'')].jvm.mem.heap_used_in_bytes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61549','30723','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61550','30724','1','12','$..[?(@.name==''{#ES.NODE}'')].jvm.mem.heap_used_percent.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61551','30724','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61552','30725','1','12','$..[?(@.name==''{#ES.NODE}'')].jvm.uptime_in_millis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61553','30725','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61554','30726','1','12','$..[?(@.name==''{#ES.NODE}'')].fs.total.available_in_bytes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61555','30726','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61556','30727','1','12','$..[?(@.name==''{#ES.NODE}'')].thread_pool.refresh.completed.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61557','30727','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61558','30728','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.search.query_time_in_millis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61559','30728','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61560','30728','3','9','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61561','30729','1','12','$..[?(@.name==''{#ES.NODE}'')].thread_pool.refresh.rejected.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61562','30729','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61563','30730','1','12','$..[?(@.name==''{#ES.NODE}'')].thread_pool.search.active.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61564','30731','1','12','$..[?(@.name==''{#ES.NODE}'')].thread_pool.search.completed.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61565','30731','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61566','30732','1','12','$..[?(@.name==''{#ES.NODE}'')].thread_pool.search.queue.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61567','30733','1','12','$..[?(@.name==''{#ES.NODE}'')].thread_pool.search.rejected.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61568','30733','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61569','30734','1','12','$..[?(@.name==''{#ES.NODE}'')].thread_pool.write.active.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61570','30735','1','12','$..[?(@.name==''{#ES.NODE}'')].thread_pool.write.completed.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61571','30735','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61572','30736','1','12','$..[?(@.name==''{#ES.NODE}'')].thread_pool.write.queue.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61573','30737','1','12','$..[?(@.name==''{#ES.NODE}'')].thread_pool.refresh.queue.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61574','30738','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.search.query_current.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61575','30739','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.search.query_time_in_millis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61576','30739','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61577','30740','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.indexing.throttle_time_in_millis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61578','30740','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61579','30740','3','9','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61580','30741','1','12','$..[?(@.name==''{#ES.NODE}'')].http.current_open.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61581','30741','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61582','30742','1','12','$..[?(@.name==''{#ES.NODE}'')].http.total_opened.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61583','30742','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61584','30743','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.flush.total_time_in_millis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61585','30743','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61586','30744','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.flush.total.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61587','30744','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61588','30745','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.indexing.index_current.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61589','30745','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61590','30746','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.indexing.index_time_in_millis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61591','30746','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61592','30747','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.indexing.index_total.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61593','30747','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61594','30748','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.merges.total_throttled_time_in_millis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61595','30748','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61596','30748','3','9','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61597','30749','1','12','$..[?(@.name==''{#ES.NODE}'')].fs.total.total_in_bytes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61598','30749','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61599','30750','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.recovery.throttle_time_in_millis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61600','30750','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61601','30750','3','9','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61602','30751','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.refresh.total.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61603','30751','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61604','30752','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.refresh.total_time_in_millis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61605','30752','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61606','30752','3','9','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61607','30753','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.search.fetch_current.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61608','30754','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.search.fetch_time_in_millis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61609','30754','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61610','30755','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.search.fetch_time_in_millis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61611','30755','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61612','30755','3','9','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61613','30756','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.search.fetch_total.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61614','30756','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61615','30757','1','12','$..[?(@.name==''{#ES.NODE}'')].indices.search.fetch_total.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61616','30757','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61617','30758','1','12','$..[?(@.name==''{#ES.NODE}'')].thread_pool.write.rejected.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61618','30758','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61619','30923','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61620','30924','1','12','$.health','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61621','30924','2','6','','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61622','30924','3','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61623','30927','1','22','process_open_fds
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61624','30928','1','22','etcd_server_proposals_applied_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61625','30928','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61626','30929','1','22','etcd_server_proposals_committed_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61627','30929','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61628','30930','1','22','etcd_server_proposals_failed_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61629','30930','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61630','30931','1','22','etcd_server_proposals_pending
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61631','30932','1','22','etcd_debugging_mvcc_put_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61632','30932','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61633','30933','1','22','etcd_debugging_mvcc_range_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61634','30933','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61635','30934','1','23','etcd_debugging_store_reads_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61636','30934','2','21','//calculates total reads
var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61637','30934','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61638','30935','1','22','etcd_network_client_grpc_received_bytes_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61639','30935','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61640','30936','1','22','process_resident_memory_bytes
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61641','30937','1','12','$.etcdserver','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61642','30937','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61643','30938','1','22','etcd_debugging_mvcc_range_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61644','30938','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61645','30939','1','22','process_start_time_seconds
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61646','30939','2','21','//use boottime to calculate uptime
return (Math.floor(Date.now()/1000)-Number(value));','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61647','30940','1','22','process_virtual_memory_bytes
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61648','30941','1','23','etcd_debugging_store_writes_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61649','30941','2','21','var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61650','30941','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61651','30942','1','22','etcd_network_client_grpc_sent_bytes_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61652','30942','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61653','30943','1','12','$.etcdcluster','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61654','30943','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61655','30944','1','22','process_max_fds
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61656','30945','1','22','etcd_server_has_leader
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61657','30945','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61658','30946','1','22','etcd_debugging_mvcc_db_total_size_in_bytes
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61659','30947','1','22','etcd_debugging_mvcc_delete_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61660','30947','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61661','30948','1','22','etcd_debugging_mvcc_pending_events_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61662','30949','1','23','grpc_server_msg_received_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61663','30949','2','21','var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61664','30949','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61665','30950','1','23','grpc_server_msg_sent_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61666','30950','2','21','var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61667','30950','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61668','30951','1','23','grpc_server_started_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61669','30951','2','21','var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61670','30951','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61671','30952','1','23','etcd_http_failed_total{code=~"4.+"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61672','30952','2','21','var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61673','30952','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61674','30953','1','22','process_cpu_seconds_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61675','30953','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61676','30954','1','23','etcd_http_failed_total{code=~"5.+"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61677','30954','2','21','var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61678','30954','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61679','30955','1','23','etcd_http_received_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61680','30955','2','21','var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61681','30955','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61682','30956','1','22','etcd_server_is_leader
','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61683','30956','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61684','30957','1','22','etcd_debugging_mvcc_db_compaction_keys_total
','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61685','30957','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61686','30958','1','22','etcd_debugging_store_expires_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61687','30958','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61688','30959','1','22','etcd_debugging_mvcc_keys_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61689','30960','1','22','etcd_server_leader_changes_seen_total
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61690','30961','1','23','grpc_server_handled_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61691','30961','2','21','var data = JSON.parse(value),
 lookup = {},
 result =[];
for (var item, i = 0; item = data[i++];) {
 var code = item.labels.grpc_code;
 if (!(code in lookup)) {
  lookup[code] = 1;
  result.push({ "{#GRPC.CODE}": code});
}
}
return JSON.stringify(result);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61692','30961','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61693','30962','1','23','etcd_network_peer_sent_bytes_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61694','30963','1','23','grpc_server_handled_total{grpc_method="{#GRPC.CODE}"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61695','30963','2','21','var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61696','30963','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61697','30964','1','22','etcd_network_peer_received_bytes_total{From="{#ETCD.PEER}"}
','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61698','30964','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61699','30965','1','22','etcd_network_peer_sent_bytes_total{To="{#ETCD.PEER}"}
','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61700','30965','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61701','30966','1','22','etcd_network_peer_received_failures_total{To="{#ETCD.PEER}"}
','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61702','30966','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61703','30967','1','22','etcd_network_peer_sent_failures_total{To="{#ETCD.PEER}"}
','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61704','30967','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61705','31499','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61706','31501','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61707','31504','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61708','31507','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61709','31510','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61710','31512','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61711','31516','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61712','31518','1','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61713','31519','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61714','31520','1','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61715','31521','1','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61716','31522','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61717','31526','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61718','31527','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61719','31528','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61720','31529','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61721','31530','1','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61722','31531','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61723','31531','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61724','31532','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61725','31533','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61726','31533','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61727','31534','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61728','31535','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61729','31535','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61730','31536','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61731','31537','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61732','31537','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61733','31538','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61734','31539','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61735','31539','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61736','31540','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61737','31540','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61738','31542','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61739','31543','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61740','31543','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61741','31545','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61742','31546','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61743','31547','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61744','31548','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61745','31549','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61746','31550','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61747','31551','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61748','32012','1','21','try {
  parsed = JSON.parse(value);
  var result = [];

  function getNodes(nodes, state) {
      Object.keys(nodes).forEach(function (field) {
          var Node = {};
          Node[''HostName''] = field || '''';
          Node[''adminState''] = nodes[field].adminState || '''';
          Node[''operState''] = state || '''';
          Node[''version''] = nodes[field].version || '''';
          result.push(Node);
      });
  }

  getNodes(JSON.parse(parsed.beans[0].LiveNodes), ''Live'');
  getNodes(JSON.parse(parsed.beans[0].DeadNodes), ''Dead'');
  getNodes(JSON.parse(parsed.beans[0].DecomNodes), ''Decommission'');
  getNodes(JSON.parse(parsed.beans[0].EnteringMaintenanceNodes), ''Maintenance'');

  return JSON.stringify(result);
}
catch (error) {
  throw ''Failed to process response received from Hadoop'';
}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61749','32013','1','21','return JSON.stringify(JSON.parse(JSON.parse(value).beans[0].LiveNodeManagers))','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61750','32014','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61751','32018','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61752','32020','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].MissingBlocks.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61753','32021','1','12','$.beans[?(@.name==''Hadoop:service=ResourceManager,name=ClusterMetrics'')].NumDecommissionedNMs.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61754','32022','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].BlocksTotal.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61755','32023','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].CapacityRemaining.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61756','32024','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].CorruptBlocks.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61757','32025','1','12','$.beans[?(@.name==''java.lang:type=Runtime'')].Uptime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61758','32025','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61759','32026','1','12','$.beans[?(@.name==''Hadoop:service=ResourceManager,name=RpcActivityForPort8031'')].RpcProcessingTimeAvgTime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61760','32027','1','12','$.beans[?(@.name==''Hadoop:service=ResourceManager,name=ClusterMetrics'')].NumUnhealthyNMs.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61761','32028','1','12','$.beans[?(@.name==''Hadoop:service=ResourceManager,name=ClusterMetrics'')].NumShutdownNMs.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61762','32029','1','12','$.beans[?(@.name==''Hadoop:service=ResourceManager,name=ClusterMetrics'')].NumRebootedNMs.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61763','32030','1','12','$.beans[?(@.name==''Hadoop:service=ResourceManager,name=ClusterMetrics'')].NumLostNMs.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61764','32030','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61765','32031','1','12','$.beans[?(@.name==''Hadoop:service=ResourceManager,name=ClusterMetrics'')].NumDecommissioningNMs.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61766','32031','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61767','32032','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].FilesTotal.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61768','32033','1','12','$.beans[?(@.name==''Hadoop:service=ResourceManager,name=ClusterMetrics'')].NumActiveNMs.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61769','32033','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61770','32034','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].NumDeadDataNodes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61771','32034','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61772','32035','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].VolumeFailuresTotal.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61773','32036','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].BlockCapacity.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61774','32037','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].UnderReplicatedBlocks.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61775','32038','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].TransactionsSinceLastCheckpoint.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61776','32039','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].TotalLoad.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61777','32040','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=RpcActivityForPort9000'')].RpcProcessingTimeAvgTime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61778','32041','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=NameNodeInfo'')].PercentRemaining.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61779','32041','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61780','32042','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=NameNodeInfo'')].PercentBlockPoolUsed.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61781','32043','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].StaleDataNodes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61782','32043','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61783','32044','1','12','$.beans[?(@.name==''Hadoop:service=NameNode,name=FSNamesystem'')].NumLiveDataNodes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61784','32044','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61785','32045','1','12','$.beans[?(@.name==''java.lang:type=Runtime'')].Uptime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61786','32045','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61787','32046','1','21','try{
  parsed = JSON.parse(value);
  var result = [];

  function getNodes(nodes) {
      Object.keys(nodes).forEach(function (field) {
          var Node = {};
          Node[''{#HOSTNAME}''] = field || '''';
          Node[''{#INFOADDR}''] = nodes[field].infoAddr || '''';
          result.push(Node);
      });
  }

  getNodes(JSON.parse(parsed.beans[0].LiveNodes));
  getNodes(JSON.parse(parsed.beans[0].DeadNodes));
  getNodes(JSON.parse(parsed.beans[0].DecomNodes));
  getNodes(JSON.parse(parsed.beans[0].EnteringMaintenanceNodes));

  return JSON.stringify(result);
}
catch (error) {
  throw ''Failed to process response received from Hadoop.'';
}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61788','32047','1','21','try {
  parsed = JSON.parse(value);
  var result = [];

  function getNodes(nodes) {
      Object.keys(nodes).forEach(function (field) {
          var Node = {};
          Node[''{#HOSTNAME}''] = nodes[field].HostName || '''';
          Node[''{#NODEHTTPADDRESS}''] = nodes[field].NodeHTTPAddress || '''';
          result.push(Node);
      });
  }

  getNodes(JSON.parse(parsed.beans[0].LiveNodeManagers));

  return JSON.stringify(result);
}
catch (error) {
  throw ''Failed to process response received from Hadoop.'';
}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61789','32050','1','12','$.[?(@.HostName==''{#HOSTNAME}'')].adminState.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61790','32050','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61791','32051','1','12','$.beans[?(@.name==''Hadoop:service=DataNode,name=FSDatasetState'')].DfsUsed.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61792','32052','1','12','$.beans[?(@.name==''Hadoop:service=DataNode,name=JvmMetrics'')].GcTimeMillis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61793','32053','1','12','$.beans[?(@.name==''Hadoop:service=DataNode,name=JvmMetrics'')].MemHeapUsedM.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61794','32054','1','12','$.beans[?(@.name==''java.lang:type=Threading'')].ThreadCount.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61795','32055','1','12','$.beans[?(@.name==''Hadoop:service=DataNode,name=FSDatasetState'')].NumFailedVolumes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61796','32056','1','12','$.[?(@.HostName==''{#HOSTNAME}'')].operState.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61797','32056','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61798','32057','1','12','$.beans[?(@.name==''Hadoop:service=DataNode,name=FSDatasetState'')].Remaining.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61799','32058','1','12','$.beans[?(@.name==''java.lang:type=Runtime'')].Uptime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61800','32058','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61801','32059','1','12','$.[?(@.HostName==''{#HOSTNAME}'')].version.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61802','32059','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61803','32060','1','12','$[?(@.HostName==''{#HOSTNAME}'')].AvailableMemoryMB.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61804','32061','1','12','$.beans[?(@.name==''Hadoop:service=NodeManager,name=NodeManagerMetrics'')].ContainerLaunchDurationAvgTime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61805','32062','1','12','$.beans[?(@.name==''Hadoop:service=NodeManager,name=JvmMetrics'')].GcTimeMillis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61806','32063','1','12','$.beans[?(@.name==''Hadoop:service=NodeManager,name=JvmMetrics'')].MemHeapUsedM.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61807','32064','1','12','$.beans[?(@.name==''java.lang:type=Threading'')].ThreadCount.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61808','32065','1','12','$[?(@.HostName==''{#HOSTNAME}'')].NumContainers.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61809','32066','1','12','$.beans[?(@.name==''Hadoop:service=NodeManager,name=RpcActivityForPort8040'')].RpcProcessingTimeAvgTime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61810','32067','1','12','$[?(@.HostName==''{#HOSTNAME}'')].State.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61811','32067','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61812','32068','1','12','$.beans[?(@.name==''java.lang:type=Runtime'')].Uptime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61813','32068','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61814','32069','1','12','$[?(@.HostName==''{#HOSTNAME}'')].UsedMemoryMB.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61815','32070','1','12','$[?(@.HostName==''{#HOSTNAME}'')].NodeManagerVersion.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61816','32070','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61817','30188','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61818','30189','1','5','# ([\s\S]*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61819','30189','2','24','

1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61820','30191','1','21','try {
    var t = value.match(/(\d+)d (\d+)h(\d+)m(\d+)s/);
    return t[1] * 86400 + t[2] * 3600 + t[3] * 60 + t[4] * 1;
}
catch (error) {
    throw "HAProxy uptime is not found : " + error;
}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61821','30192','1','5','HAProxy version ([^,]*),
\1','3','HAProxy version is not found');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61822','30192','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61939','30230','1','5','# ([\s\S]*)\n
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61940','30230','2','24','

1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61941','30790','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61942','30234','1','21','try {
    var t = value.match(/(\d+)d (\d+)h(\d+)m(\d+)s/);
    return t[1] * 86400 + t[2] * 3600 + t[3] * 60 + t[4] * 1;
}
catch (error) {
    throw "HAProxy uptime is not found : " + error;
}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61943','30235','1','5','HAProxy version ([^,]*),
\1','3','HAProxy version is not found');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('61944','30235','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62061','30968','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62062','30969','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62063','30970','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62064','30971','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62065','30972','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62066','30973','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62067','30974','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62068','30976','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62069','30977','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62070','30978','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62071','30979','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62072','30980','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62073','30981','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62074','30982','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62075','30983','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62076','30984','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62077','30985','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62078','30986','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62079','30992','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62080','30993','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62081','30994','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62082','30995','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62083','30997','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62084','30998','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62085','30999','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62086','31000','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62087','31001','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62088','31002','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62089','31003','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62090','31004','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62091','31006','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62092','31008','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62093','31009','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62094','31010','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62095','31011','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62096','31012','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62097','31013','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62098','31014','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62099','31015','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62100','31016','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62101','31018','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62102','31019','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62103','31020','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62104','31021','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62105','31022','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62106','31023','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62107','31024','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62108','31025','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62109','31026','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62110','31027','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62111','31028','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62112','31034','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62113','31035','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62114','31036','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62115','31037','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62116','31039','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62117','31040','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62118','31041','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62119','31042','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62120','31043','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62121','31044','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62122','31045','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62123','31046','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62124','31048','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62125','31050','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62126','31051','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62127','32072','1','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62128','32074','1','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62129','32075','1','21','return (Math.floor((Date.now()-Number(value))/1000))','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62130','32076','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62131','32077','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62132','32078','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62133','32079','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62134','32080','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62135','32081','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62136','32082','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62137','32087','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62138','32088','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62139','32095','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62140','32096','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62141','32097','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62142','32098','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62143','32099','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62144','32102','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62145','32104','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62146','32136','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62147','32137','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62148','32138','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62149','32139','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62150','30611','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62151','30613','1','12','$.cmd_flush','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62152','30613','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62153','30614','1','12','$.bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62154','30615','1','12','$.uptime','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62155','30616','1','12','$.total_items','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62156','30616','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62157','30617','1','12','$.threads','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62158','30618','1','12','$.get_misses','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62159','30618','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62160','30619','1','12','$.get_hits','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62161','30619','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62162','30620','1','12','$.evictions','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62163','30620','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62164','30621','1','12','$.curr_items','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62165','30622','1','12','$.bytes_written','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62166','30622','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62167','30623','1','12','$.bytes_read','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62168','30623','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62169','30624','1','12','$.pid','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62170','30624','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62171','30625','1','12','$.cmd_get','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62172','30625','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62173','30626','1','12','$.rusage_user','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62174','30627','1','12','$.rusage_system','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62175','30628','1','12','$.conn_yields','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62176','30628','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62177','30629','1','12','$.connection_structures','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62178','30630','1','12','$.total_connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62179','30630','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62180','30631','1','12','$.listen_disabled_num','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62181','30631','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62182','30632','1','12','$.max_connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62183','30632','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62184','30633','1','12','$.curr_connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62185','30634','1','12','$.limit_maxbytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62186','30634','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62187','30635','1','12','$.cmd_set','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62188','30635','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62189','30636','1','12','$.version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62190','30636','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62191','28810','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62192','28811','1','5','Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)
\3','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62193','28812','1','5','Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)
\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62194','28813','1','5','Active connections: ([0-9]+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62195','28814','1','5','Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62196','28815','1','5','server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)
\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62197','28815','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62198','28816','1','21','var a = value.match(/server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)/)
if (a) {
    return a[1]-a[2]
}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62199','28816','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62200','28817','1','5','server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62201','28817','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62202','28818','1','5','server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)
\3','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62203','28818','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62204','28819','1','5','server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)
\3','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62205','28820','1','5','Server: nginx\/(.+(?<!\r))
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62206','28820','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62207','28822','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62208','28824','1','5','server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)
\3','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62209','28825','1','5','server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)
\3','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62210','28825','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62211','28826','1','5','server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62212','28826','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62213','28827','1','21','var a = value.match(/server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)/)
if (a) {
    return a[1]-a[2]
}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62214','28827','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62215','28828','1','5','server accepts handled requests\s+([0-9]+) ([0-9]+) ([0-9]+)
\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62216','28828','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62217','28829','1','5','Active connections: ([0-9]+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62218','28830','1','5','Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62219','28831','1','5','Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)
\3','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62220','28832','1','5','Reading: ([0-9]+) Writing: ([0-9]+) Waiting: ([0-9]+)
\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62221','28833','1','5','Server: nginx\/(.+(?<!\r))
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62222','28833','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62223','31868','1','5','^[.\s\S]*({.+})
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62224','31875','1','12','$.[''slow requests'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62225','31875','2','9','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62226','31876','1','5','^[.\s\S]*X-Powered-By: PHP/([.\d]{1,})
\1','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62227','31876','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62228','31877','1','12','$.[''start since'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62229','31878','1','12','$.[''start time'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62230','31879','1','12','$.[''accepted conn'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62231','31879','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62232','31880','1','12','$.[''total processes'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62233','31881','1','12','$.[''listen queue'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62234','31882','1','12','$.[''idle processes'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62235','31883','1','12','$.[''active processes'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62236','31884','1','12','$.[''process manager'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62237','31884','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62238','31885','1','5','{$PHP_FPM.PING.REPLY}($|\n)
1','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62239','31886','1','12','$.pool','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62240','31886','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62241','31887','1','12','$.[''max children reached'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62242','31887','2','9','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62243','31888','1','12','$.[''max listen queue'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62244','31889','1','12','$.[''listen queue len'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62245','31890','1','12','$.[''max active processes'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62246','31894','1','12','$.[''accepted conn'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62247','31894','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62248','31895','1','12','$.[''idle processes'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62249','31896','1','12','$.[''start since'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62250','31897','1','12','$.[''start time'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62251','31898','1','12','$.[''slow requests'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62252','31898','2','9','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62253','31899','1','12','$.[''total processes'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62254','31900','1','12','$.[''max active processes'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62255','31901','1','5','{$PHP_FPM.PING.REPLY}($|\n)
1','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62256','31902','1','12','$.[''active processes'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62257','31903','1','12','$.[''process manager'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62258','31903','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62259','31904','1','12','$.pool','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62260','31904','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62261','31905','1','12','$.[''max children reached'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62262','31905','2','9','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62263','31906','1','12','$.[''max listen queue'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62264','31907','1','12','$.[''listen queue len'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62265','31908','1','12','$.[''listen queue'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62266','31909','1','5','^[.\s\S]*X-Powered-By: PHP/([.\d]{1,})
\1','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62267','31909','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62268','29653','1','5','\n\s?\n(.*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62269','29654','1','5','\n\s?\n(.*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62270','29655','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62271','29661','1','5','\n\s?\n(.*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62272','29662','1','5','\n\s?\n(.*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62273','29662','2','12','$.status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62274','29662','3','6','','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62275','29998','1','5','\n\s?\n(.*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62276','29999','1','5','\n\s?\n(.*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62277','29687','1','12','$.mem_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62278','29688','1','12','$.disk_free_alarm','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62279','29688','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62280','29691','1','12','$.fd_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62281','29692','1','12','$.uptime','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62282','29692','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62283','29693','1','12','$.mem_alarm','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62284','29693','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62285','29694','1','12','$.mem_limit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62286','29695','1','12','$.running','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62287','29695','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62288','29696','1','12','$.partitions','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62289','29696','2','21','return JSON.parse(value).length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62290','29697','1','12','$.sockets_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62291','29698','1','12','$.disk_free','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62292','29699','1','12','$.run_queue','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62293','29700','1','12','$.disk_free_limit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62294','29701','1','12','$.sockets_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62295','30000','1','12','$.message_stats.redeliver','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62296','30001','1','12','$.message_stats.return_unroutable_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62297','30002','1','12','$.message_stats.return_unroutable','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62298','30003','1','12','$.message_stats.publish_out_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62299','30004','1','12','$.message_stats.publish_out','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62300','30005','1','12','$.message_stats.publish_in_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62301','30006','1','12','$.message_stats.publish_in','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62302','30007','1','12','$.message_stats.publish_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62303','30008','1','12','$.message_stats.publish','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62304','30009','1','12','$.message_stats.deliver_get_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62305','30010','1','12','$.message_stats.deliver_get','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62306','30011','1','12','$.message_stats.confirm_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62307','30012','1','12','$.message_stats.confirm','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62308','30013','1','12','$.message_stats.ack_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62309','30014','1','12','$.message_stats.ack','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62310','30015','1','12','$.queue_totals.messages_unacknowledged','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62311','30016','1','12','$.queue_totals.messages_ready','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62312','30017','1','12','$.queue_totals.messages','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62313','30018','1','12','$.object_totals.exchanges','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62314','30019','1','12','$.object_totals.consumers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62315','30020','1','12','$.object_totals.queues','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62316','30021','1','12','$.object_totals.channels','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62317','30022','1','12','$.object_totals.connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62318','30023','1','12','$.message_stats.redeliver_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62319','30024','1','12','$.management_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62320','30024','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62321','30025','1','12','$.rabbitmq_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62322','30025','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62323','29720','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62324','29721','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62325','29722','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.redeliver.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62326','29723','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.publish_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62327','29724','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.publish.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62328','29725','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver_get_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62329','29726','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver_get.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62330','29727','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62331','29728','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.ack_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62332','29729','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_details.rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62333','29730','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.ack.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62334','29731','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_unacknowledged_details.rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62335','29732','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_unacknowledged.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62336','29733','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_ready_details.rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62337','29734','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_ready.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62338','29735','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].memory.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62339','29736','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].consumers.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62340','29737','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.redeliver_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62341','30027','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.ack.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62342','30028','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.ack_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62343','30029','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.confirm.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62344','30030','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.confirm_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62345','30031','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.deliver_get.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62346','30032','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.deliver_get_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62347','30033','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62348','30034','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62349','30035','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_in.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62350','30036','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_in_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62351','30037','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_out.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62352','30038','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_out_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62353','30039','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.return_unroutable.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62354','30040','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.return_unroutable_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62355','30041','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.redeliver.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62356','30042','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.redeliver_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62357','29742','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62358','29744','1','12','$.status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62359','29744','2','6','','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62360','29746','1','12','$.message_stats.redeliver','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62361','29747','1','12','$.message_stats.return_unroutable_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62362','29748','1','12','$.message_stats.return_unroutable','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62363','29749','1','12','$.message_stats.publish_out_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62364','29750','1','12','$.message_stats.publish_out','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62365','29751','1','12','$.message_stats.publish_in_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62366','29752','1','12','$.message_stats.publish_in','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62367','29753','1','12','$.message_stats.publish_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62368','29754','1','12','$.message_stats.publish','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62369','29755','1','12','$.message_stats.deliver_get_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62370','29756','1','12','$.message_stats.deliver_get','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62371','29757','1','12','$.message_stats.confirm_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62372','29758','1','12','$.message_stats.confirm','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62373','29759','1','12','$.message_stats.ack_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62374','29760','1','12','$.message_stats.ack','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62375','29761','1','12','$.queue_totals.messages_unacknowledged','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62376','29762','1','12','$.queue_totals.messages_ready','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62377','29763','1','12','$.queue_totals.messages','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62378','29764','1','12','$.object_totals.exchanges','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62379','29765','1','12','$.object_totals.consumers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62380','29766','1','12','$.object_totals.queues','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62381','29767','1','12','$.object_totals.channels','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62382','29768','1','12','$.object_totals.connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62383','29769','1','12','$.message_stats.redeliver_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62384','29771','1','12','$.partitions','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62385','29771','2','21','return JSON.parse(value).length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62386','29772','1','12','$.uptime','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62387','29772','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62388','29773','1','12','$.disk_free_alarm','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62389','29773','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62390','29774','1','12','$.mem_alarm','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62391','29774','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62392','29775','1','12','$.running','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62393','29775','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62394','29776','1','12','$.sockets_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62395','29777','1','12','$.sockets_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62396','29779','1','12','$.run_queue','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62397','29780','1','12','$.mem_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62398','29781','1','12','$.disk_free_limit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62399','29782','1','12','$.disk_free','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62400','29783','1','12','$.fd_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62401','29784','1','12','$.mem_limit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62402','30044','1','12','$.management_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62403','30044','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62404','30045','1','12','$.rabbitmq_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62405','30045','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62406','29787','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.ack.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62407','29788','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.ack_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62408','29789','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.confirm.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62409','29790','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.confirm_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62410','29791','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.deliver_get.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62411','29792','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.deliver_get_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62412','29793','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62413','29794','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62414','29795','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_in.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62415','29796','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_in_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62416','29797','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_out.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62417','29798','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_out_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62418','29799','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.return_unroutable.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62419','29800','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.return_unroutable_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62420','29801','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.redeliver.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62421','29802','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.redeliver_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62422','29803','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62423','29804','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62424','29805','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.redeliver.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62425','29806','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.publish_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62426','29807','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.publish.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62427','29808','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver_get_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62428','29809','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver_get.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62429','29810','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62430','29811','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.ack_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62431','29812','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_details.rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62432','29813','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.ack.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62433','29814','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_unacknowledged_details.rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62434','29815','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_unacknowledged.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62435','29816','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_ready_details.rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62436','29817','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_ready.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62437','29818','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].memory.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62438','29819','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].consumers.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62439','29820','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.redeliver_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62440','31910','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62441','31912','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62442','31913','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62443','31914','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62444','31915','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62445','31916','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62446','31917','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62447','31918','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62448','31919','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62449','31920','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62450','31921','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62451','31922','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62452','31923','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62453','31932','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62454','31933','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62455','31934','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62456','31935','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62457','31936','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62458','31936','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62459','31938','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62460','31941','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62462','31946','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62463','31947','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62464','31948','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62465','31949','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62466','31950','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62467','31951','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62468','31951','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62469','31952','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62470','31953','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62471','31954','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62472','31955','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62473','31956','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62474','31957','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62475','31958','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62476','31959','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62477','31959','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62478','31960','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62479','31961','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62480','31962','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62481','31962','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62482','31963','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62483','28511','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62484','32144','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62485','32145','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62486','32146','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62487','32147','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62488','32148','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62489','32149','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62490','32153','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62491','32154','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62492','32155','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62493','32157','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62494','31555','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62495','31556','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62496','31557','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62497','31562','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62498','31563','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62499','31567','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62500','31571','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62501','31572','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62502','31576','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62503','31591','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62504','31594','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62505','31595','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62506','31620','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62507','32160','1','12','$.approximate_data_size','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62508','32161','1','12','$.outstanding_requests','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62509','32162','1','12','$.max_latency','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62510','32163','1','12','$.min_latency','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62511','32164','1','12','$.num_alive_connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62512','32165','1','12','$.open_file_descriptor_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62513','32166','1','12','$.packets_received','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62514','32166','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62515','32167','1','12','$.looking_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62516','32167','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62517','32168','1','12','$.packets_sent','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62518','32168','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62519','32169','1','12','$.revalidate_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62520','32169','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62521','32170','1','12','$.server_state','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62522','32170','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62523','32171','1','12','$.snap_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62524','32171','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62525','32172','1','12','$.uptime','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62526','32172','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62527','32173','1','12','$.version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62528','32173','2','5','([^,]+)--(.+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62529','32173','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62530','32174','1','12','$.watch_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62531','32175','1','12','$.max_file_descriptor_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62532','32175','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62533','32176','1','12','$.global_sessions','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62534','32177','1','12','$.local_sessions','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62535','32178','1','21','var metrics = JSON.parse(value),
    res = metrics.avg_election_time || metrics[''election_time{quantile="0.5"}''];
if (isNaN(res)) {
    return 0;
}
return res;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62536','32179','1','12','$.ephemerals_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62537','32180','1','12','$.diff_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62538','32180','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62539','32181','1','12','$.connection_revalidate_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62540','32181','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62541','32182','1','12','$.connection_rejected','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62542','32182','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62543','32183','1','12','$.connection_drop_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62544','32183','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62545','32184','1','12','$.commit_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62546','32184','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62547','32185','1','21','var metrics = JSON.parse(value)
return metrics.snapshottime_count || metrics.cnt_snapshottime','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62548','32186','1','21','var metrics = JSON.parse(value)
return metrics.cnt_fsynctime || metrics.fsynctime_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62549','32187','1','21','var metrics = JSON.parse(value);
if (metrics.server_state === "standalone") { 
    return 0 
    }
else {
    return metrics.cnt_election_time || metrics.election_time_count
}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62550','32188','1','12','$.bytes_received_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62551','32188','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62552','32189','1','21','var metrics = JSON.parse(value),
    res = metrics[''snapshottime{quantile="0.5"}''] || metrics.avg_snapshottime ;
if (isNaN(res)) {
    return 0;
}
return res;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62553','32190','1','12','$.avg_latency','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62554','32191','1','21','var metrics = JSON.parse(value),
    res = metrics.avg_fsynctime || metrics[''fsynctime{quantile="0.5"}''];
if (isNaN(res)) {
    return 0;
}
return res;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62555','32192','1','12','$.znode_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62556','32192','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62557','32193','1','21','var source = JSON.parse(value),
    data = [];

source.connections.forEach(function(v){
    data.push({
        "{#ADDRESS}": v.remote_socket_address,
        "{#CLIENT}": v.remote_socket_address.split('':'')[0],
        "{#TYPE}": "connections"})
});

source.secure_connections.forEach(function(v){
data.push({
    "{#ADDRESS}": v.remote_socket_address,
    "{#CLIENT}":v.remote_socket_address.split('':'')[0],
    "{#TYPE}": "secure_connections"})
});

return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62558','32194','1','12','$.server_state','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62559','32194','2','21','return JSON.stringify(value == ''leader'' ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62560','32195','1','12','$.{#TYPE}.[?(@.remote_socket_address == "{#ADDRESS}")].avg_latency.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62561','32196','1','12','$.{#TYPE}.[?(@.remote_socket_address == "{#ADDRESS}")].max_latency.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62562','32197','1','12','$.{#TYPE}.[?(@.remote_socket_address == "{#ADDRESS}")].min_latency.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62563','32198','1','12','$.{#TYPE}.[?(@.remote_socket_address == "{#ADDRESS}")].outstanding_requests.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62564','32199','1','12','$.{#TYPE}.[?(@.remote_socket_address == "{#ADDRESS}")].packets_received.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62565','32199','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62566','32200','1','12','$.{#TYPE}.[?(@.remote_socket_address == "{#ADDRESS}")].packets_sent.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62567','32200','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62568','32201','1','12','$.learners','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62569','32202','1','12','$.pending_syncs','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62570','32203','1','12','$.quorum_size','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62571','32204','1','12','$.synced_followers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62572','32205','1','12','$.synced_non_voting_followers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62573','32206','1','12','$.synced_observers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62574','28586','1','12','$.queue','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62575','28587','1','12','$.queue','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62576','28588','1','12','$.data.process[''vmware collector''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62577','28589','1','12','$.data.wcache.values.uint','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62578','28589','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62579','28590','1','12','$.data.wcache.values.text','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62580','28590','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62581','28591','1','12','$.data.wcache.values.str','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62582','28591','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62583','28592','1','12','$.data.wcache.values[''not supported'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62584','28592','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62585','28593','1','12','$.data.wcache.values.log','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62586','28593','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62587','28594','1','12','$.data.wcache.values.float','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62588','28594','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62589','28595','1','12','$.data.wcache.values.all','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62590','28595','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62591','28596','1','12','$.data.wcache.index.pused','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62592','28597','1','12','$.data.wcache.history.pused','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62593','28598','1','12','$.data.vmware.pused','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62594','28599','1','12','$.data.rcache.pused','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62595','28600','1','12','$.data.process[''configuration syncer''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62596','28601','1','12','$.data.process[''data sender''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62597','28602','1','12','$.data.process.trapper.busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62598','28603','1','12','$.data.process[''task manager''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62599','28604','1','12','$.data.process[''snmp trapper''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62600','28605','1','12','$.data.process[''self-monitoring''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62601','28606','1','12','$.data.process.poller.busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62602','28607','1','12','$.data.process[''java poller''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62603','28608','1','12','$.data.process[''ipmi poller''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62604','28609','1','12','$.data.process[''ipmi manager''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62605','28610','1','12','$.data.process[''icmp pinger''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62606','28611','1','12','$.data.process[''http poller''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62607','28612','1','12','$.data.process.housekeeper.busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62608','28613','1','12','$.data.process[''history syncer''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62609','28614','1','12','$.data.process[''heartbeat sender''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62610','28615','1','12','$.data.process.discoverer.busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62611','28616','1','12','$.data.process[''unreachable poller''].busy.avg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62612','31052','1','12','$.data.version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62613','31052','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62614','28540','1','12','$.queue','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62615','28541','1','12','$.queue','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62616','28542','1','12','$.data.wcache.index.pused','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62617','28543','1','12','$.data.rcache.pused','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62618','28544','1','12','$.data.vcache.buffer.pused','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62619','28545','1','12','$.data.vcache.cache.hits','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62620','28545','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62621','28546','1','12','$.data.vcache.cache.misses','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62622','28546','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62623','28547','1','12','$.data.vcache.cache.mode','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62624','28548','1','12','$.data.vmware.pused','3','No vmware collector processes started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62625','28549','1','12','$.data.wcache.history.pused','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62626','28550','1','12','$.data.wcache.values.all','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62627','28550','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62628','28551','1','12','$.data.wcache.trend.pused','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62629','28552','1','12','$.data.process[''unreachable poller''].busy.avg','3','Processes unreachable poller not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62630','28553','1','12','$.data.wcache.values.float','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62631','28553','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62632','28554','1','12','$.data.wcache.values.log','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62633','28554','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62634','28555','1','12','$.data.wcache.values[''not supported'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62635','28555','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62636','28556','1','12','$.data.wcache.values.str','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62637','28556','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62638','28557','1','12','$.data.wcache.values.text','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62639','28557','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62640','28558','1','12','$.data.wcache.values.uint','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62641','28558','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62642','28559','1','12','$.data.process[''vmware collector''].busy.avg','3','Processes vmware collector not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62643','28560','1','12','$.data.preprocessing_queue','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62644','28561','1','12','$.data.process[''alerter''].busy.avg','3','Processes alerter not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62645','28562','1','12','$.data.process[''ipmi manager''].busy.avg','3','Processes ipmi manager not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62646','28563','1','12','$.data.process[''alert manager''].busy.avg','3','Processes alert manager not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62647','28564','1','12','$.data.process[''configuration syncer''].busy.avg','3','Processes configuration syncer not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62648','28565','1','12','$.data.process[''discoverer''].busy.avg','3','Processes discoverer not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62649','28566','1','12','$.data.process[''escalator''].busy.avg','3','Processes escalator not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62650','28567','1','12','$.data.process[''history syncer''].busy.avg','3','Processes history syncer not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62651','28568','1','12','$.data.process[''housekeeper''].busy.avg','3','Processes housekeeper not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62652','28569','1','12','$.data.process[''http poller''].busy.avg','3','Processes http poller not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62653','28570','1','12','$.data.process[''icmp pinger''].busy.avg','3','Processes icmp pinger not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62654','28571','1','12','$.data.process[''ipmi poller''].busy.avg','3','Processes ipmi poller not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62655','28572','1','12','$.data.process[''timer''].busy.avg','3','Processes timer not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62656','28573','1','12','$.data.process[''java poller''].busy.avg','3','Processes java poller not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62657','28574','1','12','$.data.process[''poller''].busy.avg','3','Processes poller not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62658','28575','1','12','$.data.process[''preprocessing manager''].busy.avg','3','Processes preprocessing manager not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62659','28576','1','12','$.data.process[''preprocessing worker''].busy.avg','3','Processes preprocessing worker not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62660','28577','1','12','$.data.process[''proxy poller''].busy.avg','3','Processes proxy poller not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62661','28578','1','12','$.data.process[''self-monitoring''].busy.avg','3','Processes self-monitoring not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62662','28579','1','12','$.data.process[''snmp trapper''].busy.avg','3','Processes snmp trapper not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62663','28580','1','12','$.data.process[''task manager''].busy.avg','3','Processes task manager not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62664','28581','1','12','$.data.process[''trapper''].busy.avg','3','Processes trapper not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62665','28582','1','12','$.data.process[''lld manager''].busy.avg','3','Processes LLD manager not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62666','28583','1','12','$.data.process[''lld worker''].busy.avg','3','Processes LLD worker not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62667','28584','1','12','$.data.lld_queue','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62668','29821','1','12','$.data.process[''alert syncer''].busy.avg','3','Processes alert syncer not started');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62669','31053','1','12','$.data.version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62670','31053','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62671','10067','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62672','10068','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62673','10069','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62674','10070','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62675','10071','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62676','10072','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62677','23340','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62678','10061','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62679','10062','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62680','10063','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62681','10064','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62682','10065','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62683','10066','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62684','22187','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62685','22196','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62686','22199','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62687','10073','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62688','10074','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62689','10075','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62690','10076','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62691','10077','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62692','10078','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62693','23277','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62694','23625','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62695','23628','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62696','22920','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62697','22924','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62698','22945','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62699','22945','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62700','22946','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62701','22946','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62702','22880','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62703','22884','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62704','23073','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62705','23073','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62706','23074','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62707','23074','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62708','22985','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62709','22985','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62710','22986','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62711','22986','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62712','23077','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62713','23077','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62714','23078','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62715','23078','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62716','22840','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62717','22844','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62718','23075','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62719','23075','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62720','23076','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62721','23076','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62722','23000','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62723','23004','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62724','23025','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62725','23025','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62726','23026','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62727','23026','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62728','32207','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62729','32238','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62730','32241','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62731','32242','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62732','32245','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62733','32246','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62734','32247','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62735','32250','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62736','32251','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62737','32252','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62738','32253','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62739','32255','1','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62740','32256','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62741','32261','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62742','32262','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62743','32263','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62744','32264','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62745','32265','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62746','32266','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62747','32267','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62748','32268','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62749','32273','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62750','32277','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62751','32278','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62752','32279','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62753','32280','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62754','32289','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62755','32291','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62756','32292','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62757','32302','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62758','32303','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62759','32304','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62760','30821','1','5','Ok\.
1','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62761','30821','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62762','30822','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62763','30823','1','12','$.data','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62764','30824','1','12','$.data','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62765','30825','1','12','$.data','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62766','30826','1','12','$.data','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62767','30828','1','12','$.data','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62768','30829','1','12','$.data','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62769','30829','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62770','30830','1','12','$.data','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62771','31054','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62772','30831','1','12','$[?(@.metric == "Write")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62773','30832','1','12','$[?(@.metric == "ReplicasSumQueueSize")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62774','30833','1','12','$[?(@.data.event == "Query")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62775','30833','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62776','30834','1','12','$[?(@.metric == "Read")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62777','30835','1','12','$[?(@.event == "ReadCompressedBytes")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62778','30835','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62779','30836','1','12','$[?(@.event == "ZooKeeperWaitMicroseconds")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62780','30836','2','1','0.000001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62781','30836','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62782','30837','1','12','$[?(@.metric == "ReplicasMaxAbsoluteDelay")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62783','30838','1','12','$[?(@.metric == "ReadonlyReplica")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62784','30839','1','12','$[?(@.metric == "Revision")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62785','30840','1','12','$[?(@.event == "ZooKeeperOtherExceptions")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62786','30840','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62787','30841','1','12','$[?(@.event == "SelectQuery")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62788','30841','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62789','30842','1','12','$[?(@.event == "ZooKeeperUserExceptions")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62790','30842','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62791','30843','1','12','$[?(@.metric == "ZooKeeperSession")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62792','30844','1','12','$[?(@.metric == "ZooKeeperRequest")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62793','30845','1','12','$[?(@.event == "ZooKeeperHardwareExceptions")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62794','30845','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62795','30846','1','12','$[?(@.metric == "Uptime")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62796','30847','1','12','$[?(@.metric == "Query")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62797','30848','1','12','$[?(@.metric == "DistributedSend")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62798','30849','1','12','$[?(@.metric == "HTTPConnection")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62799','30850','1','12','$[?(@.metric == "jemalloc.allocated")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62800','30851','1','12','$[?(@.metric == "InterserverConnection")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62801','30852','1','12','$[?(@.metric == "MySQLConnection")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62802','30853','1','12','$[?(@.metric == "TCPConnection")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62803','30854','1','12','$[?(@.metric == "DistributedFilesToInsert")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62804','30855','1','12','$[?(@.metric == "DistributedConnectionFailAtAll")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62805','30855','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62806','30856','1','12','$[?(@.metric == "DistributedConnectionFailTry")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62807','30856','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62808','30857','1','12','$[?(@.event == "InsertQuery")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62809','30857','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62810','30858','1','12','$[?(@.metric == "DelayedInserts")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62811','30859','1','12','$[?(@.event == "InsertedBytes")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62812','30859','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62813','30860','1','12','$[?(@.event == "InsertedRows")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62814','30860','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62815','30861','1','12','$[?(@.metric == "jemalloc.mapped")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62816','30862','1','12','$[?(@.event == "NetworkErrors")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62817','30862','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62818','30863','1','12','$[?(@.metric == "jemalloc.resident")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62819','30864','1','12','$[?(@.metric == "MaxPartCountForPartition")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62820','30865','1','12','$[?(@.metric == "MemoryTracking")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62821','30866','1','12','$[?(@.metric == "MemoryTrackingInBackgroundProcessingPool")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62822','30867','1','12','$[?(@.metric == "MemoryTrackingInBackgroundMoveProcessingPool")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62823','30868','1','12','$[?(@.metric == "MemoryTrackingForMerges")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62824','30869','1','12','$[?(@.metric == "MemoryTrackingInBackgroundSchedulePool")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62825','30870','1','12','$[?(@.event == "MergedUncompressedBytes")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62826','30870','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62827','30871','1','12','$[?(@.event == "MergedRows")].value.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62828','30871','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62829','30872','1','12','$[?(@.metric == "Merge")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62830','30873','1','12','$[?(@.metric == "ZooKeeperWatch")].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62831','30877','1','12','$[?(@.name == "{#NAME}")].bytes_allocated.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62832','30878','1','12','$[?(@.name == "{#NAME}")].element_count.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62833','30879','1','12','$[?(@.name == "{#NAME}")].bytes_allocated.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62834','30879','2','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62835','30880','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].active_replicas.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62836','30881','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].future_parts.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62837','30882','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].inserts_in_queue.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62838','30883','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].is_readonly.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62839','30884','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].is_session_expired.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62840','30885','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].replica_lag.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62841','30886','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].log_max_index.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62842','30887','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].log_pointer.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62843','30888','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].merges_in_queue.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62844','30889','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].parts_to_check.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62845','30890','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].queue_size.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62846','30891','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].total_replicas.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62847','30892','1','12','$[?(@.database == "{#DB}")].bytes.sum()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62848','30893','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].bytes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62849','30894','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].parts.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62850','30895','1','12','$[?(@.database == "{#DB}" && @.table == "{#TABLE}")].rows.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62851','31057','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62852','31059','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Latches'' && @.counter_name==''Average Latch Wait Time Base'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62853','31060','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Access Methods'' && @.counter_name==''Table Lock Escalations/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62854','31060','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62855','31061','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Memory Manager'' && @.counter_name==''Memory Grants Pending'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62856','31062','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Locks'' && @.counter_name==''Number of Deadlocks/sec'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62857','31062','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62858','31063','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:SQL Errors'' && @.counter_name==''Errors/sec'' && @.instance_name==''DB Offline Errors'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62859','31063','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62860','31064','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Buffer Manager'' && @.counter_name==''Page life expectancy'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62861','31065','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Buffer Manager'' && @.counter_name==''Page lookups/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62862','31065','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62863','31066','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Buffer Manager'' && @.counter_name==''Page reads/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62864','31066','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62865','31067','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Access Methods'' && @.counter_name==''Page Splits/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62866','31067','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62867','31068','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Buffer Manager'' && @.counter_name==''Page writes/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62868','31068','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62869','31069','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:General Statistics'' && @.counter_name==''Processes blocked'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62870','31070','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Buffer Manager'' && @.counter_name==''Readahead pages/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62871','31070','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62872','31071','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:SQL Statistics'' && @.counter_name==''Safe Auto-Params/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62873','31071','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62874','31072','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:SQL Statistics'' && @.counter_name==''SQL Compilations/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62875','31072','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62876','31073','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:SQL Statistics'' && @.counter_name==''SQL Re-Compilations/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62877','31073','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62878','31074','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Buffer Manager'' && @.counter_name==''Target pages'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62879','31075','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Memory Manager'' && @.counter_name==''Maximum Workspace Memory (KB)'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62880','31075','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62881','31076','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Memory Manager'' && @.counter_name==''Target Server Memory (KB)'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62882','31076','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62883','31077','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Latches'' && @.counter_name==''Total Latch Wait Time (ms)'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62884','31077','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62885','31078','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Memory Manager'' && @.counter_name==''Total Server Memory (KB)'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62886','31078','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62887','31079','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Transactions'' && @.counter_name==''Transactions'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62888','31080','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Transactions/sec'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62889','31080','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62890','31081','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:SQL Statistics'' && @.counter_name==''Unsafe Auto-Params/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62891','31081','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62892','31082','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}'' && @.counter_name==''Uptime'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62893','31083','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:General Statistics'' && @.counter_name==''User Connections'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62894','31084','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:SQL Errors'' && @.counter_name==''Errors/sec'' && @.instance_name==''User Errors'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62895','31084','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62896','31085','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}'' && @.counter_name==''Version'')].instance_name.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62897','31085','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62898','31086','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Access Methods'' && @.counter_name==''Workfiles Created/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62899','31086','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62900','31087','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Access Methods'' && @.counter_name==''Worktables Created/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62901','31087','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62902','31088','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Access Methods'' && @.counter_name==''WorktablesFromCacheRatio'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62903','31089','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Memory Manager'' && @.counter_name==''Memory Grants Outstanding'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62904','31090','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:General Statistics'' && @.counter_name==''Logouts/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62905','31090','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62906','31091','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Latches'' && @.counter_name==''Average Latch Wait Time (ms)'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62907','31092','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Access Methods'' && @.counter_name==''Forwarded Records/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62908','31092','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62909','31093','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Locks'' && @.counter_name==''Average Wait Time Base'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62910','31094','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Locks'' && @.counter_name==''Average Wait Time (ms)'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62911','31095','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:SQL Statistics'' && @.counter_name==''Batch Requests/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62912','31095','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62913','31096','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Buffer Manager'' && @.counter_name==''BufferCacheHitRatio'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62914','31097','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Plan Cache'' && @.counter_name==''CacheHitRatio'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62915','31098','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Plan Cache'' && @.counter_name==''Cache Object Counts'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62916','31099','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Plan Cache'' && @.counter_name==''Cache Objects in use'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62917','31100','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Plan Cache'' && @.counter_name==''Cache Pages'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62918','31101','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Buffer Manager'' && @.counter_name==''Checkpoint pages/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62919','31101','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62920','31102','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Data File(s) Size (KB)'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62921','31102','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62922','31103','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Buffer Manager'' && @.counter_name==''Database pages'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62923','31104','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:SQL Errors'' && @.counter_name==''Errors/sec'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62924','31104','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62925','31105','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:SQL Statistics'' && @.counter_name==''Failed Auto-Params/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62926','31105','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62927','31106','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Buffer Manager'' && @.counter_name==''Free list stalls/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62928','31106','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62929','31107','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:General Statistics'' && @.counter_name==''Logins/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62930','31107','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62931','31108','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Access Methods'' && @.counter_name==''Full Scans/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62932','31108','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62933','31109','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Memory Manager'' && @.counter_name==''Granted Workspace Memory (KB)'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62934','31109','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62935','31110','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Access Methods'' && @.counter_name==''Index Searches/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62936','31110','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62937','31111','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:SQL Errors'' && @.counter_name==''Errors/sec'' && @.instance_name==''Info Errors'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62938','31111','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62939','31112','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:SQL Errors'' && @.counter_name==''Errors/sec'' && @.instance_name==''Kill Connection Errors'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62940','31112','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62941','31113','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Latches'' && @.counter_name==''Latch Waits/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62942','31113','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62943','31114','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Buffer Manager'' && @.counter_name==''Lazy writes/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62944','31114','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62945','31115','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Locks'' && @.counter_name==''Lock Requests/sec'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62946','31115','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62947','31116','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Locks'' && @.counter_name==''Lock Timeouts/sec'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62948','31116','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62949','31117','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Locks'' && @.counter_name==''Lock Wait Time (ms)'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62950','31117','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62951','31118','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Locks'' && @.counter_name==''Lock Waits/sec'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62952','31118','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62953','31119','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Log File(s) Size (KB)'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62954','31119','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62955','31120','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:SQL Statistics'' && @.counter_name==''Auto-Param Attempts/sec'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62956','31120','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62957','31121','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Log File(s) Used Size (KB)'' && @.instance_name==''_Total'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62958','31121','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62959','31122','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62960','31123','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62961','31124','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62962','31125','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62963','31126','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62964','31127','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62965','31133','1','12','$[?(@.group_name==''{#GROUP_NAME}'')].primary_recovery_health.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62966','31133','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62967','31134','1','12','$[?(@.group_name==''{#GROUP_NAME}'')].primary_replica.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62968','31134','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62969','31135','1','12','$[?(@.group_name==''{#GROUP_NAME}'')].secondary_recovery_health.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62970','31135','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62971','31136','1','12','$[?(@.group_name==''{#GROUP_NAME}'')].synchronization_health.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62972','31136','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62973','31137','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Active Transactions'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62974','31138','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Data File(s) Size (KB)'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62975','31138','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62976','31139','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Log Bytes Flushed/sec'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62977','31139','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62978','31140','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Log File(s) Size (KB)'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62979','31140','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62980','31141','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Log File(s) Used Size (KB)'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62981','31141','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62982','31142','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Log Flush Wait Time'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62983','31142','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62984','31143','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Log Flush Waits/sec'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62985','31143','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62986','31144','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Log Flushes/sec'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62987','31144','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62988','31145','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Log Growths'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62989','31146','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Log Shrinks'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62990','31147','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Log Truncations'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62991','31148','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Percent Log Used'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62992','31149','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''State'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62993','31149','2','20','15m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62994','31150','1','12','$[?(@.object_name==''{$MSSQL.INSTANCE}:Databases'' && @.counter_name==''Transactions/sec'' && @.instance_name==''{#DBNAME}'')].cntr_value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62995','31150','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62996','31151','1','12','$[?(@.group_name==''{#GROUP_NAME}'' && @.replica_name==''{#REPLICA_NAME}'' && @.dbname==''{#DBNAME}'')].is_suspended.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62997','31151','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62998','31152','1','12','$[?(@.group_name==''{#GROUP_NAME}'' && @.replica_name==''{#REPLICA_NAME}'' && @.dbname==''{#DBNAME}'')].database_state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('62999','31152','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63000','31153','1','12','$[?(@.group_name==''{#GROUP_NAME}'' && @.replica_name==''{#REPLICA_NAME}'' && @.dbname==''{#DBNAME}'')].synchronization_health.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63001','31153','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63002','31154','1','12','$[?(@.dbname==''{#DBNAME}'')].mirroring_role_sequence.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63003','31154','2','9','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63004','31155','1','12','$[?(@.dbname==''{#DBNAME}'')].mirroring_role.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63005','31155','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63006','31156','1','12','$[?(@.dbname==''{#DBNAME}'')].mirroring_safety_level.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63007','31156','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63008','31157','1','12','$[?(@.dbname==''{#DBNAME}'')].mirroring_state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63009','31157','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63010','31158','1','12','$[?(@.dbname==''{#DBNAME}'')].mirroring_witness_state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63011','31158','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63018','31161','1','12','$[?(@.group_name==''{#GROUP_NAME}'' && @.replica_name==''{#REPLICA_NAME}'')].connected_state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63019','31161','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63020','31162','1','12','$[?(@.group_name==''{#GROUP_NAME}'' && @.replica_name==''{#REPLICA_NAME}'')].is_local.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63021','31162','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63022','31163','1','12','$[?(@.group_name==''{#GROUP_NAME}'' && @.replica_name==''{#REPLICA_NAME}'')].join_state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63023','31163','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63024','31164','1','12','$[?(@.group_name==''{#GROUP_NAME}'' && @.replica_name==''{#REPLICA_NAME}'')].operational_state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63025','31164','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63026','31165','1','12','$[?(@.group_name==''{#GROUP_NAME}'' && @.replica_name==''{#REPLICA_NAME}'')].recovery_health.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63027','31165','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63028','31166','1','12','$[?(@.group_name==''{#GROUP_NAME}'' && @.replica_name==''{#REPLICA_NAME}'')].role.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63029','31166','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63030','31167','1','12','$[?(@.group_name==''{#GROUP_NAME}'' && @.replica_name==''{#REPLICA_NAME}'')].synchronization_health.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63031','31167','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63032','30431','1','5','(Server version)\s+(.+)
\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63033','30431','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63034','30432','1','21','return value.indexOf(''is alive'') !== -1 ? 1 : 0;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63035','30432','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63036','30436','1','11','/resultset/row[field/text()=''Innodb_buffer_pool_reads'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63037','30437','1','11','/resultset/row[field/text()=''Innodb_buffer_pool_reads'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63038','30437','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63039','30438','1','11','/resultset/row[field/text()=''Innodb_row_lock_time'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63040','30438','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63041','30438','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63042','30439','1','11','/resultset/row[field/text()=''Innodb_row_lock_time_max'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63043','30439','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63044','30439','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63045','30440','1','11','/resultset/row[field/text()=''Innodb_row_lock_waits'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63046','30441','1','11','/resultset/row[field/text()=''Max_used_connections'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63047','30441','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63048','30442','1','11','/resultset/row[field/text()=''Queries'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63049','30442','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63050','30443','1','11','/resultset/row[field/text()=''Innodb_buffer_pool_read_requests'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63051','30444','1','11','/resultset/row[field/text()=''Questions'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63052','30444','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63053','30445','1','11','/resultset/row[field/text()=''Slow_queries'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63054','30445','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63055','30446','1','11','/resultset/row[field/text()=''Threads_cached'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63056','30447','1','11','/resultset/row[field/text()=''Threads_connected'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63057','30449','1','11','/resultset/row[field/text()=''Threads_running'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63058','30450','1','11','/resultset/row[field/text()=''Uptime'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63059','30451','1','11','/resultset/row[field/text()=''Innodb_buffer_pool_read_requests'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63060','30451','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63061','30452','1','11','/resultset/row[field/text()=''Innodb_buffer_pool_pages_total'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63062','30452','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63063','30453','1','11','/resultset/row[field/text()=''Bytes_received'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63064','30453','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63065','30454','1','11','/resultset/row[field/text()=''Connection_errors_max_connections'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63066','30454','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63067','30455','1','11','/resultset/row[field/text()=''Bytes_sent'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63068','30455','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63069','30456','1','11','/resultset/row[field/text()=''Com_delete'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63070','30456','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63071','30457','1','11','/resultset/row[field/text()=''Com_insert'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63072','30457','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63073','30458','1','11','/resultset/row[field/text()=''Com_select'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63074','30458','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63075','30459','1','11','/resultset/row[field/text()=''Com_update'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63076','30459','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63077','30460','1','11','/resultset/row[field/text()=''Connection_errors_accept'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63078','30460','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63079','30461','1','11','/resultset/row[field/text()=''Connection_errors_internal'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63080','30461','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63081','30462','1','11','/resultset/row[field/text()=''Connection_errors_peer_address'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63082','30462','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63083','30463','1','11','/resultset/row[field/text()=''Innodb_buffer_pool_pages_free'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63084','30464','1','11','/resultset/row[field/text()=''Connection_errors_select'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63085','30464','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63086','30465','1','11','/resultset/row[field/text()=''Connection_errors_tcpwrap'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63087','30465','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63088','30466','1','11','/resultset/row[field/text()=''Connections'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63089','30466','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63090','30470','1','11','/resultset/row[field/text()=''Aborted_connects'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63091','30470','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63092','30471','1','11','/resultset/row[field/text()=''Aborted_clients'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63093','30471','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63094','31168','1','11','/resultset/row[field/text()=''Threads_created'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63095','31168','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63096','31169','1','11','/resultset/row[field/text()=''Created_tmp_disk_tables'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63097','31169','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63098','31170','1','11','/resultset/row[field/text()=''Created_tmp_files'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63099','31170','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63100','31171','1','11','/resultset/row[field/text()=''Created_tmp_tables'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63101','31171','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63102','30472','1','21','return JSON.stringify(value.split("\n").map(function (name) {
    return ({"{#DBNAME}": name});
}));','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63103','30472','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63104','30473','1','21','var matches = value.match(/Master_Host.*>(.*)<.*/);
if (matches) {
    return JSON.stringify([{"{#MASTERHOST}": matches[1]}]);
}

return ''[]'';','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63105','30473','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63106','30474','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63107','30476','1','11','/resultset/row/field[@name=''Seconds_Behind_Master'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63108','30476','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63109','30476','3','15','null','3','Replication is not performed.');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63110','30477','1','11','/resultset/row/field[@name=''Slave_IO_Running'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63111','30477','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63112','30478','1','11','/resultset/row/field[@name=''Slave_SQL_Running'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63113','30478','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63114','30637','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63115','30638','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63116','30642','1','12','$.Innodb_buffer_pool_reads','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63117','30643','1','12','$.Innodb_buffer_pool_reads','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63118','30643','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63119','30644','1','12','$.Innodb_row_lock_time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63120','30644','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63121','30644','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63122','30645','1','12','$.Innodb_row_lock_time_max','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63123','30645','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63124','30645','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63125','30646','1','12','$.Innodb_row_lock_waits','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63126','30647','1','12','$.Max_used_connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63127','30647','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63128','30648','1','12','$.Queries','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63129','30648','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63130','30649','1','12','$.Innodb_buffer_pool_read_requests','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63131','30650','1','12','$.Questions','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63132','30650','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63133','30651','1','12','$.Slow_queries','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63134','30651','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63135','30652','1','12','$.Threads_cached','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63136','30653','1','12','$.Threads_connected','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63137','30655','1','12','$.Threads_running','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63138','30656','1','12','$.Uptime','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63139','30657','1','12','$.Innodb_buffer_pool_read_requests','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63140','30657','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63141','30658','1','12','$.Innodb_buffer_pool_pages_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63142','30658','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63143','30659','1','12','$.Bytes_received','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63144','30659','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63145','30660','1','12','$.Connection_errors_max_connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63146','30660','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63147','30661','1','12','$.Bytes_sent','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63148','30661','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63149','30662','1','12','$.Com_delete','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63150','30662','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63151','30663','1','12','$.Com_insert','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63152','30663','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63153','30664','1','12','$.Com_select','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63154','30664','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63155','30665','1','12','$.Com_update','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63156','30665','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63157','30666','1','12','$.Connection_errors_accept','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63158','30666','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63159','30667','1','12','$.Connection_errors_internal','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63160','30667','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63161','30668','1','12','$.Connection_errors_peer_address','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63162','30668','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63163','30669','1','12','$.Innodb_buffer_pool_pages_free','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63164','30670','1','12','$.Connection_errors_select','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63165','30670','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63166','30671','1','12','$.Connection_errors_tcpwrap','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63167','30671','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63168','30672','1','12','$.Connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63169','30672','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63170','30676','1','12','$.Aborted_connects','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63171','30676','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63172','30677','1','12','$.Aborted_clients','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63173','30677','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63174','31172','1','12','$.Threads_created','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63175','31172','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63176','31173','1','12','$.Created_tmp_disk_tables','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63177','31173','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63178','31174','1','12','$.Created_tmp_files','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63179','31174','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63180','31175','1','12','$.Created_tmp_tables','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63181','31175','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63182','30678','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63183','30679','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63184','30680','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63185','30682','1','12','$.Seconds_Behind_Master','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63186','30682','2','14','\d+','3','Replication is not performed.');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63187','30682','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63188','30683','1','12','$.Slave_IO_Running','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63189','30683','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63190','30684','1','12','$.Slave_SQL_Running','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63191','30684','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63192','30480','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63193','30481','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63194','30484','1','12','$[?(@.Variable_name==''Innodb_row_lock_waits'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63195','30485','1','12','$[?(@.Variable_name==''Innodb_buffer_pool_read_requests'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63196','30486','1','12','$[?(@.Variable_name==''Innodb_buffer_pool_read_requests'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63197','30486','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63198','30487','1','12','$[?(@.Variable_name==''Innodb_buffer_pool_reads'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63199','30488','1','12','$[?(@.Variable_name==''Innodb_buffer_pool_reads'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63200','30488','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63201','30489','1','12','$[?(@.Variable_name==''Innodb_row_lock_time'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63202','30489','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63203','30489','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63204','30490','1','12','$[?(@.Variable_name==''Innodb_row_lock_time_max'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63205','30490','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63206','30490','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63207','30491','1','12','$[?(@.Variable_name==''Queries'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63208','30491','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63209','30492','1','12','$[?(@.Variable_name==''Max_used_connections'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63210','30492','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63211','30493','1','12','$[?(@.Variable_name==''Innodb_buffer_pool_pages_free'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63212','30494','1','12','$[?(@.Variable_name==''Questions'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63213','30494','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63214','30495','1','12','$[?(@.Variable_name==''Slow_queries'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63215','30495','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63216','30496','1','12','$[?(@.Variable_name==''Threads_cached'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63217','30497','1','12','$[?(@.Variable_name==''Threads_connected'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63218','30499','1','12','$[?(@.Variable_name==''Threads_running'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63219','30500','1','12','$[?(@.Variable_name==''Innodb_buffer_pool_pages_total'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63220','30500','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63221','30503','1','12','$[?(@.Variable_name==''Com_select'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63222','30503','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63223','30504','1','12','$[?(@.Variable_name==''Aborted_clients'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63224','30504','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63225','30505','1','12','$[?(@.Variable_name==''Aborted_connects'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63226','30505','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63227','30506','1','12','$[?(@.Variable_name==''Bytes_received'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63228','30506','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63229','30507','1','12','$[?(@.Variable_name==''Bytes_sent'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63230','30507','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63231','30508','1','12','$[?(@.Variable_name==''Com_delete'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63232','30508','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63233','30509','1','12','$[?(@.Variable_name==''Com_insert'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63234','30509','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63235','30510','1','12','$[?(@.Variable_name==''Com_update'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63236','30510','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63237','30512','1','12','$[?(@.Variable_name==''Connection_errors_accept'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63238','30512','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63239','30513','1','12','$[?(@.Variable_name==''Connection_errors_internal'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63240','30513','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63241','30514','1','12','$[?(@.Variable_name==''Connection_errors_max_connections'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63242','30514','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63243','30515','1','12','$[?(@.Variable_name==''Connection_errors_peer_address'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63244','30515','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63245','30516','1','12','$[?(@.Variable_name==''Connection_errors_select'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63246','30516','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63247','30517','1','12','$[?(@.Variable_name==''Connection_errors_tcpwrap'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63248','30517','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63249','30518','1','12','$[?(@.Variable_name==''Connections'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63250','30518','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63251','30519','1','12','$[?(@.Variable_name==''Uptime'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63252','31176','1','12','$[?(@.Variable_name==''Threads_created'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63253','31176','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63254','31177','1','12','$[?(@.Variable_name==''Created_tmp_disk_tables'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63255','31177','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63256','31178','1','12','$[?(@.Variable_name==''Created_tmp_tables'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63257','31178','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63258','31179','1','12','$[?(@.Variable_name==''Created_tmp_files'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63259','31179','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63260','30520','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63261','30521','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63262','30522','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63263','30524','1','12','$.[?(@.Master_Host==''{#MASTER_HOST}'')][''Seconds_Behind_Master''].first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63264','30524','2','14','\d+','3','Replication is not performed.');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63265','30524','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63266','30525','1','12','$.[?(@.Master_Host==''{#MASTER_HOST}'')][''Slave_IO_Running''].first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63267','30525','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63268','30526','1','12','$.[?(@.Master_Host==''{#MASTER_HOST}'')][''Slave_SQL_Running''].first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63269','30526','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63270','31629','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63271','31630','1','12','$.datafile_num','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63272','31632','1','12','$.proc_num','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63273','31640','1','12','$.available','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63274','31641','1','12','$.exp_passwd_days_before','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63275','31646','1','12','$.active_user','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63276','31647','1','12','$.[''Rows Per Sort'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63277','31648','1','12','$.active_background','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63278','31649','1','12','$.concurrency_rate','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63279','31650','1','12','$.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63280','31651','1','12','$.inactive_user','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63281','31652','1','12','$.[''SQL Service Response Time'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63282','31652','2','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63283','31653','1','12','$.sessions','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63284','31654','1','12','$.lock_rate','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63285','31655','1','12','$.processes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63286','31656','1','12','$.[''Active Parallel Sessions'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63287','31657','1','12','$.long_time_locked','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63288','31658','1','12','$.buffer_cache','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63289','31659','1','12','$.fixed_sga','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63290','31660','1','12','$.java_pool','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63291','31661','1','12','$.log_buffer','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63292','31662','1','12','$.shared_pool','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63293','31663','1','12','$.[''Shared Pool Free %'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63294','31664','1','12','$.[''Total Sorts Per User Call'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63295','31665','1','12','$.[''Temp Space Used'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63296','31666','1','12','$.[''total PGA allocated'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63297','31667','1','12','$.[''total freeable PGA memory'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63298','31668','1','12','$.[''total PGA inuse'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63299','31669','1','12','$.uptime','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63300','31670','1','12','$.[''User Rollbacks Per Sec'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63301','31671','1','12','$.large_pool','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63302','31672','1','12','$.[''Physical Read Bytes Per Sec'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63303','31673','1','12','$.[''Physical Writes Per Sec'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63304','31674','1','12','$.space_reclaimable','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63305','31675','1','12','$.[''Average Active Sessions'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63306','31676','1','12','$..archiver.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63307','31677','1','12','$.[''Buffer Cache Hit Ratio'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63308','31678','1','12','$.[''Global Cache Blocks Corrupted'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63309','31679','1','12','$.[''Global Cache Blocks Lost'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63310','31680','1','12','$.[''Cursor Cache Hit Ratio'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63311','31681','1','12','$.[''Database CPU Time Ratio'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63312','31682','1','12','$.[''Database Wait Time Ratio'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63313','31683','1','12','$.db_files','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63314','31684','1','12','$.[''Disk Sort Per Sec'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63315','31685','1','12','$.[''Enqueue Timeouts Per Sec'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63316','31686','1','12','$.number_of_files','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63317','31687','1','12','$.restore_point','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63318','31688','1','12','$.space_limit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63319','31689','1','12','$.space_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63320','31690','1','12','$.[''Physical Write Bytes Per Sec'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63321','31691','1','12','$.usable_pct','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63322','31692','1','12','$.[''GC CR Block Received Per Second'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63323','31693','1','12','$..hostname.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63324','31694','1','12','$.instance','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63325','31695','1','12','$.status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63326','31696','1','12','$.role','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63327','31697','1','12','$.[''Library Cache Hit Ratio'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63328','31698','1','12','$.[''Logons Per Sec'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63329','31699','1','12','$.[''Long Table Scans Per Sec'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63330','31700','1','12','$.[''Memory Sorts Ratio'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63331','31701','1','12','$.[''global memory bound'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63332','31702','1','12','$.[''aggregate PGA target parameter'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63333','31703','1','12','$.[''Active Serial Sessions'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63334','31704','1','12','$.[''Physical Reads Per Sec'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63335','31705','1','12','$.version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63336','31705','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63337','31711','1','12','$..[''{#DEST_NAME}''].error.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63338','31712','1','12','$..[''{#DEST_NAME}''].log_sequence.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63339','31713','1','12','$..[''{#DEST_NAME}''].status.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63340','31714','1','12','$..{#DBNAME}.force_logging.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63341','31714','2','20','15m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63342','31715','1','12','$..{#DBNAME}.log_mode.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63343','31715','2','20','15m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63344','31716','1','12','$..{#DBNAME}.open_mode.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63345','31716','2','20','15m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63346','31717','1','12','$..{#DBNAME}.role.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63347','31717','2','20','15m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63348','31718','1','12','$..[''{#DG_NAME}''].free_size_byte.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63349','31719','1','12','$..[''{#DG_NAME}''].size_byte.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63350','31720','1','12','$..[''{#DG_NAME}''].used_percent.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63351','31721','1','12','$..{#DBNAME}.open_mode.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63352','31721','2','20','15m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63353','31722','1','12','$..[''{#TABLESPACE}''].file_bytes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63354','31723','1','12','$..[''{#TABLESPACE}''].free_bytes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63355','31724','1','12','$..[''{#TABLESPACE}''].max_bytes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63356','31725','1','12','$..[''{#TABLESPACE}''].status.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63357','31726','1','12','$..[''{#TABLESPACE}''].used_pct_max.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63447','28673','1','5','Time:\s(\d+\.\d+)\sms
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63448','28674','1','21','return value.search(/accepting connections/)>0 ? 1 : 0','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63449','28674','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63450','28680','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63451','28685','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63452','28688','1','12','$.idle','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63453','28689','1','12','$.active','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63454','28690','1','12','$.prepared','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63455','28691','1','12','$.waiting','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63456','28692','1','12','$.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63457','28693','1','12','$.buffers_alloc','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63458','28693','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63459','28694','1','12','$.buffers_backend','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63460','28694','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63461','28695','1','12','$.checkpoint_write_time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63462','28695','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63463','28695','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63464','28696','1','12','$.buffers_backend_fsync','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63465','28696','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63466','28697','1','12','$.buffers_checkpoint','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63467','28697','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63468','28698','1','12','$.buffers_clean','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63469','28698','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63470','28699','1','12','$.checkpoints_req','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63471','28699','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63472','28700','1','12','$.checkpoints_timed','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63473','28700','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63474','28701','1','12','$.checkpoint_write_time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63475','28701','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63476','28701','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63477','28702','1','12','$.maxwritten_clean','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63478','28702','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63479','28703','1','12','$.waiting','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63480','28704','1','12','$.active','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63481','28705','1','12','$.idle','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63482','28706','1','12','$.idle_in_transaction','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63483','28707','1','12','$.prepared','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63484','28708','1','12','$.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63485','28709','1','12','$.total_pct','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63486','28710','1','12','$.write','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63487','28710','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63488','28715','1','12','$[''{#DBNAME}''].conflicts','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63489','28715','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63490','28716','1','12','$[''{#DBNAME}''].total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63491','28717','1','12','$.seq','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63492','28717','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63493','28718','1','12','$.idx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63494','28718','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63495','28719','1','12','$[''{#DBNAME}''].tx_time_sum','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63496','28720','1','12','$[''{#DBNAME}''].tx_time_max','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63497','28721','1','12','$[''{#DBNAME}''].tx_slow_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63498','28722','1','12','$[''{#DBNAME}''].query_time_sum','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63499','28723','1','12','$[''{#DBNAME}''].query_time_max','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63500','28724','1','12','$[''{#DBNAME}''].query_slow_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63501','28725','1','12','$[''{#DBNAME}''].mro_time_sum','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63502','28726','1','12','$[''{#DBNAME}''].mro_time_max','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63503','28727','1','12','$[''{#DBNAME}''].mro_slow_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63504','28728','1','12','$[''{#DBNAME}''].blks_read','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63505','28728','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63506','28729','1','12','$[''{#DBNAME}''].deadlocks','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63507','28729','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63508','28730','1','12','$[''{#DBNAME}''].blks_hit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63509','28730','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63510','28731','1','12','$.prc_before_av','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63511','28732','1','12','$[''{#DBNAME}''].xact_rollback','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63512','28732','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63513','28733','1','12','$[''{#DBNAME}''].xact_commit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63514','28733','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63515','28734','1','12','$[''{#DBNAME}''].tup_updated','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63516','28734','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63517','28735','1','12','$[''{#DBNAME}''].tup_returned','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63518','28735','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63519','28736','1','12','$[''{#DBNAME}''].tup_inserted','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63520','28736','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63521','28737','1','12','$[''{#DBNAME}''].tup_fetched','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63522','28737','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63523','28738','1','12','$[''{#DBNAME}''].tup_deleted','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63524','28738','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63525','28739','1','12','$[''{#DBNAME}''].temp_files','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63526','28739','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63527','28740','1','12','$[''{#DBNAME}''].temp_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63528','28740','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63529','28741','1','12','$.prc_before_stop','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63530','31188','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63531','31197','1','12','$.tup_fetched','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63532','31197','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63533','31198','1','12','$.numbackends','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63534','31199','1','12','$.deadlocks','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63535','31199','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63536','31200','1','12','$.temp_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63537','31200','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63538','31201','1','12','$.temp_files','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63539','31201','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63540','31202','1','12','$.tup_deleted','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63541','31202','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63542','31203','1','12','$.archived_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63543','31204','1','12','$.tup_inserted','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63544','31204','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63545','31205','1','12','$.tup_returned','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63546','31205','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63547','31206','1','12','$.tup_updated','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63548','31206','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63549','31207','1','12','$.xact_commit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63550','31207','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63551','31208','1','12','$.xact_rollback','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63552','31208','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63553','31209','1','12','$.checksum_failures','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63554','31209','2','14','^\d*$','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63555','31209','3','10','','2','-1');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63556','31210','1','12','$.write','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63557','31211','1','12','$.conflicts','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63558','31211','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63559','31212','1','12','$.blk_read_time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63560','31212','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63561','31213','1','12','$.blks_read','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63562','31213','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63566','31215','1','12','$.failed_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63567','31216','1','12','$.size_files','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63568','31217','1','12','$.buffers_alloc','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63569','31217','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63570','31218','1','12','$.buffers_backend_fsync','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63571','31218','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63572','31219','1','12','$.buffers_backend','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63573','31219','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63574','31220','1','12','$.buffers_checkpoint','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63575','31220','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63576','31221','1','12','$.buffers_clean','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63577','31221','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63578','31222','1','12','$.checkpoint_write_time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63579','31222','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63580','31222','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63581','31223','1','12','$.checkpoints_req','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63582','31223','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63583','31224','1','12','$.checkpoints_timed','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63584','31224','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63585','31225','1','12','$.maxwritten_clean','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63586','31225','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63587','31226','1','12','$.active','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63588','31227','1','12','$.blks_hit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63589','31227','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63590','31228','1','12','$.disabled','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63591','31229','1','12','$.idle_in_transaction','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63592','31230','1','12','$.idle','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63593','31231','1','12','$.idle_in_transaction','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63594','31232','1','12','$.idle_in_transaction_aborted','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63595','31233','1','12','$.prepared','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63596','31234','1','12','$.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63597','31235','1','12','$.total_pct','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63598','31236','1','12','$.waiting','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63599','31237','1','12','$.blk_read_time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63600','31237','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63601','31238','1','12','$.count_files','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63602','31239','1','12','$.write','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63603','31239','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63604','31244','1','12','$[''{#DBNAME}''].tup_returned','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63605','31244','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63606','31245','1','12','$[''{#DBNAME}''].shareupdateexclusive','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63607','31246','1','12','$[''{#DBNAME}''].sharerowexclusive','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63608','31247','1','12','$[''{#DBNAME}''].share','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63609','31248','1','12','$[''{#DBNAME}''].rowshare','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63610','31249','1','12','$[''{#DBNAME}''].rowexclusive','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63611','31250','1','12','$[''{#DBNAME}''].exclusive','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63612','31251','1','12','$[''{#DBNAME}''].accessshare','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63613','31252','1','12','$[''{#DBNAME}''].accessexclusive','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63614','31253','1','12','$[''{#DBNAME}''].xact_rollback','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63615','31253','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63616','31254','1','12','$[''{#DBNAME}''].xact_commit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63617','31254','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63618','31255','1','12','$[''{#DBNAME}''].tup_updated','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63619','31255','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63620','31256','1','12','$[''{#DBNAME}''].tup_fetched','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63621','31256','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63622','31257','1','12','$[''{#DBNAME}''].tup_inserted','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63623','31257','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63624','31258','1','12','$[''{#DBNAME}''].tup_deleted','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63625','31258','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63626','31259','1','12','$[''{#DBNAME}''].temp_files','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63627','31259','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63628','31260','1','12','$[''{#DBNAME}''].temp_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63629','31260','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63630','31261','1','12','$[''{#DBNAME}''].numbackends','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63631','31262','1','12','$[''{#DBNAME}''].deadlocks','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63632','31262','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63633','31263','1','12','$[''{#DBNAME}''].conflicts','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63634','31263','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63635','31264','1','12','$[''{#DBNAME}''].checksum_failures','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63636','31264','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63638','31265','1','12','$[''{#DBNAME}''].blks_read','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63639','31265','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63640','31266','1','12','$[''{#DBNAME}''].blks_hit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63641','31266','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63642','31267','1','12','$[''{#DBNAME}''].blk_write_time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63643','31267','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63644','31267','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63645','31268','1','12','$[''{#DBNAME}''].blk_read_time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63646','31268','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63647','31268','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63648','31269','1','12','$[''{#DBNAME}''].total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63649','30273','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63650','30274','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63651','30275','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63652','30277','1','12','$.Clients.blocked_clients','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63653','30278','1','12','$.Server.tcp_port','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63654','30278','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63655','30279','1','12','$.Stats.expired_keys','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63656','30280','1','12','$.Stats.evicted_keys','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63657','30281','1','12','$.Server.uptime_in_seconds','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63658','30282','1','12','$.Server.redis_mode','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63659','30282','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63660','30283','1','12','$.Server.redis_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63661','30283','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63662','30284','1','12','$.Stats.instantaneous_ops_per_sec','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63663','30285','1','12','$.Server.process_id','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63664','30285','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63665','30286','1','12','$.Replication.role','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63666','30286','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63667','30287','1','12','$.Replication.repl_backlog_size','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63668','30288','1','12','$.Replication.repl_backlog_histlen','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63669','30289','1','12','$.Stats.instantaneous_input_kbps','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63670','30289','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63671','30290','1','12','$.Stats.keyspace_hits','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63672','30291','1','12','$.Stats.instantaneous_output_kbps','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63673','30291','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63674','30292','1','12','$.Replication.repl_backlog_active','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63675','30293','1','12','$.Stats.keyspace_misses','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63676','30294','1','12','$.Stats.latest_fork_usec','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63677','30294','2','1','1.0E-5','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63678','30295','1','12','$.Stats.migrate_cached_sockets','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63679','30296','1','12','$.Stats.pubsub_channels','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63680','30297','1','12','$.Stats.pubsub_patterns','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63681','30298','1','12','$.Stats.rejected_connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63682','30299','1','12','$.Stats.sync_full','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63683','30300','1','12','$.Stats.sync_partial_err','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63684','30301','1','12','$.Stats.sync_partial_ok','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63685','30302','1','12','$.Stats.total_commands_processed','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63686','30303','1','12','$.Stats.total_connections_received','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63687','30304','1','12','$.Stats.total_net_input_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63688','30305','1','12','$.Replication.repl_backlog_first_byte_offset','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63689','30306','1','12','$.Replication.connected_slaves','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63690','30307','1','12','$.Replication.master_repl_offset','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63691','30308','1','12','$.Memory.used_memory_rss','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63692','30309','1','21','var clients = JSON.parse(value).Clients
return clients.client_recent_max_input_buffer || clients.client_biggest_input_buf','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63693','30310','1','21','var clients = JSON.parse(value).Clients
return clients.client_recent_max_output_buffer || clients.client_longest_output_list','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63694','30311','1','12','$.Cluster.cluster_enabled','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63695','30312','1','12','$.maxclients','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63696','30312','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63697','30313','1','12','$.CPU.used_cpu_sys','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63698','30314','1','12','$.CPU.used_cpu_sys_children','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63699','30315','1','12','$.CPU.used_cpu_user','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63700','30316','1','12','$.CPU.used_cpu_user_children','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63701','30317','1','12','$.Memory.mem_fragmentation_ratio','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63702','30318','1','12','$.Memory.used_memory','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63703','30319','1','12','$.Memory.used_memory_lua','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63704','30320','1','12','$.Memory.used_memory_peak','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63705','30321','1','12','$.Persistence.aof_current_rewrite_time_sec','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63706','30322','1','12','$.Clients.connected_clients','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63707','30323','1','12','$.Persistence.aof_enabled','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63708','30324','1','12','$.Persistence.aof_last_bgrewrite_status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63709','30324','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63710','30325','1','12','$.Persistence.aof_last_rewrite_time_sec','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63711','30326','1','12','$.Persistence.aof_last_write_status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63712','30326','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63713','30327','1','12','$.Persistence.aof_rewrite_in_progress','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63714','30328','1','12','$.Persistence.aof_rewrite_scheduled','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63715','30329','1','12','$.Persistence.loading','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63716','30330','1','12','$.Persistence.rdb_bgsave_in_progress','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63717','30331','1','12','$.Persistence.rdb_changes_since_last_save','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63718','30332','1','12','$.Persistence.rdb_current_bgsave_time_sec','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63719','30333','1','12','$.Persistence.rdb_last_bgsave_status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63720','30333','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63721','30334','1','12','$.Persistence.rdb_last_bgsave_time_sec','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63722','30335','1','12','$.Persistence.rdb_last_save_time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63723','30336','1','12','$.Stats.total_net_output_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63724','30337','1','21','return JSON.stringify(value > 0 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63725','30338','1','21','return JSON.stringify(Object.keys(JSON.parse(value).Keyspace)
  .map(function (v){return {"{#DB}": v}}));','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63726','30339','1','12','$.Server.redis_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63727','30339','2','21','return JSON.stringify(parseInt(value.split(''.'')[0]) >= 4 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63728','30340','1','12','$.Server.redis_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63729','30340','2','21','return JSON.stringify(parseInt(value.split(''.'')[0]) >= 5 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63730','30341','1','21','return JSON.stringify(JSON.parse(value).Persistence.aof_enabled === ''1''
  ? [{''{#SINGLETON}'': ''''}]
  : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63731','30342','1','21','var repl = JSON.parse(value).Replication;
return JSON.stringify(Object.keys(repl)
  .filter(function (v) {return v.match(/slave\d+/)})
  .map(function (v){
    return {"{#SLAVE_IP}": repl[v].ip, "{#SLAVE_PORT}": repl[v].port}
  }));','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63732','30343','1','21','return JSON.stringify(JSON.parse(value).Replication.role === ''slave''
  ? [{''{#SINGLETON}'': ''''}]
  : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63733','30348','1','12','$.Keyspace["{#DB}"].avg_ttl','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63734','30348','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63735','30349','1','12','$.Keyspace["{#DB}"].expires','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63736','30350','1','12','$.Keyspace["{#DB}"].keys','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63737','30351','1','12','$.Memory.active_defrag_running','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63738','30352','1','12','$.Persistence.rdb_last_cow_size','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63739','30353','1','12','$.Stats.expired_time_cap_reached_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63740','30354','1','12','$.Stats.expired_stale_perc','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63741','30355','1','12','$.Stats.active_defrag_misses','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63742','30356','1','12','$.Stats.active_defrag_key_misses','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63743','30357','1','12','$.Stats.active_defrag_key_hits','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63744','30358','1','12','$.Stats.active_defrag_hits','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63745','30359','1','12','$.Server.executable','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63746','30359','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63747','30360','1','12','$.Replication.second_repl_offset','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63748','30361','1','12','$.Persistence.aof_last_cow_size','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63749','30362','1','12','$.Memory.lazyfree_pending_objects','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63750','30363','1','12','$.Memory.used_memory_startup','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63751','30364','1','12','$.Memory.used_memory_peak_perc','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63752','30364','2','5','(.+)%
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63753','30365','1','12','$.Memory.used_memory_overhead','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63754','30366','1','12','$.Memory.used_memory_dataset','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63755','30367','1','12','$.Memory.used_memory_dataset_perc','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63756','30367','2','5','(.+)%
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63757','30368','1','12','$.Memory.total_system_memory','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63758','30369','1','12','$.Memory.maxmemory','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63759','30370','1','12','$.Memory.maxmemory_policy','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63760','30370','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63761','30371','1','12','$.Stats.slave_expires_tracked_keys','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63762','30372','1','12','$.Memory.allocator_active','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63763','30373','1','12','$.Memory.mem_clients_normal','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63764','30374','1','12','$.Memory.rss_overhead_ratio','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63765','30375','1','12','$.Memory.rss_overhead_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63766','30376','1','12','$.Memory.mem_replication_backlog','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63767','30377','1','12','$.Memory.number_of_cached_scripts','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63768','30378','1','12','$.Memory.mem_not_counted_for_evict','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63769','30379','1','12','$.Memory.mem_clients_slaves','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63770','30380','1','12','$.Memory.mem_aof_buffer','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63771','30381','1','12','$.Memory.allocator_allocated','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63772','30382','1','12','$.Memory.mem_fragmentation_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63773','30383','1','12','$.Memory.allocator_rss_ratio','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63774','30384','1','12','$.Memory.allocator_rss_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63775','30385','1','12','$.Memory.allocator_resident','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63776','30386','1','12','$.Memory.allocator_frag_ratio','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63777','30387','1','12','$.Memory.allocator_frag_bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63778','30388','1','12','$.Memory.used_memory_scripts','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63779','30389','1','12','$.Persistence.aof_base_size','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63780','30390','1','12','$.Persistence.aof_buffer_length','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63781','30391','1','12','$.Persistence.aof_current_size','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63782','30392','1','12','$.Persistence.aof_delayed_fsync','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63783','30393','1','12','$.Persistence.aof_pending_bio_fsync','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63784','30394','1','12','$.Persistence.aof_pending_rewrite','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63785','30395','1','12','$.Persistence.aof_rewrite_buffer_length','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63786','30396','1','21','var repl = JSON.parse(value).Replication;
var res = Object.keys(repl)
    .filter(function (v) {return v.match(/slave\d+/)})
    .filter(function (v) {return (repl[v].ip === "{#SLAVE_IP}" && repl[v].port === "{#SLAVE_PORT}")})
    .map(function (v) {return repl[v].offset})[0];

if (res === undefined) {
    throw ''Slave {#SLAVE_IP}:{#SLAVE_PORT} is no longer available.'';
}

return res;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63787','30397','1','12','$.Replication.master_host','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63788','30397','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63789','30398','1','12','$.Replication.master_last_io_seconds_ago','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63790','30399','1','12','$.Replication.master_link_status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63791','30399','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63792','30400','1','12','$.Replication.master_port','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63793','30400','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63794','30401','1','12','$.Replication.master_sync_in_progress','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63795','30402','1','12','$.Replication.slave_priority','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63796','30403','1','12','$.Replication.slave_read_only','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63797','30403','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63798','30404','1','12','$.Replication.slave_repl_offset','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63799','27031','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63800','27190','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63801','27331','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63802','27460','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63803','27530','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63804','27566','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63805','27629','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63806','27652','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63807','27732','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63808','27798','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63809','27954','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63810','28128','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63811','28280','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63812','28955','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of EtherLike-MIB discovery.'';
}
var fields = [''{#SNMPVALUE}'',''{#IFOPERSTATUS}'',''{#IFALIAS}'',''{#IFNAME}'',''{#IFDESCR}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63813','27152','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63814','29844','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63815','29845','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63816','29846','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63817','29847','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63818','29848','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63819','27199','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63820','27232','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63821','27268','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63822','27289','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63823','27340','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63824','27372','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63825','27469','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63826','27503','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63827','27539','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63828','27575','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63829','27638','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63830','27661','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63831','27741','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63832','27773','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63833','27807','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63834','27889','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63835','27926','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63836','27963','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63837','27993','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63838','28022','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63839','28137','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63841','28240','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63842','28289','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63843','28337','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63844','28384','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63845','28461','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63846','28489','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63847','28964','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63848','29057','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63849','29834','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63850','29835','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63851','29836','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63852','29837','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63853','29838','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63854','29849','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63855','29850','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63856','29851','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63857','29852','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63858','29853','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63859','29854','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63860','29855','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63861','29856','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63862','29857','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63863','29858','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63864','29859','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63865','29860','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63866','29861','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63867','29862','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63868','29863','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63869','29864','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63870','29865','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63871','29866','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63872','29867','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63873','29868','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63874','29869','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63875','29870','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63876','29871','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63877','29872','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63878','29873','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63879','29874','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63880','29875','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63881','29876','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63882','29877','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63883','29878','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63884','29879','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63885','29880','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63886','29881','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63887','29882','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63888','29883','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63889','29884','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63890','29885','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63891','29886','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63892','29887','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63893','29888','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63894','29889','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63895','29890','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63896','29891','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63897','29892','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63898','29893','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63899','29894','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63900','29895','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63901','29896','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63902','29897','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63903','29898','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63904','29899','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63905','29900','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63906','29901','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63907','29902','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63908','29903','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63909','29904','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63910','29905','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63911','29906','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63912','29907','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63913','29908','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63914','29909','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63915','29910','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63916','29911','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63917','29912','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63918','29913','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63919','29914','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63920','29915','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63921','29916','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63922','29917','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63923','29918','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63924','29919','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63925','29920','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63926','29921','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63927','29922','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63928','29923','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63929','29924','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63930','29925','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63931','29926','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63932','29927','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63933','29928','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63934','29929','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63935','29930','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63936','29931','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63937','29932','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63938','29933','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63939','29934','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63940','29935','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63941','29936','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63942','29937','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63943','29938','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63944','29939','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63945','29940','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63946','29941','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63947','29942','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63948','29943','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63949','29944','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63950','29945','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63951','29946','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63952','29947','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63953','29948','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63959','29954','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63960','29955','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63961','29956','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63962','29957','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63963','29958','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63964','29959','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63965','29960','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63966','29961','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63967','29962','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63968','29963','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63969','29964','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63970','29965','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63971','29966','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63972','29967','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63973','29968','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63974','29969','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63975','29970','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63976','29971','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63977','29972','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63978','29973','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63979','29974','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63980','29975','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63981','29976','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63982','29977','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63983','29978','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63984','29979','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63985','29980','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63986','29981','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63987','29982','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63988','29983','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63989','29984','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63990','29985','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63991','29986','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63992','29987','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63993','29988','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63994','29989','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63995','29990','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63996','29991','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63997','29992','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63998','29993','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('63999','30050','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64000','30051','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64001','30052','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64002','30053','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64003','30054','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64004','30055','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64005','30142','1','12','$..[''{#CPU.UTIL}''].avg()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64006','30143','1','12','$..[''{#CPU.UTIL}''].avg()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64008','30145','1','12','$..[''{#CPU.UTIL}''].avg()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64009','30146','1','12','$..[''{#CPU.UTIL}''].avg()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64010','30157','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64011','30158','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64012','30161','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64013','30162','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64014','30163','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64015','30164','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64016','30167','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64017','30168','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64022','30175','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64023','30176','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64024','30179','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64025','30180','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64026','30181','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64027','30182','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64028','30185','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64029','30186','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64030','27079','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64031','27080','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64032','27082','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64033','27083','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64034','27084','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64035','27084','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64036','27085','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64037','27085','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64038','27086','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64039','27620','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64040','27621','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64041','27622','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64042','27622','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64043','27623','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64044','27624','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64045','27625','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64046','27625','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64047','27628','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64048','27977','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64049','27978','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64050','27979','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64051','27979','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64052','27980','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64053','27981','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64054','27982','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64055','27982','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64056','27985','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64057','28006','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64058','28007','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64059','28008','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64060','28008','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64061','28009','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64062','28010','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64063','28011','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64064','28011','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64065','28014','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64066','27099','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64067','27100','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64068','27101','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64069','27101','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64070','27102','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64071','27103','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64072','27104','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64073','27104','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64074','27105','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64075','27105','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64076','27106','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64077','27181','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64078','27182','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64079','27183','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64080','27183','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64081','27184','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64082','27185','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64083','27186','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64084','27186','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64085','27187','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64086','27187','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64087','27189','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64088','27216','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64089','27217','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64090','27218','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64091','27218','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64092','27219','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64093','27220','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64094','27221','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64095','27221','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64096','27222','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64097','27222','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64098','27224','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64099','27252','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64100','27253','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64101','27254','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64102','27254','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64103','27255','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64104','27256','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64105','27257','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64106','27257','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64107','27258','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64108','27258','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64109','27260','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64110','27273','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64111','27274','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64112','27275','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64113','27275','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64114','27276','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64115','27277','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64116','27278','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64117','27278','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64118','27279','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64119','27279','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64120','27281','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64121','27322','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64122','27323','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64123','27324','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64124','27324','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64125','27325','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64126','27326','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64127','27327','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64128','27327','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64129','27328','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64130','27328','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64131','27330','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64132','27451','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64133','27452','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64134','27453','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64135','27453','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64136','27454','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64137','27455','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64138','27456','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64139','27456','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64140','27457','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64141','27457','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64142','27459','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64143','27487','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64144','27488','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64145','27489','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64146','27489','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64147','27490','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64148','27491','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64149','27492','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64150','27492','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64151','27493','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64152','27493','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64153','27495','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64154','27521','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64155','27522','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64156','27523','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64157','27523','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64158','27524','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64159','27525','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64160','27526','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64161','27526','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64162','27527','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64163','27527','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64164','27529','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64165','27557','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64166','27558','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64167','27559','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64168','27559','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64169','27560','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64170','27561','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64171','27562','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64172','27562','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64173','27563','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64174','27563','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64175','27565','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64176','27643','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64177','27644','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64178','27645','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64179','27645','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64180','27646','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64181','27647','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64182','27648','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64183','27648','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64184','27649','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64185','27649','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64186','27651','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64187','27723','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64188','27724','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64189','27725','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64190','27725','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64191','27726','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64192','27727','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64193','27728','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64194','27728','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64195','27729','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64196','27729','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64197','27731','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64198','27757','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64199','27758','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64200','27759','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64201','27759','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64202','27760','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64203','27761','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64204','27762','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64205','27762','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64206','27763','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64207','27763','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64208','27765','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64209','27789','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64210','27790','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64211','27791','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64212','27791','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64213','27792','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64214','27793','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64215','27794','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64216','27794','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64217','27795','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64218','27795','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64219','27797','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64220','27873','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64221','27874','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64222','27875','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64223','27875','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64224','27876','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64225','27877','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64226','27878','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64227','27878','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64228','27879','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64229','27879','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64230','27881','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64231','27910','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64232','27911','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64233','27912','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64234','27912','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64235','27913','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64236','27914','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64237','27915','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64238','27915','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64239','27916','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64240','27916','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64241','27918','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64242','27945','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64243','27946','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64244','27947','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64245','27947','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64246','27948','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64247','27949','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64248','27950','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64249','27950','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64250','27951','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64251','27951','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64252','27953','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64253','28119','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64254','28120','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64255','28121','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64256','28121','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64257','28122','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64258','28123','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64259','28124','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64260','28124','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64261','28125','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64262','28125','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64263','28127','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64275','28224','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64276','28225','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64277','28226','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64278','28226','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64279','28227','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64280','28228','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64281','28229','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64282','28229','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64283','28230','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64284','28230','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64285','28232','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64286','28294','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64287','28295','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64288','28296','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64289','28296','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64290','28297','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64291','28298','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64292','28299','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64293','28299','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64294','28300','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64295','28300','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64296','28302','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64297','28969','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64298','28970','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64299','28971','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64300','28971','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64301','28972','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64302','28973','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64303','28974','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64304','28974','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64305','28975','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64306','28975','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64307','28977','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64308','27119','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64309','27120','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64310','27121','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64311','27121','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64312','27122','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64313','27123','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64314','27124','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64315','27124','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64316','27125','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64317','27125','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64318','27126','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64319','29078','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64320','29079','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64321','29080','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64322','29080','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64323','29081','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64324','29082','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64325','29083','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64326','29083','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64327','29084','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64328','29084','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64329','29086','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64330','22231','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64331','23318','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64332','29545','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64333','29546','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64334','10059','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64335','22834','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64336','22874','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64337','22914','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64338','22954','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64339','22994','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64340','23034','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64341','23161','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64342','23319','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64343','23320','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64344','23321','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64345','23322','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64346','23323','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64347','23324','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64348','23325','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64349','23326','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64350','29558','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64351','29560','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64352','29995','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64353','29997','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64354','23288','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64355','23327','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64356','27203','1','5','^(\w|-|\.|/)+ (\w|-|\.|/)+ (.+) Copyright
\3','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64357','27203','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64358','27207','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64359','30086','1','5','^((\w|-|\.|/)+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64360','30086','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64361','30087','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64362','27214','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64363','28305','1','21','try {
    var data = JSON.parse(value);
}
catch (error) {
    throw ''Failed to parse JSON of Arista sensor discovery.'';
}
var fields = [''{#SNMPINDEX}'',''{#SENSOR_TYPE}'',''{#SENSOR_INFO}'',''{#SENSOR_PRECISION}'',''{#THRESHOLD_LO_WARN}'',''{#THRESHOLD_LO_CRIT}'',''{#THRESHOLD_HI_WARN}'',''{#THRESHOLD_HI_CRIT}''];
data.forEach(function (element) {
    fields.forEach(function (field) {
        element[field] = element[field] || '''';
    });
});
return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64364','28323','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64365','28327','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64366','28328','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64367','27236','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64368','27237','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64369','27295','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64370','27296','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64371','27297','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64372','27314','1','1','0.5','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64373','27315','1','1','0.5','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64374','27318','1','1','0.5','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64375','27319','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64376','27320','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64377','27378','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64378','27379','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64379','30097','1','5','Version (.+), RELEASE
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64380','30097','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64381','27382','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64382','27383','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64383','27385','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64384','27386','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64385','28209','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64386','28210','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64387','30098','1','5','Version (.+), RELEASE
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64388','30098','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64389','30099','1','5','Version (.+), RELEASE
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64390','30099','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64391','30100','1','5','Version (.+), RELEASE
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64392','30100','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64393','27419','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64394','27428','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64395','27445','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64396','28208','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64397','27481','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64398','27482','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64399','27483','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64400','27484','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64401','27508','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64402','27509','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64403','27510','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64404','30106','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64405','27543','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64406','27544','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64407','27545','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64408','27546','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64409','27579','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64410','27580','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64411','27582','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64412','27583','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64413','30109','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64414','27591','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64415','30110','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64416','27675','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64417','27676','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64418','27677','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64419','27678','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64420','27679','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64421','28141','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64422','28142','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64423','28157','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64424','28158','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64425','27748','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64426','27749','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64427','27750','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64428','27754','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64429','27777','1','5','Firmware Version: ([0-9.]+),
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64430','27777','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64431','27778','1','5','(.+) - Firmware
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64432','27778','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64433','27785','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64434','27812','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64435','27813','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64436','30117','1','5','kernel (JUNOS [0-9a-zA-Z\.\-]+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64437','30117','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64438','28201','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64439','28204','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64440','28205','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64441','27893','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64442','27894','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64443','27895','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64444','27898','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64445','27900','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64446','30119','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64447','27905','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64448','27907','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64449','27908','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64450','31790','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64451','31792','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64452','31793','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64453','31794','1','20','15m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64454','31797','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64455','31799','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64456','32309','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64457','32312','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64458','32313','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64459','32314','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64460','32314','2','21','var FIELDS = [
  ''externalShortCircuit'',
  ''overcurrent'',
  ''mosfetShorted'',
  ''software'',
  ''loadHvd'',
  ''highTempDisconnect'',
  ''dipSwitchChanged'',
  ''customSettingsEdit''
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No faults'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64461','32315','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64462','32315','2','21','var FIELDS = [
  ''overcurrent'',
  ''mosfetSShorted'',
  ''software'',
  ''batteryHvd'',
  ''arrayHvd'',
  ''customSettingsEdit'',
  ''rtsShorted'',
  ''rtsNoLongerValid'',
  ''localTempSensorDamaged'',
  ''batteryLowVoltageDisconnect'',
  ''slaveTimeout'',
  ''dipSwitchChanged'',
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No faults'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64463','32316','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64464','32316','2','21','var FIELDS = [
  ''rtsOpen'',
  ''rtsShorted'',
  ''rtsDisconnected'',
  ''heatsinkTempSensorOpen'',
  ''heatsinkTempSensorShorted'',
  ''heatsinkTempLimit'',
  ''inductorTempSensorOpen'',
  ''inductorTempSensorShorted'',
  ''inductorTempLimit'',
  ''currentLimit'',
  ''currentMeasurementError'',
  ''batterySenseOutOfRange'',
  ''batterySenseDisconnected'',
  ''uncalibrated'',
  ''tb5v'',
  ''fp10SupplyOutOfRange'',
  ''unused'',
  ''mosfetOpen'',
  ''arrayCurrentOffset'',
  ''loadCurrentOffset'',
  ''p33SupplyOutOfRange'',
  ''p12SupplyOutOfRange'',
  ''hightInputVoltageLimit'',
  ''controllerReset'',
  ''loadLvd'',
  ''logTimeout'',
  ''eepromAccessFailure''
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No alarms'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64465','32320','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64466','32322','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64467','32323','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64468','32329','1','21','var v_range = [
      [[0, 18], [12, 15, 11.5, 15.5]],
      [[18, 36], [24, 30, 23, 31]],
      [[36, 99], [48, 60, 46, 62]],
  ],
  result = [];

for (var idx in v_range) {
    if (v_range[idx][0][0] < value && value <= v_range[idx][0][1]) {
        result = [{
            ''{#VOLTAGE.MIN.WARN}'': parseInt({$VOLTAGE.MIN.WARN}) || v_range[idx][1][0],
            ''{#VOLTAGE.MAX.WARN}'': parseInt({$VOLTAGE.MAX.WARN}) || v_range[idx][1][1],
            ''{#VOLTAGE.MIN.CRIT}'': parseInt({$VOLTAGE.MIN.CRIT}) || v_range[idx][1][2],
            ''{#VOLTAGE.MAX.CRIT}'': parseInt({$VOLTAGE.MAX.CRIT}) || v_range[idx][1][3],
            ''{#SINGLETON}'': ''''
        }];
        break;
    }
}

return JSON.stringify(result);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64469','32332','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64470','32332','2','21','var FIELDS = [
  ''rtsOpen'',
  ''rtsShorted'',
  ''rtsDisconnected'',
  ''heatsinkTempSensorOpen'',
  ''heatsinkTempSensorShorted'',
  ''heatsinkTempLimit'',
  ''currentLimit'',
  ''currentMeasurementError'',
  ''batterySenseOutOfRange'',
  ''batterySenseDisconnected'',
  ''uncalibrated'',
  ''batteryTempOutOfRange'',
  ''fp10SupplyOutOfRange'',
  ''mosfetOpen'',
  ''arrayCurrentOffset'',
  ''loadCurrentOffset'',
  ''p33SupplyOutOfRange'',
  ''p12SupplyOutOfRange'',
  ''hightInputVoltageLimit'',
  ''controllerReset'',
  ''loadLvd'',
  ''logTimeout'',
  ''eepromAccessFailure''
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No alarms'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64471','32335','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64472','32336','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64473','32337','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64474','32337','2','21','var FIELDS = [
  ''externalShortCircuit'',
  ''overcurrent'',
  ''mosfetShorted'',
  ''software'',
  ''loadHvd'',
  ''highTempDisconnect'',
  ''dipSwitchChanged'',
  ''customSettingsEdit'',
  ''p3Fault''
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No faults'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64475','32338','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64476','32338','2','21','var FIELDS = [
  ''overcurrent'',
  ''mosfetSShorted'',
  ''software'',
  ''batteryHvd'',
  ''arrayHvd'',
  ''customSettingsEdit'',
  ''rtsShorted'',
  ''rtsNoLongerValid'',
  ''localTempSensorDamaged'',
  ''batteryLowVoltageDisconnect'',
  ''slaveTimeout'',
  ''dipSwitchChanged'',
  ''p3Fault'',
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No faults'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64477','32341','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64478','32343','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64479','32345','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64480','32346','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64481','32349','1','21','var v_range = [
      [[0, 18], [12, 15, 11.5, 15.5]],
      [[18, 36], [24, 30, 23, 31]],
      [[36, 99], [48, 60, 46, 62]],
  ],
  result = [];

for (var idx in v_range) {
    if (v_range[idx][0][0] < value && value <= v_range[idx][0][1]) {
        result = [{
            ''{#VOLTAGE.MIN.WARN}'': parseInt({$VOLTAGE.MIN.WARN}) || v_range[idx][1][0],
            ''{#VOLTAGE.MAX.WARN}'': parseInt({$VOLTAGE.MAX.WARN}) || v_range[idx][1][1],
            ''{#VOLTAGE.MIN.CRIT}'': parseInt({$VOLTAGE.MIN.CRIT}) || v_range[idx][1][2],
            ''{#VOLTAGE.MAX.CRIT}'': parseInt({$VOLTAGE.MAX.CRIT}) || v_range[idx][1][3],
            ''{#SINGLETON}'': ''''
        }];
        break;
    }
}

return JSON.stringify(result);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64482','32351','1','1','0.01509857178','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64483','32351','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64484','32352','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64485','32355','1','1','0.003051757813','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64486','32355','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64487','32356','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64488','32357','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64489','32357','2','21','var FIELDS = [
  ''externalShortCircuit'',
  ''overcurrent'',
  ''mosfetShorted'',
  ''software'',
  ''loadHvd'',
  ''highTempDisconnect'',
  ''customSettingsEdit'',
  ''unknownLoadFault''
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No faults'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64490','32358','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64491','32358','2','21','var FIELDS = [
  ''overcurrent'',
  ''mosfetSShorted'',
  ''softwareFault'',
  ''batteryHvd'',
  ''arrayHvd'',
  ''customSettingsEdit'',
  ''rtsShorted'',
  ''rtsNoLongerValid'',
  ''localTempSensorDamaged'',
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No faults'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64492','32359','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64493','32359','2','21','var FIELDS = [
  ''rtsOpen'',
  ''rtsShorted'',
  ''rtsDisconnected'',
  ''heatsinkTempSensorOpen'',
  ''heatsinkTempSensorShorted'',
  ''sspptHot'',
  ''currentLimit'',
  ''currentOffset'',
  ''undefined'',
  ''undefined1'',
  ''uncalibrated'',
  ''rtsMiswire'',
  ''undefined12'',
  ''undefined123'',
  ''systemMiswire'',
  ''mosfetSOpen'',
  ''p12VoltageReferenceOff'',
  ''highVaCurrentLimit'',
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No alarms'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64494','32360','1','1','0.003051757813','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64495','32360','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64496','32361','1','1','0.002415771484','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64497','32361','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64498','32362','1','1','0.003051757813','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64499','32362','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64500','32363','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64501','32365','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64502','32366','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64503','32367','1','1','0.002415771484','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64504','32367','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64505','32368','1','1','0.003051757813','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64506','32369','1','1','0.003051757813','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64507','32369','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64508','32370','1','1','0.003051757813','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64509','32370','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64510','32372','1','21','var v_range = [
      [[0, 18], [12, 15, 11.5, 15.5]],
      [[18, 36], [24, 30, 23, 31]],
      [[36, 99], [48, 60, 46, 62]],
  ],
  result = [];

for (var idx in v_range) {
    if (v_range[idx][0][0] < value && value <= v_range[idx][0][1]) {
        result = [{
            ''{#VOLTAGE.MIN.WARN}'': parseInt({$VOLTAGE.MIN.WARN}) || v_range[idx][1][0],
            ''{#VOLTAGE.MAX.WARN}'': parseInt({$VOLTAGE.MAX.WARN}) || v_range[idx][1][1],
            ''{#VOLTAGE.MIN.CRIT}'': parseInt({$VOLTAGE.MIN.CRIT}) || v_range[idx][1][2],
            ''{#VOLTAGE.MAX.CRIT}'': parseInt({$VOLTAGE.MAX.CRIT}) || v_range[idx][1][3],
            ''{#SINGLETON}'': ''''
        }];
        break;
    }
}

return JSON.stringify(result);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64511','32373','1','1','0.003051757813','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64512','32373','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64513','32374','1','1','2.581787109375E-4','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64514','32374','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64515','32375','1','1','1.953125E-4','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64516','32375','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64517','32376','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64518','32377','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64519','32377','2','21','var FIELDS = [
  ''heatsinkTempSensorOpen'',
  ''heatsinkTempSensorShort'',
  ''unknownAlarm'',
  ''suresineHot''
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No alarms'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64520','32378','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64521','32378','2','21','var FIELDS = [
  ''reset'',
  ''overcurrent'',
  ''unknownFault'',
  ''software'',
  ''highVoltageDisconnect'',
  ''suresineHot'',
  ''dipSwitchChanged'',
  ''customSettingsEdit''
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No faults'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64522','32379','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64523','32381','1','21','var v_range = [
      [[0, 18], [12, 15, 11.5, 15.5]],
      [[18, 36], [24, 30, 23, 31]],
      [[36, 99], [48, 60, 46, 62]],
  ],
  result = [];

for (var idx in v_range) {
    if (v_range[idx][0][0] < value && value <= v_range[idx][0][1]) {
        result = [{
            ''{#VOLTAGE.MIN.WARN}'': parseInt({$VOLTAGE.MIN.WARN}) || v_range[idx][1][0],
            ''{#VOLTAGE.MAX.WARN}'': parseInt({$VOLTAGE.MAX.WARN}) || v_range[idx][1][1],
            ''{#VOLTAGE.MIN.CRIT}'': parseInt({$VOLTAGE.MIN.CRIT}) || v_range[idx][1][2],
            ''{#VOLTAGE.MAX.CRIT}'': parseInt({$VOLTAGE.MAX.CRIT}) || v_range[idx][1][3],
            ''{#SINGLETON}'': ''''
        }];
        break;
    }
}

return JSON.stringify(result);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64524','32382','1','1','2.581787109375E-4','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64525','32382','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64526','32386','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64527','32387','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64528','32388','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64529','32388','2','21','var FIELDS = [
  ''overcurrent'',
  ''fetShort'',
  ''softwareFault'',
  ''batteryHvd'',
  ''arrayHvd'',
  ''dipSwitchChange'',
  ''customSettingsEdit'',
  ''rtsShorted'',
  ''rtsDisconnected'',
  ''eepromRetryLimit'',
  ''controllerWasReset'',
  ''chargeSlaveControlTimeout'',
  ''rs232SerialToMeterBridge'',
  ''batteryLvd'',
  ''fault14Undefined'',
  ''powerboardCommunicationFault'',
  ''fault16Software'',
  ''fault17Software'',
  ''fault18Software'',
  ''fault19Software'',
  ''fault20Software'',
  ''fault21Software'',
  ''fpgaVersion'',
  ''currentSensorReferenceOutOfRange'',
  ''ia-refSlaveModeTimeout'',
  ''blockbusBoot'',
  ''hscommMaster'',
  ''hscomm'',
  ''slave'',
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No faults'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64530','32389','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64531','32389','2','21','var FIELDS = [
  ''rtsOpen'',
  ''rtsShorted'',
  ''rtsDisconnected'',
  ''heatsinkTempSensorOpen'',
  ''heatsinkTempSensorShorted'',
  ''highTemperatureCurrentLimit'',
  ''currentLimit'',
  ''currentOffset'',
  ''batterySense'',
  ''batterySenseDisconnected'',
  ''uncalibrated'',
  ''rtsMiswire'',
  ''highVoltageDisconnect'',
  ''undefined'',
  ''systemMiswire'',
  ''mosfetSOpen'',
  ''p12VoltageOutOfRange'',
  ''highArrayVCurrentLimit'',
  ''maxAdcValueReached'',
  ''controllerWasReset'',
  ''alarm21Internal'',
  ''p3VoltageOutOfRange'',
  ''derateLimit'',
  ''arrayCurrentOffset'',
  ''ee-i2cRetryLimit'',
  ''ethernetAlarm'',
  ''lvd'',
  ''software'',
  ''fp12VoltageOutOfRange'',
  ''extflashFault'',
  ''slaveControlFault'',
  ''alarm32Undefined''
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No alarms'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64532','32391','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64533','32400','1','21','var v_range = [
      [[0, 18], [12, 15, 11.5, 15.5]],
      [[18, 36], [24, 30, 23, 31]],
      [[36, 99], [48, 60, 46, 62]],
  ],
  result = [];

for (var idx in v_range) {
    if (v_range[idx][0][0] < value && value <= v_range[idx][0][1]) {
        result = [{
            ''{#VOLTAGE.MIN.WARN}'': parseInt({$VOLTAGE.MIN.WARN}) || v_range[idx][1][0],
            ''{#VOLTAGE.MAX.WARN}'': parseInt({$VOLTAGE.MAX.WARN}) || v_range[idx][1][1],
            ''{#VOLTAGE.MIN.CRIT}'': parseInt({$VOLTAGE.MIN.CRIT}) || v_range[idx][1][2],
            ''{#VOLTAGE.MAX.CRIT}'': parseInt({$VOLTAGE.MAX.CRIT}) || v_range[idx][1][3],
            ''{#SINGLETON}'': ''''
        }];
        break;
    }
}

return JSON.stringify(result);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64534','32402','1','1','0.00244140625','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64535','32402','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64536','32403','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64537','32405','1','1','0.005493164063','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64538','32405','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64539','32406','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64540','32407','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64541','32407','2','21','var FIELDS = [
  ''overcurrent'',
  ''fetShort'',
  ''softwareFault'',
  ''batteryHvd'',
  ''arrayHvd'',
  ''dipSwitchChange'',
  ''customSettingsEdit'',
  ''rtsShorted'',
  ''rtsDisconnected'',
  ''eepromRetryLimit'',
  ''fault11Undefined'',
  ''slaveControlTimeout'',
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No faults'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64542','32408','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64543','32408','2','21','var FIELDS = [
  ''rtsOpen'',
  ''rtsShorted'',
  ''rtsDisconnected'',
  ''heatsinkTempSensorOpen'',
  ''heatsinkTempSensorShorted'',
  ''highTemperatureCurrentLimit'',
  ''currentLimit'',
  ''currentOffset'',
  ''batterySense'',
  ''batterySenseDisconnected'',
  ''uncalibrated'',
  ''rtsMiswire'',
  ''highVoltageDisconnect'',
  ''undefined'',
  ''systemMiswire'',
  ''mosfetSOpen'',
  ''p12VoltageReferenceOff'',
  ''highArrayVCurrentLimit'',
  ''maxAdcValueReached'',
  ''controllerWasReset'',
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No alarms'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64544','32410','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64545','32411','1','1','0.1098632813','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64546','32411','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64547','32412','1','1','0.1098632813','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64548','32412','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64549','32413','1','1','0.00244140625','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64550','32413','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64551','32414','1','1','0.005493164063','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64552','32415','1','1','0.005493164063','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64553','32415','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64554','32416','1','1','0.005493164063','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64555','32416','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64556','32417','1','1','0.005493164063','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64557','32417','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64558','32419','1','21','var v_range = [
      [[0, 18], [12, 15, 11.5, 15.5]],
      [[18, 36], [24, 30, 23, 31]],
      [[36, 99], [48, 60, 46, 62]],
  ],
  result = [];

for (var idx in v_range) {
    if (v_range[idx][0][0] < value && value <= v_range[idx][0][1]) {
        result = [{
            ''{#VOLTAGE.MIN.WARN}'': parseInt({$VOLTAGE.MIN.WARN}) || v_range[idx][1][0],
            ''{#VOLTAGE.MAX.WARN}'': parseInt({$VOLTAGE.MAX.WARN}) || v_range[idx][1][1],
            ''{#VOLTAGE.MIN.CRIT}'': parseInt({$VOLTAGE.MIN.CRIT}) || v_range[idx][1][2],
            ''{#VOLTAGE.MAX.CRIT}'': parseInt({$VOLTAGE.MAX.CRIT}) || v_range[idx][1][3],
            ''{#SINGLETON}'': ''''
        }];
        break;
    }
}

return JSON.stringify(result);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64559','32420','1','1','0.005493164063','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64560','32420','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64561','32421','1','1','0.002950042725','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64562','32423','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64563','32424','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64564','32424','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64565','32425','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64566','32425','2','21','var FIELDS = [
  ''rtsOpen'',
  ''rtsShorted'',
  ''rtsDisconnected'',
  ''heatsinkTempSensorOpen'',
  ''heatsinkTempSensorShorted'',
  ''tristarHot'',
  ''currentLimit'',
  ''currentOffset'',
  ''batterySense'',
  ''batterySenseDisconnected'',
  ''uncalibrated'',
  ''rtsMiswire'',
  ''highVoltageDisconnect'',
  ''diversionLoadNearMax'',
  ''systemMiswire'',
  ''mosfetSOpen'',
  ''p12VoltageReferenceOff'',
  ''loadDisconnectState'',
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No alarms'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64567','32426','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64568','32426','2','21','var FIELDS = [
  ''externalShort'',
  ''overcurrent'',
  ''mosfetSShorted'',
  ''softwareFault'',
  ''highVoltageDisconnect'',
  ''tristarHot'',
  ''dipSwitchChange'',
  ''customSettingsEdit'',
  ''reset'',
  ''systemMiswire'',
  ''rtsShorted'',
  ''rtsDisconnected'',
];

var flags = parseInt(value.replace(/\x20/g, ''''), 16),
  result = [];

for (var i = 0, f = 1 << 31 >>> 0, l = FIELDS.length; i < l; i++, f >>>= 1) {
    if (flags & f) {
        result.push(FIELDS[i]);
    }
}

return result.length ? result.join(''\n'') : ''No faults'';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64569','32427','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64570','32430','1','21','var v_range = [
      [[0, 18], [12, 15, 11.5, 15.5]],
      [[18, 36], [24, 30, 23, 31]],
      [[36, 99], [48, 60, 46, 62]],
  ],
  result = [];

for (var idx in v_range) {
    if (v_range[idx][0][0] < value && value <= v_range[idx][0][1]) {
        result = [{
            ''{#VOLTAGE.MIN.WARN}'': parseInt({$VOLTAGE.MIN.WARN}) || v_range[idx][1][0],
            ''{#VOLTAGE.MAX.WARN}'': parseInt({$VOLTAGE.MAX.WARN}) || v_range[idx][1][1],
            ''{#VOLTAGE.MIN.CRIT}'': parseInt({$VOLTAGE.MIN.CRIT}) || v_range[idx][1][2],
            ''{#VOLTAGE.MAX.CRIT}'': parseInt({$VOLTAGE.MAX.CRIT}) || v_range[idx][1][3],
            ''{#SINGLETON}'': ''''
        }];
        break;
    }
}

return JSON.stringify(result);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64571','32431','1','21','var mode = parseInt(value);
return JSON.stringify((mode === 0 || mode === 2) ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64572','32432','1','21','return JSON.stringify(parseInt(value) === 0 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64573','32433','1','21','return JSON.stringify(parseInt(value) === 2 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64574','32434','1','21','var mode = parseInt(value);
return JSON.stringify((mode === 1 || mode === 2) ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64575','32435','1','21','return JSON.stringify(parseInt(value) === 1 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64576','32436','1','1','0.002950042725','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64577','32436','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64578','32437','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64579','32438','1','1','0.002950042725','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64580','32438','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64581','32439','1','1','0.004246520996','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64582','32439','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64583','32440','1','1','0.002034515381','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64584','32440','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64585','32441','1','1','0.3921568627','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64586','32441','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64587','32442','1','1','0.009664001465','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64588','32442','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64589','32443','1','1','0.004246520996','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64590','32443','2','5','^(\d+)(\.\d{1,2})?
\1\2','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64591','32444','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64592','27930','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64593','27931','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64594','27936','1','5','60 Secs \( ([0-9\.]+)%\).+300 Secs
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64595','30121','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64596','27967','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64597','27968','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64598','27970','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64599','27971','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64600','30125','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64601','27997','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64602','27998','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64603','27999','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64604','28000','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64605','28026','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64606','28027','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64607','30132','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64608','30133','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64609','30134','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64610','30135','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64611','29087','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64612','29089','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64613','29102','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64614','29111','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64615','29113','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64616','29114','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64617','29116','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64618','29117','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64619','29120','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64620','29121','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64621','29122','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64622','29123','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64623','29124','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64624','29126','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64625','29139','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64626','29148','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64627','29150','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64628','29151','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64629','29153','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64630','29154','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64631','29157','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64632','29158','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64633','29159','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64634','29160','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64635','29161','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64636','29163','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64637','29176','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64638','29185','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64639','29187','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64640','29188','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64641','29190','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64642','29191','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64643','29194','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64644','29195','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64645','29196','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64646','29197','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64647','29198','1','21','//Calculate utilization
return (100 - value)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64648','31270','1','21','return (100-value);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64649','29199','1','21','//Calculate utilization
return (100 - value)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64650','31271','1','21','return (100-value);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64651','29200','1','21','//Calculate utilization
return (100 - value)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64652','31272','1','21','return (100-value);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64653','31273','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64654','31274','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64655','31275','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64656','29216','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64657','29216','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64658','29217','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64659','29217','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64660','29218','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64661','29219','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64662','29220','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64663','29221','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64664','29222','1','21','var newvalue;
switch(value) {
  case "up":
    newvalue = 1;
    break;
  case "down":
    newvalue = 2;
    break;
  case "testing":
    newvalue = 4;
    break;
  case "unknown":
    newvalue = 5;
    break;
  case "dormant":
    newvalue = 6;
    break;
  case "notPresent":
    newvalue = 7;
    break;
  default:
    newvalue = "Problem parsing interface operstate in JS";
}
return newvalue;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64665','29223','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64666','31278','1','21','return JSON.stringify(value.trim().split(/ +/));','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64667','29230','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64668','29230','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64669','29231','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64670','29231','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64671','29232','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64672','29233','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64673','29234','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64674','29235','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64675','29236','1','21','var newvalue;
switch(value) {
  case "up":
    newvalue = 1;
    break;
  case "down":
    newvalue = 2;
    break;
  case "testing":
    newvalue = 4;
    break;
  case "unknown":
    newvalue = 5;
    break;
  case "dormant":
    newvalue = 6;
    break;
  case "notPresent":
    newvalue = 7;
    break;
  default:
    newvalue = "Problem parsing interface operstate in JS";
}
return newvalue;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64676','29237','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64677','31281','1','21','return JSON.stringify(value.trim().split(/ +/));','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64678','29244','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64679','29244','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64680','29245','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64681','29245','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64682','29246','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64683','29247','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64684','29248','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64685','29249','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64686','29250','1','21','var newvalue;
switch(value) {
  case "up":
    newvalue = 1;
    break;
  case "down":
    newvalue = 2;
    break;
  case "testing":
    newvalue = 4;
    break;
  case "unknown":
    newvalue = 5;
    break;
  case "dormant":
    newvalue = 6;
    break;
  case "notPresent":
    newvalue = 7;
    break;
  default:
    newvalue = "Problem parsing interface operstate in JS";
}
return newvalue;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64687','29251','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64688','31284','1','21','return JSON.stringify(value.trim().split(/ +/));','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64689','31285','1','12','$[10]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64690','31285','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64691','31285','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64692','31286','1','12','$[0]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64693','31286','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64694','31287','1','12','$[3]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64695','31287','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64696','31287','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64697','31288','1','12','$[9]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64698','31288','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64699','31288','3','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64700','31289','1','12','$[4]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64701','31289','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64702','31290','1','12','$[7]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64703','31290','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64704','31290','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64705','31291','1','12','$[10]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64706','31291','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64707','31291','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64708','31292','1','12','$[0]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64709','31292','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64710','31293','1','12','$[3]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64711','31293','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64712','31293','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64713','31294','1','12','$[9]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64714','31294','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64715','31294','3','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64716','31295','1','12','$[4]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64717','31295','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64718','31296','1','12','$[7]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64719','31296','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64720','31296','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64721','31297','1','12','$[10]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64722','31297','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64723','31297','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64724','31298','1','12','$[0]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64725','31298','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64726','31299','1','12','$[3]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64727','31299','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64728','31299','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64729','31300','1','12','$[9]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64730','31300','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64731','31300','3','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64732','31301','1','12','$[4]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64733','31301','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64734','31302','1','12','$[7]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64735','31302','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64736','31302','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64737','29273','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64738','29275','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64739','29288','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64740','29297','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64741','29299','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64742','29300','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64743','29302','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64744','29303','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64745','29306','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64746','29307','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64747','29308','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64748','29309','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64749','29310','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64750','29312','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64751','29325','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64752','29334','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64753','29336','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64754','29337','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64755','29339','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64756','29340','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64757','29343','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64758','29344','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64759','29345','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64760','29346','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64761','29347','1','21','//Calculate utilization
return (100 - value)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64762','31303','1','21','return (100-value);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64763','29348','1','21','//Calculate utilization
return (100 - value)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64764','31304','1','21','return (100-value);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64765','31305','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64766','31306','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64767','29361','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64768','29361','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64769','29362','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64770','29362','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64771','29363','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64772','29364','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64773','29365','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64774','29366','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64775','29367','1','21','var newvalue;
switch(value) {
  case "up":
    newvalue = 1;
    break;
  case "down":
    newvalue = 2;
    break;
  case "testing":
    newvalue = 4;
    break;
  case "unknown":
    newvalue = 5;
    break;
  case "dormant":
    newvalue = 6;
    break;
  case "notPresent":
    newvalue = 7;
    break;
  default:
    newvalue = "Problem parsing interface operstate in JS";
}
return newvalue;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64776','29368','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64777','31309','1','21','return JSON.stringify(value.trim().split(/ +/));','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64778','29375','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64779','29375','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64780','29376','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64781','29376','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64782','29377','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64783','29378','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64784','29379','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64785','29380','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64786','29381','1','21','var newvalue;
switch(value) {
  case "up":
    newvalue = 1;
    break;
  case "down":
    newvalue = 2;
    break;
  case "testing":
    newvalue = 4;
    break;
  case "unknown":
    newvalue = 5;
    break;
  case "dormant":
    newvalue = 6;
    break;
  case "notPresent":
    newvalue = 7;
    break;
  default:
    newvalue = "Problem parsing interface operstate in JS";
}
return newvalue;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64787','29382','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64788','31312','1','21','return JSON.stringify(value.trim().split(/ +/));','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64789','31313','1','12','$[10]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64790','31313','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64791','31313','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64792','31314','1','12','$[0]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64793','31314','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64794','31315','1','12','$[3]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64795','31315','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64796','31315','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64797','31316','1','12','$[9]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64798','31316','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64799','31316','3','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64800','31317','1','12','$[4]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64801','31317','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64802','31318','1','12','$[7]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64803','31318','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64804','31318','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64805','31319','1','12','$[10]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64806','31319','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64807','31319','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64808','31320','1','12','$[0]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64809','31320','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64810','31321','1','12','$[3]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64811','31321','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64812','31321','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64813','31322','1','12','$[9]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64814','31322','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64815','31322','3','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64816','31323','1','12','$[4]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64817','31323','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64818','31324','1','12','$[7]','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64819','31324','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64820','31324','3','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64821','29398','1','22','{__name__=~"^node_time(?:_seconds)?$"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64822','29399','1','23','{__name__=~"^node_cpu(?:_seconds_total)?$",cpu=~".+",mode="steal"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64823','29399','2','21','//calculates average, all cpu utilization
var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0)/valueArr.length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64824','29399','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64825','29399','4','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64826','29400','1','22','{__name__=~"node_memory_SwapFree"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64827','29401','1','22','{__name__=~"node_memory_SwapTotal"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64828','29402','1','22','{__name__=~"node_memory_MemAvailable"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64829','29403','1','22','{__name__=~"node_memory_MemTotal"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64830','29404','1','22','{__name__=~"^node_boot_time(?:_seconds)?$"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64831','29405','1','22','{__name__=~"node_context_switches"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64832','29405','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64833','29406','1','22','{__name__=~"node_intr"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64834','29406','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64835','29407','1','23','{__name__=~"^node_cpu(?:_guest_seconds_total)?$",cpu=~".+",mode=~"^(?:nice|guest_nice)$"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64836','29407','2','21','//calculates average, all cpu utilization
var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0)/valueArr.length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64837','29407','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64838','29407','4','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64839','29408','1','23','{__name__=~"^node_cpu(?:_guest_seconds_total)?$",cpu=~".+",mode=~"^(?:user|guest)$"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64840','29408','2','21','//calculates average, all cpu utilization
var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0)/valueArr.length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64841','29408','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64842','29408','4','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64843','29409','1','23','{__name__=~"^node_cpu(?:_seconds_total)?$",cpu=~".+",mode="irq"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64844','29409','2','21','//calculates average, all cpu utilization
var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0)/valueArr.length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64845','29409','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64846','29409','4','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64847','29410','1','23','{__name__=~"^node_cpu(?:_seconds_total)?$",cpu=~".+",mode="iowait"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64848','29410','2','21','//calculates average, all cpu utilization
var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0)/valueArr.length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64849','29410','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64850','29410','4','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64851','29411','1','23','{__name__=~"^node_cpu(?:_seconds_total)?$",cpu=~".+",mode="nice"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64852','29411','2','21','//calculates average, all cpu utilization
var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0)/valueArr.length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64853','29411','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64854','29411','4','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64855','29412','1','23','{__name__=~"^node_cpu(?:_seconds_total)?$",cpu=~".+",mode="softirq"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64856','29412','2','21','//calculates average, all cpu utilization
var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0)/valueArr.length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64857','29412','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64858','29412','4','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64859','29413','1','23','{__name__=~"^node_cpu(?:_seconds_total)?$",cpu=~".+",mode="user"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64860','29413','2','21','//calculates average, all cpu utilization
var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0)/valueArr.length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64861','29413','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64862','29413','4','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64863','29414','1','22','node_uname_info
nodename','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64864','29414','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64865','29415','1','22','node_exporter_build_info
version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64866','29415','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64867','29416','1','23','{__name__=~"^node_cpu(?:_seconds_total)?$",cpu=~".+",mode="idle"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64868','29416','2','21','//calculates average, all cpu utilization
var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0)/valueArr.length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64869','29416','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64870','29416','4','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64871','29417','1','23','{__name__=~"^node_cpu(?:_seconds_total)?$",cpu=~".+",mode="idle"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64872','29417','2','21','//count the number of cores
return JSON.parse(value).length
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64873','29418','1','22','node_load15
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64874','29419','1','22','node_load5
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64875','29420','1','22','node_load1
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64876','29421','1','22','{__name__=~"^node_boot_time(?:_seconds)?$"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64877','29421','2','21','//use boottime to calculate uptime
return (Math.floor(Date.now()/1000)-Number(value));','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64878','29422','1','22','node_uname_info
machine','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64879','29422','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64880','29423','1','22','node_filefd_allocated
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64881','29424','1','22','node_filefd_maximum
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64882','29424','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64883','29425','1','23','node_uname_info','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64884','29425','2','21','var info = JSON.parse(value)[0];
   return info.labels.sysname+'' version: ''+info.labels.release+'' ''+info.labels.version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64885','29425','3','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64886','29426','1','23','{__name__=~"^node_cpu(?:_seconds_total)?$",cpu=~".+",mode="system"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64887','29426','2','21','//calculates average, all cpu utilization
var valueArr = JSON.parse(value);
return valueArr.reduce(function(acc,obj){
   return acc + parseFloat(obj[''value''])
},0)/valueArr.length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64888','29426','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64889','29426','4','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64890','29427','1','21','//Calculate utilization
return (100 - value)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64891','29428','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64892','29429','1','23','{__name__=~"^node_network_info$"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64893','29430','1','23','{__name__=~"^node_filesystem_size(?:_bytes)?$", mountpoint=~".+"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64894','29431','1','23','node_disk_io_now{device=~".+"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64895','29436','1','22','node_network_receive_bytes_total{device="{#IFNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64896','29436','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64897','29436','3','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64898','29437','1','22','node_network_transmit_bytes_total{device="{#IFNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64899','29437','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64900','29437','3','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64901','29438','1','22','node_network_transmit_errs_total{device="{#IFNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64902','29438','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64903','29439','1','22','node_network_receive_errs_total{device="{#IFNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64904','29439','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64905','29440','1','22','node_network_receive_drop_total{device="{#IFNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64906','29440','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64907','29441','1','22','node_network_transmit_drop_total{device="{#IFNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64908','29441','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64909','29442','1','22','node_network_speed_bytes{device="{#IFNAME}"}
','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64910','29442','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64911','29443','1','22','node_network_protocol_type{device="{#IFNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64912','29444','1','22','node_network_info{device="{#IFNAME}"}
operstate','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64913','29444','2','21','var newvalue;
switch(value) {
  case "up":
    newvalue = 1;
    break;
  case "down":
    newvalue = 2;
    break;
  case "testing":
    newvalue = 4;
    break;
  case "unknown":
    newvalue = 5;
    break;
  case "dormant":
    newvalue = 6;
    break;
  case "notPresent":
    newvalue = 7;
    break;
  default:
    newvalue = "Problem parsing interface operstate in JS";
}
return newvalue;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64914','29445','1','22','{__name__=~"^node_filesystem_avail(?:_bytes)?$", mountpoint="{#FSNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64915','29446','1','22','{__name__=~"^node_filesystem_size(?:_bytes)?$", mountpoint="{#FSNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64916','29447','1','23','{__name__=~"node_filesystem_files.*",mountpoint="{#FSNAME}"}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64917','29447','2','21','//count vfs.fs.inode.pfree
var inode_free;
var inode_total;
JSON.parse(value).forEach(function(metric) {
  if (metric[''name''] == ''node_filesystem_files''){
      inode_total = metric[''value''];
  } else if (metric[''name''] == ''node_filesystem_files_free''){
      inode_free = metric[''value''];
  }
});
return (inode_free/inode_total)*100;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64918','29448','1','22','node_disk_reads_completed_total{device="{#DEVNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64919','29448','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64920','29449','1','22','node_disk_writes_completed_total{device="{#DEVNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64921','29449','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64922','29450','1','22','node_disk_read_time_seconds_total{device="{#DEVNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64923','29450','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64924','29451','1','22','node_disk_write_time_seconds_total{device="{#DEVNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64925','29451','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64926','29452','1','22','node_disk_io_time_weighted_seconds_total{device="{#DEVNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64927','29452','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64928','29453','1','22','node_disk_io_time_seconds_total{device="{#DEVNAME}"}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64929','29453','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64930','29453','3','1','100','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64931','28979','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64932','28980','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64933','28981','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64934','28982','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64935','28984','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64936','28985','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64937','28990','1','21','//count the number of cores
return JSON.parse(value).length;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64938','28991','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64939','28992','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64940','28994','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64941','28995','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64942','28996','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64943','28997','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64944','28999','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64945','29000','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64946','29005','1','21','//count the number of cores
return JSON.parse(value).length;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64947','29006','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64948','29007','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64949','29009','1','21','//count the number of CPU cores
return JSON.stringify([{"{#CPU.COUNT}": value, "{#SNMPINDEX}": 0, "{#SINGLETON}":""}])
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64950','29012','1','21','//count the number of CPU cores
return JSON.stringify([{"{#CPU.COUNT}": value, "{#SNMPINDEX}": 0, "{#SINGLETON}":""}])
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64951','29014','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64952','29015','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64953','29017','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64954','29017','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64955','29018','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64956','29018','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64957','29019','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64958','29019','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64959','29020','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64960','29020','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64961','29021','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64962','29021','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64963','29022','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64964','29022','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64965','29023','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64966','29023','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64967','29024','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64968','29024','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64969','29025','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64970','29025','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64971','29026','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64972','29026','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64973','29027','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64974','29028','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64975','29030','1','21','return (100-value);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64976','29031','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64977','29032','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64978','29034','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64979','29034','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64980','29035','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64981','29035','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64982','29036','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64983','29036','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64984','29037','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64985','29037','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64986','29038','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64987','29038','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64988','29039','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64989','29039','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64990','29040','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64991','29040','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64992','29041','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64993','29041','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64994','29042','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64995','29042','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64996','29043','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64997','29043','2','21','//to get utilization in %, divide by N, where N is number of cores.
return value/{#CPU.COUNT}
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64998','29044','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('64999','29045','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65000','29047','1','21','return (100-value);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65001','29048','1','21','//Calculate utilization
return (100 - value)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65002','29049','1','21','//Calculate utilization
return (100 - value)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65003','29474','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65004','29475','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65005','29478','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65006','29500','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65007','29501','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65008','29504','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65009','31331','1','21','return (100 - value)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65010','31332','1','21','return (100 - value)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65011','31333','1','25','{#INSTANCE}
{#DEVNAME}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65014','31334','1','25','{#INSTANCE}
{#DEVNAME}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65047','29581','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65048','29582','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65049','29585','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65050','29607','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65051','29608','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65052','29611','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65053','31349','1','21','return (100 - value)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65054','31350','1','21','return (100 - value)','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65055','31351','1','25','{#INSTANCE}
{#DEVNAME}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65058','31352','1','25','{#INSTANCE}
{#DEVNAME}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65091','30688','1','12','$.[?(@.id==''{#SENSOR_ID}'')].state.text.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65092','30688','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65093','30689','1','12','$.[?(@.id==''{#SENSOR_ID}'')].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65094','30689','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65095','30073','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65096','30074','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65097','30079','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65098','30082','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65099','28342','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65100','28344','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65101','28345','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65102','30141','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65103','28354','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65104','28356','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65105','28367','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65106','28372','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65107','28390','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65108','28391','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65109','28422','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65110','28425','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65111','28466','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65112','28467','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65113','28479','1','5','(\d{1,3}) *%( of maximum)?
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65157','32465','1','13','0
{$ACTIVEMQ.BROKER.CONSUMERS.MIN.HIGH}','2','{$ACTIVEMQ.BROKER.CONSUMERS.MIN.HIGH}');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65158','32465','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65159','32466','1','13','0
{$ACTIVEMQ.BROKER.PRODUCERS.MIN.HIGH}','2','{$ACTIVEMQ.BROKER.PRODUCERS.MIN.HIGH}');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65160','32466','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65161','32468','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65162','32469','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65163','32470','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65164','32474','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65165','32475','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65166','32477','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65167','32479','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65168','32482','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65169','32483','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65170','32485','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65171','32486','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65172','32497','1','21','var data = JSON.parse(value);

data.forEach(function(instance) {
    if (instance["{#INSTANCE}"] === ''_total'') {
        instance["{#INF.STORE}"] = ''Information Store'';
    }
    else {
        instance["{#INF.STORE}"] = ''Information Store - '' + instance["{#INSTANCE}"];
    }
})

return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65173','32498','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65174','32499','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65175','32501','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65176','32506','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65177','32507','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65178','32509','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65179','32510','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65180','32512','1','20','3m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65181','32513','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65182','32516','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65183','32527','1','21','var data = JSON.parse(value);

data.forEach(function(instance) {
    if (instance["{#INSTANCE}"] === ''_total'') {
        instance["{#INF.STORE}"] = ''Information Store'';
    }
    else {
        instance["{#INF.STORE}"] = ''Information Store - '' + instance["{#INSTANCE}"];
    }
})

return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65184','32528','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65185','32529','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65186','32531','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65187','32536','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65188','32537','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65189','32539','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65190','32540','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65191','32542','1','20','3m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65192','32543','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65193','32546','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65194','32547','1','11','/resultset/row[field/text()=''Innodb_buffer_pool_wait_free'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65195','32547','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65196','32548','1','11','/resultset/row[field/text()=''Innodb_num_open_files'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65197','32548','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65198','32549','1','11','/resultset/row[field/text()=''Innodb_os_log_written'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65199','32550','1','11','/resultset/row[field/text()=''Open_table_definitions'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65200','32550','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65201','32551','1','11','/resultset/row[field/text()=''Open_tables'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65202','32551','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65203','32552','1','11','/resultset/row[field/text()=''Binlog_cache_disk_use'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65204','32552','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65205','32553','1','21','return JSON.stringify(value.search(''MariaDB'')>-1 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65206','32554','1','11','/resultset/row[field/text()=''Binlog_commits'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65207','32555','1','11','/resultset/row[field/text()=''Binlog_group_commits'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65208','32556','1','11','/resultset/row[field/text()=''Master_gtid_wait_count'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65209','32556','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65210','32557','1','11','/resultset/row[field/text()=''Master_gtid_wait_time'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65211','32557','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65212','32558','1','11','/resultset/row[field/text()=''Master_gtid_wait_timeouts'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65213','32558','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65214','32559','1','11','/resultset/row[field/text()=''Slave_SQL_Running_State'']/field[@name=''Value'']/text()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65215','32559','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65216','32560','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65217','32561','1','12','$.Innodb_buffer_pool_wait_free','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65218','32561','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65219','32562','1','12','$.Innodb_num_open_files','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65220','32562','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65221','32563','1','12','$.Innodb_os_log_written','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65222','32563','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65223','32564','1','12','$.Open_table_definitions','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65224','32564','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65225','32565','1','12','$.Open_tables','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65226','32565','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65227','32566','1','12','$.Binlog_cache_disk_use','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65228','32566','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65229','32567','1','21','return JSON.stringify(value.search(''MariaDB'')>-1 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65230','32568','1','12','$.Binlog_commits','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65231','32569','1','12','$.Binlog_group_commits','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65232','32570','1','12','$.Master_gtid_wait_count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65233','32570','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65234','32571','1','12','$.Master_gtid_wait_time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65235','32571','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65236','32572','1','12','$.Master_gtid_wait_timeouts','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65237','32572','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65238','32573','1','12','$.Slave_SQL_Running_State','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65239','32573','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65240','32574','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65241','32575','1','12','$[?(@.Variable_name==''Innodb_buffer_pool_wait_free'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65242','32575','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65243','32576','1','12','$[?(@.Variable_name==''Innodb_num_open_files'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65244','32576','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65245','32577','1','12','$[?(@.Variable_name==''Innodb_os_log_written'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65246','32577','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65247','32578','1','12','$[?(@.Variable_name==''Open_table_definitions'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65248','32578','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65249','32579','1','12','$[?(@.Variable_name==''Open_tables'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65250','32579','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65251','32580','1','12','$[?(@.Variable_name==''Binlog_cache_disk_use'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65252','32580','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65253','32581','1','21','return JSON.stringify(value.search(''MariaDB'')>-1 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65254','32582','1','12','$.[?(@.Master_Host==''{#MASTER_HOST}'')][''Slave_SQL_Running_State''].first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65255','32582','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65256','32583','1','12','$[?(@.Variable_name==''Binlog_commits'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65257','32584','1','12','$[?(@.Variable_name==''Binlog_group_commits'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65258','32585','1','12','$[?(@.Variable_name==''Master_gtid_wait_count'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65259','32585','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65260','32586','1','12','$[?(@.Variable_name==''Master_gtid_wait_time'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65261','32586','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65262','32587','1','12','$[?(@.Variable_name==''Master_gtid_wait_timeouts'')].Value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65263','32587','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65264','32588','1','12','$..[''{#TABLESPACE}''].used_bytes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65265','32589','1','12','$..[''{#TABLESPACE}''].used_file_pct.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65268','32596','1','12','$.checkpoint_sync_time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65269','32596','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65270','32596','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65271','32598','1','12','$[''{#APPLICATION}''].flush_lag','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65272','32599','1','12','$[''{#APPLICATION}''].replay_lag','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65273','32600','1','12','$[''{#APPLICATION}''].write_lag','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65274','32605','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65275','32606','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65276','32607','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65277','32608','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65278','32609','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65279','32610','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65280','32612','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65281','32613','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65282','32614','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65283','32615','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65284','32620','1','21','var data = JSON.parse(value);
var descriptions = {};
var out = [];

data.forEach(function(elem) {
    if (elem["{#IFDESCR}"]) {
        var parts = elem["{#IFDESCR}"].split(":");
        var port = parts[parts.length-1].split('' '');
        descriptions[parts[0] + '':'' + port[port.length-1]] = {
            "{#IFDESCR}": elem["{#IFDESCR}"],
            "{#SNMPINDEX}": elem["{#SNMPINDEX}"]
        }
    }
});

data.forEach(function(elem) {
    if (elem["{#IFNAME}"]) {
        var port = descriptions[elem["{#NODE}"] + '':'' + elem["{#IFNAME}"]];

        elem["{#IFDESCR}"] = port["{#IFDESCR}"];
        elem["{#IFSNMPINDEX}"] = port["{#SNMPINDEX}"];


        switch(elem["{#TYPE}"]) {
            case ''0'':
                elem["{#TYPE}"] = ''physical'';
                break;
            case ''1'':
                elem["{#TYPE}"] = ''if-group'';
                break;
            case ''2'':
                elem["{#TYPE}"] = ''vlan'';
                break;
            case ''3'':
                elem["{#TYPE}"] = ''undef'';
                break;
        };
    
        out.push(elem);
    }
});

return JSON.stringify(out);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65285','32621','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65286','32622','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65287','32623','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65288','32624','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65289','32625','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65290','32626','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65291','32627','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65292','32628','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65293','32629','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65294','32630','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65295','32631','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65296','32633','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65297','32634','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65298','32635','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65299','32639','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65300','32640','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65301','32641','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65302','32642','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65303','32643','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65304','32643','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65305','32644','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65306','32645','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65307','32646','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65308','32646','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65309','32647','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65310','32648','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65311','32649','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65312','32650','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65313','32651','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65314','32652','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65315','32653','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65316','32653','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65317','32654','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65318','32654','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65319','32655','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65320','32655','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65321','32656','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65322','32657','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65323','32658','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)

','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65324','32659','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)


','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65325','32660','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)


','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65326','32661','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)


','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65327','32662','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65328','32662','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65329','32664','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65330','32694','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65331','32695','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65332','32696','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65333','32697','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65334','32698','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65335','32699','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65336','32700','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65337','32701','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65338','32702','1','5','(.*)-\d+
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65339','32702','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65340','32703','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65341','32704','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65342','32706','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65344','32708','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65345','32709','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65346','32714','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65347','32715','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65348','32716','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65349','32722','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65350','32725','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65351','32726','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65352','32728','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65353','32729','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65354','32730','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65355','31711','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65356','31713','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65359','28388','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65360','29994','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65361','32731','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65362','28392','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65363','28393','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65364','28394','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65365','28395','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65366','28396','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65367','28397','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65368','28398','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65369','28399','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65370','28400','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65371','28401','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65372','28402','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65373','28403','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65374','32732','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65375','32733','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65376','32734','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65377','32735','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65378','32736','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65379','32737','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65380','32738','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65381','32739','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65382','32740','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65383','28404','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65384','28405','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65385','28406','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65386','28407','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65387','28408','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65388','28409','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65389','28411','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65390','28412','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65391','28413','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65392','28414','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65393','28415','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65394','28416','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65395','28417','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65396','28418','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65397','28419','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65398','28420','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65399','28421','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65400','28422','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65401','28423','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65402','28424','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65403','28425','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65404','32744','1','12','$[?(@.disk_name==''{#NAME}'')].ata_smart_attributes.table[?(@.id=={#ID})].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65405','32744','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65406','32745','1','12','$[?(@.disk_name==''{#NAME}'')].nvme_smart_health_information_log.critical_warning.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65407','32745','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65408','32746','1','12','$[?(@.disk_name==''{#NAME}'')].power_on_time.hours.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65409','32747','1','12','$[?(@.disk_name==''{#NAME}'')].nvme_smart_health_information_log.media_errors.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65410','32747','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65411','32748','1','12','$[?(@.disk_name==''{#NAME}'')].model_name.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65412','32748','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65413','32749','1','12','$[?(@.disk_name==''{#NAME}'')].nvme_smart_health_information_log.percentage_used.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65414','32749','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65415','32750','1','12','$[?(@.disk_name==''{#NAME}'')].serial_number.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65416','32750','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65417','32751','1','12','$[?(@.disk_name==''{#NAME}'')].temperature.current.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65418','32751','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65419','32752','1','12','$[?(@.disk_name==''{#NAME}'')].ata_smart_data.self_test.status.passed.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65420','32752','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65421','32756','1','12','$[?(@.disk_name==''{#NAME}'')].ata_smart_attributes.table[?(@.id=={#ID})].value.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65422','32756','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65423','32757','1','12','$[?(@.disk_name==''{#NAME}'')].nvme_smart_health_information_log.critical_warning.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65424','32757','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65425','32758','1','12','$[?(@.disk_name==''{#NAME}'')].power_on_time.hours.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65426','32759','1','12','$[?(@.disk_name==''{#NAME}'')].nvme_smart_health_information_log.media_errors.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65427','32759','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65428','32760','1','12','$[?(@.disk_name==''{#NAME}'')].model_name.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65429','32760','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65430','32761','1','12','$[?(@.disk_name==''{#NAME}'')].nvme_smart_health_information_log.percentage_used.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65431','32761','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65432','32762','1','12','$[?(@.disk_name==''{#NAME}'')].serial_number.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65433','32762','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65434','32763','1','12','$[?(@.disk_name==''{#NAME}'')].temperature.current.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65435','32763','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65436','32764','1','12','$[?(@.disk_name==''{#NAME}'')].ata_smart_data.self_test.status.passed.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65437','32764','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65438','32769','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65439','32770','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65440','32771','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65441','32772','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65442','32773','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65443','32774','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65444','32776','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65445','32777','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65446','32777','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65447','32778','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65448','32779','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65449','32788','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65450','32789','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65451','32791','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65452','32793','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65453','32794','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65454','32795','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65455','32796','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65456','32797','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65457','32799','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65458','32800','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65459','32802','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65460','32803','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65461','32804','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65462','32805','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65463','32806','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65464','32808','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65465','32810','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65466','32812','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65467','32813','1','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65468','32813','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65469','32814','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65470','32818','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65471','32820','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65472','32822','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65473','32823','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65474','32825','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65475','32826','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65476','32827','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65477','32828','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65478','32828','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65479','32829','1','5','\n\s?\n(.*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65480','32830','1','5','\n\s?\n(.*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65481','32832','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65482','32833','1','5','\n\s?\n(.*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65483','32834','1','5','\n\s?\n(.*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65484','32835','1','5','\n\s?\n(.*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65485','32840','1','12','$.message_stats.return_unroutable','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65486','32841','1','12','$.queue_totals.messages_unacknowledged','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65487','32842','1','12','$.queue_totals.messages_ready','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65488','32843','1','12','$.queue_totals.messages','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65489','32844','1','12','$.object_totals.queues','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65490','32845','1','12','$.object_totals.exchanges','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65491','32846','1','12','$.object_totals.consumers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65492','32847','1','12','$.object_totals.connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65493','32848','1','12','$.object_totals.channels','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65494','32849','1','12','$.message_stats.return_unroutable_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65495','32850','1','12','$.message_stats.ack','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65496','32851','1','12','$.message_stats.ack_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65497','32852','1','12','$.message_stats.redeliver','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65498','32853','1','12','$.message_stats.publish_out_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65499','32854','1','12','$.message_stats.publish_out','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65500','32855','1','12','$.message_stats.publish_in_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65501','32856','1','12','$.message_stats.publish_in','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65502','32857','1','12','$.message_stats.publish_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65503','32858','1','12','$.message_stats.publish','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65504','32859','1','12','$.message_stats.deliver_get_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65505','32860','1','12','$.message_stats.deliver_get','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65506','32861','1','12','$.message_stats.confirm_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65507','32862','1','12','$.message_stats.confirm','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65508','32863','1','12','$.message_stats.redeliver_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65509','32864','1','12','$.running','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65510','32864','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65511','32865','1','12','$.uptime','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65512','32865','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65513','32866','1','12','$.sockets_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65514','32867','1','12','$.sockets_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65515','32868','1','12','$.run_queue','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65516','32869','1','12','$.rabbitmq_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65517','32869','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65518','32870','1','12','$.partitions','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65519','32870','2','21','return JSON.parse(value).length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65520','32871','1','12','$.disk_free','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65521','32872','1','12','$.management_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65522','32872','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65523','32873','1','12','$.mem_limit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65524','32874','1','12','$.mem_alarm','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65525','32874','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65526','32875','1','12','$.fd_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65527','32876','1','12','$.disk_free_limit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65528','32877','1','12','$.disk_free_alarm','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65529','32877','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65530','32878','1','12','$.mem_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65531','32880','1','12','$.management_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65532','32880','2','21','var rabbit_version = parseInt(value.split(''.'')[0]) * 10000 +
                     parseInt(value.split(''.'')[1]) * 100 +
                     parseInt(value.split(''.'')[2]) 
return JSON.stringify(rabbit_version >= 30810 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65533','32881','1','12','$.management_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65534','32881','2','21','var rabbit_version = parseInt(value.split(''.'')[0]) * 10000 +
                     parseInt(value.split(''.'')[1]) * 100 +
                     parseInt(value.split(''.'')[2]) 
return JSON.stringify(rabbit_version < 30810 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65535','32882','1','12','$.management_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65536','32882','2','21','var rabbit_version = parseInt(value.split(''.'')[0]) * 10000 +
                     parseInt(value.split(''.'')[1]) * 100 +
                     parseInt(value.split(''.'')[2]) 
return JSON.stringify(rabbit_version >= 30810 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65537','32884','1','5','HTTP\/1\.1\b\s(\d+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65538','32884','2','21','switch(value){ 
case ''200'': return 1 
case ''503'': return 0 
default: 2}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65539','32884','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65540','32885','1','5','\n\s?\n(.*)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65541','32885','2','12','$.status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65542','32885','3','6','','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65543','32886','1','5','HTTP\/1\.1\b\s(\d+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65544','32886','2','21','switch(value){ 
case ''200'': return 1 
case ''503'': return 0 
default: 2}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65545','32886','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65546','32887','1','5','HTTP\/1\.1\b\s(\d+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65547','32887','2','21','switch(value){ 
case ''200'': return 1 
case ''503'': return 0 
default: 2}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65548','32887','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65549','32888','1','5','HTTP\/1\.1\b\s(\d+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65550','32888','2','21','switch(value){ 
case ''200'': return 1 
case ''503'': return 0 
default: 2}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65551','32888','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65552','32889','1','5','HTTP\/1\.1\b\s(\d+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65553','32889','2','21','switch(value){ 
case ''200'': return 1 
case ''503'': return 0 
default: 2}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65554','32889','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65555','32890','1','5','HTTP\/1\.1\b\s(\d+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65556','32890','2','21','switch(value){ 
case ''200'': return 1 
case ''503'': return 0 
default: 2}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65557','32890','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65558','32891','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.ack_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65559','32892','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.ack.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65560','32893','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.confirm_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65561','32894','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.confirm.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65562','32895','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.deliver_get_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65563','32896','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.deliver_get.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65564','32897','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65565','32898','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65566','32899','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_in_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65567','32900','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_in.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65568','32901','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_out_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65569','32902','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_out.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65570','32903','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.redeliver_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65571','32904','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.redeliver.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65572','32905','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.return_unroutable_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65573','32906','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.return_unroutable.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65574','32907','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].consumers.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65575','32908','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_details.rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65576','32909','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_unacknowledged_details.rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65577','32910','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_ready.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65578','32911','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_ready_details.rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65579','32912','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65580','32913','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.redeliver.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65581','32914','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.redeliver_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65582','32915','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.publish.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65583','32916','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].memory.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65584','32917','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.publish_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65585','32918','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver_get.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65586','32919','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver_get_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65587','32920','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65588','32921','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65589','32922','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.ack.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65590','32923','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.ack_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65591','32924','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_unacknowledged.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65592','32931','1','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65593','32932','1','12','$.queue_totals.messages_ready','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65594','32933','1','12','$.queue_totals.messages','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65595','32934','1','12','$.object_totals.queues','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65596','32935','1','12','$.object_totals.exchanges','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65597','32936','1','12','$.object_totals.consumers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65598','32937','1','12','$.object_totals.connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65599','32938','1','12','$.object_totals.channels','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65600','32939','1','12','$.message_stats.return_unroutable_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65601','32940','1','12','$.message_stats.return_unroutable','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65602','32941','1','12','$.message_stats.redeliver_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65603','32942','1','12','$.message_stats.redeliver','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65604','32943','1','12','$.message_stats.publish_out_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65605','32944','1','12','$.message_stats.publish_out','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65606','32945','1','12','$.message_stats.publish_in_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65607','32946','1','12','$.message_stats.publish_in','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65608','32947','1','12','$.message_stats.publish_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65609','32948','1','12','$.message_stats.publish','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65610','32949','1','12','$.message_stats.deliver_get_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65611','32950','1','12','$.message_stats.deliver_get','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65612','32951','1','12','$.message_stats.confirm_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65613','32952','1','12','$.message_stats.confirm','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65614','32953','1','12','$.message_stats.ack_details.rate','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65615','32954','1','12','$.message_stats.ack','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65616','32955','1','12','$.queue_totals.messages_unacknowledged','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65617','32956','1','12','$.rabbitmq_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65618','32956','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65619','32957','1','12','$.sockets_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65620','32958','1','12','$.sockets_total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65621','32959','1','12','$.run_queue','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65622','32960','1','12','$.running','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65623','32960','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65624','32961','1','12','$.partitions','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65625','32961','2','21','return JSON.parse(value).length;','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65626','32962','1','12','$.mem_limit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65627','32963','1','12','$.management_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65628','32963','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65629','32964','1','12','$.mem_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65630','32965','1','12','$.mem_alarm','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65631','32965','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65632','32966','1','12','$.fd_used','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65633','32967','1','12','$.disk_free_limit','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65634','32968','1','12','$.disk_free_alarm','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65635','32968','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65636','32969','1','12','$.disk_free','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65637','32970','1','12','$.uptime','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65638','32970','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65639','32972','1','12','$.management_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65640','32972','2','21','var rabbit_version = parseInt(value.split(''.'')[0]) * 10000 +
                     parseInt(value.split(''.'')[1]) * 100 +
                     parseInt(value.split(''.'')[2]) 
return JSON.stringify(rabbit_version >= 30810 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65641','32973','1','12','$.management_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65642','32973','2','21','var rabbit_version = parseInt(value.split(''.'')[0]) * 10000 +
                     parseInt(value.split(''.'')[1]) * 100 +
                     parseInt(value.split(''.'')[2]) 
return JSON.stringify(rabbit_version < 30810 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65643','32974','1','12','$.management_version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65644','32974','2','21','var rabbit_version = parseInt(value.split(''.'')[0]) * 10000 +
                     parseInt(value.split(''.'')[1]) * 100 +
                     parseInt(value.split(''.'')[2]) 
return JSON.stringify(rabbit_version >= 30810 ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65645','32976','1','5','HTTP\/1\.1\b\s(\d+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65646','32976','2','21','switch(value){ 
case ''200'': return 1 
case ''503'': return 0 
default: 2}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65647','32976','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65648','32977','1','12','$.status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65649','32977','2','6','','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65650','32978','1','5','HTTP\/1\.1\b\s(\d+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65651','32978','2','21','switch(value){ 
case ''200'': return 1 
case ''503'': return 0 
default: 2}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65652','32978','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65653','32979','1','5','HTTP\/1\.1\b\s(\d+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65654','32979','2','21','switch(value){ 
case ''200'': return 1 
case ''503'': return 0 
default: 2}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65655','32979','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65656','32980','1','5','HTTP\/1\.1\b\s(\d+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65657','32980','2','21','switch(value){ 
case ''200'': return 1 
case ''503'': return 0 
default: 2}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65658','32980','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65659','32981','1','5','HTTP\/1\.1\b\s(\d+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65660','32981','2','21','switch(value){ 
case ''200'': return 1 
case ''503'': return 0 
default: 2}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65661','32981','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65662','32982','1','5','HTTP\/1\.1\b\s(\d+)
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65663','32982','2','21','switch(value){ 
case ''200'': return 1 
case ''503'': return 0 
default: 2}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65664','32982','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65665','32983','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.ack_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65666','32984','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.ack.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65667','32985','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.confirm_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65668','32986','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.confirm.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65669','32987','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.deliver_get_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65670','32988','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.deliver_get.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65671','32989','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65672','32990','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65673','32991','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_in_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65674','32992','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_in.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65675','32993','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_out_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65676','32994','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.publish_out.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65677','32995','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.redeliver_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65678','32996','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.redeliver.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65679','32997','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.return_unroutable_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65680','32998','1','12','$[?(@.name == "{#EXCHANGE}" && @.vhost == "{#VHOST}" && @.type =="{#TYPE}")].message_stats.return_unroutable.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65681','32999','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].consumers.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65682','33000','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_details.rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65683','33001','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_unacknowledged_details.rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65684','33002','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_ready.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65685','33003','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_ready_details.rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65686','33004','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65687','33005','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.redeliver.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65688','33006','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.redeliver_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65689','33007','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.publish.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65690','33008','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].memory.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65691','33009','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.publish_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65692','33010','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver_get.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65693','33011','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver_get_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65694','33012','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65695','33013','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.deliver_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65696','33014','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.ack.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65697','33015','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].message_stats.ack_details.rate.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65698','33016','1','12','$[?(@.name == "{#QUEUE}" && @.vhost == "{#VHOST}")].messages_unacknowledged.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65699','33019','1','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65700','33022','1','12','$.metrics.document.deleted','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65701','33022','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65702','33023','1','12','$.network.numRequests','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65703','33023','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65704','33024','1','12','$.mem.mappedWithJournal','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65705','33024','2','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65706','33025','1','12','$.mem.resident','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65707','33025','2','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65708','33026','1','12','$.mem.virtual','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65709','33026','2','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65710','33027','1','12','$.metrics.cursor.open.noTimeout','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65711','33028','1','12','$.network.bytesIn','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65712','33028','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65713','33029','1','12','$.network.bytesOut','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65714','33029','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65715','33030','1','12','$.opcounters.delete','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65716','33030','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65717','33031','1','12','$.opcounters.command','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65718','33031','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65719','33032','1','12','$.mem.bits','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65720','33032','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65721','33033','1','12','$.opcounters.getmore','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65722','33033','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65723','33034','1','12','$.opcounters.insert','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65724','33034','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65725','33035','1','12','$.opcounters.query','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65726','33035','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65727','33036','1','12','$.opcounters.update','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65728','33036','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65729','33037','1','12','$.uptime','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65730','33038','1','12','$.mem.mapped','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65731','33038','2','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65732','33039','1','12','$.metrics.cursor.timedOut','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65733','33039','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65734','33040','1','12','$.metrics.document.inserted','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65735','33040','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65736','33041','1','12','$.asserts.user','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65737','33041','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65738','33042','1','12','$.metrics.document.returned','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65739','33042','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65740','33043','1','12','$.metrics.document.updated','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65741','33043','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65742','33044','1','12','$.globalLock.activeClients.readers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65743','33045','1','12','$.globalLock.activeClients.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65744','33046','1','12','$.globalLock.activeClients.writers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65745','33047','1','12','$.asserts.msg','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65746','33047','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65747','33048','1','12','$.asserts.regular','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65748','33048','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65749','33049','1','12','$.asserts.rollovers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65750','33049','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65751','33050','1','12','$.asserts.warning','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65752','33050','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65753','33051','1','12','$.metrics.cursor.open.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65754','33052','1','12','$.connections.active','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65755','33053','1','12','$.connections.available','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65756','33054','1','12','$.connections.current','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65757','33055','1','12','$.connections.totalCreated','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65758','33055','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65759','33056','1','12','$.globalLock.currentQueue.readers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65760','33057','1','12','$.globalLock.currentQueue.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65761','33058','1','12','$.globalLock.currentQueue.writers','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65762','33059','1','12','$.metrics.cursor.open.pinned','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65763','33060','1','12','$.version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65764','33060','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65765','33063','1','21','var status = JSON.parse(value)
return JSON.stringify(status.set
? [{''{#RS_NAME}'': status.set, ''{#NODE_STATE}'': status.myState}]
: []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65766','33063','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65767','33064','1','21','return JSON.stringify(JSON.parse(value).wiredTiger
  ? [{''{#SINGLETON}'': ''''}] : []);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65768','33064','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65769','33067','1','12','$.avgObjSize','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65770','33068','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].remove.time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65771','33068','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65772','33069','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].writeLock.time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65773','33069','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65774','33070','1','12','$.storageSize','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65775','33071','1','12','$.size','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65776','33072','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].readLock.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65777','33072','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65778','33073','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].readLock.time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65779','33073','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65780','33074','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].update.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65781','33074','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65782','33075','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].update.time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65783','33075','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65784','33076','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].total.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65785','33076','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65786','33077','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].total.time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65787','33077','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65788','33078','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].remove.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65789','33078','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65790','33079','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].queries.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65791','33079','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65792','33080','1','12','$.capped','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65793','33080','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65794','33080','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65795','33081','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].queries.time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65796','33081','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65797','33082','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].insert.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65798','33082','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65799','33083','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].insert.time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65800','33083','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65801','33084','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].getmore.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65802','33084','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65803','33085','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].getmore.time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65804','33085','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65805','33086','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].commands.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65806','33086','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65807','33087','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].commands.time','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65808','33087','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65809','33088','1','12','$.nindexes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65810','33089','1','12','$.maxSize','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65811','33090','1','12','$.max','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65812','33091','1','12','$.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65813','33092','1','12','$.totals["{#DBNAME}.{#COLLECTION}"].writeLock.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65814','33092','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65815','33093','1','12','$.collections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65816','33094','1','12','$.dataSize','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65817','33095','1','12','$.numExtents','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65818','33096','1','12','$.fileSize','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65819','33097','1','12','$.indexSize','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65820','33098','1','12','$.objects','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65821','33099','1','12','$.avgObjSize','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65822','33100','1','12','$.storageSize','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65823','33101','1','12','$.metrics.repl.apply.batches.totalMillis','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65824','33101','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65825','33102','1','12','$.metrics.repl.network.readersCreated','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65826','33102','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65827','33103','1','12','$.members[?(@.self == "true")].unhealthyCount.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65828','33103','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65829','33104','1','12','$.members[?(@.self == "true")].totalNodes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65830','33104','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65831','33105','1','12','$.myState','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65832','33105','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65833','33106','1','12','$.metrics.repl.preload.indexes.num','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65834','33106','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65835','33107','1','12','$.metrics.repl.preload.indexes.totalMillis','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65836','33107','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65837','33108','1','12','$.metrics.repl.preload.docs.num','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65838','33108','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65839','33109','1','12','$.metrics.repl.preload.docs.totalMillis','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65840','33109','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65841','33110','1','12','$.timediff','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65842','33111','1','12','$.metrics.repl.network.ops','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65843','33111','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65844','33112','1','12','$.metrics.repl.apply.batches.num','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65845','33112','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65846','33113','1','12','$.metrics.repl.network.getmores.num','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65847','33113','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65848','33114','1','12','$.metrics.repl.network.getmores.totalMillis','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65849','33114','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65850','33115','1','12','$.metrics.repl.network.bytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65851','33115','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65852','33116','1','12','$.members[?(@.self == "true")].lag.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65853','33117','1','12','$.metrics.repl.buffer.sizeBytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65854','33118','1','12','$.metrics.repl.buffer.maxSizeBytes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65855','33119','1','12','$.metrics.repl.buffer.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65856','33120','1','12','$.metrics.repl.apply.ops','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65857','33120','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65858','33121','1','12','$.members[?(@.self == "true")].unhealthyNodes.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65859','33121','2','21','var value = JSON.parse(value);
return value.length ? JSON.stringify(value) : '''';
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65860','33121','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65861','33122','1','12','$.wiredTiger.cache[''bytes currently in the cache'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65862','33123','1','12','$.wiredTiger.cache.[''tracked dirty bytes in the cache'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65863','33124','1','12','$.wiredTiger.concurrentTransactions.write.out','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65864','33125','1','12','$.wiredTiger.concurrentTransactions.write.available','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65865','33126','1','12','$.wiredTiger.concurrentTransactions.read.totalTickets','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65866','33127','1','12','$.wiredTiger.concurrentTransactions.read.out','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65867','33128','1','12','$.wiredTiger.concurrentTransactions.read.available','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65868','33129','1','12','$.wiredTiger.cache.[''unmodified pages evicted'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65869','33130','1','12','$.wiredTiger.cache[''in-memory page splits'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65870','33131','1','12','$.wiredTiger.cache[''maximum page size at eviction'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65871','33132','1','12','$.wiredTiger.cache[''pages written from cache'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65872','33133','1','12','$.wiredTiger.cache[''pages read into cache'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65873','33134','1','12','$.wiredTiger.cache[''pages currently held in the cache'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65874','33135','1','12','$.wiredTiger.cache.[''pages evicted by application threads'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65875','33136','1','12','$.wiredTiger.cache[''modified pages evicted'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65876','33137','1','12','$.wiredTiger.cache[''maximum bytes configured'']','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65877','33138','1','12','$.wiredTiger.concurrentTransactions.write.totalTickets','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65878','33141','1','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65880','33144','1','12','$.opcounters.command','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65881','33144','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65882','33145','1','12','$.network.bytesIn','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65883','33145','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65884','33146','1','12','$.network.bytesOut','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65885','33146','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65886','33147','1','12','$.network.numRequests','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65887','33147','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65888','33148','1','12','$.opcounters.getmore','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65889','33148','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65890','33149','1','12','$.opcounters.delete','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65891','33149','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65892','33150','1','12','$.mem.virtual','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65893','33150','2','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65894','33151','1','12','$.opcounters.insert','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65895','33151','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65896','33152','1','12','$.opcounters.query','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65897','33152','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65898','33153','1','12','$.opcounters.update','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65899','33153','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65900','33154','1','12','$.uptime','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65901','33155','1','12','$.metrics.cursor.open.noTimeout','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65902','33156','1','12','$.mem.bits','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65903','33156','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65904','33157','1','12','$.mem.resident','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65905','33157','2','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65906','33158','1','12','$.totalAvailable','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65907','33159','1','21','data = JSON.parse(value)
return data.sharding.lastSeenConfigServerOpTime.ts/Math.pow(2,32)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65908','33160','1','12','$.metrics.cursor.timedOut','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65909','33160','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65910','33161','1','12','$.metrics.cursor.open.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65911','33162','1','12','$.metrics.cursor.open.pinned','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65912','33163','1','12','$.connections.totalCreated','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65913','33163','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65914','33164','1','12','$.connections.current','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65915','33165','1','12','$.connections.available','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65916','33166','1','12','$.connections.active','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65917','33167','1','12','$.numAScopedConnections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65918','33168','1','12','$.totalRefreshing','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65919','33169','1','12','$.totalInUse','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65920','33170','1','12','$.totalCreated','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65921','33170','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65922','33171','1','12','$.numClientConnections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65923','33172','1','12','$.version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65924','33172','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65925','33179','1','12','$.avgObjSize','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65926','33180','1','12','$.capped','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65927','33180','2','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65928','33180','3','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65929','33181','1','12','$.count','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65930','33182','1','12','$.maxSize','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65931','33183','1','12','$.max','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65932','33184','1','12','$.nindexes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65933','33185','1','12','$.size','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65934','33186','1','12','$.storageSize','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65935','33187','1','12','$.dataSize','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65936','33188','1','12','$.numExtents','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65937','33189','1','12','$.fileSize','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65938','33190','1','12','$.indexSize','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65939','33191','1','12','$.objects','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65940','33192','1','12','$.avgObjSize','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65941','33193','1','12','$.storageSize','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65942','33195','1','12','$[?(@.group_name==''{#GROUP_NAME}'' && @.replica_name==''{#REPLICA_NAME}'' && @.dbname==''{#DBNAME}'')].log_send_queue_size.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65943','33195','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65944','33195','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65945','33196','1','12','$[?(@.group_name==''{#GROUP_NAME}'' && @.replica_name==''{#REPLICA_NAME}'' && @.dbname==''{#DBNAME}'')].redo_queue_size.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65946','33196','2','1','1024','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65947','33196','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65948','33201','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65949','33202','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65950','33203','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65951','33204','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65952','33205','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65953','33206','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65954','33207','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65955','33208','1','5','Version (.+), RELEASE
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65956','33208','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65957','33209','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65958','33220','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65959','33225','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65960','33226','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65961','33227','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65962','33227','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65963','33228','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65964','33229','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65965','33230','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65966','33230','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65967','33231','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65968','33231','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65969','33232','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65970','33233','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65971','33242','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65972','33243','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65973','33244','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65974','33245','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65975','33246','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65976','33247','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65977','33248','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65978','33249','1','5','Version (.+), RELEASE
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65979','33249','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65980','33250','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65981','33261','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65982','33266','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65983','33267','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65984','33268','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65985','33268','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65986','33269','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65987','33270','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65988','33271','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65989','33271','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65990','33272','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65991','33272','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65992','33273','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65993','33274','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65994','33283','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65995','33284','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65996','33285','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65997','33286','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65998','33287','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('65999','33288','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66000','33289','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66001','33290','1','5','Version (.+), RELEASE
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66002','33290','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66003','33291','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66004','33302','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66005','33307','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66006','33308','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66007','33309','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66008','33309','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66009','33310','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66010','33311','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66011','33312','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66012','33312','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66013','33313','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66014','33313','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66015','33314','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66016','33315','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66017','33324','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66018','33325','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66019','33326','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66020','33327','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66021','33328','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66022','33329','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66023','33330','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66024','33331','1','5','Version (.+), RELEASE
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66025','33331','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66026','33332','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66027','33343','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66028','33348','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66029','33349','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66030','33350','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66031','33350','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66032','33351','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66033','33352','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66034','33353','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66035','33353','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66036','33354','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66037','33354','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66038','33355','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66039','33356','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66040','33365','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66041','33366','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66042','33367','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66043','33368','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66044','33369','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66045','33370','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66046','33371','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66047','33372','1','5','Version (.+), RELEASE
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66048','33372','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66049','33373','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66050','33384','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66051','33389','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66052','33390','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66053','33391','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66054','33391','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66055','33392','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66056','33393','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66057','33394','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66058','33394','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66059','33395','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66060','33395','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66061','33396','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66062','33397','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66063','33406','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66064','33407','1','12','$..[''{#CPU.UTIL}''].avg()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66065','33408','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66066','33409','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66067','33410','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66068','33411','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66069','33412','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66070','33414','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66071','33415','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66072','33416','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66073','28196','1','21','var data = JSON.parse(value).filter(function (item) {
  return (typeof item[''{#SENSOR_PRECISION}''] !== ''undefined'');
});

return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66074','28196','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66075','28197','1','21','var data = JSON.parse(value).filter(function (item) {
  return (typeof item[''{#SNMPVALUE}''] !== ''undefined'');
});

return JSON.stringify(data);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66076','28197','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66077','28198','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66078','28199','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66079','33417','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66080','33418','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66081','33419','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66082','33419','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66083','33420','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66084','33421','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66085','33422','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66086','33422','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66087','33423','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66088','33423','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66089','33425','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66090','33427','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66091','33428','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66092','33429','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66093','33430','1','1','{#ALLOC_UNITS}','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66095','33433','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66096','33433','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66097','33434','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66098','33435','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66099','33436','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66101','33438','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66102','33439','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66103','33440','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66104','33441','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66105','33443','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66106','33443','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66107','33444','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66108','33445','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66109','33445','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66110','33446','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66111','33447','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66112','33447','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66113','33448','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66114','33448','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66115','33449','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66116','33453','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66117','33453','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66118','33454','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66119','33454','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66120','33455','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66121','33456','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66122','33456','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66123','33457','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66124','33458','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66125','33465','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66126','33466','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66127','33467','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66128','33468','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66129','33469','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66130','33469','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66131','33470','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66132','33471','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66133','33472','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66134','33473','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66135','33474','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66136','33475','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66137','33476','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66138','33477','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66139','33477','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66140','33478','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66141','33486','1','21','var result = [];

JSON.parse(value).records.forEach(function(chassis) {
    chassis.frus.forEach(function(frus) {
        frus.chassisId = chassis.id;
        result.push(frus);
    })
});

return JSON.stringify(result);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66142','33493','1','12','$.statistics.status','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66143','33493','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66144','33494','1','12','$.location','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66145','33494','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66146','33495','1','12','$.name','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66147','33495','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66148','33496','1','12','$.statistics.iops_raw.other','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66149','33497','1','12','$.statistics.iops_raw.read','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66150','33498','1','12','$.statistics.iops_raw.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66151','33499','1','12','$.statistics.iops_raw.write','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66152','33500','1','12','$.statistics.iops_raw.other','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66153','33500','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66154','33501','1','12','$.version.full','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66155','33501','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66156','33502','1','12','$.statistics.latency_raw.read','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66157','33503','1','12','$.statistics.latency_raw.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66158','33504','1','12','$.statistics.throughput_raw.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66159','33504','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66160','33505','1','12','$.statistics.throughput_raw.read','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66161','33505','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66162','33506','1','12','$.statistics.throughput_raw.other','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66163','33506','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66164','33507','1','12','$.statistics.iops_raw.read','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66165','33507','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66166','33508','1','12','$.statistics.iops_raw.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66167','33508','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66168','33509','1','12','$.statistics.iops_raw.write','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66169','33509','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66170','33510','1','12','$.statistics.latency_raw.other','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66171','33511','1','12','$.statistics.latency_raw.write','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66172','33512','1','12','$.statistics.throughput_raw.write','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66173','33512','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66174','33513','1','21','var result = [];

JSON.parse(value).records.forEach(function (chassis) {
    result.push({"{#ID}": chassis.id});
});

return JSON.stringify(result);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66175','33514','1','21','var result = [];

JSON.parse(value).records.forEach(function (disk) {
    result.push({"{#DISKNAME}": disk.name, "{#NODENAME}": disk.node.name});
});

return JSON.stringify(result);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66176','33515','1','21','var result = [];

JSON.parse(value).forEach(function (fru) {
    result.push({"{#CHASSISID}": fru.chassisId, "{#FRUID}": fru.id});
});

return JSON.stringify(result);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66177','33515','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66178','33516','1','21','var result = [];

JSON.parse(value).records.forEach(function (lun) {
    result.push({"{#LUNNAME}": lun.name, "{#SVMNAME}": lun.svm.name});
});

return JSON.stringify(result);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66179','33517','1','21','var result = [];

JSON.parse(value).records.forEach(function (node) {
    result.push({"{#NODENAME}": node.name});
});

return JSON.stringify(result);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66180','33518','1','21','var result = [];

JSON.parse(value).records.forEach(function (port) {
    result.push({"{#NODENAME}": port.node.name, "{#ETHPORTNAME}": port.name, "{#ETHPORTSTATE}": port.state});
});

return JSON.stringify(result);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66181','33519','1','21','var result = [];

JSON.parse(value).records.forEach(function (port) {
    result.push({"{#NODENAME}": port.node.name, "{#FCPORTNAME}": port.name, "{#FCPORTSTATE}": port.state});
});

return JSON.stringify(result);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66182','33520','1','21','var result = [];

JSON.parse(value).records.forEach(function (svm) {
    result.push({"{#SVMNAME}": svm.name});
});

return JSON.stringify(result);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66183','33521','1','21','var result = [];

JSON.parse(value).records.forEach(function (volume) {
    result.push({"{#VOLUMENAME}": volume.name});
});

return JSON.stringify(result);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66184','33526','1','12','$.records[?(@.id==''{#ID}'')].state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66185','33526','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66186','33527','1','12','$.records[?(@.name==''{#DISKNAME}''&&@.node.name==''{#NODENAME}'')].state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66187','33527','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66188','33528','1','12','$[?(@.id==''{#FRUID}''&&@.chassisId==''{#CHASSISID}'')].state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66189','33528','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66190','33529','1','12','$.records[?(@.svm.name==''{#SVMNAME}''&&@.name==''{#LUNNAME}'')].space.size.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66191','33529','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66192','33530','1','12','$.records[?(@.svm.name==''{#SVMNAME}''&&@.name==''{#LUNNAME}'')].space.used.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66193','33530','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66194','33531','1','12','$.records[?(@.svm.name==''{#SVMNAME}''&&@.name==''{#LUNNAME}'')].status.container_state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66195','33531','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66196','33532','1','12','$.records[?(@.svm.name==''{#SVMNAME}''&&@.name==''{#LUNNAME}'')].status.state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66197','33532','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66198','33533','1','12','$.records[?(@.name==''{#NODENAME}'')].version.full.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66199','33533','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66200','33534','1','12','$.records[?(@.name==''{#NODENAME}'')].controller.over_temperature.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66201','33534','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66202','33535','1','12','$.records[?(@.name==''{#NODENAME}'')].location.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66203','33535','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66204','33536','1','12','$.records[?(@.name==''{#NODENAME}'')].membership.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66205','33536','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66206','33537','1','12','$.records[?(@.name==''{#NODENAME}'')].state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66207','33537','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66208','33538','1','12','$.records[?(@.name==''{#NODENAME}'')].uptime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66209','33539','1','12','$.records[?(@.name==''{#ETHPORTNAME}'')].state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66210','33539','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66211','33540','1','12','$.records[?(@.name==''{#FCPORTNAME}'')].description.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66212','33540','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66213','33541','1','12','$.records[?(@.name==''{#FCPORTNAME}'')].state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66214','33541','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66215','33542','1','12','$.records[?(@.name==''{#SVMNAME}'')].comment.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66216','33542','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66217','33543','1','12','$.records[?(@.name==''{#SVMNAME}'')].state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66218','33543','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66219','33544','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].comment.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66220','33544','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66221','33545','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.latency_raw.read.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66222','33546','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].svm.name.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66223','33546','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66224','33547','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.throughput_raw.write.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66225','33547','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66226','33548','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.throughput_raw.total.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66227','33548','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66228','33549','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.throughput_raw.read.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66229','33549','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66230','33550','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.throughput_raw.other.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66231','33550','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66232','33551','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.latency_raw.write.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66233','33552','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.latency_raw.total.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66234','33553','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.latency_raw.other.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66235','33554','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].space.available.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66236','33554','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66237','33555','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.iops_raw.write.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66238','33555','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66239','33556','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.iops_raw.total.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66240','33556','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66241','33557','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.iops_raw.read.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66242','33557','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66243','33558','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.iops_raw.other.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66244','33558','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66245','33559','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.iops_raw.write.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66246','33560','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.iops_raw.total.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66247','33561','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.iops_raw.read.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66248','33562','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].statistics.iops_raw.other.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66249','33563','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66250','33563','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66251','33564','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].space.used.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66252','33564','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66253','33565','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].space.size.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66254','33565','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66255','33566','1','12','$.records[?(@.name==''{#VOLUMENAME}'')].type.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66256','33566','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66257','33567','1','21','data = JSON.parse(value)
return (data["$clusterTime"].clusterTime-data.sharding.lastSeenConfigServerOpTime.ts)/Math.pow(2,32);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66258','28673','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66259','33568','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66260','33568','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66261','33569','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66262','33569','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66263','33570','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66264','33571','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66265','33572','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66267','33574','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66268','33575','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66269','33576','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66270','33577','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66271','33579','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66272','33579','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66273','33580','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66274','33581','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66275','33581','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66276','33582','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66277','33583','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66278','33583','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66279','33584','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66280','33584','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66281','33585','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66282','33589','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66283','33589','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66284','33590','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66285','33590','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66286','33591','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66287','33592','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66288','33592','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66289','33593','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66290','33594','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66291','33602','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66292','33603','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66293','33604','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66294','33605','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66295','33606','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66296','33606','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66297','33607','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66298','33608','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66299','33609','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66300','33610','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66301','33611','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66302','33612','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66303','33613','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66304','33614','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66305','33614','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66306','33615','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66307','33616','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66308','33616','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66309','33617','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66310','33618','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66311','33619','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66312','33619','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66313','33620','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66314','33620','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66315','33621','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66316','33622','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66317','33623','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66319','33625','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66320','33626','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66321','33627','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66322','33628','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66323','33630','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66324','33630','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66325','33631','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66326','33632','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66327','33632','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66328','33633','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66329','33634','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66330','33634','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66331','33635','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66332','33635','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66333','33636','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66334','33640','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66335','33640','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66336','33641','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66337','33641','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66338','33642','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66339','33643','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66340','33643','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66341','33644','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66342','33645','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66343','33653','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66344','33654','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66345','33655','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66346','33656','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66347','33657','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66348','33657','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66349','33658','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66350','33659','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66351','33660','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66352','33661','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66353','33662','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66354','33663','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66355','33664','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66356','33665','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66357','33665','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66358','33666','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66359','33667','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66360','33667','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66361','33668','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66362','33669','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66363','33670','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66364','33670','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66365','33671','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66366','33671','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66367','33672','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66368','33673','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66369','33674','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66371','33676','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66372','33677','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66373','33678','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66374','33679','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66375','33681','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66376','33681','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66377','33682','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66378','33683','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66379','33683','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66380','33684','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66381','33685','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66382','33685','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66383','33686','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66384','33686','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66385','33687','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66386','33691','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66387','33691','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66388','33692','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66389','33692','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66390','33693','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66391','33694','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66392','33694','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66393','33695','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66394','33696','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66395','33704','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66396','33705','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66397','33706','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66398','33707','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66399','33708','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66400','33708','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66401','33709','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66402','33710','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66403','33711','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66404','33712','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66405','33713','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66406','33714','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66407','33715','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66408','33716','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66409','33716','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66410','33717','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66411','33718','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66412','33718','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66413','33719','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66414','33720','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66415','33721','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66416','33721','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66417','33722','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66418','33722','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66419','33723','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66420','33724','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66421','33725','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66423','33727','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66424','33728','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66425','33729','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66426','33730','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66427','33732','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66428','33732','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66429','33733','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66430','33734','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66431','33734','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66432','33735','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66433','33736','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66434','33736','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66435','33737','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66436','33737','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66437','33738','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66438','33742','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66439','33742','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66440','33743','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66441','33743','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66442','33744','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66443','33745','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66444','33745','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66445','33746','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66446','33747','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66447','33755','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66448','33756','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66449','33757','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66450','33758','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66451','33759','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66452','33759','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66453','33760','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66454','33761','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66455','33762','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66456','33763','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66457','33764','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66458','33765','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66459','33766','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66460','33767','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66461','33767','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66462','33768','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66463','33769','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66464','33769','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66465','33770','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66466','33771','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66467','33772','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66468','33772','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66469','33773','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66470','33773','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66471','33774','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66472','33775','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66473','33776','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66475','33778','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66476','33779','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66477','33780','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66478','33781','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66479','33783','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66480','33783','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66481','33784','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66482','33785','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66483','33785','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66484','33786','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66485','33787','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66486','33787','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66487','33788','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66488','33788','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66489','33789','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66490','33793','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66491','33793','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66492','33794','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66493','33794','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66494','33795','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66495','33796','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66496','33796','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66497','33797','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66498','33798','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66499','33806','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66500','33807','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66501','33808','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66502','33809','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66503','33810','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66504','33810','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66505','33811','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66506','33812','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66507','33813','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66508','33814','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66509','33815','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66510','33816','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66511','33817','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66512','33818','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66513','33818','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66514','33819','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66515','33820','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66516','33820','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66517','33821','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66518','33822','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66519','33823','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66520','33823','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66521','33824','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66522','33824','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66523','33825','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66524','33826','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66525','33827','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66527','33829','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66528','33830','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66529','33831','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66530','33832','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66531','33834','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66532','33834','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66533','33835','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66534','33836','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66535','33836','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66536','33837','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66537','33838','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66538','33838','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66539','33839','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66540','33839','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66541','33840','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66542','33844','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66543','33844','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66544','33845','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66545','33845','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66546','33846','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66547','33847','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66548','33847','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66549','33848','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66550','33849','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66551','33857','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66552','33858','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66553','33859','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66554','33860','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66555','33861','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66556','33861','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66557','33862','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66558','33863','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66559','33864','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66560','33865','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66561','33866','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66562','33867','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66563','33868','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66564','33869','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66565','33869','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66566','33870','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66567','33871','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66568','33871','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66569','33872','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66570','33873','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66571','33874','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66572','33874','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66573','33875','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66574','33875','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66575','33876','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66576','33877','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66577','33878','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66579','33880','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66580','33881','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66581','33882','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66582','33883','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66583','33885','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66584','33885','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66585','33886','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66586','33887','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66587','33887','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66588','33888','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66589','33889','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66590','33889','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66591','33890','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66592','33890','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66593','33891','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66594','33895','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66595','33895','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66596','33896','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66597','33896','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66598','33897','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66599','33898','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66600','33898','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66601','33899','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66602','33900','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66603','33908','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66604','33909','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66605','33910','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66606','33911','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66607','33912','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66608','33912','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66609','33913','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66610','33914','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66611','33915','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66612','33916','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66613','33917','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66614','33918','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66615','33919','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66616','33920','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66617','33920','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66618','33921','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66619','33922','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66620','33922','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66621','33923','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66622','33924','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66623','33925','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66624','33925','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66625','33927','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66626','33927','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66627','33928','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66628','33929','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66629','33930','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66630','33930','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66631','33931','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66632','33931','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66633','33932','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66634','33933','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66635','33934','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66637','33936','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66638','33937','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66639','33938','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66640','33939','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66641','33941','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66642','33941','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66643','33942','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66644','33943','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66645','33943','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66646','33944','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66647','33945','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66648','33945','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66649','33946','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66650','33946','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66651','33947','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66652','33951','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66653','33951','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66654','33952','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66655','33952','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66656','33953','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66657','33954','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66658','33954','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66659','33955','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66660','33956','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66661','33964','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66662','33965','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66663','33966','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66664','33967','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66665','33968','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66666','33968','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66667','33969','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66668','33970','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66669','33971','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66670','33972','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66671','33973','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66672','33974','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66673','33975','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66674','33976','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66675','33976','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66676','33977','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66677','33978','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66678','33978','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66679','33979','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66680','33980','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66681','33981','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66682','33981','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66683','33982','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66684','33982','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66685','33983','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66686','33984','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66687','33985','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66689','33987','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66690','33988','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66691','33989','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66692','33990','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66693','33992','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66694','33992','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66695','33993','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66696','33994','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66697','33994','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66698','33995','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66699','33996','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66700','33996','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66701','33997','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66702','33997','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66703','33998','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66704','34002','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66705','34002','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66706','34003','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66707','34003','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66708','34004','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66709','34005','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66710','34005','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66711','34006','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66712','34007','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66713','34015','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66714','34016','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66715','34017','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66716','34018','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66717','34019','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66718','34019','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66719','34020','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66720','34021','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66721','34022','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66722','34023','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66723','34024','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66724','34025','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66725','34026','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66726','34027','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66727','34027','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66728','34028','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66729','34029','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66730','34029','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66731','34030','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66732','34031','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66733','34032','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66734','34032','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66735','34033','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66736','34033','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66737','34034','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66738','34035','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66739','34036','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66741','34038','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66742','34039','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66743','34040','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66744','34041','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66745','34043','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66746','34043','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66747','34044','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66748','34045','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66749','34045','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66750','34046','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66751','34047','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66752','34047','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66753','34048','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66754','34048','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66755','34049','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66756','34053','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66757','34053','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66758','34054','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66759','34054','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66760','34055','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66761','34056','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66762','34056','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66763','34057','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66764','34058','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66765','34066','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66766','34067','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66767','34068','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66768','34069','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66769','34070','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66770','34070','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66771','34071','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66772','34072','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66773','34073','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66774','34074','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66775','34075','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66776','34076','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66777','34077','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66778','34078','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66779','34078','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66780','34079','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66781','34080','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66782','34080','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66783','34081','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66784','34082','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66785','34083','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66786','33595','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66787','34084','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66788','33646','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66789','34085','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66790','33697','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66791','34086','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66792','33748','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66793','34087','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66794','33799','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66795','34088','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66796','33850','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66797','34089','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66798','33901','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66799','34090','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66800','33459','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66801','34091','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66802','33957','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66803','34092','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66804','34008','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66805','34093','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66806','34059','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66807','34094','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66808','34095','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66809','34096','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66810','34097','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66811','34098','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66812','34101','1','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66813','34101','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66814','34102','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66815','34103','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66816','34104','1','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66817','34104','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66818','34105','1','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66819','34105','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66820','34106','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66821','34107','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66822','34108','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66823','34109','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66824','34110','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66825','34111','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66826','34113','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66827','34114','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66828','34115','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66829','34116','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66830','34117','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66831','34118','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66832','34119','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66833','34120','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66834','34121','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66835','34122','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66836','34127','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66837','34128','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66838','34130','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66839','34131','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66840','34132','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66843','34137','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66844','34139','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66845','34141','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66846','34143','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66847','34145','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66848','34147','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66849','34150','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66850','34151','1','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66851','34151','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66852','34155','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66853','34156','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66854','34157','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66855','34163','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66856','34164','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66857','34165','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66858','34166','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66859','34167','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66860','34168','1','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66861','34168','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66862','34169','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66863','34169','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66864','34170','1','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66865','34170','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66866','34171','1','6','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66867','34171','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66868','34172','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66869','34175','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66870','34176','1','12','$[?(@.dbname==''{#DBNAME}'' && @.type==''I'')].duration.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66871','34177','1','12','$[?(@.dbname==''{#DBNAME}'' && @.type==''I'')].timesincelastbackup.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66872','34178','1','12','$[?(@.dbname==''{#DBNAME}'' && @.type==''L'')].timesincelastbackup.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66873','34179','1','12','$[?(@.dbname==''{#DBNAME}'' && @.type==''L'')].duration.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66874','34180','1','12','$[?(@.dbname==''{#DBNAME}'' && @.type==''D'')].timesincelastbackup.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66875','34181','1','12','$[?(@.dbname==''{#DBNAME}'' && @.type==''D'')].duration.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66876','34182','1','12','$[?(@.JobName==''{#JOBNAME}'')].LastRunDateTime.first()','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66877','34182','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66878','34183','1','12','$[?(@.JobName==''{#JOBNAME}'')].LastRunStatusMessage.first()','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66879','34183','2','20','15m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66880','34184','1','12','$[?(@.JobName==''{#JOBNAME}'')].NextRunDateTime.first()','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66881','34184','2','20','15m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66882','34185','1','12','$[?(@.JobName==''{#JOBNAME}'')].RunDuration.first()','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66883','34185','2','20','15m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66884','34186','1','12','$[?(@.JobName==''{#JOBNAME}'')].RunStatus.first()','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66885','34186','2','20','15m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66886','34189','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66887','34196','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66894','34207','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66895','34208','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66896','34209','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66897','34210','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66898','34211','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66899','34212','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66900','34213','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66901','34214','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66902','34215','1','21','var valueArray = [
    ''moduleNoDefect'',
    ''moduleOverHeat'',
    ''moduleFanRpmLow'',
    ''moduleVoltageLow'',
    ''moduleThermalSensorFailure'',
    ''modulePullOut'',
    ''powerDC48VAFailure'',
    ''powerDC48VBFailure'',
    ''extAlarmInputTrigger'',
    ''moduleDown'',
    ''mscSwitchOverOK'',
    ''networkTopologyChange'',
    ''macSpoof'',
    ''cpuHigh'',
    ''memoryUsageHigh'',
    ''packetBufferUsageHigh'',
    ''loopguardOccurence''
];
var base2 = parseInt(value).toString(2);
var outArray = [];
for (var i = 0; i < base2.length; ++i) {
    if (base2[base2.length - 1 - i] === ''1'') outArray.push(valueArray[i]);
}
return outArray.join();
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66903','34216','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66904','34220','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
    item["{#ZYXEL.VOLT.THRESH.LOW}"] /= 1000;
    item["{#ZYXEL.VOLT.THRESH.HIGH}"] /= 1000;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66905','34221','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66906','34222','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66907','34222','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66908','34223','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66909','34223','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66910','34224','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66911','34224','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66912','34225','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66913','34225','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66914','34226','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66915','34226','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66916','34227','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66917','34227','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66918','34228','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66919','34228','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66920','34229','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66921','34230','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66922','34231','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66923','34231','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66924','34232','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66925','34233','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66926','34233','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66927','34234','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66928','34235','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66929','34236','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66930','34236','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66931','34237','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66932','34238','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66933','34238','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66934','34239','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66935','34240','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66936','34242','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66937','34242','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66938','34243','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66939','34244','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66940','34245','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66941','34246','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66942','34247','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66943','34248','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66944','34251','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66945','34253','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66946','34254','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66947','34255','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66948','34256','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66949','34257','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66950','34258','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66951','34259','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66952','34260','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66953','34260','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66954','34261','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66955','34262','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66956','34263','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66957','34264','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66958','34265','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66959','34266','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66960','34267','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66961','34268','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66962','34268','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66963','34269','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66964','34270','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66965','34271','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66966','34271','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66967','34272','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66968','34273','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66969','34273','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66970','34274','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66971','34275','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66972','34276','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66973','34277','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66974','34278','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66975','34279','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66976','34280','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66977','34281','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66978','34282','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66979','34282','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66980','34283','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66981','34284','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66982','34286','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66983','34286','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66984','34287','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66985','34288','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66986','34289','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66987','34290','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66988','34291','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66989','34292','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66990','34295','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66991','34296','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66992','34297','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66993','34298','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66994','34299','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66995','34300','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66996','34301','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66997','34302','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66998','34302','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('66999','34303','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67000','34304','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67001','34305','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67002','34306','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67003','34307','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67004','34308','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67005','34309','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67006','34310','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67007','34310','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67008','34311','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67009','34312','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67010','34313','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67011','34313','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67012','34314','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67013','34315','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67014','34316','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67015','34316','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67016','34317','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67017','34318','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67018','34319','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67019','34320','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67020','34321','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67021','34322','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67022','34323','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67023','34324','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67024','34325','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67025','34327','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67026','34328','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = Math.floor(item[''{#SNMPINDEX}''] / 100);
    item[''{#ZYXEL.PORTID}''] = item[''{#SNMPINDEX}''] % 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67027','34331','1','21','var inArray = JSON.parse(value);
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.TEMP.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item);
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67028','34332','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
    item["{#ZYXEL.VOLT.THRESH.LOW}"] /= 1000;
    item["{#ZYXEL.VOLT.THRESH.HIGH}"] /= 1000;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67029','34333','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67030','34334','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67031','34335','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67032','34336','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67033','34337','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67034','34338','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67035','34338','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67036','34339','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67037','34339','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67038','34340','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67039','34341','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67040','34342','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67041','34343','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67042','34344','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67043','34345','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67044','34346','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67045','34346','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67046','34347','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67047','34348','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67048','34349','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67049','34349','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67050','34350','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67051','34350','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67052','34351','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67053','34351','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67054','34352','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67055','34352','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67056','34353','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67057','34353','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67058','34354','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67059','34355','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67060','34356','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67061','34357','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67062','34357','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67063','34358','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67064','34359','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67065','34360','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67066','34360','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67067','34361','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67068','34362','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67069','34363','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67070','34364','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67071','34365','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67072','34366','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67073','34367','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67074','34367','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67075','34368','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67076','34369','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67077','34370','1','21','var valueArray = [
    ''moduleNoDefect'',
    ''moduleOverHeat'',
    ''moduleFanRpmLow'',
    ''moduleVoltageLow'',
    ''moduleThermalSensorFailure'',
    ''modulePullOut'',
    ''powerDC48VAFailure'',
    ''powerDC48VBFailure'',
    ''extAlarmInputTrigger'',
    ''moduleDown'',
    ''mscSwitchOverOK'',
    ''networkTopologyChange'',
    ''macSpoof'',
    ''cpuHigh'',
    ''memoryUsageHigh'',
    ''packetBufferUsageHigh'',
    ''loopguardOccurence''
];
var base2 = parseInt(value).toString(2);
var outArray = [];
for (var i = 0; i < base2.length; ++i) {
    if (base2[base2.length - 1 - i] === ''1'') outArray.push(valueArray[i]);
}
return outArray.join();
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67078','34371','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67079','34372','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67080','34373','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67081','34374','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67082','34375','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67083','34376','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67084','34377','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67085','34378','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67086','34379','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67087','34380','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67088','34382','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67089','34383','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67090','34383','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67091','34384','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67092','34385','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67093','34386','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67094','34387','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67095','34388','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67096','34389','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67097','34390','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67098','34391','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67099','34392','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67100','34394','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67101','34395','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = Math.floor(item[''{#SNMPINDEX}''] / 100);
    item[''{#ZYXEL.PORTID}''] = item[''{#SNMPINDEX}''] % 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67102','34398','1','21','var inArray = JSON.parse(value);
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.TEMP.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item);
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67103','34399','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
    item["{#ZYXEL.VOLT.THRESH.LOW}"] /= 1000;
    item["{#ZYXEL.VOLT.THRESH.HIGH}"] /= 1000;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67104','34400','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67105','34401','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67106','34402','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67107','34403','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67108','34404','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67109','34405','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67110','34405','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67111','34406','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67112','34406','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67113','34407','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67114','34408','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67115','34409','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67116','34410','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67117','34411','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67118','34412','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67119','34413','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67120','34413','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67121','34414','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67122','34415','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67123','34416','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67124','34416','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67125','34417','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67126','34417','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67127','34418','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67128','34418','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67129','34419','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67130','34419','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67131','34420','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67132','34420','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67133','34421','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67134','34422','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67135','34423','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67136','34424','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67137','34424','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67138','34425','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67139','34426','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67140','34427','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67141','34427','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67142','34428','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67143','34429','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67144','34430','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67145','34431','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67146','34432','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67147','34433','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67148','34434','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67149','34434','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67150','34435','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67151','34436','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67152','34437','1','21','var valueArray = [
    ''moduleNoDefect'',
    ''moduleOverHeat'',
    ''moduleFanRpmLow'',
    ''moduleVoltageLow'',
    ''moduleThermalSensorFailure'',
    ''modulePullOut'',
    ''powerDC48VAFailure'',
    ''powerDC48VBFailure'',
    ''extAlarmInputTrigger'',
    ''moduleDown'',
    ''mscSwitchOverOK'',
    ''networkTopologyChange'',
    ''macSpoof'',
    ''cpuHigh'',
    ''memoryUsageHigh'',
    ''packetBufferUsageHigh'',
    ''loopguardOccurence''
];
var base2 = parseInt(value).toString(2);
var outArray = [];
for (var i = 0; i < base2.length; ++i) {
    if (base2[base2.length - 1 - i] === ''1'') outArray.push(valueArray[i]);
}
return outArray.join();
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67153','34438','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67154','34439','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67155','34440','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67156','34441','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67157','34442','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67158','34443','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67159','34444','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67160','34445','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67161','34446','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67162','34447','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67163','34449','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67164','34450','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67165','34450','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67166','34451','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67167','34452','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67168','34453','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67169','34454','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67170','34455','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67171','34456','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67172','34457','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67173','34458','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67174','34459','1','21','var valueArray = [
    ''moduleNoDefect'',
    ''moduleOverHeat'',
    ''moduleFanRpmLow'',
    ''moduleVoltageLow'',
    ''moduleThermalSensorFailure'',
    ''modulePullOut'',
    ''powerDC48VAFailure'',
    ''powerDC48VBFailure'',
    ''extAlarmInputTrigger'',
    ''moduleDown'',
    ''mscSwitchOverOK'',
    ''networkTopologyChange'',
    ''macSpoof'',
    ''cpuHigh'',
    ''memoryUsageHigh'',
    ''packetBufferUsageHigh'',
    ''loopguardOccurence''
];
var base2 = parseInt(value).toString(2);
var outArray = [];
for (var i = 0; i < base2.length; ++i) {
    if (base2[base2.length - 1 - i] === ''1'') outArray.push(valueArray[i]);
}
return outArray.join();
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67175','34460','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67176','34465','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
    item["{#ZYXEL.VOLT.THRESH.LOW}"] /= 1000;
    item["{#ZYXEL.VOLT.THRESH.HIGH}"] /= 1000;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67177','34466','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67178','34467','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67179','34468','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67180','34468','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67181','34469','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67182','34469','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67183','34470','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67184','34470','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67185','34471','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67186','34471','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67187','34472','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67188','34472','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67189','34473','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67190','34473','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67191','34474','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67192','34474','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67193','34475','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67194','34476','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67195','34477','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67196','34477','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67197','34478','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67198','34479','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67199','34479','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67200','34480','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67201','34481','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67202','34482','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67203','34482','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67204','34483','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67205','34484','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67206','34484','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67207','34485','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67208','34486','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67209','34488','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67210','34488','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67211','34489','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67212','34490','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67213','34491','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67214','34492','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67215','34493','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67216','34494','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67217','34496','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67218','34498','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67219','34499','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67220','34500','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67221','34501','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67222','34502','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67223','34502','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67224','34503','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67225','34504','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67226','34505','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67227','34506','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67228','34507','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67229','34508','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67230','34509','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67231','34510','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67232','34510','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67233','34511','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67234','34512','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67235','34513','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67236','34513','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67237','34514','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67238','34515','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67239','34515','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67240','34516','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67241','34517','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67242','34518','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67243','34519','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67244','34520','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67245','34521','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67246','34522','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67247','34523','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67248','34524','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67249','34526','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67250','34526','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67251','34527','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67252','34528','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67253','34529','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67254','34530','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67255','34531','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67256','34532','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67257','34535','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67258','34537','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67259','34538','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67260','34539','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67261','34540','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67262','34541','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67263','34542','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67264','34543','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67265','34544','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67266','34544','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67267','34545','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67268','34546','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67269','34547','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67270','34548','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67271','34549','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67272','34550','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67273','34551','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67274','34552','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67275','34552','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67276','34553','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67277','34554','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67278','34555','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67279','34555','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67280','34556','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67281','34557','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67282','34557','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67283','34558','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67284','34559','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67285','34560','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67286','34561','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67287','34562','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67288','34563','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67289','34564','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67290','34565','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67291','34566','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67292','34566','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67293','34567','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67294','34568','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67295','34570','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67296','34570','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67297','34571','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67298','34572','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67299','34573','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67300','34574','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67301','34575','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67302','34576','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67303','34579','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67304','34581','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67305','34582','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67306','34583','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67307','34584','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67308','34585','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67309','34586','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67310','34587','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67311','34588','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67312','34588','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67313','34589','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67314','34590','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67315','34591','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67316','34592','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67317','34593','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67318','34594','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67319','34595','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67320','34596','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67321','34596','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67322','34597','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67323','34598','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67324','34599','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67325','34599','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67326','34600','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67327','34601','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67328','34601','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67329','34602','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67330','34603','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67331','34604','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67332','34605','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67333','34606','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67334','34607','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67335','34608','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67336','34609','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67337','34610','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67338','34610','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67339','34611','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67340','34612','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67341','34614','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67342','34614','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67343','34615','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67344','34616','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67345','34617','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67346','34618','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67347','34619','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67348','34620','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67349','34623','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67350','34625','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67351','34626','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67352','34627','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67353','34628','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67354','34629','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67355','34630','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67356','34631','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67357','34632','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67358','34632','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67359','34633','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67360','34634','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67361','34635','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67362','34636','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67363','34637','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67364','34638','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67365','34639','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67366','34640','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67367','34640','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67368','34641','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67369','34642','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67370','34643','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67371','34643','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67372','34644','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67373','34645','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67374','34645','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67375','34646','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67376','34647','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67377','34648','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67378','34649','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67379','34650','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67380','34651','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67381','34652','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67382','34653','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67383','34654','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67384','34654','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67385','34655','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67386','34656','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67387','34658','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67388','34658','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67389','34659','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67390','34660','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67391','34661','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67392','34662','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67393','34663','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67394','34664','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67395','34667','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67396','34669','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67397','34670','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67398','34671','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67399','34672','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67400','34673','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67401','34674','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67402','34675','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67403','34676','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67404','34676','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67405','34677','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67406','34678','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67407','34679','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67408','34680','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67409','34681','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67410','34682','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67411','34683','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67412','34684','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67413','34684','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67414','34685','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67415','34686','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67416','34687','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67417','34687','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67418','34688','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67419','34689','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67420','34689','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67421','34690','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67422','34691','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67423','34692','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67424','34693','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67425','34694','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67426','34695','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67427','34696','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67428','34697','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67429','34698','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67430','34698','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67431','34699','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67432','34700','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67433','34702','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67434','34703','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67435','34704','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67436','34706','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67437','34707','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67438','34708','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67439','34709','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67440','34712','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67441','34715','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.THRESH.LOW}"] /= 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67442','34716','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67443','34717','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67444','34718','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67445','34719','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67446','34720','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67447','34721','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67448','34721','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67449','34722','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67450','34723','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67451','34724','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67452','34725','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67453','34726','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67454','34727','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67455','34728','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67456','34729','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67457','34729','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67458','34730','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67459','34731','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67460','34732','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67461','34732','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67462','34733','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67463','34734','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67464','34734','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67465','34735','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67466','34736','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67467','34737','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67468','34738','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67469','34739','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67470','34740','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67471','34741','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67472','34742','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67473','34743','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67474','34743','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67475','34744','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67476','34745','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67477','34747','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67478','34748','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67479','34749','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67480','34751','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67481','34752','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67482','34753','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67483','34754','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67484','34757','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67485','34760','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.THRESH.LOW}"] /= 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67486','34761','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67487','34762','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67488','34763','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67489','34764','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67490','34765','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67491','34766','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67492','34766','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67493','34767','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67494','34768','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67495','34769','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67496','34770','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67497','34771','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67498','34772','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67499','34773','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67500','34774','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67501','34774','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67502','34775','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67503','34776','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67504','34777','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67505','34777','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67506','34778','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67507','34779','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67508','34779','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67509','34780','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67510','34781','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67511','34782','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67512','34783','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67513','34784','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67514','34785','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67515','34786','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67516','34787','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67517','34788','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67518','34788','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67519','34789','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67520','34790','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67521','34792','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67522','34792','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67523','34793','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67524','34794','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67525','34795','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67526','34796','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67527','34797','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67528','34798','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67529','34802','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67530','34804','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67531','34805','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67532','34806','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67533','34807','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67534','34808','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67535','34809','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67536','34810','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67537','34811','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67538','34812','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67539','34812','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67540','34813','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67541','34814','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67542','34815','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67543','34816','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67544','34817','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67545','34818','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67546','34819','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67547','34820','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67548','34820','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67549','34821','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67550','34822','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67551','34823','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67552','34823','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67553','34824','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67554','34825','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67555','34825','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67556','34826','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67557','34827','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67558','34828','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67559','34829','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67560','34830','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67561','34831','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67562','34832','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67563','34833','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67564','34834','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67565','34834','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67566','34845','1','12','$.idle','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67567','34846','1','12','$.active','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67568','34847','1','12','$.session_reuses','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67569','34847','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67570','34848','1','12','$.handshakes','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67571','34848','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67572','34849','1','12','$.handshakes_failed','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67573','34849','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67574','34850','1','12','$.dropped','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67575','34851','1','12','$.current','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67576','34852','1','12','$.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67577','34852','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67578','34853','1','12','$.version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67579','34853','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67580','34854','1','12','$.accepted','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67581','34854','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67582','34855','1','12','$.generation','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67583','34855','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67584','34856','1','12','$.error.text','2','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67585','34856','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67586','34857','1','12','$.address','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67587','34857','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67588','34858','1','12','$.load_timestamp','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67589','34858','2','21','return Math.floor((Date.now() - new Date(value)) / 1000);','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67590','34859','1','21','var output = [];

Object.keys(JSON.parse(value)).forEach(function (v) {
    output.push({ ''{#NAME}'': v })
});

return JSON.stringify(output);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67591','34859','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67592','34860','1','21','var output = [];

Object.keys(JSON.parse(value)).forEach(function (v) {
    output.push({ ''{#NAME}'': v })
});

return JSON.stringify(output);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67593','34860','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67594','34861','1','21','var input = JSON.parse(value),
    output = [];

Object.keys(input).forEach(function (upstream) {
    input[upstream].peers.forEach(function (peer) {
        output.push({ ''{#UPSTREAM}'': upstream, ''{#PEER}'': peer.server })
    });
});

return JSON.stringify(output);

','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67595','34861','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67596','34862','1','21','var output = [];

Object.keys(JSON.parse(value)).forEach(function (v) {
    output.push({ ''{#NAME}'': v })
});

return JSON.stringify(output);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67597','34862','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67598','34863','1','21','var output = [];

Object.keys(JSON.parse(value)).forEach(function (v) {
    output.push({ ''{#NAME}'': v })
});

return JSON.stringify(output);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67599','34863','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67600','34864','1','21','var output = [];

Object.keys(JSON.parse(value)).forEach(function (v) {
    output.push({ ''{#NAME}'': v })
});

return JSON.stringify(output);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67601','34864','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67602','34865','1','21','var input = JSON.parse(value),
    output = [];

Object.keys(input).forEach(function (upstream) {
    input[upstream].peers.forEach(function (peer) {
        output.push({ ''{#UPSTREAM}'': upstream, ''{#PEER}'': peer.server })
    });
});

return JSON.stringify(output);

','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67603','34865','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67604','34866','1','21','var output = [];

Object.keys(JSON.parse(value)).forEach(function (v) {
    output.push({ ''{#NAME}'': v })
});

return JSON.stringify(output);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67605','34866','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67606','34867','1','12','$[''{#NAME}''].discarded','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67607','34867','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67608','34868','1','12','$[''{#NAME}''].received','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67609','34868','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67610','34869','1','12','$[''{#NAME}''].requests','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67611','34869','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67612','34870','1','12','$[''{#NAME}''].responses.1xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67613','34870','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67614','34871','1','12','$[''{#NAME}''].responses.2xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67615','34871','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67616','34872','1','12','$[''{#NAME}''].responses.3xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67617','34872','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67618','34873','1','12','$[''{#NAME}''].responses.4xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67619','34873','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67620','34874','1','12','$[''{#NAME}''].responses.5xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67621','34874','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67622','34875','1','12','$[''{#NAME}''].responses.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67623','34875','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67624','34876','1','12','$[''{#NAME}''].sent','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67625','34876','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67626','34877','1','12','$[''{#NAME}''].discarded','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67627','34877','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67628','34878','1','12','$[''{#NAME}''].processing','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67629','34879','1','12','$[''{#NAME}''].received','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67630','34879','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67631','34880','1','12','$[''{#NAME}''].requests','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67632','34880','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67633','34881','1','12','$[''{#NAME}''].responses.1xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67634','34881','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67635','34882','1','12','$[''{#NAME}''].responses.2xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67636','34882','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67637','34883','1','12','$[''{#NAME}''].responses.3xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67638','34883','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67639','34884','1','12','$[''{#NAME}''].responses.4xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67640','34884','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67641','34885','1','12','$[''{#NAME}''].responses.5xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67642','34885','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67643','34886','1','12','$[''{#NAME}''].responses.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67644','34886','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67645','34887','1','12','$[''{#NAME}''].sent','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67646','34887','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67647','34888','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].active.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67648','34889','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].responses.2xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67649','34889','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67650','34890','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67651','34890','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67652','34891','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].sent.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67653','34891','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67654','34892','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].responses.total.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67655','34892','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67656','34893','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].responses.5xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67657','34893','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67658','34894','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].responses.4xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67659','34894','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67660','34895','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].responses.3xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67661','34895','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67662','34896','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].responses.1xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67663','34896','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67664','34897','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].fails.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67665','34897','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67666','34898','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].response_time.first()','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67667','34899','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].requests.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67668','34899','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67669','34900','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].received.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67670','34900','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67671','34901','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].health_checks.unhealthy.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67672','34902','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].health_checks.fails.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67673','34903','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].health_checks.checks.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67674','34904','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].header_time.first()','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67675','34905','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].unavail.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67676','34906','1','12','$[''{#NAME}''].keepalive','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67677','34907','1','12','$[''{#NAME}''].zombies','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67678','34908','1','12','$[''{#NAME}''].zone','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67679','34908','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67680','34909','1','12','$[''{#NAME}''].requests.addr','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67681','34909','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67682','34910','1','12','$[''{#NAME}''].requests.name','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67683','34910','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67684','34911','1','12','$[''{#NAME}''].requests.srv','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67685','34911','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67686','34912','1','12','$[''{#NAME}''].responses.formerr','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67687','34912','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67688','34913','1','12','$[''{#NAME}''].responses.noerror','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67689','34913','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67690','34914','1','12','$[''{#NAME}''].responses.notimp','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67691','34914','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67692','34915','1','12','$[''{#NAME}''].responses.nxdomain','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67693','34915','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67694','34916','1','12','$[''{#NAME}''].responses.refused','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67695','34916','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67696','34917','1','12','$[''{#NAME}''].responses.servfail','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67697','34917','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67698','34918','1','12','$[''{#NAME}''].responses.timedout','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67699','34918','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67700','34919','1','12','$[''{#NAME}''].responses.unknown','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67701','34919','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67702','34920','1','12','$[''{#NAME}''].connections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67703','34920','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67704','34921','1','12','$[''{#NAME}''].discarded','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67705','34921','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67706','34922','1','12','$[''{#NAME}''].processing','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67707','34923','1','12','$[''{#NAME}''].received','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67708','34923','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67709','34924','1','12','$[''{#NAME}''].sent','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67710','34924','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67711','34925','1','12','$[''{#NAME}''].sessions.2xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67712','34925','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67713','34926','1','12','$[''{#NAME}''].sessions.4xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67714','34926','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67715','34927','1','12','$[''{#NAME}''].sessions.5xx','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67716','34927','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67717','34928','1','12','$[''{#NAME}''].sessions.total','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67718','34928','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67719','34929','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].active.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67720','34930','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].connect_time.first()','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67721','34931','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].connections.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67722','34932','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].fails.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67723','34932','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67724','34933','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].first_byte_time.first()','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67725','34934','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].health_checks.checks.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67726','34935','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].health_checks.fails.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67727','34936','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].health_checks.unhealthy.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67728','34937','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].received.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67729','34937','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67730','34938','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].response_time.first()','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67731','34939','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].sent.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67732','34939','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67733','34940','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].state.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67734','34940','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67735','34941','1','12','$[''{#UPSTREAM}''].peers[?(@.server == ''{#PEER}'')].unavail.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67736','34942','1','12','$[''{#NAME}''].zombies','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67737','34943','1','12','$[''{#NAME}''].zone','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67738','34943','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67739','34946','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67740','34947','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67741','34948','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67742','34949','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67743','34950','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67744','34951','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67745','34953','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67746','34957','1','21','var result = [];

JSON.parse(value).forEach(function (netif) {
    if (typeof netif["{#IFNAME}"] === ''undefined'') {
        netif["{#IFNAME}"] = netif["{#IFDESCR}"];
    }
    if (typeof netif["{#IFALIAS}"] === ''undefined'') {
        netif["{#IFALIAS}"] = "";
    }
    result.push(netif);
});

return JSON.stringify(result);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67747','34964','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67748','34965','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67749','34966','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67750','34967','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67751','34968','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67752','34969','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67753','34970','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67754','34971','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67755','34972','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67756','34973','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67757','34973','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67758','34974','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67759','34975','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67760','34976','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67761','34977','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67762','34978','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67763','34978','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67764','34979','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67765','34979','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67766','34980','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67767','34981','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67768','34982','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67769','34983','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67770','34984','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67771','34985','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67772','34985','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67773','34986','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67774','34987','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67775','34988','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67776','34989','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67777','34990','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67778','34991','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67779','34992','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67780','34993','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67781','34994','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67782','34995','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67783','34996','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67784','34997','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67785','34997','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67786','34998','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67854','35041','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67855','35042','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67856','35043','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67857','35044','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67858','35045','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67859','35046','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67860','35047','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67861','35048','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67862','35049','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67863','35050','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67864','35051','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67865','35053','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67866','35054','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67867','35055','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67868','35056','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67869','35057','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67870','35058','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67871','35059','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67872','35060','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67873','35061','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67874','35062','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67875','35063','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67876','35065','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67877','35066','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67878','35067','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67879','35068','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67880','35069','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67881','35069','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67882','35070','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67883','35071','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67884','35072','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67885','35073','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67886','35074','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67887','35074','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67888','35075','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67889','35077','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67890','35077','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67891','35079','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67959','35123','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67960','35124','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67961','35125','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67962','35126','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67963','35127','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67964','35128','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67965','35129','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67966','35130','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67967','35131','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67968','35132','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67969','35133','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67970','35135','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67971','35136','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67972','35137','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67973','35138','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67974','35139','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67975','35140','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67976','35141','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67977','35142','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67978','35143','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67979','35144','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67980','35145','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67981','35147','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67982','35148','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67983','35149','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67984','35150','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67985','35151','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67986','35151','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67987','35152','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67988','35153','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67989','35154','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67990','35155','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67991','35156','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67992','35156','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67993','35157','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67994','35159','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67995','35159','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('67996','35161','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68064','35205','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68065','35206','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68066','35207','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68067','35208','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68068','35209','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68069','35210','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68070','35211','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68071','35212','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68072','35213','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68073','35214','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68074','35215','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68075','35217','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68076','35218','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68077','35219','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68078','35220','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68079','35221','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68080','35222','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68081','35223','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68082','35224','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68083','35225','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68084','35226','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68085','35227','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68086','35229','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68087','35230','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68088','35231','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68089','35232','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68090','35233','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68091','35233','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68092','35234','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68093','35235','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68094','35236','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68095','35237','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68096','35238','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68097','35238','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68098','35239','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68099','35241','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68100','35241','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68101','35243','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68169','35287','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68170','35288','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68171','35289','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68172','35290','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68173','35291','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68174','35292','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68175','35293','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68176','35294','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68177','35295','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68178','35296','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68179','35297','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68180','35299','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68181','35300','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68182','35301','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68183','35302','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68184','35303','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68185','35304','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68186','35305','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68187','35306','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68188','35307','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68189','35308','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68190','35309','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68191','35311','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68192','35312','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68193','35313','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68194','35314','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68195','35315','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68196','35315','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68197','35316','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68198','35317','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68199','35318','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68200','35319','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68201','35320','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68202','35320','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68203','35321','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68204','35323','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68205','35323','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68206','35325','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68207','35327','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68208','35328','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68209','35329','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68210','35330','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68211','35331','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68212','35332','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68213','35333','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68214','35334','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68215','35335','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68216','35336','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68217','35338','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68218','35339','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68219','35340','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68220','35341','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68221','35342','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68222','35343','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68223','35344','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68224','35345','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68225','35346','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68226','35347','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68227','35348','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68228','35349','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68229','35350','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68230','35351','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68231','35352','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68232','35353','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68233','35354','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68234','35355','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68235','35356','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68236','35357','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68237','35358','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68238','35359','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68239','35360','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68240','35361','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68241','35362','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68242','35362','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68243','35363','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68244','35364','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68245','35365','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68246','35366','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68247','35367','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68248','35368','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68249','35369','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68250','35370','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68251','35371','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68252','35372','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68253','35373','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68254','35374','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68255','35375','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68256','35376','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68257','35377','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68258','35378','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68259','35379','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68260','35380','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68261','35381','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68262','35382','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68263','35382','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68264','35383','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68265','35384','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68266','35385','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68267','35386','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68268','35387','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68269','35388','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68270','35389','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68271','35390','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68272','35391','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68273','35392','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68274','35393','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68275','35395','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68276','35396','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68277','35397','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68278','35398','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68279','35399','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68280','35400','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68281','35401','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68282','35402','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68283','35403','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68284','35404','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68285','35405','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68286','35406','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68287','35407','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68288','35408','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68289','35409','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68290','35410','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68291','35411','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68292','35412','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68293','35413','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68294','35414','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68295','35415','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68296','35416','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68297','35417','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68298','35418','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68299','35419','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68300','35419','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68301','35420','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68302','35421','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68303','35422','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68304','35423','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68305','35424','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68306','35425','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68307','35426','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68308','35427','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68309','35428','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68310','35429','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68311','35430','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68312','35431','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68313','35432','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68314','35433','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68315','35434','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68316','35435','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68317','35436','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68318','35437','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68319','35438','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68320','35439','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68321','35439','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68322','35440','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68323','35441','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68324','35442','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68325','35443','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68326','35444','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68327','35445','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68328','35446','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68329','35447','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68330','35448','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68331','35449','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68332','35450','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68333','35452','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68334','35453','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68335','35454','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68336','35455','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68337','35456','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68338','35457','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68339','35458','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68340','35459','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68341','35460','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68342','35461','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68343','35462','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68344','35463','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68345','35464','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68346','35465','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68347','35466','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68348','35467','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68349','35468','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68350','35469','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68351','35470','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68352','35471','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68353','35472','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68354','35473','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68355','35474','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68356','35475','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68357','35476','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68358','35476','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68359','35477','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68360','35478','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68361','35479','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68362','35480','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68363','35481','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68364','35482','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68365','35483','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68366','35484','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68367','35485','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68368','35486','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68369','35487','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68370','35488','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68371','35489','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68372','35490','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68373','35491','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68374','35492','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68375','35493','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68376','35494','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68377','35495','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68378','35496','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68379','35496','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68380','35497','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68381','35498','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68382','35499','1','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68383','35500','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68384','35501','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68385','35502','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68386','35503','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68387','35504','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68388','35505','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68389','35506','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68390','35507','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68391','35509','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68392','35510','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68393','35511','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68394','35512','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68395','35513','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68396','35514','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68397','35515','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68398','35516','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68399','35517','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68400','35518','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68401','35519','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68402','35520','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68403','35521','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68404','35522','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68405','35523','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68406','35524','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68407','35525','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68408','35526','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68409','35527','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68410','35528','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68411','35529','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68412','35530','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68413','35531','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68414','35532','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68415','35533','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68416','35533','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68417','35534','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68418','35535','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68419','35536','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68420','35537','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68421','35538','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68422','35539','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68423','35540','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68424','35541','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68425','35542','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68426','35543','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68427','35544','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68428','35545','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68429','35546','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68430','35547','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68431','35548','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68432','35549','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68433','35550','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68434','35551','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68435','35552','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68436','35553','1','1','1048576','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68437','35553','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68438','35554','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68442','35562','1','12','$.ActiveState.state','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68443','35562','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68444','35563','1','12','$.LoadState.state','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68445','35563','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68446','35564','1','12','$.UnitFileState.state','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68447','35564','2','20','30m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68448','35565','1','21','data = JSON.parse(value)
  if (data.ActiveEnterTimestamp > data.ActiveExitTimestamp) {
      return Math.floor(Date.now()/1000)-Number(data.ActiveEnterTimestamp)/1000000;
    }
  return null;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68449','35566','1','12','$.NAccepted','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68450','35566','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68451','35567','1','12','$.NConnections','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68452','35568','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68453','35568','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68454','35569','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68455','35569','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68456','35570','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68457','35570','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68458','35571','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68459','35572','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68460','35573','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)

','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68461','35574','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)


','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68462','35575','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)


','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68463','35576','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)


','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68464','35577','1','21','var data = JSON.parse(value);
for (var item, i = 0; item = data.data[i++];) {
    if (!(''{#JMXIGNITEINSTANCENAME}'' in item)) {
        Object.assign(item, {
            ''{#JMXIGNITEINSTANCENAME}'': ''null''
        });
    }

}

return JSON.stringify(data)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68465','35577','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68466','35579','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68467','35609','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68468','35610','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68469','35611','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68470','35612','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68471','35613','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68472','35614','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68473','35615','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68474','35616','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68475','35617','1','5','(.*)-\d+
\1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68476','35617','2','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68477','35618','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68478','35619','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68479','35621','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68481','35623','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68482','35624','1','20','3h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68483','35629','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68484','35630','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68485','35631','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68486','35637','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68487','35640','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68488','35641','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68489','35643','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68490','35644','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68491','35645','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68492','35646','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68493','35648','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68494','35654','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68495','35655','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68496','35656','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68497','35657','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68498','35658','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68499','35659','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68500','35660','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68501','35661','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68502','35662','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68503','35663','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68504','35664','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68505','35665','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68506','35666','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68507','35667','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68508','35668','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68509','35669','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68510','35670','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68511','35671','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68512','35672','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68513','35673','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68514','35674','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68515','35675','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68516','35676','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68517','35677','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68518','35678','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68519','35679','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68520','35680','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68521','35681','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68522','35681','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68523','35682','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68524','35683','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68525','35684','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68526','35685','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68527','35686','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68528','35714','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68529','35715','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68530','35716','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68531','35717','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68532','35718','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68533','35719','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68534','35720','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68535','35721','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68536','35722','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68537','35723','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68538','35724','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68539','35725','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68540','35726','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68541','35727','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68542','35728','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68543','35729','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68544','35730','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68545','35731','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68546','35732','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68547','35733','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68548','35733','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68549','35734','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68550','35735','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68551','35736','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68552','35736','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68553','35737','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68554','35737','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68555','35738','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68556','35738','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68557','35739','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68558','35739','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68559','35740','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68560','35741','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68561','35742','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68562','35742','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68563','35743','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68564','35743','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68565','35744','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68566','35744','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68567','35745','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68568','35746','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68569','35747','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68570','35747','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68571','35748','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68572','35748','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68573','35749','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68574','35749','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68575','35750','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68576','35750','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68577','35751','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68578','35752','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68579','35753','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68580','35754','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68581','35755','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68582','35755','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68583','35756','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68584','35756','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68585','35757','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68586','35757','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68587','35758','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68588','35758','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68589','35759','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68590','35760','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68591','35760','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68592','35761','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68593','35762','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68594','35763','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68595','35763','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68596','35764','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68597','35764','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68598','35765','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68599','35765','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68600','35766','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68601','35766','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68602','35767','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68603','35768','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68604','35769','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68605','35770','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68606','35771','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68607','35772','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68608','35773','1','12','$.x509.alternative_names','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68609','35774','1','12','$.x509.issuer','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68610','35775','1','12','$.result.message','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68611','35776','1','12','$.x509.not_after.timestamp','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68612','35777','1','12','$.x509.not_before.timestamp','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68613','35778','1','12','$.x509.public_key_algorithm','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68614','35779','1','12','$.x509.serial_number','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68615','35780','1','12','$.sha1_fingerprint','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68616','35781','1','12','$.x509.signature_algorithm','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68617','35782','1','12','$.x509.subject','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68618','35783','1','12','$.result.value','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68619','35784','1','12','$.x509.version','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68620','35785','1','21','return JSON.stringify(JSON.parse(value),[''mode'',''pxname'',''svname''])','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68621','35785','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68622','35787','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].act.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68623','35787','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68624','35788','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_5xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68625','35788','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68626','35789','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].wredis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68627','35789','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68628','35790','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].weight.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68629','35790','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68630','35791','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].stot.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68631','35791','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68632','35792','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].status.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68633','35792','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68634','35793','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].rtime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68635','35793','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68636','35794','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].qtime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68637','35794','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68638','35795','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].qcur.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68639','35796','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_4xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68640','35796','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68641','35797','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bck.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68642','35797','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68643','35798','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_3xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68644','35798','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68645','35799','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_2xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68646','35799','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68647','35800','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_1xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68648','35800','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68649','35801','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].eresp.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68650','35801','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68651','35802','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].econ.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68652','35802','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68653','35803','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].dresp.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68654','35803','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68655','35804','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bout.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68656','35804','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68657','35804','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68658','35805','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bin.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68659','35805','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68660','35805','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68661','35806','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].wretr.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68662','35806','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68663','35807','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bin.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68664','35807','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68665','35807','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68666','35808','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bout.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68667','35808','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68668','35808','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68669','35809','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].dreq.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68670','35809','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68671','35810','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].ereq.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68672','35810','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68673','35811','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_1xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68674','35811','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68675','35812','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_2xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68676','35812','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68677','35813','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_3xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68678','35813','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68679','35814','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_4xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68680','35814','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68681','35815','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_5xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68682','35815','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68683','35816','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68684','35817','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].req_rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68685','35818','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].scur.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68686','35819','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].slim.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68687','35819','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68688','35820','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].status.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68689','35820','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68690','35821','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].act.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68691','35821','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68692','35822','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_5xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68693','35822','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68694','35823','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].wredis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68695','35823','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68696','35824','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].weight.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68697','35824','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68698','35825','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].stot.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68699','35825','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68700','35826','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].status.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68701','35826','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68702','35827','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].rtime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68703','35827','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68704','35828','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].qtime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68705','35828','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68706','35829','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].qlimit.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68707','35829','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68708','35829','3','14','^\d+$','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68709','35830','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].qcur.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68710','35831','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].lbtot.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68711','35831','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68712','35832','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_4xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68713','35832','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68714','35833','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bck.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68715','35833','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68716','35834','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_3xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68717','35834','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68718','35835','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_2xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68719','35835','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68720','35836','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_1xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68721','35836','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68722','35837','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].eresp.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68723','35837','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68724','35838','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].econ.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68725','35838','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68726','35839','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].dresp.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68727','35839','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68728','35840','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].check_status.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68729','35840','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68730','35841','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bout.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68731','35841','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68732','35841','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68733','35842','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bin.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68734','35842','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68735','35842','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68736','35843','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].wretr.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68737','35843','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68738','35844','1','21','return JSON.stringify(JSON.parse(value),[''mode'',''pxname'',''svname''])','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68739','35844','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68740','35846','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].act.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68741','35846','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68742','35847','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_5xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68743','35847','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68744','35848','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].wredis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68745','35848','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68746','35849','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].weight.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68747','35849','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68748','35850','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].stot.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68749','35850','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68750','35851','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].status.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68751','35851','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68752','35852','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].rtime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68753','35852','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68754','35853','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].qtime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68755','35853','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68756','35854','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].qcur.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68757','35855','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_4xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68758','35855','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68759','35856','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bck.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68760','35856','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68761','35857','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_3xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68762','35857','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68763','35858','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_2xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68764','35858','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68765','35859','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_1xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68766','35859','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68767','35860','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].eresp.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68768','35860','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68769','35861','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].econ.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68770','35861','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68771','35862','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].dresp.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68772','35862','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68773','35863','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bout.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68774','35863','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68775','35863','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68776','35864','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bin.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68777','35864','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68778','35864','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68779','35865','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].wretr.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68780','35865','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68781','35866','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bin.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68782','35866','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68783','35866','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68784','35867','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bout.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68785','35867','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68786','35867','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68787','35868','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].dreq.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68788','35868','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68789','35869','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].ereq.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68790','35869','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68791','35870','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_1xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68792','35870','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68793','35871','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_2xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68794','35871','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68795','35872','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_3xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68796','35872','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68797','35873','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_4xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68798','35873','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68799','35874','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_5xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68800','35874','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68801','35875','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68802','35876','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].req_rate.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68803','35877','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].scur.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68804','35878','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].slim.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68805','35878','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68806','35879','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].status.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68807','35879','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68808','35880','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].act.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68809','35880','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68810','35881','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_5xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68811','35881','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68812','35882','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].wredis.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68813','35882','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68814','35883','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].weight.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68815','35883','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68816','35884','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].stot.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68817','35884','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68818','35885','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].status.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68819','35885','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68820','35886','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].rtime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68821','35886','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68822','35887','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].qtime.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68823','35887','2','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68824','35888','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].qlimit.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68825','35888','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68826','35888','3','14','^\d+$','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68827','35889','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].qcur.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68828','35890','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].lbtot.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68829','35890','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68830','35891','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_4xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68831','35891','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68832','35892','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bck.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68833','35892','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68834','35893','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_3xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68835','35893','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68836','35894','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_2xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68837','35894','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68838','35895','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].hrsp_1xx.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68839','35895','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68840','35896','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].eresp.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68841','35896','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68842','35897','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].econ.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68843','35897','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68844','35898','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].dresp.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68845','35898','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68846','35899','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].check_status.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68847','35899','2','20','10m','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68848','35900','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bout.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68849','35900','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68850','35900','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68851','35901','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].bin.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68852','35901','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68853','35901','3','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68854','35902','1','12','$.[?(@.pxname == ''{#PXNAME}'' && @.svname == ''{#SVNAME}'')].wretr.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68855','35902','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68856','35903','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68857','35904','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68858','35905','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68859','35906','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68860','35907','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68861','35908','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68862','35918','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68863','35919','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68864','35920','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68865','35920','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68866','35921','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68867','35922','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68868','35923','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68869','35923','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68870','35924','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68871','35925','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68872','35925','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68873','35926','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68874','35927','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68875','35928','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68876','35929','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68877','35930','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68878','35930','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68879','35931','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68880','35932','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68881','35932','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68882','35933','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68883','35934','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68884','35935','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68885','35936','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68886','35937','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68887','35938','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68888','35939','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68889','35940','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68890','35941','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68891','35942','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68892','35943','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68893','35944','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68894','35945','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68895','35946','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68896','35947','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68897','35948','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68898','35948','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68899','35949','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68900','35949','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68901','35950','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68902','35951','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68903','35952','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68904','35953','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68905','35954','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68906','35955','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68907','35956','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68908','35957','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68909','35958','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68910','35959','1','21','var valueArray = [
    ''moduleNoDefect'',
    ''moduleOverHeat'',
    ''moduleFanRpmLow'',
    ''moduleVoltageLow'',
    ''moduleThermalSensorFailure'',
    ''modulePullOut'',
    ''powerDC48VAFailure'',
    ''powerDC48VBFailure'',
    ''extAlarmInputTrigger'',
    ''moduleDown'',
    ''mscSwitchOverOK'',
    ''networkTopologyChange'',
    ''macSpoof'',
    ''cpuHigh'',
    ''memoryUsageHigh'',
    ''packetBufferUsageHigh'',
    ''loopguardOccurence''
];
var base2 = parseInt(value).toString(2);
var outArray = [];
for (var i = 0; i < base2.length; ++i) {
    if (base2[base2.length - 1 - i] === ''1'') outArray.push(valueArray[i]);
}
return outArray.join();
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68911','35960','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68912','35964','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
    item["{#ZYXEL.VOLT.THRESH.LOW}"] /= 1000;
    item["{#ZYXEL.VOLT.THRESH.HIGH}"] /= 1000;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68913','35965','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68914','35966','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68915','35966','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68916','35967','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68917','35967','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68918','35968','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68919','35968','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68920','35969','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68921','35969','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68922','35970','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68923','35970','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68924','35971','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68925','35971','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68926','35972','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68927','35972','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68928','35973','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68929','35974','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68930','35975','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68931','35975','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68932','35976','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68933','35977','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68934','35977','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68935','35978','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68936','35979','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68937','35980','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68938','35980','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68939','35981','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68940','35982','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68941','35982','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68942','35983','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68943','35984','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68944','35986','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68945','35986','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68946','35987','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68947','35988','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68948','35989','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68949','35990','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68950','35991','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68951','35992','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68952','35995','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68953','35997','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68954','35998','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68955','35999','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68956','36000','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68957','36001','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68958','36002','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68959','36002','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68960','36003','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68961','36004','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68962','36004','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68963','36005','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68964','36006','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68965','36007','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68966','36008','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68967','36009','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68968','36010','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68969','36010','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68970','36011','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68971','36012','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68972','36012','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68973','36013','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68974','36014','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68975','36015','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68976','36015','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68977','36016','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68978','36017','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68979','36017','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68980','36018','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68981','36019','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68982','36020','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68983','36021','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68984','36022','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68985','36023','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68986','36024','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68987','36025','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68988','36026','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68989','36026','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68990','36027','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68991','36028','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68992','36030','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68993','36030','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68994','36031','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68995','36032','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68996','36033','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68997','36034','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68998','36035','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('68999','36036','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69000','36039','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69001','36040','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69002','36041','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69003','36042','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69004','36043','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69005','36044','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69006','36044','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69007','36045','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69008','36046','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69009','36046','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69010','36047','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69011','36048','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69012','36049','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69013','36050','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69014','36051','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69015','36052','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69016','36052','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69017','36053','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69018','36054','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69019','36054','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69020','36055','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69021','36056','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69022','36057','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69023','36057','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69024','36058','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69025','36059','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69026','36060','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69027','36060','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69028','36061','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69029','36062','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69030','36063','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69031','36064','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69032','36065','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69033','36066','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69034','36067','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69035','36068','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69036','36069','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69037','36071','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69038','36072','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = Math.floor(item[''{#SNMPINDEX}''] / 100);
    item[''{#ZYXEL.PORTID}''] = item[''{#SNMPINDEX}''] % 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69039','36075','1','21','var inArray = JSON.parse(value);
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.TEMP.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item);
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69040','36076','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
    item["{#ZYXEL.VOLT.THRESH.LOW}"] /= 1000;
    item["{#ZYXEL.VOLT.THRESH.HIGH}"] /= 1000;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69041','36077','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69042','36078','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69043','36079','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69044','36080','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69045','36081','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69046','36082','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69047','36082','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69048','36083','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69049','36083','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69050','36084','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69051','36085','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69052','36086','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69053','36087','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69054','36088','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69055','36089','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69056','36090','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69057','36090','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69058','36091','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69059','36092','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69060','36093','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69061','36093','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69062','36094','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69063','36094','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69064','36095','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69065','36095','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69066','36096','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69067','36096','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69068','36097','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69069','36097','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69070','36098','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69071','36099','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69072','36100','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69073','36101','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69074','36101','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69075','36102','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69076','36103','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69077','36104','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69078','36104','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69079','36105','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69080','36106','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69081','36106','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69082','36107','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69083','36108','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69084','36109','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69085','36110','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69086','36111','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69087','36111','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69088','36112','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69089','36113','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69090','36113','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69091','36114','1','21','var valueArray = [
    ''moduleNoDefect'',
    ''moduleOverHeat'',
    ''moduleFanRpmLow'',
    ''moduleVoltageLow'',
    ''moduleThermalSensorFailure'',
    ''modulePullOut'',
    ''powerDC48VAFailure'',
    ''powerDC48VBFailure'',
    ''extAlarmInputTrigger'',
    ''moduleDown'',
    ''mscSwitchOverOK'',
    ''networkTopologyChange'',
    ''macSpoof'',
    ''cpuHigh'',
    ''memoryUsageHigh'',
    ''packetBufferUsageHigh'',
    ''loopguardOccurence''
];
var base2 = parseInt(value).toString(2);
var outArray = [];
for (var i = 0; i < base2.length; ++i) {
    if (base2[base2.length - 1 - i] === ''1'') outArray.push(valueArray[i]);
}
return outArray.join();
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69092','36115','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69093','36116','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69094','36117','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69095','36118','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69096','36119','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69097','36120','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69098','36121','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69099','36122','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69100','36123','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69101','36124','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69102','36126','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69103','36127','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69104','36127','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69105','36128','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69106','36129','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69107','36130','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69108','36131','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69109','36132','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69110','36133','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69111','36134','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69112','36135','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69113','36136','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69114','36138','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69115','36139','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = Math.floor(item[''{#SNMPINDEX}''] / 100);
    item[''{#ZYXEL.PORTID}''] = item[''{#SNMPINDEX}''] % 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69116','36142','1','21','var inArray = JSON.parse(value);
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.TEMP.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    outArr.push(item);
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69117','36143','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
    item["{#ZYXEL.VOLT.THRESH.LOW}"] /= 1000;
    item["{#ZYXEL.VOLT.THRESH.HIGH}"] /= 1000;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69118','36144','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69119','36145','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69120','36146','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69121','36147','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69122','36148','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69123','36149','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69124','36149','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69125','36150','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69126','36150','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69127','36151','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69128','36152','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69129','36153','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69130','36154','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69131','36155','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69132','36156','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69133','36157','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69134','36157','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69135','36158','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69136','36159','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69137','36160','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69138','36160','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69139','36161','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69140','36161','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69141','36162','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69142','36162','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69143','36163','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69144','36163','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69145','36164','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69146','36164','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69147','36165','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69148','36166','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69149','36167','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69150','36168','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69151','36168','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69152','36169','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69153','36170','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69154','36171','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69155','36171','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69156','36172','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69157','36173','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69158','36173','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69159','36174','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69160','36175','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69161','36176','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69162','36177','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69163','36178','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69164','36178','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69165','36179','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69166','36180','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69167','36180','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69168','36181','1','21','var valueArray = [
    ''moduleNoDefect'',
    ''moduleOverHeat'',
    ''moduleFanRpmLow'',
    ''moduleVoltageLow'',
    ''moduleThermalSensorFailure'',
    ''modulePullOut'',
    ''powerDC48VAFailure'',
    ''powerDC48VBFailure'',
    ''extAlarmInputTrigger'',
    ''moduleDown'',
    ''mscSwitchOverOK'',
    ''networkTopologyChange'',
    ''macSpoof'',
    ''cpuHigh'',
    ''memoryUsageHigh'',
    ''packetBufferUsageHigh'',
    ''loopguardOccurence''
];
var base2 = parseInt(value).toString(2);
var outArray = [];
for (var i = 0; i < base2.length; ++i) {
    if (base2[base2.length - 1 - i] === ''1'') outArray.push(valueArray[i]);
}
return outArray.join();
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69169','36182','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69170','36183','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69171','36184','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69172','36185','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69173','36186','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69174','36187','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69175','36188','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69176','36189','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69177','36190','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69178','36191','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69179','36193','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69180','36194','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69181','36194','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69182','36195','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69183','36196','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69184','36197','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69185','36198','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69186','36199','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69187','36200','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69188','36201','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69189','36202','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69190','36203','1','21','var valueArray = [
    ''moduleNoDefect'',
    ''moduleOverHeat'',
    ''moduleFanRpmLow'',
    ''moduleVoltageLow'',
    ''moduleThermalSensorFailure'',
    ''modulePullOut'',
    ''powerDC48VAFailure'',
    ''powerDC48VBFailure'',
    ''extAlarmInputTrigger'',
    ''moduleDown'',
    ''mscSwitchOverOK'',
    ''networkTopologyChange'',
    ''macSpoof'',
    ''cpuHigh'',
    ''memoryUsageHigh'',
    ''packetBufferUsageHigh'',
    ''loopguardOccurence''
];
var base2 = parseInt(value).toString(2);
var outArray = [];
for (var i = 0; i < base2.length; ++i) {
    if (base2[base2.length - 1 - i] === ''1'') outArray.push(valueArray[i]);
}
return outArray.join();
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69191','36204','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69192','36209','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SLOT.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[1];
    item[''{#ZYXEL.SENSOR.ID}''] = item[''{#SNMPINDEX}''].split(''.'')[2];
    item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
    item["{#ZYXEL.VOLT.THRESH.LOW}"] /= 1000;
    item["{#ZYXEL.VOLT.THRESH.HIGH}"] /= 1000;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69193','36210','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69194','36211','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69195','36212','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69196','36212','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69197','36213','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69198','36213','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69199','36214','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69200','36214','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69201','36215','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69202','36215','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69203','36216','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69204','36216','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69205','36217','1','1','0.1','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69206','36217','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69207','36218','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69208','36218','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69209','36219','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69210','36220','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69211','36221','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69212','36221','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69213','36222','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69214','36223','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69215','36223','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69216','36224','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69217','36225','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69218','36226','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69219','36226','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69220','36227','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69221','36228','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69222','36228','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69223','36229','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69224','36230','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69225','36232','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69226','36232','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69227','36233','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69228','36234','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69229','36235','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69230','36236','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69231','36237','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69232','36238','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69233','36240','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69234','36242','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69235','36243','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69236','36244','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69237','36244','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69238','36245','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69239','36246','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69240','36246','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69241','36247','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69242','36248','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69243','36249','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69244','36250','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69245','36251','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69246','36252','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69247','36252','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69248','36253','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69249','36254','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69250','36254','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69251','36255','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69252','36256','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69253','36257','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69254','36257','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69255','36258','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69256','36259','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69257','36259','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69258','36260','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69259','36261','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69260','36262','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69261','36263','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69262','36264','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69263','36265','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69264','36266','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69265','36267','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69266','36268','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69267','36270','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69268','36270','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69269','36271','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69270','36272','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69271','36273','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69272','36274','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69273','36275','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69274','36276','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69275','36279','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69276','36281','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69277','36282','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69278','36283','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69279','36284','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69280','36285','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69281','36286','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69282','36286','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69283','36287','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69284','36288','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69285','36288','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69286','36289','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69287','36290','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69288','36291','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69289','36292','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69290','36293','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69291','36294','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69292','36294','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69293','36295','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69294','36296','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69295','36296','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69296','36297','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69297','36298','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69298','36299','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69299','36299','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69300','36300','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69301','36301','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69302','36301','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69303','36302','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69304','36303','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69305','36304','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69306','36305','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69307','36306','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69308','36307','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69309','36308','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69310','36309','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69311','36310','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69312','36310','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69313','36311','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69314','36312','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69315','36314','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69316','36314','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69317','36315','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69318','36316','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69319','36317','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69320','36318','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69321','36319','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69322','36320','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69323','36323','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69324','36325','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69325','36326','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69326','36327','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69327','36328','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69328','36329','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69329','36330','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69330','36330','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69331','36331','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69332','36332','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69333','36332','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69334','36333','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69335','36334','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69336','36335','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69337','36336','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69338','36337','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69339','36338','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69340','36338','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69341','36339','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69342','36340','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69343','36340','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69344','36341','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69345','36342','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69346','36343','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69347','36343','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69348','36344','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69349','36345','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69350','36345','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69351','36346','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69352','36347','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69353','36348','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69354','36349','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69355','36350','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69356','36351','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69357','36352','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69358','36353','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69359','36354','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69360','36354','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69361','36355','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69362','36356','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69363','36358','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69364','36358','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69365','36359','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69366','36360','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69367','36361','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69368','36362','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69369','36363','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69370','36364','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69371','36367','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69372','36369','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69373','36370','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69374','36371','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69375','36372','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69376','36373','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69377','36374','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69378','36374','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69379','36375','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69380','36376','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69381','36376','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69382','36377','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69383','36378','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69384','36379','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69385','36380','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69386','36381','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69387','36382','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69388','36382','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69389','36383','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69390','36384','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69391','36384','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69392','36385','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69393','36386','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69394','36387','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69395','36387','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69396','36388','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69397','36389','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69398','36389','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69399','36390','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69400','36391','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69401','36392','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69402','36393','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69403','36394','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69404','36395','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69405','36396','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69406','36397','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69407','36398','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69408','36398','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69409','36399','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69410','36400','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69411','36402','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69412','36402','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69413','36403','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69414','36404','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69415','36405','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69416','36406','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69417','36407','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69418','36408','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69419','36411','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69420','36413','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69421','36414','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69422','36415','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69423','36416','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69424','36417','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69425','36418','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69426','36418','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69427','36419','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69428','36420','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69429','36420','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69430','36421','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69431','36422','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69432','36423','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69433','36424','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69434','36425','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69435','36426','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69436','36426','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69437','36427','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69438','36428','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69439','36428','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69440','36429','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69441','36430','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69442','36431','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69443','36431','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69444','36432','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69445','36433','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69446','36433','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69447','36434','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69448','36435','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69449','36436','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69450','36437','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69451','36438','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69452','36439','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69453','36440','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69454','36441','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69455','36442','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69456','36442','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69457','36443','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69458','36444','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69459','36446','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69460','36447','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69461','36448','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69462','36450','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69463','36451','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69464','36452','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69465','36453','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69466','36456','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69467','36459','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.THRESH.LOW}"] /= 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69468','36460','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69469','36461','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69470','36462','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69471','36463','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69472','36463','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69473','36464','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69474','36465','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69475','36465','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69476','36466','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69477','36467','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69478','36468','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69479','36469','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69480','36470','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69481','36471','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69482','36471','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69483','36472','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69484','36473','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69485','36473','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69486','36474','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69487','36475','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69488','36476','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69489','36476','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69490','36477','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69491','36478','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69492','36478','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69493','36479','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69494','36480','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69495','36481','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69496','36482','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69497','36483','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69498','36484','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69499','36485','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69500','36486','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69501','36487','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69502','36487','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69503','36488','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69504','36489','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69505','36491','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69506','36492','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69507','36493','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69508','36495','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69509','36496','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69510','36497','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69511','36498','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69512','36501','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69513','36504','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.THRESH.LOW}"] /= 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69514','36505','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69515','36506','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69516','36507','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69517','36508','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69518','36508','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69519','36509','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69520','36510','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69521','36510','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69522','36511','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69523','36512','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69524','36513','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69525','36514','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69526','36515','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69527','36516','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69528','36516','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69529','36517','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69530','36518','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69531','36518','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69532','36519','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69533','36520','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69534','36521','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69535','36521','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69536','36522','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69537','36523','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69538','36523','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69539','36524','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69540','36525','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69541','36526','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69542','36527','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69543','36528','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69544','36529','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69545','36530','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69546','36531','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69547','36532','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69548','36532','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69549','36533','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69550','36534','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69551','36536','1','21','var inArray = JSON.parse(value);
var tmpObj = {};
inArray.forEach(function(item, i, arr) {
  tmpObj[item["{#SNMPINDEX}"]] = item["{#SNMP.ARRAY}"]
});
var strOut = ''V'' + tmpObj["1.0"] + ''.'' + tmpObj["2.0"]
  + ''('' + tmpObj["3.0"] + ''.'' + tmpObj["4.0"] + '')_'' 
  + tmpObj["7.0"] + ''.'' + tmpObj["6.0"] + ''.'' + tmpObj["5.0"];
return strOut;
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69552','36536','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69553','36537','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69554','36538','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69555','36539','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69556','36540','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69557','36541','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69558','36542','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69559','36546','1','21','var inArray = JSON.parse(value);
var nameMap = {
    ''Temperature'': ''°C'',
    ''Voltage'': ''V'',
    ''TxBias'': ''mA'',
    ''TxPower'': ''dbm'',
    ''RxPower'': ''dbm''
};
var outArr = [];
inArray.forEach(function (item, i, arr) {
    item[''{#ZYXEL.SFP.PORT}''] = item[''{#SNMPINDEX}''].split(''.'')[0];
    item[''{#ZYXEL.SFP.UNIT}''] = nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']] === undefined ? "" : nameMap[item[''{#ZYXEL.SFP.DESCRIPTION}'']];
    item[''{#ZYXEL.SFP.WARN.MAX}''] /= 100;
    item[''{#ZYXEL.SFP.WARN.MIN}''] /= 100;
    outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69560','36548','1','21','var inArray = JSON.parse(value);
var nameMap = {"1":"MAC", "2":"CPU", "3":"PHY"};
var outArr = [];
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.TEMP.ID}"] = nameMap[item["{#SNMPINDEX}"]] 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69561','36549','1','21','var inArray = JSON.parse(value);
var outArr = []
inArray.forEach(function(item, i, arr) {
item["{#ZYXEL.VOLT.NOMINAL}"] = "+" + item["{#ZYXEL.VOLT.NOMINAL}"] / 1000 + "V";
item["{#ZYXEL.VOLT.THRESH.LOW}"] = item["{#ZYXEL.VOLT.THRESH.LOW}"] / 1000; 
outArr.push(item)
});
return JSON.stringify(outArr);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69562','36550','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69563','36551','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69564','36552','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69565','36553','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69566','36554','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69567','36554','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69568','36555','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69569','36556','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69570','36556','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69571','36557','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69572','36558','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69573','36559','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69574','36560','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69575','36561','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69576','36562','1','13','0
100','1','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69577','36562','2','21','return +parseFloat(value).toFixed(0);
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69578','36563','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69579','36564','1','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69580','36564','2','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69581','36565','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69582','36566','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69583','36567','1','1','1000000','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69584','36567','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69585','36568','1','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69586','36569','1','1','0.01','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69587','36569','2','20','6h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69588','36570','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69589','36571','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69590','36572','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69591','36573','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69592','36574','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69593','36575','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69594','36576','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69595','36577','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69596','36578','1','1','0.001','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69597','36578','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69598','36579','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69599','36580','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69600','36581','1','21','output = JSON.parse(value).map(function(net){
    return {
        "{#IFNAME}": net.Name,
        "{#IFDESCR}": net.Description,
        "{#IFALIAS}": net.NetConnectionID,
        "{#IFGUID}": net.GUID
    }})
return JSON.stringify({"data": output})','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69601','36581','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69602','36582','1','21','output = JSON.parse(value).map(function(net){
    return {
        "{#IFNAME}": net.Name,
        "{#IFDESCR}": net.Description,
        "{#IFALIAS}": net.NetConnectionID,
        "{#IFGUID}": net.GUID
    }})
return JSON.stringify({"data": output})','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69603','36582','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69604','36583','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69605','36584','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69606','36585','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69607','36585','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69608','36586','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69609','36587','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69610','36588','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69611','36588','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69612','36589','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69613','36590','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69614','36591','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69615','36591','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69616','36592','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69617','36593','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69618','36594','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69619','36594','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69620','36595','1','12','$[?(@.GUID == "{#IFGUID}")].Speed.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69621','36595','2','21','return (value==''9223372036854775807'' ? 0 : value)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69622','36595','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69623','36596','1','12','$[?(@.GUID == "{#IFGUID}")].NetConnectionStatus.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69624','36596','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69625','36597','1','12','$[?(@.GUID == "{#IFGUID}")].AdapterTypeId.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69626','36597','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69627','36598','1','12','$[?(@.GUID == "{#IFGUID}")].Speed.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69628','36598','2','21','return (value==''9223372036854775807'' ? 0 : value)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69629','36598','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69630','36599','1','12','$[?(@.GUID == "{#IFGUID}")].NetConnectionStatus.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69631','36599','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69632','36600','1','12','$[?(@.GUID == "{#IFGUID}")].AdapterTypeId.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69633','36600','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69634','36601','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69635','36602','1','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69636','36603','1','21','output = JSON.parse(value).map(function(net){
    return {
        "{#IFNAME}": net.Name,
        "{#IFDESCR}": net.Description,
        "{#IFALIAS}": net.NetConnectionID,
        "{#IFGUID}": net.GUID
    }})
return JSON.stringify({"data": output})','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69637','36603','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69638','36604','1','21','output = JSON.parse(value).map(function(net){
    return {
        "{#IFNAME}": net.Name,
        "{#IFDESCR}": net.Description,
        "{#IFALIAS}": net.NetConnectionID,
        "{#IFGUID}": net.GUID
    }})
return JSON.stringify({"data": output})','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69639','36604','2','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69640','36605','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69641','36606','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69642','36607','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69643','36607','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69644','36608','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69645','36609','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69646','36610','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69647','36610','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69648','36611','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69649','36612','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69650','36613','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69651','36613','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69652','36614','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69653','36615','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69654','36616','1','10','','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69655','36616','2','1','8','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69656','36617','1','12','$[?(@.GUID == "{#IFGUID}")].Speed.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69657','36617','2','21','return (value==''9223372036854775807'' ? 0 : value)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69658','36617','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69659','36618','1','12','$[?(@.GUID == "{#IFGUID}")].NetConnectionStatus.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69660','36618','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69661','36619','1','12','$[?(@.GUID == "{#IFGUID}")].AdapterTypeId.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69662','36619','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69663','36620','1','12','$[?(@.GUID == "{#IFGUID}")].Speed.first()','2','0');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69664','36620','2','21','return (value==''9223372036854775807'' ? 0 : value)
','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69665','36620','3','20','1h','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69666','36621','1','12','$[?(@.GUID == "{#IFGUID}")].NetConnectionStatus.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69667','36621','2','20','1d','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69668','36622','1','12','$[?(@.GUID == "{#IFGUID}")].AdapterTypeId.first()','0','');
INSERT INTO item_preproc (item_preprocid,itemid,step,type,params,error_handler,error_handler_params) values ('69669','36622','2','20','1d','0','');
INSERT INTO sysmap_shape (sysmap_shapeid,sysmapid,type,x,y,width,height,text,font,font_size,font_color,text_halign,text_valign,border_type,border_width,border_color,background_color,zindex) values ('1','1','0','0','0','680','15','{MAP.NAME}','9','11','000000','0','0','0','0','000000','','0');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('1','29429','{#IFNAME}','$.labels.device');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('2','29429','{#HELP}','$.help');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('3','29429','{#IFALIAS}','$.labels.ifalias');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('4','29429','{#IFOPERSTATUS}','$.labels.operstate');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('5','29430','{#FSTYPE}','$.labels.fstype');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('6','29430','{#FSNAME}','$.labels.mountpoint');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('7','29430','{#FSDEVICE}','$.labels.device');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('8','29430','{#HELP}','$.help');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('9','29431','{#DEVNAME}','$.labels.device');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('10','29431','{#HELP}','$.help');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('38','29703','{#QUEUE}','$.name');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('39','29703','{#VHOST}','$.vhost');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('40','29703','{#NODE}','$.node');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('41','29785','{#EXCHANGE}','$.name');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('42','29785','{#TYPE}','$.type');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('43','29785','{#VHOST}','$.vhost');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('44','29786','{#QUEUE}','$.name');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('45','29786','{#VHOST}','$.vhost');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('46','29786','{#NODE}','$.node');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('47','30026','{#EXCHANGE}','$.name');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('48','30026','{#TYPE}','$.type');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('49','30026','{#VHOST}','$.vhost');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('50','30193','{#PXNAME}','$.pxname');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('51','30193','{#SVNAME}','$.svname');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('52','30194','{#PXNAME}','$.pxname');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('53','30194','{#SVNAME}','$.svname');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('54','30195','{#PXNAME}','$.pxname');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('55','30195','{#SVNAME}','$.svname');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('56','30236','{#PXNAME}','$.pxname');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('57','30236','{#SVNAME}','$.svname');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('58','30237','{#PXNAME}','$.pxname');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('59','30237','{#SVNAME}','$.svname');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('60','30238','{#PXNAME}','$.pxname');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('61','30238','{#SVNAME}','$.svname');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('62','30678','{#DATABASE}','$.Database');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('63','30679','{#MASTER_HOST}','$.Master_Host');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('64','30686','{#SENSOR_ID}','$.id');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('65','30686','{#SENSOR_READING_TYPE}','$.reading.text');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('66','30686','{#SENSOR_TYPE}','$.sensor.text');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('67','30686','{#SENSOR_UNIT}','$.units');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('68','30687','{#SENSOR_ID}','$.id');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('69','30687','{#SENSOR_READING_TYPE}','$.reading.text');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('70','30687','{#SENSOR_TYPE}','$.sensor.text');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('71','30687','{#SENSOR_UNIT}','$.units');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('72','30687','{#SENSOR_LO_WARN}','$.threshold.lower.non_crit');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('73','30687','{#SENSOR_LO_CRIT}','$.threshold.lower.crit');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('74','30687','{#SENSOR_LO_DISAST}','$.threshold.lower.non_recover');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('75','30687','{#SENSOR_HI_WARN}','$.threshold.upper.non_crit');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('76','30687','{#SENSOR_HI_CRIT}','$.threshold.upper.crit');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('77','30687','{#SENSOR_HI_DISAST}','$.threshold.upper.non_recover');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('78','30713','{#ES.NODE}','$..name.first()');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('88','30193','{#MODE}','$.mode');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('89','30194','{#MODE}','$.mode');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('90','30195','{#MODE}','$.mode');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('100','30236','{#MODE}','$.mode');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('101','30237','{#MODE}','$.mode');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('102','30238','{#MODE}','$.mode');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('103','30874','{#NAME}','$.name');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('104','30875','{#DB}','$.database');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('105','30875','{#TABLE}','$.table');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('106','30876','{#DB}','$.database');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('107','30876','{#TABLE}','$.table');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('108','30962','{#ETCD.PEER}','$.labels.To');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('109','31005','{#APPPOOL}','$.Name');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('110','31047','{#APPPOOL}','$.Name');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('115','32879','{#EXCHANGE}','$.name');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('116','32879','{#TYPE}','$.type');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('117','32879','{#VHOST}','$.vhost');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('118','32883','{#QUEUE}','$.name');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('119','32883','{#VHOST}','$.vhost');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('120','32883','{#NODE}','$.node');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('121','32971','{#EXCHANGE}','$.name');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('122','32971','{#TYPE}','$.type');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('123','32971','{#VHOST}','$.vhost');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('124','32975','{#QUEUE}','$.name');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('125','32975','{#VHOST}','$.vhost');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('126','32975','{#NODE}','$.node');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('127','34099','{#SERVER}','$.properties.["server-config"]');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('128','34099','{#JMXOBJ}','$.object');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('129','34100','{#SERVER_GROUP}','$.properties.["server-group"]');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('130','34100','{#DEPLOYMENT}','$.properties.deployment');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('131','34100','{#JMXOBJ}','$.object');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('132','34123','{#JMX_DATA_SOURCE}','$.properties.["data-source"]');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('133','34123','{#JMXOBJ}','$.object');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('134','34124','{#JMX_DATA_SOURCE}','$.properties.["data-source"]');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('135','34124','{#JMXOBJ}','$.object');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('136','34125','{#SERVER}','$.properties.["server"]');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('137','34125','{#HTTP_LISTENER}','$.properties.["http-listener"]');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('138','34125','{#JMXOBJ}','$.object');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('139','34126','{#DEPLOYMENT}','$.properties.deployment');
INSERT INTO lld_macro_path (lld_macro_pathid,itemid,lld_macro,path) values ('140','34126','{#JMXOBJ}','$.object');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('511','34217','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('512','34217','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('513','34218','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('514','34218','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('515','34250','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('516','34250','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('517','34294','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('518','34294','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('519','34328','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('520','34328','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('521','34329','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('522','34329','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('523','34395','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('524','34395','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('525','34396','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('526','34396','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('527','34462','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('528','34462','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('529','34463','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('530','34463','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('531','34495','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('532','34495','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('533','34534','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('534','34534','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('535','34578','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('536','34578','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('537','34622','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('538','34622','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('539','34666','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('540','34666','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('541','34711','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('542','34711','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('543','34756','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('544','34756','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('545','34801','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('546','34801','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('576','30961','trigger','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('577','30193','Discard HTTP status codes','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('578','30194','Discard HTTP status codes','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('579','30195','Discard HTTP status codes','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('580','30236','Discard HTTP status codes','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('581','30237','Discard HTTP status codes','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('582','30238','Discard HTTP status codes','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('583','33063','Primary metrics','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('584','33063','Arbiter metrics','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('585','32742','ID filter','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('586','32743','Self-test','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('587','32743','Not NVMe','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('588','32754','ID filter','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('589','32755','Self-test','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('590','32755','Not NVMe','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('591','28306','trigger THRESHOLD_LO_WARN','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('592','28306','trigger THRESHOLD_LO_CRIT','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('593','28306','trigger THRESHOLD_HI_WARN','3','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('594','28306','trigger THRESHOLD_HI_CRIT','4','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('595','28307','trigger THRESHOLD_LO_WARN','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('596','28307','trigger THRESHOLD_LO_CRIT','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('597','28307','trigger THRESHOLD_HI_WARN','3','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('598','28307','trigger THRESHOLD_HI_CRIT','4','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('599','32306','trigger THRESHOLD_LO_WARN','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('600','32306','trigger THRESHOLD_LO_CRIT','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('601','32306','trigger THRESHOLD_HI_WARN','3','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('602','32306','trigger THRESHOLD_HI_CRIT','4','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('603','35911','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('604','35961','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('605','35962','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('606','35994','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('607','36038','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('608','36072','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('609','36073','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('610','36139','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('611','36140','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('612','36206','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('613','36207','Trigger disabled','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('614','36207','Trigger enabled','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('615','36239','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('616','36278','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('617','36322','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('618','36366','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('619','36410','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('620','36455','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('621','36500','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('622','36545','Don''t create triggers for matching interface','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('623','33598','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('624','33599','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('625','33649','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('626','33650','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('627','33700','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('628','33701','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('629','33751','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('630','33752','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('631','33802','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('632','33803','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('633','33853','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('634','33854','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('635','33904','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('636','33905','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('637','33462','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('638','33463','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('639','33960','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('640','33961','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('641','34011','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('642','34012','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('643','34062','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('644','34063','Temp','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('645','32618','Do not discover aggregate metrics','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('646','30687','trigger SENSOR_LO_WARN','1','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('647','30687','trigger SENSOR_LO_CRIT','2','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('648','30687','trigger SENSOR_LO_DISAST','3','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('649','30687','trigger SENSOR_HI_WARN','4','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('650','30687','trigger SENSOR_HI_CRIT','5','0','','0');
INSERT INTO lld_override (lld_overrideid,itemid,name,step,evaltype,formula,stop) values ('651','30687','trigger SENSOR_HI_DISAST','6','0','','0');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('441','511','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('442','512','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('443','513','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('444','514','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('445','515','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('446','516','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('447','517','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('448','518','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('449','519','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('450','520','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('451','521','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('452','522','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('453','523','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('454','524','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('455','525','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('456','526','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('457','527','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('458','528','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('459','529','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('460','530','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('461','531','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('462','532','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('463','533','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('464','534','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('465','535','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('466','536','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('467','537','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('468','538','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('469','539','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('470','540','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('471','541','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('472','542','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('473','543','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('474','544','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('475','545','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('476','546','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('500','576','8','{#GRPC.CODE}','{$ETCD.GRPC_CODE.TRIGGER.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('501','577','8','{#MODE}','tcp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('502','578','8','{#MODE}','tcp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('503','579','8','{#MODE}','tcp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('504','580','8','{#MODE}','tcp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('505','581','8','{#MODE}','tcp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('506','582','8','{#MODE}','tcp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('507','583','8','{#NODE_STATE}','1');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('508','584','8','{#NODE_STATE}','7');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('509','585','8','{#ID}','{$SMART.ATTRIBUTE.ID.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('510','585','8','{#NAME}','{$SMART.DISK.NAME.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('511','586','8','{#DISKTYPE}','nvme');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('512','587','9','{#DISKTYPE}','nvme');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('513','588','8','{#ID}','{$SMART.ATTRIBUTE.ID.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('514','588','8','{#NAME}','{$SMART.DISK.NAME.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('515','589','8','{#DISKTYPE}','nvme');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('516','590','9','{#DISKTYPE}','nvme');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('517','591','8','{#THRESHOLD_LO_WARN}','^$');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('518','592','8','{#THRESHOLD_LO_CRIT}','^$');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('519','593','8','{#THRESHOLD_HI_WARN}','^$');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('520','594','8','{#THRESHOLD_HI_CRIT}','^$');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('521','595','8','{#THRESHOLD_LO_WARN}','^$');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('522','596','8','{#THRESHOLD_LO_CRIT}','^$');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('523','597','8','{#THRESHOLD_HI_WARN}','^$');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('524','598','8','{#THRESHOLD_HI_CRIT}','^$');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('525','599','8','{#THRESHOLD_LO_WARN}','^$');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('526','600','8','{#THRESHOLD_LO_CRIT}','^$');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('527','601','8','{#THRESHOLD_HI_WARN}','^$');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('528','602','8','{#THRESHOLD_HI_CRIT}','^$');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('529','603','9','{#CISCO.IF.NAME}','{$CISCO.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('530','604','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('531','605','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('532','606','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('533','607','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('534','608','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('535','609','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('536','610','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('537','611','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('538','612','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('539','613','8','{#ZYXEL.IF.NAME}','.*');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('540','614','8','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('541','615','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('542','616','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('543','617','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('544','618','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('545','619','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('546','620','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('547','621','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('548','622','9','{#ZYXEL.IF.NAME}','{$ZYXEL.LLD.FILTER.IF.CONTROL.MATCHES}');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('549','623','8','{#EXTERNAL_SENSOR1_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('550','624','8','{#EXTERNAL_SENSOR2_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('551','625','8','{#EXTERNAL_SENSOR1_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('552','626','8','{#EXTERNAL_SENSOR2_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('553','627','8','{#EXTERNAL_SENSOR1_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('554','628','8','{#EXTERNAL_SENSOR2_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('555','629','8','{#EXTERNAL_SENSOR1_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('556','630','8','{#EXTERNAL_SENSOR2_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('557','631','8','{#EXTERNAL_SENSOR1_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('558','632','8','{#EXTERNAL_SENSOR2_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('559','633','8','{#EXTERNAL_SENSOR1_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('560','634','8','{#EXTERNAL_SENSOR2_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('561','635','8','{#EXTERNAL_SENSOR1_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('562','636','8','{#EXTERNAL_SENSOR2_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('563','637','8','{#EXTERNAL_SENSOR1_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('564','638','8','{#EXTERNAL_SENSOR2_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('565','639','8','{#EXTERNAL_SENSOR1_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('566','640','8','{#EXTERNAL_SENSOR2_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('567','641','8','{#EXTERNAL_SENSOR1_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('568','642','8','{#EXTERNAL_SENSOR2_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('569','643','8','{#EXTERNAL_SENSOR1_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('570','644','8','{#EXTERNAL_SENSOR2_NAME}','Temp');
INSERT INTO lld_override_condition (lld_override_conditionid,lld_overrideid,operator,macro,value) values ('571','645','8','{#FSTYPE}','3|4');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('532','511','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('533','512','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('534','513','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('535','514','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('536','515','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('537','516','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('538','517','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('539','518','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('540','519','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('541','520','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('542','521','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('543','522','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('544','523','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('545','524','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('546','525','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('547','526','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('548','527','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('549','528','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('550','529','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('551','530','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('552','531','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('553','532','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('554','533','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('555','534','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('556','535','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('557','536','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('558','537','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('559','538','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('560','539','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('561','540','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('562','541','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('563','542','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('564','543','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('565','544','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('566','545','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('567','546','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('597','576','1','2','Too many failed gRPC requests');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('598','577','0','2','Number of responses with codes');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('599','578','0','2','Number of responses with codes');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('600','579','0','2','Number of responses with codes');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('601','580','0','2','Number of responses with codes');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('602','581','0','2','Number of responses with codes');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('603','582','0','2','Number of responses with codes');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('604','583','0','2','Number of replicas');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('605','583','0','2','Unhealthy replicas');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('606','583','0','2','Number of unhealthy replicas');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('607','583','0','2','Replication lag');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('608','584','0','2','Replication lag');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('609','585','0','8','');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('610','586','0','2','Self-test');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('611','587','0','8','Media|Percentage|Critical');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('612','588','0','8','');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('613','589','0','2','Self-test');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('614','590','0','8','Media|Percentage|Critical');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('615','591','1','8','Temperature is below the warning threshold');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('616','592','1','8','Temperature is below the critical threshold');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('617','593','1','8','Temperature is above the warning threshold');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('618','594','1','8','Temperature is above the critical threshold');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('619','595','1','8','Fan speed is below the warning threshold');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('620','596','1','8','Fan speed is below the critical threshold');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('621','597','1','8','Fan speed is above the warning threshold');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('622','598','1','8','Fan speed is above the critical threshold');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('623','599','1','8','Voltage is below the warning threshold');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('624','600','1','8','Voltage is below the critical threshold');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('625','601','1','8','Voltage is above the warning threshold');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('626','602','1','8','Voltage is above the critical threshold');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('627','603','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('628','604','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('629','605','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('630','606','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('631','607','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('632','608','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('633','609','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('634','610','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('635','611','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('636','612','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('637','613','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('638','614','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('639','615','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('640','616','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('641','617','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('642','618','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('643','619','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('644','620','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('645','621','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('646','622','1','8','.*');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('647','623','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('648','624','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('649','625','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('650','626','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('651','627','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('652','628','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('653','629','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('654','630','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('655','631','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('656','632','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('657','633','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('658','634','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('659','635','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('660','636','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('661','637','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('662','638','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('663','639','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('664','640','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('665','641','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('666','642','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('667','643','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('668','644','0','2','Humidity');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('669','645','0','2','Saved');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('670','646','1','2','{#SENSOR_LO_WARN}');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('671','647','1','2','{#SENSOR_LO_CRIT}');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('672','648','1','2','{#SENSOR_LO_DISAST}');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('673','649','1','2','{#SENSOR_HI_WARN}');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('674','650','1','2','{#SENSOR_HI_CRIT}');
INSERT INTO lld_override_operation (lld_override_operationid,lld_overrideid,operationobject,operator,value) values ('675','651','1','2','{#SENSOR_HI_DISAST}');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('532','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('533','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('534','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('535','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('536','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('537','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('538','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('539','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('540','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('541','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('542','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('543','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('544','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('545','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('546','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('547','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('548','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('549','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('550','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('551','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('552','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('553','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('554','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('555','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('556','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('557','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('558','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('559','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('560','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('561','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('562','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('563','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('564','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('565','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('566','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('567','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('597','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('598','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('599','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('600','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('601','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('602','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('603','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('604','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('605','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('606','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('607','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('608','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('609','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('610','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('611','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('612','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('613','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('614','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('615','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('616','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('617','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('618','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('619','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('620','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('621','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('622','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('623','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('624','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('625','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('626','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('627','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('628','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('629','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('630','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('631','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('632','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('633','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('634','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('635','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('636','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('637','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('638','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('639','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('640','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('641','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('642','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('643','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('644','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('645','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('646','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('647','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('648','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('649','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('650','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('651','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('652','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('653','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('654','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('655','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('656','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('657','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('658','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('659','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('660','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('661','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('662','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('663','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('664','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('665','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('666','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('667','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('668','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('669','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('670','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('671','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('672','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('673','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('674','0');
INSERT INTO lld_override_opstatus (lld_override_operationid,status) values ('675','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('532','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('533','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('534','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('535','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('536','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('537','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('538','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('539','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('540','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('541','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('542','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('543','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('544','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('545','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('546','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('547','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('548','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('549','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('550','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('551','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('552','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('553','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('554','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('555','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('556','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('557','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('558','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('559','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('560','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('561','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('562','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('563','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('564','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('565','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('566','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('567','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('597','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('598','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('599','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('600','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('601','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('602','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('603','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('604','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('605','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('606','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('607','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('608','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('609','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('610','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('611','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('612','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('613','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('614','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('615','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('616','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('617','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('618','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('619','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('620','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('621','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('622','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('623','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('624','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('625','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('626','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('627','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('628','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('629','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('630','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('631','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('632','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('633','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('634','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('635','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('636','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('637','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('638','0');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('639','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('640','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('641','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('642','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('643','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('644','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('645','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('646','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('647','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('648','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('649','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('650','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('651','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('652','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('653','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('654','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('655','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('656','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('657','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('658','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('659','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('660','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('661','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('662','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('663','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('664','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('665','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('666','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('667','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('668','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('669','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('670','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('671','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('672','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('673','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('674','1');
INSERT INTO lld_override_opdiscover (lld_override_operationid,discover) values ('675','1');
INSERT INTO dashboard (dashboardid,name,userid,private) values ('1','Global view','1','0');
INSERT INTO dashboard (dashboardid,name,userid,private) values ('2','Zabbix server health','1','1');
INSERT INTO dashboard_usrgrp (dashboard_usrgrpid,dashboardid,usrgrpid,permission) values ('1','2','7','3');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('1','1','systeminfo','','0','0','8','4','0');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('2','1','hostavail','','8','0','12','2','1');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('3','1','problemsbysv','','8','2','12','2','1');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('4','1','clock','','20','0','4','4','1');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('5','1','problems','','0','4','20','10','0');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('6','1','favmaps','','20','4','4','5','0');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('7','1','favgraphs','','20','9','4','5','0');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('8','2','problems','Zabbix server problems','0','0','20','4','0');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('9','2','clock','Local time','20','0','4','4','1');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('10','2','svggraph','Values processed per second','0','4','8','5','0');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('11','2','svggraph','Utilization of data collectors','8','4','8','5','0');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('12','2','svggraph','Utilization of internal processes','16','4','8','5','0');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('13','2','svggraph','Cache usage','0','9','8','5','0');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('14','2','svggraph','Value cache effectiveness','8','9','8','5','0');
INSERT INTO widget (widgetid,dashboardid,type,name,x,y,width,height,view_mode) values ('15','2','svggraph','Queue size','16','9','8','5','0');
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('1','2','0','interface_type','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('2','3','0','show_type','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('3','5','0','show','3','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('4','5','0','show_tags','3','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('5','8','3','hostids','0','',NULL,'10084',NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('6','10','0','ds.axisy.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('7','10','0','ds.fill.0','3','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('8','10','0','ds.missingdatafunc.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('9','10','0','ds.transparency.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('10','10','0','ds.type.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('11','10','0','ds.width.0','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('12','10','0','graph_item_problems','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('13','10','0','legend','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('14','10','0','righty','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('15','10','0','show_problems','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('16','10','1','ds.color.0','0','00BFFF',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('17','10','1','ds.hosts.0.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('18','10','1','ds.items.0.0','0','Number of processed *values per second',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('19','10','1','ds.timeshift.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('20','10','1','lefty_min','0','0',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('21','10','1','problemhosts.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('22','11','0','ds.axisy.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('23','11','0','ds.fill.0','3','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('24','11','0','ds.missingdatafunc.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('25','11','0','ds.transparency.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('26','11','0','ds.type.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('27','11','0','ds.width.0','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('28','11','0','graph_item_problems','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('29','11','0','legend','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('30','11','0','righty','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('31','11','0','show_problems','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('32','11','1','ds.color.0','0','E57373',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('33','11','1','ds.hosts.0.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('34','11','1','ds.items.0.0','0','Utilization of * data collector *',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('35','11','1','ds.timeshift.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('36','11','1','lefty_max','0','100',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('37','11','1','lefty_min','0','0',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('38','11','1','problemhosts.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('39','12','0','ds.axisy.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('40','12','0','ds.fill.0','3','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('41','12','0','ds.missingdatafunc.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('42','12','0','ds.transparency.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('43','12','0','ds.type.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('44','12','0','ds.width.0','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('45','12','0','graph_item_problems','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('46','12','0','legend','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('47','12','0','righty','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('48','12','0','show_problems','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('49','12','1','ds.color.0','0','E57373',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('50','12','1','ds.hosts.0.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('51','12','1','ds.items.0.0','0','Utilization of * internal *',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('52','12','1','ds.timeshift.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('53','12','1','lefty_max','0','100',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('54','12','1','lefty_min','0','0',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('55','12','1','problemhosts.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('56','13','0','ds.axisy.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('57','13','0','ds.fill.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('58','13','0','ds.missingdatafunc.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('59','13','0','ds.transparency.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('60','13','0','ds.type.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('61','13','0','ds.width.0','2','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('62','13','0','graph_item_problems','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('63','13','0','legend','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('64','13','0','righty','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('65','13','0','show_problems','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('66','13','1','ds.color.0','0','4DB6AC',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('67','13','1','ds.hosts.0.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('68','13','1','ds.items.0.0','0','Zabbix*cache*% used',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('69','13','1','ds.timeshift.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('70','13','1','lefty_max','0','100',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('71','13','1','lefty_min','0','0',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('72','13','1','problemhosts.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('73','14','0','ds.axisy.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('74','14','0','ds.axisy.1','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('75','14','0','ds.fill.0','3','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('76','14','0','ds.fill.1','3','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('77','14','0','ds.missingdatafunc.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('78','14','0','ds.missingdatafunc.1','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('79','14','0','ds.transparency.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('80','14','0','ds.transparency.1','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('81','14','0','ds.type.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('82','14','0','ds.type.1','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('83','14','0','ds.width.0','2','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('84','14','0','ds.width.1','2','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('85','14','0','graph_item_problems','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('86','14','0','legend','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('87','14','0','righty','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('88','14','0','show_problems','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('89','14','1','ds.color.0','0','9CCC65',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('90','14','1','ds.color.1','0','FF465C',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('91','14','1','ds.hosts.0.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('92','14','1','ds.hosts.1.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('93','14','1','ds.items.0.0','0','Zabbix value cache hits',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('94','14','1','ds.items.1.0','0','Zabbix value cache misses',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('95','14','1','ds.timeshift.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('96','14','1','ds.timeshift.1','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('97','14','1','lefty_min','0','0',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('98','14','1','problemhosts.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('99','15','0','ds.axisy.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('100','15','0','ds.axisy.1','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('101','15','0','ds.axisy.2','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('102','15','0','ds.fill.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('103','15','0','ds.fill.1','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('104','15','0','ds.fill.2','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('105','15','0','ds.missingdatafunc.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('106','15','0','ds.missingdatafunc.1','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('107','15','0','ds.missingdatafunc.2','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('108','15','0','ds.transparency.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('109','15','0','ds.transparency.1','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('110','15','0','ds.transparency.2','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('111','15','0','ds.type.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('112','15','0','ds.type.1','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('113','15','0','ds.type.2','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('114','15','0','ds.width.0','2','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('115','15','0','ds.width.1','2','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('116','15','0','ds.width.2','2','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('117','15','0','graph_item_problems','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('118','15','0','legend','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('119','15','0','righty','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('120','15','0','show_problems','1','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('121','15','1','ds.color.0','0','B0AF07',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('122','15','1','ds.color.1','0','E53935',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('123','15','1','ds.color.2','0','0275B8',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('124','15','1','ds.hosts.0.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('125','15','1','ds.hosts.1.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('126','15','1','ds.hosts.2.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('127','15','1','ds.items.0.0','0','Zabbix queue',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('128','15','1','ds.items.1.0','0','Zabbix queue over 10 minutes',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('129','15','1','ds.items.2.0','0','Zabbix preprocessing queue',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('130','15','1','ds.timeshift.0','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('131','15','1','ds.timeshift.1','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('132','15','1','ds.timeshift.2','0','',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('133','15','1','lefty_min','0','0',NULL,NULL,NULL,NULL,NULL);
INSERT INTO widget_field (widget_fieldid,widgetid,type,name,value_int,value_str,value_groupid,value_hostid,value_itemid,value_graphid,value_sysmapid) values ('134','15','1','problemhosts.0','0','Zabbix server',NULL,NULL,NULL,NULL,NULL);
COMMIT;
